#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 9611
#define LARGE_STATE_COUNT 2212
#define SYMBOL_COUNT 271
#define ALIAS_COUNT 1
#define TOKEN_COUNT 128
#define EXTERNAL_TOKEN_COUNT 7
#define FIELD_COUNT 15
#define MAX_ALIAS_SEQUENCE_LENGTH 14
#define PRODUCTION_ID_COUNT 72

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_LBRACE = 2,
  anon_sym_RBRACE = 3,
  anon_sym_POUND_PLUS = 4,
  aux_sym_build_tag_token1 = 5,
  anon_sym_package = 6,
  anon_sym_foreign = 7,
  anon_sym_import = 8,
  anon_sym_COMMA = 9,
  anon_sym_COLON_COLON = 10,
  anon_sym_proc = 11,
  anon_sym_DASH_GT = 12,
  anon_sym_where = 13,
  anon_sym_DQUOTEodin_DQUOTE = 14,
  anon_sym_DQUOTEcontextless_DQUOTE = 15,
  anon_sym_DQUOTEstdcall_DQUOTE = 16,
  anon_sym_DQUOTEstd_DQUOTE = 17,
  anon_sym_DQUOTEcdecl_DQUOTE = 18,
  anon_sym_DQUOTEc_DQUOTE = 19,
  anon_sym_DQUOTEfastcall_DQUOTE = 20,
  anon_sym_DQUOTEfast_DQUOTE = 21,
  anon_sym_DQUOTEnone_DQUOTE = 22,
  anon_sym_DQUOTEsystem_DQUOTE = 23,
  anon_sym_struct = 24,
  anon_sym_using = 25,
  anon_sym_enum = 26,
  anon_sym_EQ = 27,
  anon_sym_union = 28,
  anon_sym_bit_field = 29,
  anon_sym_COLON = 30,
  anon_sym_PIPE = 31,
  anon_sym_COLON_EQ = 32,
  anon_sym_POUNDtype = 33,
  anon_sym_AT = 34,
  anon_sym_LPAREN = 35,
  anon_sym_RPAREN = 36,
  anon_sym_DOLLAR = 37,
  anon_sym_PLUS_EQ = 38,
  anon_sym_DASH_EQ = 39,
  anon_sym_STAR_EQ = 40,
  anon_sym_SLASH_EQ = 41,
  anon_sym_PERCENT_EQ = 42,
  anon_sym_AMP_EQ = 43,
  anon_sym_PIPE_EQ = 44,
  anon_sym_CARET_EQ = 45,
  anon_sym_LT_LT_EQ = 46,
  anon_sym_GT_GT_EQ = 47,
  anon_sym_PIPE_PIPE_EQ = 48,
  anon_sym_AMP_AMP_EQ = 49,
  anon_sym_AMP_TILDE_EQ = 50,
  anon_sym_if = 51,
  anon_sym_SEMI = 52,
  anon_sym_do = 53,
  anon_sym_else = 54,
  anon_sym_when = 55,
  anon_sym_for = 56,
  anon_sym_in = 57,
  anon_sym_switch = 58,
  anon_sym_case = 59,
  anon_sym_defer = 60,
  anon_sym_break = 61,
  anon_sym_continue = 62,
  sym_fallthrough_statement = 63,
  anon_sym_return = 64,
  anon_sym_QMARK = 65,
  anon_sym_PLUS = 66,
  anon_sym_DASH = 67,
  anon_sym_TILDE = 68,
  anon_sym_BANG = 69,
  anon_sym_AMP = 70,
  anon_sym_PIPE_PIPE = 71,
  anon_sym_or_else = 72,
  anon_sym_AMP_AMP = 73,
  anon_sym_GT = 74,
  anon_sym_GT_EQ = 75,
  anon_sym_LT_EQ = 76,
  anon_sym_LT = 77,
  anon_sym_EQ_EQ = 78,
  anon_sym_BANG_EQ = 79,
  anon_sym_TILDE_EQ = 80,
  anon_sym_AMP_TILDE = 81,
  anon_sym_LT_LT = 82,
  anon_sym_GT_GT = 83,
  anon_sym_STAR = 84,
  anon_sym_SLASH = 85,
  anon_sym_PERCENT = 86,
  anon_sym_PERCENT_PERCENT = 87,
  anon_sym_DOT = 88,
  anon_sym_LBRACK = 89,
  anon_sym_RBRACK = 90,
  anon_sym_DOT_DOT_EQ = 91,
  anon_sym_DOT_DOT_LT = 92,
  anon_sym_cast = 93,
  anon_sym_transmute = 94,
  anon_sym_auto_cast = 95,
  anon_sym_not_in = 96,
  anon_sym_DOT_DOT = 97,
  anon_sym_or_return = 98,
  anon_sym_or_continue = 99,
  anon_sym_or_break = 100,
  anon_sym_CARET = 101,
  anon_sym_DOT_DOT_DOT = 102,
  anon_sym_dynamic = 103,
  anon_sym_map = 104,
  anon_sym_bit_set = 105,
  anon_sym_matrix = 106,
  anon_sym_DOT2 = 107,
  anon_sym_distinct = 108,
  sym_number = 109,
  anon_sym_DQUOTE = 110,
  anon_sym_BQUOTE = 111,
  anon_sym_SQUOTE = 112,
  aux_sym_character_token1 = 113,
  sym_string_content = 114,
  sym__raw_string_content = 115,
  sym_escape_sequence = 116,
  anon_sym_true = 117,
  anon_sym_false = 118,
  sym_nil = 119,
  sym_uninitialized = 120,
  sym_tag = 121,
  sym_comment = 122,
  sym__newline = 123,
  sym__backslash = 124,
  sym__nl_comma = 125,
  sym_float = 126,
  sym_block_comment = 127,
  sym_source_file = 128,
  sym_block = 129,
  sym_tagged_block = 130,
  sym_declaration = 131,
  sym_build_tag = 132,
  sym_package_declaration = 133,
  sym_import_declaration = 134,
  sym_procedure_declaration = 135,
  sym_procedure = 136,
  sym_where_clause = 137,
  sym_calling_convention = 138,
  sym_overloaded_procedure_declaration = 139,
  sym_struct_declaration = 140,
  sym_enum_declaration = 141,
  sym_union_declaration = 142,
  sym_bit_field_declaration = 143,
  sym_variable_declaration = 144,
  sym_const_declaration = 145,
  sym_const_type_declaration = 146,
  sym_foreign_block = 147,
  sym_attributes = 148,
  sym_attribute = 149,
  sym_parameters = 150,
  sym_parameter = 151,
  sym__param_header = 152,
  sym__param_type = 153,
  sym_default_parameter = 154,
  sym_polymorphic_parameters = 155,
  sym_field = 156,
  sym_statement = 157,
  sym_assignment_statement = 158,
  sym_update_statement = 159,
  sym_if_statement = 160,
  sym_else_if_clause = 161,
  sym_else_clause = 162,
  sym_when_statement = 163,
  sym_else_when_clause = 164,
  sym_for_statement = 165,
  sym__for_in_expression = 166,
  sym__simple_assignment_statement = 167,
  sym_switch_statement = 168,
  sym_switch_case = 169,
  sym_defer_statement = 170,
  sym_break_statement = 171,
  sym_continue_statement = 172,
  sym_var_declaration = 173,
  sym_return_statement = 174,
  sym_label_statement = 175,
  sym_using_statement = 176,
  sym_expression = 177,
  sym__expression_no_tag = 178,
  sym_unary_expression = 179,
  sym_binary_expression = 180,
  sym_ternary_expression = 181,
  sym_call_expression = 182,
  sym_selector_call_expression = 183,
  sym_member_expression = 184,
  sym_index_expression = 185,
  sym_slice_expression = 186,
  sym_range_expression = 187,
  sym_cast_expression = 188,
  sym_in_expression = 189,
  sym_variadic_expression = 190,
  sym_parenthesized_expression = 191,
  sym_or_return_expression = 192,
  sym_or_continue_expression = 193,
  sym_or_break_expression = 194,
  sym_address = 195,
  sym_type = 196,
  sym_pointer_type = 197,
  sym_variadic_type = 198,
  sym_array_type = 199,
  sym_map_type = 200,
  sym_union_type = 201,
  sym_bit_set_type = 202,
  sym_matrix_type = 203,
  sym_field_type = 204,
  sym_tuple_type = 205,
  sym_struct_type = 206,
  sym__struct_members = 207,
  sym_struct_member = 208,
  sym_enum_type = 209,
  sym_bit_field_type = 210,
  sym_named_type = 211,
  sym_default_type = 212,
  sym_constant_type = 213,
  sym_specialized_type = 214,
  sym__procedure_type = 215,
  sym_distinct_type = 216,
  sym_empty_type = 217,
  sym_polymorphic_type = 218,
  sym_conditional_type = 219,
  sym_literal = 220,
  sym_struct = 221,
  sym_map = 222,
  sym_bit_set = 223,
  sym_matrix = 224,
  sym_struct_field = 225,
  sym_string = 226,
  sym__string_literal = 227,
  sym__raw_string_literal = 228,
  sym_character = 229,
  sym_boolean = 230,
  sym_field_identifier = 231,
  sym__separator = 232,
  aux_sym_source_file_repeat1 = 233,
  aux_sym_block_repeat1 = 234,
  aux_sym_import_declaration_repeat1 = 235,
  aux_sym_where_clause_repeat1 = 236,
  aux_sym_overloaded_procedure_declaration_repeat1 = 237,
  aux_sym_struct_declaration_repeat1 = 238,
  aux_sym_struct_declaration_repeat2 = 239,
  aux_sym_enum_declaration_repeat1 = 240,
  aux_sym_union_declaration_repeat1 = 241,
  aux_sym_bit_field_declaration_repeat1 = 242,
  aux_sym_variable_declaration_repeat1 = 243,
  aux_sym_const_declaration_repeat1 = 244,
  aux_sym_attributes_repeat1 = 245,
  aux_sym_parameters_repeat1 = 246,
  aux_sym_parameter_repeat1 = 247,
  aux_sym_polymorphic_parameters_repeat1 = 248,
  aux_sym_polymorphic_parameters_repeat2 = 249,
  aux_sym_field_repeat1 = 250,
  aux_sym_if_statement_repeat1 = 251,
  aux_sym_when_statement_repeat1 = 252,
  aux_sym__simple_assignment_statement_repeat1 = 253,
  aux_sym_switch_statement_repeat1 = 254,
  aux_sym_switch_case_repeat1 = 255,
  aux_sym_return_statement_repeat1 = 256,
  aux_sym_call_expression_repeat1 = 257,
  aux_sym_field_type_repeat1 = 258,
  aux_sym_tuple_type_repeat1 = 259,
  aux_sym_struct_type_repeat1 = 260,
  aux_sym_struct_type_repeat2 = 261,
  aux_sym__struct_members_repeat1 = 262,
  aux_sym_struct_member_repeat1 = 263,
  aux_sym_polymorphic_type_repeat1 = 264,
  aux_sym_struct_repeat1 = 265,
  aux_sym_struct_repeat2 = 266,
  aux_sym_map_repeat1 = 267,
  aux_sym__string_literal_repeat1 = 268,
  aux_sym__raw_string_literal_repeat1 = 269,
  aux_sym_field_identifier_repeat1 = 270,
  alias_sym_procedure_type = 271,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_POUND_PLUS] = "#+",
  [aux_sym_build_tag_token1] = "build_tag_token1",
  [anon_sym_package] = "package",
  [anon_sym_foreign] = "foreign",
  [anon_sym_import] = "import",
  [anon_sym_COMMA] = ",",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_proc] = "proc",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_where] = "where",
  [anon_sym_DQUOTEodin_DQUOTE] = "\"odin\"",
  [anon_sym_DQUOTEcontextless_DQUOTE] = "\"contextless\"",
  [anon_sym_DQUOTEstdcall_DQUOTE] = "\"stdcall\"",
  [anon_sym_DQUOTEstd_DQUOTE] = "\"std\"",
  [anon_sym_DQUOTEcdecl_DQUOTE] = "\"cdecl\"",
  [anon_sym_DQUOTEc_DQUOTE] = "\"c\"",
  [anon_sym_DQUOTEfastcall_DQUOTE] = "\"fastcall\"",
  [anon_sym_DQUOTEfast_DQUOTE] = "\"fast\"",
  [anon_sym_DQUOTEnone_DQUOTE] = "\"none\"",
  [anon_sym_DQUOTEsystem_DQUOTE] = "\"system\"",
  [anon_sym_struct] = "struct",
  [anon_sym_using] = "using",
  [anon_sym_enum] = "enum",
  [anon_sym_EQ] = "=",
  [anon_sym_union] = "union",
  [anon_sym_bit_field] = "bit_field",
  [anon_sym_COLON] = ":",
  [anon_sym_PIPE] = "|",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_POUNDtype] = "tag",
  [anon_sym_AT] = "@",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_PIPE_PIPE_EQ] = "||=",
  [anon_sym_AMP_AMP_EQ] = "&&=",
  [anon_sym_AMP_TILDE_EQ] = "&~=",
  [anon_sym_if] = "if",
  [anon_sym_SEMI] = ";",
  [anon_sym_do] = "do",
  [anon_sym_else] = "else",
  [anon_sym_when] = "when",
  [anon_sym_for] = "for",
  [anon_sym_in] = "in",
  [anon_sym_switch] = "switch",
  [anon_sym_case] = "case",
  [anon_sym_defer] = "defer",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [sym_fallthrough_statement] = "fallthrough_statement",
  [anon_sym_return] = "return",
  [anon_sym_QMARK] = "\?",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_TILDE] = "~",
  [anon_sym_BANG] = "!",
  [anon_sym_AMP] = "&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_or_else] = "or_else",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT] = "<",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_TILDE_EQ] = "~=",
  [anon_sym_AMP_TILDE] = "&~",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_PERCENT_PERCENT] = "%%",
  [anon_sym_DOT] = ".",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_DOT_DOT_EQ] = "..=",
  [anon_sym_DOT_DOT_LT] = "..<",
  [anon_sym_cast] = "cast",
  [anon_sym_transmute] = "transmute",
  [anon_sym_auto_cast] = "auto_cast",
  [anon_sym_not_in] = "not_in",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_or_return] = "or_return",
  [anon_sym_or_continue] = "or_continue",
  [anon_sym_or_break] = "or_break",
  [anon_sym_CARET] = "^",
  [anon_sym_DOT_DOT_DOT] = "...",
  [anon_sym_dynamic] = "dynamic",
  [anon_sym_map] = "map",
  [anon_sym_bit_set] = "bit_set",
  [anon_sym_matrix] = "matrix",
  [anon_sym_DOT2] = ".",
  [anon_sym_distinct] = "distinct",
  [sym_number] = "number",
  [anon_sym_DQUOTE] = "\"",
  [anon_sym_BQUOTE] = "`",
  [anon_sym_SQUOTE] = "'",
  [aux_sym_character_token1] = "character_token1",
  [sym_string_content] = "string_content",
  [sym__raw_string_content] = "string_content",
  [sym_escape_sequence] = "escape_sequence",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [sym_nil] = "nil",
  [sym_uninitialized] = "uninitialized",
  [sym_tag] = "tag",
  [sym_comment] = "comment",
  [sym__newline] = "_newline",
  [sym__backslash] = "_backslash",
  [sym__nl_comma] = ",",
  [sym_float] = "float",
  [sym_block_comment] = "block_comment",
  [sym_source_file] = "source_file",
  [sym_block] = "block",
  [sym_tagged_block] = "tagged_block",
  [sym_declaration] = "declaration",
  [sym_build_tag] = "build_tag",
  [sym_package_declaration] = "package_declaration",
  [sym_import_declaration] = "import_declaration",
  [sym_procedure_declaration] = "procedure_declaration",
  [sym_procedure] = "procedure",
  [sym_where_clause] = "where_clause",
  [sym_calling_convention] = "calling_convention",
  [sym_overloaded_procedure_declaration] = "overloaded_procedure_declaration",
  [sym_struct_declaration] = "struct_declaration",
  [sym_enum_declaration] = "enum_declaration",
  [sym_union_declaration] = "union_declaration",
  [sym_bit_field_declaration] = "bit_field_declaration",
  [sym_variable_declaration] = "variable_declaration",
  [sym_const_declaration] = "const_declaration",
  [sym_const_type_declaration] = "const_type_declaration",
  [sym_foreign_block] = "foreign_block",
  [sym_attributes] = "attributes",
  [sym_attribute] = "attribute",
  [sym_parameters] = "parameters",
  [sym_parameter] = "parameter",
  [sym__param_header] = "_param_header",
  [sym__param_type] = "_param_type",
  [sym_default_parameter] = "default_parameter",
  [sym_polymorphic_parameters] = "polymorphic_parameters",
  [sym_field] = "field",
  [sym_statement] = "statement",
  [sym_assignment_statement] = "assignment_statement",
  [sym_update_statement] = "update_statement",
  [sym_if_statement] = "if_statement",
  [sym_else_if_clause] = "else_if_clause",
  [sym_else_clause] = "else_clause",
  [sym_when_statement] = "when_statement",
  [sym_else_when_clause] = "else_when_clause",
  [sym_for_statement] = "for_statement",
  [sym__for_in_expression] = "_for_in_expression",
  [sym__simple_assignment_statement] = "assignment_statement",
  [sym_switch_statement] = "switch_statement",
  [sym_switch_case] = "switch_case",
  [sym_defer_statement] = "defer_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_var_declaration] = "var_declaration",
  [sym_return_statement] = "return_statement",
  [sym_label_statement] = "label_statement",
  [sym_using_statement] = "using_statement",
  [sym_expression] = "expression",
  [sym__expression_no_tag] = "_expression_no_tag",
  [sym_unary_expression] = "unary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_ternary_expression] = "ternary_expression",
  [sym_call_expression] = "call_expression",
  [sym_selector_call_expression] = "selector_call_expression",
  [sym_member_expression] = "member_expression",
  [sym_index_expression] = "index_expression",
  [sym_slice_expression] = "slice_expression",
  [sym_range_expression] = "range_expression",
  [sym_cast_expression] = "cast_expression",
  [sym_in_expression] = "in_expression",
  [sym_variadic_expression] = "variadic_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_or_return_expression] = "or_return_expression",
  [sym_or_continue_expression] = "or_continue_expression",
  [sym_or_break_expression] = "or_break_expression",
  [sym_address] = "address",
  [sym_type] = "type",
  [sym_pointer_type] = "pointer_type",
  [sym_variadic_type] = "variadic_type",
  [sym_array_type] = "array_type",
  [sym_map_type] = "map_type",
  [sym_union_type] = "union_type",
  [sym_bit_set_type] = "bit_set_type",
  [sym_matrix_type] = "matrix_type",
  [sym_field_type] = "field_type",
  [sym_tuple_type] = "tuple_type",
  [sym_struct_type] = "struct_type",
  [sym__struct_members] = "_struct_members",
  [sym_struct_member] = "struct_member",
  [sym_enum_type] = "enum_type",
  [sym_bit_field_type] = "bit_field_type",
  [sym_named_type] = "named_type",
  [sym_default_type] = "default_type",
  [sym_constant_type] = "constant_type",
  [sym_specialized_type] = "specialized_type",
  [sym__procedure_type] = "_procedure_type",
  [sym_distinct_type] = "distinct_type",
  [sym_empty_type] = "empty_type",
  [sym_polymorphic_type] = "polymorphic_type",
  [sym_conditional_type] = "conditional_type",
  [sym_literal] = "literal",
  [sym_struct] = "struct",
  [sym_map] = "map",
  [sym_bit_set] = "bit_set",
  [sym_matrix] = "matrix",
  [sym_struct_field] = "struct_field",
  [sym_string] = "string",
  [sym__string_literal] = "_string_literal",
  [sym__raw_string_literal] = "_raw_string_literal",
  [sym_character] = "character",
  [sym_boolean] = "boolean",
  [sym_field_identifier] = "field_identifier",
  [sym__separator] = "_separator",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_import_declaration_repeat1] = "import_declaration_repeat1",
  [aux_sym_where_clause_repeat1] = "where_clause_repeat1",
  [aux_sym_overloaded_procedure_declaration_repeat1] = "overloaded_procedure_declaration_repeat1",
  [aux_sym_struct_declaration_repeat1] = "struct_declaration_repeat1",
  [aux_sym_struct_declaration_repeat2] = "struct_declaration_repeat2",
  [aux_sym_enum_declaration_repeat1] = "enum_declaration_repeat1",
  [aux_sym_union_declaration_repeat1] = "union_declaration_repeat1",
  [aux_sym_bit_field_declaration_repeat1] = "bit_field_declaration_repeat1",
  [aux_sym_variable_declaration_repeat1] = "variable_declaration_repeat1",
  [aux_sym_const_declaration_repeat1] = "const_declaration_repeat1",
  [aux_sym_attributes_repeat1] = "attributes_repeat1",
  [aux_sym_parameters_repeat1] = "parameters_repeat1",
  [aux_sym_parameter_repeat1] = "parameter_repeat1",
  [aux_sym_polymorphic_parameters_repeat1] = "polymorphic_parameters_repeat1",
  [aux_sym_polymorphic_parameters_repeat2] = "polymorphic_parameters_repeat2",
  [aux_sym_field_repeat1] = "field_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_when_statement_repeat1] = "when_statement_repeat1",
  [aux_sym__simple_assignment_statement_repeat1] = "_simple_assignment_statement_repeat1",
  [aux_sym_switch_statement_repeat1] = "switch_statement_repeat1",
  [aux_sym_switch_case_repeat1] = "switch_case_repeat1",
  [aux_sym_return_statement_repeat1] = "return_statement_repeat1",
  [aux_sym_call_expression_repeat1] = "call_expression_repeat1",
  [aux_sym_field_type_repeat1] = "field_type_repeat1",
  [aux_sym_tuple_type_repeat1] = "tuple_type_repeat1",
  [aux_sym_struct_type_repeat1] = "struct_type_repeat1",
  [aux_sym_struct_type_repeat2] = "struct_type_repeat2",
  [aux_sym__struct_members_repeat1] = "_struct_members_repeat1",
  [aux_sym_struct_member_repeat1] = "struct_member_repeat1",
  [aux_sym_polymorphic_type_repeat1] = "polymorphic_type_repeat1",
  [aux_sym_struct_repeat1] = "struct_repeat1",
  [aux_sym_struct_repeat2] = "struct_repeat2",
  [aux_sym_map_repeat1] = "map_repeat1",
  [aux_sym__string_literal_repeat1] = "_string_literal_repeat1",
  [aux_sym__raw_string_literal_repeat1] = "_raw_string_literal_repeat1",
  [aux_sym_field_identifier_repeat1] = "field_identifier_repeat1",
  [alias_sym_procedure_type] = "procedure_type",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_POUND_PLUS] = anon_sym_POUND_PLUS,
  [aux_sym_build_tag_token1] = aux_sym_build_tag_token1,
  [anon_sym_package] = anon_sym_package,
  [anon_sym_foreign] = anon_sym_foreign,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_proc] = anon_sym_proc,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_where] = anon_sym_where,
  [anon_sym_DQUOTEodin_DQUOTE] = anon_sym_DQUOTEodin_DQUOTE,
  [anon_sym_DQUOTEcontextless_DQUOTE] = anon_sym_DQUOTEcontextless_DQUOTE,
  [anon_sym_DQUOTEstdcall_DQUOTE] = anon_sym_DQUOTEstdcall_DQUOTE,
  [anon_sym_DQUOTEstd_DQUOTE] = anon_sym_DQUOTEstd_DQUOTE,
  [anon_sym_DQUOTEcdecl_DQUOTE] = anon_sym_DQUOTEcdecl_DQUOTE,
  [anon_sym_DQUOTEc_DQUOTE] = anon_sym_DQUOTEc_DQUOTE,
  [anon_sym_DQUOTEfastcall_DQUOTE] = anon_sym_DQUOTEfastcall_DQUOTE,
  [anon_sym_DQUOTEfast_DQUOTE] = anon_sym_DQUOTEfast_DQUOTE,
  [anon_sym_DQUOTEnone_DQUOTE] = anon_sym_DQUOTEnone_DQUOTE,
  [anon_sym_DQUOTEsystem_DQUOTE] = anon_sym_DQUOTEsystem_DQUOTE,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_using] = anon_sym_using,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_bit_field] = anon_sym_bit_field,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_POUNDtype] = sym_tag,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_PIPE_PIPE_EQ] = anon_sym_PIPE_PIPE_EQ,
  [anon_sym_AMP_AMP_EQ] = anon_sym_AMP_AMP_EQ,
  [anon_sym_AMP_TILDE_EQ] = anon_sym_AMP_TILDE_EQ,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_when] = anon_sym_when,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_defer] = anon_sym_defer,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [sym_fallthrough_statement] = sym_fallthrough_statement,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_or_else] = anon_sym_or_else,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_TILDE_EQ] = anon_sym_TILDE_EQ,
  [anon_sym_AMP_TILDE] = anon_sym_AMP_TILDE,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_PERCENT_PERCENT] = anon_sym_PERCENT_PERCENT,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_DOT_DOT_EQ] = anon_sym_DOT_DOT_EQ,
  [anon_sym_DOT_DOT_LT] = anon_sym_DOT_DOT_LT,
  [anon_sym_cast] = anon_sym_cast,
  [anon_sym_transmute] = anon_sym_transmute,
  [anon_sym_auto_cast] = anon_sym_auto_cast,
  [anon_sym_not_in] = anon_sym_not_in,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_or_return] = anon_sym_or_return,
  [anon_sym_or_continue] = anon_sym_or_continue,
  [anon_sym_or_break] = anon_sym_or_break,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [anon_sym_dynamic] = anon_sym_dynamic,
  [anon_sym_map] = anon_sym_map,
  [anon_sym_bit_set] = anon_sym_bit_set,
  [anon_sym_matrix] = anon_sym_matrix,
  [anon_sym_DOT2] = anon_sym_DOT,
  [anon_sym_distinct] = anon_sym_distinct,
  [sym_number] = sym_number,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [anon_sym_BQUOTE] = anon_sym_BQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym_character_token1] = aux_sym_character_token1,
  [sym_string_content] = sym_string_content,
  [sym__raw_string_content] = sym_string_content,
  [sym_escape_sequence] = sym_escape_sequence,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [sym_nil] = sym_nil,
  [sym_uninitialized] = sym_uninitialized,
  [sym_tag] = sym_tag,
  [sym_comment] = sym_comment,
  [sym__newline] = sym__newline,
  [sym__backslash] = sym__backslash,
  [sym__nl_comma] = anon_sym_COMMA,
  [sym_float] = sym_float,
  [sym_block_comment] = sym_block_comment,
  [sym_source_file] = sym_source_file,
  [sym_block] = sym_block,
  [sym_tagged_block] = sym_tagged_block,
  [sym_declaration] = sym_declaration,
  [sym_build_tag] = sym_build_tag,
  [sym_package_declaration] = sym_package_declaration,
  [sym_import_declaration] = sym_import_declaration,
  [sym_procedure_declaration] = sym_procedure_declaration,
  [sym_procedure] = sym_procedure,
  [sym_where_clause] = sym_where_clause,
  [sym_calling_convention] = sym_calling_convention,
  [sym_overloaded_procedure_declaration] = sym_overloaded_procedure_declaration,
  [sym_struct_declaration] = sym_struct_declaration,
  [sym_enum_declaration] = sym_enum_declaration,
  [sym_union_declaration] = sym_union_declaration,
  [sym_bit_field_declaration] = sym_bit_field_declaration,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym_const_declaration] = sym_const_declaration,
  [sym_const_type_declaration] = sym_const_type_declaration,
  [sym_foreign_block] = sym_foreign_block,
  [sym_attributes] = sym_attributes,
  [sym_attribute] = sym_attribute,
  [sym_parameters] = sym_parameters,
  [sym_parameter] = sym_parameter,
  [sym__param_header] = sym__param_header,
  [sym__param_type] = sym__param_type,
  [sym_default_parameter] = sym_default_parameter,
  [sym_polymorphic_parameters] = sym_polymorphic_parameters,
  [sym_field] = sym_field,
  [sym_statement] = sym_statement,
  [sym_assignment_statement] = sym_assignment_statement,
  [sym_update_statement] = sym_update_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_else_if_clause] = sym_else_if_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_when_statement] = sym_when_statement,
  [sym_else_when_clause] = sym_else_when_clause,
  [sym_for_statement] = sym_for_statement,
  [sym__for_in_expression] = sym__for_in_expression,
  [sym__simple_assignment_statement] = sym_assignment_statement,
  [sym_switch_statement] = sym_switch_statement,
  [sym_switch_case] = sym_switch_case,
  [sym_defer_statement] = sym_defer_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_var_declaration] = sym_var_declaration,
  [sym_return_statement] = sym_return_statement,
  [sym_label_statement] = sym_label_statement,
  [sym_using_statement] = sym_using_statement,
  [sym_expression] = sym_expression,
  [sym__expression_no_tag] = sym__expression_no_tag,
  [sym_unary_expression] = sym_unary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_selector_call_expression] = sym_selector_call_expression,
  [sym_member_expression] = sym_member_expression,
  [sym_index_expression] = sym_index_expression,
  [sym_slice_expression] = sym_slice_expression,
  [sym_range_expression] = sym_range_expression,
  [sym_cast_expression] = sym_cast_expression,
  [sym_in_expression] = sym_in_expression,
  [sym_variadic_expression] = sym_variadic_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_or_return_expression] = sym_or_return_expression,
  [sym_or_continue_expression] = sym_or_continue_expression,
  [sym_or_break_expression] = sym_or_break_expression,
  [sym_address] = sym_address,
  [sym_type] = sym_type,
  [sym_pointer_type] = sym_pointer_type,
  [sym_variadic_type] = sym_variadic_type,
  [sym_array_type] = sym_array_type,
  [sym_map_type] = sym_map_type,
  [sym_union_type] = sym_union_type,
  [sym_bit_set_type] = sym_bit_set_type,
  [sym_matrix_type] = sym_matrix_type,
  [sym_field_type] = sym_field_type,
  [sym_tuple_type] = sym_tuple_type,
  [sym_struct_type] = sym_struct_type,
  [sym__struct_members] = sym__struct_members,
  [sym_struct_member] = sym_struct_member,
  [sym_enum_type] = sym_enum_type,
  [sym_bit_field_type] = sym_bit_field_type,
  [sym_named_type] = sym_named_type,
  [sym_default_type] = sym_default_type,
  [sym_constant_type] = sym_constant_type,
  [sym_specialized_type] = sym_specialized_type,
  [sym__procedure_type] = sym__procedure_type,
  [sym_distinct_type] = sym_distinct_type,
  [sym_empty_type] = sym_empty_type,
  [sym_polymorphic_type] = sym_polymorphic_type,
  [sym_conditional_type] = sym_conditional_type,
  [sym_literal] = sym_literal,
  [sym_struct] = sym_struct,
  [sym_map] = sym_map,
  [sym_bit_set] = sym_bit_set,
  [sym_matrix] = sym_matrix,
  [sym_struct_field] = sym_struct_field,
  [sym_string] = sym_string,
  [sym__string_literal] = sym__string_literal,
  [sym__raw_string_literal] = sym__raw_string_literal,
  [sym_character] = sym_character,
  [sym_boolean] = sym_boolean,
  [sym_field_identifier] = sym_field_identifier,
  [sym__separator] = sym__separator,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_import_declaration_repeat1] = aux_sym_import_declaration_repeat1,
  [aux_sym_where_clause_repeat1] = aux_sym_where_clause_repeat1,
  [aux_sym_overloaded_procedure_declaration_repeat1] = aux_sym_overloaded_procedure_declaration_repeat1,
  [aux_sym_struct_declaration_repeat1] = aux_sym_struct_declaration_repeat1,
  [aux_sym_struct_declaration_repeat2] = aux_sym_struct_declaration_repeat2,
  [aux_sym_enum_declaration_repeat1] = aux_sym_enum_declaration_repeat1,
  [aux_sym_union_declaration_repeat1] = aux_sym_union_declaration_repeat1,
  [aux_sym_bit_field_declaration_repeat1] = aux_sym_bit_field_declaration_repeat1,
  [aux_sym_variable_declaration_repeat1] = aux_sym_variable_declaration_repeat1,
  [aux_sym_const_declaration_repeat1] = aux_sym_const_declaration_repeat1,
  [aux_sym_attributes_repeat1] = aux_sym_attributes_repeat1,
  [aux_sym_parameters_repeat1] = aux_sym_parameters_repeat1,
  [aux_sym_parameter_repeat1] = aux_sym_parameter_repeat1,
  [aux_sym_polymorphic_parameters_repeat1] = aux_sym_polymorphic_parameters_repeat1,
  [aux_sym_polymorphic_parameters_repeat2] = aux_sym_polymorphic_parameters_repeat2,
  [aux_sym_field_repeat1] = aux_sym_field_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_when_statement_repeat1] = aux_sym_when_statement_repeat1,
  [aux_sym__simple_assignment_statement_repeat1] = aux_sym__simple_assignment_statement_repeat1,
  [aux_sym_switch_statement_repeat1] = aux_sym_switch_statement_repeat1,
  [aux_sym_switch_case_repeat1] = aux_sym_switch_case_repeat1,
  [aux_sym_return_statement_repeat1] = aux_sym_return_statement_repeat1,
  [aux_sym_call_expression_repeat1] = aux_sym_call_expression_repeat1,
  [aux_sym_field_type_repeat1] = aux_sym_field_type_repeat1,
  [aux_sym_tuple_type_repeat1] = aux_sym_tuple_type_repeat1,
  [aux_sym_struct_type_repeat1] = aux_sym_struct_type_repeat1,
  [aux_sym_struct_type_repeat2] = aux_sym_struct_type_repeat2,
  [aux_sym__struct_members_repeat1] = aux_sym__struct_members_repeat1,
  [aux_sym_struct_member_repeat1] = aux_sym_struct_member_repeat1,
  [aux_sym_polymorphic_type_repeat1] = aux_sym_polymorphic_type_repeat1,
  [aux_sym_struct_repeat1] = aux_sym_struct_repeat1,
  [aux_sym_struct_repeat2] = aux_sym_struct_repeat2,
  [aux_sym_map_repeat1] = aux_sym_map_repeat1,
  [aux_sym__string_literal_repeat1] = aux_sym__string_literal_repeat1,
  [aux_sym__raw_string_literal_repeat1] = aux_sym__raw_string_literal_repeat1,
  [aux_sym_field_identifier_repeat1] = aux_sym_field_identifier_repeat1,
  [alias_sym_procedure_type] = alias_sym_procedure_type,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND_PLUS] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_build_tag_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_package] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_foreign] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_proc] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_where] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEodin_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEcontextless_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEstdcall_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEstd_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEcdecl_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEc_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEfastcall_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEfast_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEnone_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTEsystem_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_using] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bit_field] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDtype] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_TILDE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_when] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defer] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [sym_fallthrough_statement] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cast] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_transmute] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_auto_cast] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dynamic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_map] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bit_set] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_matrix] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_distinct] = {
    .visible = true,
    .named = false,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_character_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__raw_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [sym_nil] = {
    .visible = true,
    .named = true,
  },
  [sym_uninitialized] = {
    .visible = true,
    .named = true,
  },
  [sym_tag] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__newline] = {
    .visible = false,
    .named = true,
  },
  [sym__backslash] = {
    .visible = false,
    .named = true,
  },
  [sym__nl_comma] = {
    .visible = true,
    .named = false,
  },
  [sym_float] = {
    .visible = true,
    .named = true,
  },
  [sym_block_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_tagged_block] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_build_tag] = {
    .visible = true,
    .named = true,
  },
  [sym_package_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_import_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_procedure_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_procedure] = {
    .visible = true,
    .named = true,
  },
  [sym_where_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_calling_convention] = {
    .visible = true,
    .named = true,
  },
  [sym_overloaded_procedure_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_union_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_bit_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_const_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_const_type_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_foreign_block] = {
    .visible = true,
    .named = true,
  },
  [sym_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__param_header] = {
    .visible = false,
    .named = true,
  },
  [sym__param_type] = {
    .visible = false,
    .named = true,
  },
  [sym_default_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_polymorphic_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_field] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_assignment_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_update_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_else_if_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_when_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_else_when_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__for_in_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_assignment_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_case] = {
    .visible = true,
    .named = true,
  },
  [sym_defer_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_var_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_label_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_using_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__expression_no_tag] = {
    .visible = false,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_selector_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_member_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_index_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_slice_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_range_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_in_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_or_return_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_or_continue_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_or_break_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_address] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_type] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_map_type] = {
    .visible = true,
    .named = true,
  },
  [sym_union_type] = {
    .visible = true,
    .named = true,
  },
  [sym_bit_set_type] = {
    .visible = true,
    .named = true,
  },
  [sym_matrix_type] = {
    .visible = true,
    .named = true,
  },
  [sym_field_type] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_type] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_type] = {
    .visible = true,
    .named = true,
  },
  [sym__struct_members] = {
    .visible = false,
    .named = true,
  },
  [sym_struct_member] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_type] = {
    .visible = true,
    .named = true,
  },
  [sym_bit_field_type] = {
    .visible = true,
    .named = true,
  },
  [sym_named_type] = {
    .visible = true,
    .named = true,
  },
  [sym_default_type] = {
    .visible = true,
    .named = true,
  },
  [sym_constant_type] = {
    .visible = true,
    .named = true,
  },
  [sym_specialized_type] = {
    .visible = true,
    .named = true,
  },
  [sym__procedure_type] = {
    .visible = false,
    .named = true,
  },
  [sym_distinct_type] = {
    .visible = true,
    .named = true,
  },
  [sym_empty_type] = {
    .visible = true,
    .named = true,
  },
  [sym_polymorphic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_type] = {
    .visible = true,
    .named = true,
  },
  [sym_literal] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_struct] = {
    .visible = true,
    .named = true,
  },
  [sym_map] = {
    .visible = true,
    .named = true,
  },
  [sym_bit_set] = {
    .visible = true,
    .named = true,
  },
  [sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_field] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym__string_literal] = {
    .visible = false,
    .named = true,
  },
  [sym__raw_string_literal] = {
    .visible = false,
    .named = true,
  },
  [sym_character] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__separator] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_import_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_where_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_overloaded_procedure_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_union_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bit_field_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_const_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_polymorphic_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_polymorphic_parameters_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_when_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__simple_assignment_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_case_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_return_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_call_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_type_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__struct_members_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_member_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_polymorphic_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_map_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__raw_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_identifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_procedure_type] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alias = 1,
  field_alternative = 2,
  field_argument = 3,
  field_condition = 4,
  field_consequence = 5,
  field_end = 6,
  field_function = 7,
  field_initializer = 8,
  field_label = 9,
  field_left = 10,
  field_operator = 11,
  field_post = 12,
  field_right = 13,
  field_start = 14,
  field_underlying_type = 15,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_end] = "end",
  [field_function] = "function",
  [field_initializer] = "initializer",
  [field_label] = "label",
  [field_left] = "left",
  [field_operator] = "operator",
  [field_post] = "post",
  [field_right] = "right",
  [field_start] = "start",
  [field_underlying_type] = "underlying_type",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 2},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 1},
  [5] = {.index = 4, .length = 3},
  [6] = {.index = 7, .length = 1},
  [7] = {.index = 8, .length = 1},
  [8] = {.index = 9, .length = 1},
  [9] = {.index = 10, .length = 2},
  [10] = {.index = 12, .length = 2},
  [11] = {.index = 14, .length = 2},
  [12] = {.index = 16, .length = 1},
  [13] = {.index = 17, .length = 2},
  [14] = {.index = 19, .length = 1},
  [15] = {.index = 20, .length = 3},
  [16] = {.index = 23, .length = 2},
  [17] = {.index = 25, .length = 3},
  [18] = {.index = 28, .length = 1},
  [19] = {.index = 29, .length = 1},
  [20] = {.index = 30, .length = 1},
  [21] = {.index = 31, .length = 3},
  [22] = {.index = 34, .length = 2},
  [23] = {.index = 36, .length = 2},
  [24] = {.index = 38, .length = 1},
  [25] = {.index = 39, .length = 2},
  [26] = {.index = 41, .length = 2},
  [27] = {.index = 43, .length = 2},
  [28] = {.index = 45, .length = 3},
  [29] = {.index = 48, .length = 1},
  [30] = {.index = 49, .length = 1},
  [31] = {.index = 50, .length = 4},
  [32] = {.index = 54, .length = 2},
  [33] = {.index = 56, .length = 2},
  [34] = {.index = 58, .length = 2},
  [35] = {.index = 60, .length = 3},
  [36] = {.index = 63, .length = 2},
  [37] = {.index = 65, .length = 2},
  [38] = {.index = 67, .length = 3},
  [39] = {.index = 70, .length = 3},
  [40] = {.index = 73, .length = 2},
  [41] = {.index = 75, .length = 3},
  [42] = {.index = 78, .length = 3},
  [43] = {.index = 81, .length = 3},
  [44] = {.index = 84, .length = 1},
  [45] = {.index = 85, .length = 2},
  [46] = {.index = 87, .length = 3},
  [47] = {.index = 90, .length = 2},
  [48] = {.index = 92, .length = 3},
  [49] = {.index = 95, .length = 3},
  [50] = {.index = 98, .length = 3},
  [51] = {.index = 101, .length = 3},
  [52] = {.index = 104, .length = 3},
  [53] = {.index = 107, .length = 3},
  [54] = {.index = 110, .length = 3},
  [55] = {.index = 113, .length = 4},
  [56] = {.index = 117, .length = 4},
  [57] = {.index = 121, .length = 2},
  [58] = {.index = 123, .length = 2},
  [59] = {.index = 125, .length = 2},
  [60] = {.index = 127, .length = 3},
  [61] = {.index = 130, .length = 1},
  [62] = {.index = 131, .length = 4},
  [63] = {.index = 135, .length = 3},
  [64] = {.index = 138, .length = 4},
  [65] = {.index = 142, .length = 4},
  [66] = {.index = 146, .length = 4},
  [67] = {.index = 150, .length = 4},
  [68] = {.index = 154, .length = 3},
  [69] = {.index = 157, .length = 5},
  [70] = {.index = 162, .length = 3},
  [71] = {.index = 165, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_argument, 1},
    {field_operator, 0},
  [2] =
    {field_alias, 1},
  [3] =
    {field_function, 0},
  [4] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [7] =
    {field_label, 2},
  [8] =
    {field_consequence, 1},
  [9] =
    {field_alias, 2},
  [10] =
    {field_argument, 2},
    {field_function, 0},
  [12] =
    {field_function, 0},
    {field_function, 1},
  [14] =
    {field_condition, 1},
    {field_consequence, 2},
  [16] =
    {field_consequence, 2},
  [17] =
    {field_consequence, 1},
    {field_consequence, 2},
  [19] =
    {field_argument, 1},
  [20] =
    {field_argument, 2},
    {field_argument, 3, .inherited = true},
    {field_function, 0},
  [23] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [25] =
    {field_argument, 3},
    {field_function, 0},
    {field_function, 1},
  [28] =
    {field_alias, 3},
  [29] =
    {field_end, 3},
  [30] =
    {field_start, 2},
  [31] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [34] =
    {field_condition, 2},
    {field_consequence, 3},
  [36] =
    {field_condition, 1},
    {field_consequence, 3},
  [38] =
    {field_consequence, 3},
  [39] =
    {field_consequence, 2},
    {field_consequence, 3},
  [41] =
    {field_consequence, 3},
    {field_post, 2},
  [43] =
    {field_consequence, 3},
    {field_initializer, 1},
  [45] =
    {field_condition, 1},
    {field_consequence, 2},
    {field_consequence, 3},
  [48] =
    {field_condition, 1},
  [49] =
    {field_underlying_type, 1},
  [50] =
    {field_argument, 3},
    {field_argument, 4, .inherited = true},
    {field_function, 0},
    {field_function, 1},
  [54] =
    {field_end, 4},
    {field_start, 2},
  [56] =
    {field_condition, 3},
    {field_consequence, 4},
  [58] =
    {field_condition, 2},
    {field_consequence, 4},
  [60] =
    {field_condition, 3},
    {field_consequence, 4},
    {field_initializer, 1},
  [63] =
    {field_consequence, 3},
    {field_consequence, 4},
  [65] =
    {field_consequence, 4},
    {field_post, 3},
  [67] =
    {field_consequence, 3},
    {field_consequence, 4},
    {field_post, 2},
  [70] =
    {field_condition, 2},
    {field_consequence, 3},
    {field_consequence, 4},
  [73] =
    {field_consequence, 4},
    {field_initializer, 1},
  [75] =
    {field_consequence, 3},
    {field_consequence, 4},
    {field_initializer, 1},
  [78] =
    {field_condition, 1},
    {field_consequence, 3},
    {field_consequence, 4},
  [81] =
    {field_condition, 1},
    {field_consequence, 4},
    {field_post, 3},
  [84] =
    {field_condition, 2},
  [85] =
    {field_condition, 1},
    {field_condition, 2},
  [87] =
    {field_argument, 2},
    {field_argument, 5, .inherited = true},
    {field_function, 0},
  [90] =
    {field_condition, 3},
    {field_consequence, 5},
  [92] =
    {field_condition, 4},
    {field_consequence, 5},
    {field_initializer, 1},
  [95] =
    {field_condition, 3},
    {field_consequence, 5},
    {field_initializer, 1},
  [98] =
    {field_consequence, 4},
    {field_consequence, 5},
    {field_post, 3},
  [101] =
    {field_condition, 2},
    {field_consequence, 4},
    {field_consequence, 5},
  [104] =
    {field_condition, 2},
    {field_consequence, 5},
    {field_post, 4},
  [107] =
    {field_consequence, 4},
    {field_consequence, 5},
    {field_initializer, 1},
  [110] =
    {field_consequence, 5},
    {field_initializer, 1},
    {field_post, 4},
  [113] =
    {field_condition, 3},
    {field_consequence, 4},
    {field_consequence, 5},
    {field_initializer, 1},
  [117] =
    {field_condition, 1},
    {field_consequence, 4},
    {field_consequence, 5},
    {field_post, 3},
  [121] =
    {field_condition, 1},
    {field_condition, 2, .inherited = true},
  [123] =
    {field_condition, 0, .inherited = true},
    {field_condition, 1, .inherited = true},
  [125] =
    {field_condition, 2},
    {field_condition, 3},
  [127] =
    {field_condition, 1},
    {field_condition, 2},
    {field_condition, 3},
  [130] =
    {field_underlying_type, 4},
  [131] =
    {field_argument, 3},
    {field_argument, 6, .inherited = true},
    {field_function, 0},
    {field_function, 1},
  [135] =
    {field_condition, 4},
    {field_consequence, 6},
    {field_initializer, 1},
  [138] =
    {field_condition, 2},
    {field_consequence, 5},
    {field_consequence, 6},
    {field_post, 4},
  [142] =
    {field_consequence, 5},
    {field_consequence, 6},
    {field_initializer, 1},
    {field_post, 4},
  [146] =
    {field_condition, 3},
    {field_consequence, 5},
    {field_consequence, 6},
    {field_initializer, 1},
  [150] =
    {field_condition, 3},
    {field_consequence, 6},
    {field_initializer, 1},
    {field_post, 5},
  [154] =
    {field_condition, 2},
    {field_condition, 3},
    {field_condition, 4},
  [157] =
    {field_condition, 3},
    {field_consequence, 6},
    {field_consequence, 7},
    {field_initializer, 1},
    {field_post, 5},
  [162] =
    {field_condition, 4},
    {field_consequence, 5},
    {field_initializer, 2},
  [165] =
    {field_condition, 4},
    {field_consequence, 6},
    {field_initializer, 2},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = alias_sym_procedure_type,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_procedure, 2,
    sym_procedure,
    alias_sym_procedure_type,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 2,
  [9] = 2,
  [10] = 2,
  [11] = 2,
  [12] = 2,
  [13] = 2,
  [14] = 2,
  [15] = 2,
  [16] = 2,
  [17] = 2,
  [18] = 2,
  [19] = 2,
  [20] = 2,
  [21] = 2,
  [22] = 2,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 24,
  [27] = 25,
  [28] = 25,
  [29] = 29,
  [30] = 24,
  [31] = 25,
  [32] = 24,
  [33] = 25,
  [34] = 24,
  [35] = 24,
  [36] = 24,
  [37] = 25,
  [38] = 29,
  [39] = 25,
  [40] = 40,
  [41] = 41,
  [42] = 41,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 43,
  [48] = 43,
  [49] = 49,
  [50] = 43,
  [51] = 51,
  [52] = 51,
  [53] = 51,
  [54] = 51,
  [55] = 51,
  [56] = 51,
  [57] = 51,
  [58] = 51,
  [59] = 51,
  [60] = 51,
  [61] = 51,
  [62] = 51,
  [63] = 51,
  [64] = 51,
  [65] = 51,
  [66] = 51,
  [67] = 51,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 68,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 25,
  [94] = 24,
  [95] = 25,
  [96] = 24,
  [97] = 97,
  [98] = 84,
  [99] = 87,
  [100] = 88,
  [101] = 90,
  [102] = 91,
  [103] = 92,
  [104] = 104,
  [105] = 105,
  [106] = 69,
  [107] = 70,
  [108] = 71,
  [109] = 72,
  [110] = 73,
  [111] = 77,
  [112] = 104,
  [113] = 79,
  [114] = 82,
  [115] = 105,
  [116] = 80,
  [117] = 74,
  [118] = 89,
  [119] = 119,
  [120] = 97,
  [121] = 76,
  [122] = 119,
  [123] = 83,
  [124] = 75,
  [125] = 125,
  [126] = 126,
  [127] = 24,
  [128] = 24,
  [129] = 25,
  [130] = 24,
  [131] = 25,
  [132] = 25,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 29,
  [144] = 24,
  [145] = 25,
  [146] = 146,
  [147] = 25,
  [148] = 148,
  [149] = 24,
  [150] = 150,
  [151] = 134,
  [152] = 139,
  [153] = 141,
  [154] = 142,
  [155] = 29,
  [156] = 156,
  [157] = 138,
  [158] = 135,
  [159] = 140,
  [160] = 140,
  [161] = 29,
  [162] = 138,
  [163] = 135,
  [164] = 139,
  [165] = 25,
  [166] = 142,
  [167] = 141,
  [168] = 24,
  [169] = 134,
  [170] = 141,
  [171] = 134,
  [172] = 25,
  [173] = 138,
  [174] = 135,
  [175] = 139,
  [176] = 24,
  [177] = 140,
  [178] = 142,
  [179] = 25,
  [180] = 25,
  [181] = 24,
  [182] = 24,
  [183] = 142,
  [184] = 138,
  [185] = 141,
  [186] = 140,
  [187] = 139,
  [188] = 188,
  [189] = 134,
  [190] = 135,
  [191] = 146,
  [192] = 150,
  [193] = 156,
  [194] = 188,
  [195] = 148,
  [196] = 29,
  [197] = 140,
  [198] = 141,
  [199] = 139,
  [200] = 134,
  [201] = 142,
  [202] = 135,
  [203] = 138,
  [204] = 204,
  [205] = 205,
  [206] = 206,
  [207] = 207,
  [208] = 206,
  [209] = 207,
  [210] = 138,
  [211] = 135,
  [212] = 139,
  [213] = 138,
  [214] = 135,
  [215] = 140,
  [216] = 141,
  [217] = 142,
  [218] = 141,
  [219] = 140,
  [220] = 134,
  [221] = 134,
  [222] = 139,
  [223] = 142,
  [224] = 135,
  [225] = 134,
  [226] = 138,
  [227] = 135,
  [228] = 139,
  [229] = 140,
  [230] = 141,
  [231] = 142,
  [232] = 138,
  [233] = 140,
  [234] = 139,
  [235] = 141,
  [236] = 142,
  [237] = 134,
  [238] = 141,
  [239] = 139,
  [240] = 142,
  [241] = 138,
  [242] = 134,
  [243] = 135,
  [244] = 140,
  [245] = 138,
  [246] = 135,
  [247] = 140,
  [248] = 141,
  [249] = 141,
  [250] = 142,
  [251] = 139,
  [252] = 142,
  [253] = 138,
  [254] = 135,
  [255] = 139,
  [256] = 134,
  [257] = 134,
  [258] = 140,
  [259] = 140,
  [260] = 141,
  [261] = 135,
  [262] = 139,
  [263] = 138,
  [264] = 142,
  [265] = 134,
  [266] = 134,
  [267] = 141,
  [268] = 139,
  [269] = 142,
  [270] = 138,
  [271] = 135,
  [272] = 140,
  [273] = 140,
  [274] = 138,
  [275] = 135,
  [276] = 142,
  [277] = 141,
  [278] = 134,
  [279] = 139,
  [280] = 135,
  [281] = 142,
  [282] = 134,
  [283] = 140,
  [284] = 138,
  [285] = 141,
  [286] = 139,
  [287] = 287,
  [288] = 287,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 294,
  [296] = 294,
  [297] = 297,
  [298] = 294,
  [299] = 299,
  [300] = 291,
  [301] = 294,
  [302] = 294,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 303,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 304,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 318,
  [321] = 321,
  [322] = 314,
  [323] = 304,
  [324] = 305,
  [325] = 306,
  [326] = 307,
  [327] = 308,
  [328] = 309,
  [329] = 310,
  [330] = 303,
  [331] = 312,
  [332] = 313,
  [333] = 315,
  [334] = 317,
  [335] = 319,
  [336] = 318,
  [337] = 321,
  [338] = 314,
  [339] = 304,
  [340] = 305,
  [341] = 306,
  [342] = 307,
  [343] = 308,
  [344] = 309,
  [345] = 310,
  [346] = 303,
  [347] = 312,
  [348] = 313,
  [349] = 308,
  [350] = 315,
  [351] = 317,
  [352] = 309,
  [353] = 319,
  [354] = 318,
  [355] = 321,
  [356] = 314,
  [357] = 304,
  [358] = 305,
  [359] = 306,
  [360] = 307,
  [361] = 308,
  [362] = 309,
  [363] = 310,
  [364] = 303,
  [365] = 312,
  [366] = 313,
  [367] = 315,
  [368] = 317,
  [369] = 319,
  [370] = 318,
  [371] = 321,
  [372] = 314,
  [373] = 304,
  [374] = 305,
  [375] = 306,
  [376] = 307,
  [377] = 308,
  [378] = 319,
  [379] = 312,
  [380] = 313,
  [381] = 310,
  [382] = 315,
  [383] = 317,
  [384] = 319,
  [385] = 321,
  [386] = 314,
  [387] = 304,
  [388] = 305,
  [389] = 306,
  [390] = 307,
  [391] = 303,
  [392] = 312,
  [393] = 313,
  [394] = 315,
  [395] = 317,
  [396] = 319,
  [397] = 321,
  [398] = 314,
  [399] = 304,
  [400] = 305,
  [401] = 306,
  [402] = 307,
  [403] = 303,
  [404] = 312,
  [405] = 313,
  [406] = 315,
  [407] = 315,
  [408] = 317,
  [409] = 319,
  [410] = 321,
  [411] = 314,
  [412] = 304,
  [413] = 305,
  [414] = 306,
  [415] = 307,
  [416] = 303,
  [417] = 312,
  [418] = 313,
  [419] = 315,
  [420] = 317,
  [421] = 319,
  [422] = 321,
  [423] = 314,
  [424] = 304,
  [425] = 305,
  [426] = 306,
  [427] = 307,
  [428] = 303,
  [429] = 312,
  [430] = 313,
  [431] = 315,
  [432] = 317,
  [433] = 319,
  [434] = 321,
  [435] = 314,
  [436] = 304,
  [437] = 305,
  [438] = 306,
  [439] = 307,
  [440] = 303,
  [441] = 312,
  [442] = 313,
  [443] = 315,
  [444] = 317,
  [445] = 319,
  [446] = 321,
  [447] = 314,
  [448] = 304,
  [449] = 305,
  [450] = 306,
  [451] = 307,
  [452] = 303,
  [453] = 312,
  [454] = 313,
  [455] = 303,
  [456] = 315,
  [457] = 317,
  [458] = 319,
  [459] = 321,
  [460] = 314,
  [461] = 304,
  [462] = 305,
  [463] = 306,
  [464] = 307,
  [465] = 303,
  [466] = 312,
  [467] = 313,
  [468] = 315,
  [469] = 315,
  [470] = 315,
  [471] = 315,
  [472] = 317,
  [473] = 473,
  [474] = 312,
  [475] = 475,
  [476] = 476,
  [477] = 313,
  [478] = 478,
  [479] = 315,
  [480] = 321,
  [481] = 317,
  [482] = 305,
  [483] = 306,
  [484] = 319,
  [485] = 476,
  [486] = 478,
  [487] = 307,
  [488] = 473,
  [489] = 475,
  [490] = 490,
  [491] = 318,
  [492] = 321,
  [493] = 314,
  [494] = 494,
  [495] = 494,
  [496] = 490,
  [497] = 497,
  [498] = 498,
  [499] = 498,
  [500] = 500,
  [501] = 498,
  [502] = 498,
  [503] = 498,
  [504] = 498,
  [505] = 498,
  [506] = 498,
  [507] = 498,
  [508] = 498,
  [509] = 498,
  [510] = 498,
  [511] = 498,
  [512] = 498,
  [513] = 498,
  [514] = 498,
  [515] = 498,
  [516] = 516,
  [517] = 498,
  [518] = 518,
  [519] = 519,
  [520] = 520,
  [521] = 521,
  [522] = 522,
  [523] = 520,
  [524] = 524,
  [525] = 525,
  [526] = 526,
  [527] = 527,
  [528] = 528,
  [529] = 529,
  [530] = 530,
  [531] = 522,
  [532] = 532,
  [533] = 533,
  [534] = 534,
  [535] = 535,
  [536] = 536,
  [537] = 532,
  [538] = 535,
  [539] = 539,
  [540] = 520,
  [541] = 521,
  [542] = 542,
  [543] = 521,
  [544] = 544,
  [545] = 545,
  [546] = 546,
  [547] = 545,
  [548] = 522,
  [549] = 524,
  [550] = 525,
  [551] = 534,
  [552] = 526,
  [553] = 553,
  [554] = 554,
  [555] = 555,
  [556] = 524,
  [557] = 542,
  [558] = 532,
  [559] = 545,
  [560] = 525,
  [561] = 561,
  [562] = 526,
  [563] = 534,
  [564] = 535,
  [565] = 542,
  [566] = 566,
  [567] = 567,
  [568] = 568,
  [569] = 566,
  [570] = 570,
  [571] = 568,
  [572] = 566,
  [573] = 570,
  [574] = 574,
  [575] = 568,
  [576] = 566,
  [577] = 570,
  [578] = 568,
  [579] = 579,
  [580] = 568,
  [581] = 566,
  [582] = 570,
  [583] = 566,
  [584] = 584,
  [585] = 568,
  [586] = 566,
  [587] = 570,
  [588] = 570,
  [589] = 568,
  [590] = 566,
  [591] = 570,
  [592] = 568,
  [593] = 566,
  [594] = 570,
  [595] = 574,
  [596] = 568,
  [597] = 566,
  [598] = 570,
  [599] = 568,
  [600] = 566,
  [601] = 570,
  [602] = 602,
  [603] = 568,
  [604] = 566,
  [605] = 570,
  [606] = 606,
  [607] = 568,
  [608] = 566,
  [609] = 570,
  [610] = 568,
  [611] = 566,
  [612] = 570,
  [613] = 568,
  [614] = 566,
  [615] = 570,
  [616] = 566,
  [617] = 570,
  [618] = 568,
  [619] = 566,
  [620] = 570,
  [621] = 568,
  [622] = 566,
  [623] = 570,
  [624] = 568,
  [625] = 566,
  [626] = 570,
  [627] = 568,
  [628] = 566,
  [629] = 570,
  [630] = 568,
  [631] = 566,
  [632] = 570,
  [633] = 568,
  [634] = 566,
  [635] = 570,
  [636] = 568,
  [637] = 566,
  [638] = 570,
  [639] = 568,
  [640] = 566,
  [641] = 570,
  [642] = 568,
  [643] = 566,
  [644] = 570,
  [645] = 568,
  [646] = 566,
  [647] = 570,
  [648] = 568,
  [649] = 566,
  [650] = 570,
  [651] = 568,
  [652] = 566,
  [653] = 570,
  [654] = 566,
  [655] = 655,
  [656] = 574,
  [657] = 568,
  [658] = 566,
  [659] = 570,
  [660] = 660,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 668,
  [669] = 669,
  [670] = 670,
  [671] = 671,
  [672] = 672,
  [673] = 673,
  [674] = 674,
  [675] = 675,
  [676] = 566,
  [677] = 568,
  [678] = 570,
  [679] = 568,
  [680] = 570,
  [681] = 681,
  [682] = 682,
  [683] = 683,
  [684] = 684,
  [685] = 568,
  [686] = 566,
  [687] = 570,
  [688] = 568,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 693,
  [694] = 694,
  [695] = 695,
  [696] = 696,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 700,
  [701] = 701,
  [702] = 702,
  [703] = 703,
  [704] = 704,
  [705] = 705,
  [706] = 706,
  [707] = 665,
  [708] = 708,
  [709] = 709,
  [710] = 667,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 669,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 671,
  [721] = 721,
  [722] = 722,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 665,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 738,
  [739] = 739,
  [740] = 740,
  [741] = 741,
  [742] = 742,
  [743] = 743,
  [744] = 744,
  [745] = 745,
  [746] = 746,
  [747] = 747,
  [748] = 748,
  [749] = 749,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 763,
  [764] = 764,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 773,
  [774] = 675,
  [775] = 683,
  [776] = 667,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 669,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 804,
  [805] = 805,
  [806] = 806,
  [807] = 671,
  [808] = 808,
  [809] = 809,
  [810] = 675,
  [811] = 683,
  [812] = 812,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 815,
  [843] = 843,
  [844] = 844,
  [845] = 845,
  [846] = 846,
  [847] = 739,
  [848] = 848,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 852,
  [853] = 853,
  [854] = 854,
  [855] = 855,
  [856] = 856,
  [857] = 857,
  [858] = 858,
  [859] = 815,
  [860] = 815,
  [861] = 815,
  [862] = 815,
  [863] = 815,
  [864] = 815,
  [865] = 815,
  [866] = 815,
  [867] = 815,
  [868] = 815,
  [869] = 815,
  [870] = 870,
  [871] = 871,
  [872] = 872,
  [873] = 873,
  [874] = 874,
  [875] = 875,
  [876] = 876,
  [877] = 527,
  [878] = 878,
  [879] = 663,
  [880] = 880,
  [881] = 666,
  [882] = 882,
  [883] = 883,
  [884] = 668,
  [885] = 885,
  [886] = 886,
  [887] = 672,
  [888] = 681,
  [889] = 682,
  [890] = 684,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 895,
  [896] = 896,
  [897] = 897,
  [898] = 898,
  [899] = 899,
  [900] = 900,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 561,
  [905] = 905,
  [906] = 906,
  [907] = 533,
  [908] = 908,
  [909] = 909,
  [910] = 910,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 893,
  [915] = 915,
  [916] = 896,
  [917] = 912,
  [918] = 880,
  [919] = 892,
  [920] = 895,
  [921] = 897,
  [922] = 901,
  [923] = 902,
  [924] = 910,
  [925] = 911,
  [926] = 913,
  [927] = 663,
  [928] = 666,
  [929] = 668,
  [930] = 672,
  [931] = 681,
  [932] = 682,
  [933] = 684,
  [934] = 893,
  [935] = 915,
  [936] = 896,
  [937] = 912,
  [938] = 880,
  [939] = 895,
  [940] = 897,
  [941] = 901,
  [942] = 902,
  [943] = 910,
  [944] = 911,
  [945] = 913,
  [946] = 946,
  [947] = 893,
  [948] = 915,
  [949] = 896,
  [950] = 912,
  [951] = 894,
  [952] = 880,
  [953] = 895,
  [954] = 897,
  [955] = 901,
  [956] = 902,
  [957] = 910,
  [958] = 911,
  [959] = 913,
  [960] = 893,
  [961] = 915,
  [962] = 896,
  [963] = 912,
  [964] = 880,
  [965] = 895,
  [966] = 897,
  [967] = 901,
  [968] = 902,
  [969] = 910,
  [970] = 915,
  [971] = 911,
  [972] = 899,
  [973] = 913,
  [974] = 893,
  [975] = 900,
  [976] = 915,
  [977] = 896,
  [978] = 912,
  [979] = 880,
  [980] = 895,
  [981] = 897,
  [982] = 901,
  [983] = 902,
  [984] = 910,
  [985] = 911,
  [986] = 913,
  [987] = 893,
  [988] = 915,
  [989] = 896,
  [990] = 912,
  [991] = 880,
  [992] = 895,
  [993] = 897,
  [994] = 901,
  [995] = 902,
  [996] = 910,
  [997] = 909,
  [998] = 911,
  [999] = 913,
  [1000] = 893,
  [1001] = 915,
  [1002] = 896,
  [1003] = 912,
  [1004] = 880,
  [1005] = 895,
  [1006] = 897,
  [1007] = 901,
  [1008] = 902,
  [1009] = 910,
  [1010] = 911,
  [1011] = 913,
  [1012] = 893,
  [1013] = 915,
  [1014] = 896,
  [1015] = 912,
  [1016] = 880,
  [1017] = 895,
  [1018] = 897,
  [1019] = 901,
  [1020] = 902,
  [1021] = 910,
  [1022] = 911,
  [1023] = 913,
  [1024] = 893,
  [1025] = 915,
  [1026] = 896,
  [1027] = 912,
  [1028] = 880,
  [1029] = 895,
  [1030] = 897,
  [1031] = 901,
  [1032] = 902,
  [1033] = 910,
  [1034] = 911,
  [1035] = 913,
  [1036] = 893,
  [1037] = 915,
  [1038] = 896,
  [1039] = 912,
  [1040] = 880,
  [1041] = 895,
  [1042] = 897,
  [1043] = 901,
  [1044] = 902,
  [1045] = 910,
  [1046] = 911,
  [1047] = 913,
  [1048] = 893,
  [1049] = 915,
  [1050] = 896,
  [1051] = 912,
  [1052] = 880,
  [1053] = 895,
  [1054] = 897,
  [1055] = 901,
  [1056] = 902,
  [1057] = 910,
  [1058] = 911,
  [1059] = 913,
  [1060] = 893,
  [1061] = 915,
  [1062] = 896,
  [1063] = 912,
  [1064] = 880,
  [1065] = 895,
  [1066] = 897,
  [1067] = 901,
  [1068] = 902,
  [1069] = 910,
  [1070] = 911,
  [1071] = 913,
  [1072] = 946,
  [1073] = 898,
  [1074] = 903,
  [1075] = 878,
  [1076] = 882,
  [1077] = 883,
  [1078] = 885,
  [1079] = 898,
  [1080] = 903,
  [1081] = 878,
  [1082] = 882,
  [1083] = 883,
  [1084] = 885,
  [1085] = 898,
  [1086] = 903,
  [1087] = 878,
  [1088] = 882,
  [1089] = 883,
  [1090] = 885,
  [1091] = 898,
  [1092] = 903,
  [1093] = 906,
  [1094] = 882,
  [1095] = 883,
  [1096] = 885,
  [1097] = 898,
  [1098] = 903,
  [1099] = 878,
  [1100] = 882,
  [1101] = 883,
  [1102] = 885,
  [1103] = 898,
  [1104] = 903,
  [1105] = 878,
  [1106] = 882,
  [1107] = 883,
  [1108] = 885,
  [1109] = 898,
  [1110] = 903,
  [1111] = 878,
  [1112] = 882,
  [1113] = 883,
  [1114] = 885,
  [1115] = 898,
  [1116] = 903,
  [1117] = 878,
  [1118] = 882,
  [1119] = 883,
  [1120] = 885,
  [1121] = 898,
  [1122] = 903,
  [1123] = 878,
  [1124] = 882,
  [1125] = 883,
  [1126] = 885,
  [1127] = 898,
  [1128] = 903,
  [1129] = 878,
  [1130] = 882,
  [1131] = 883,
  [1132] = 885,
  [1133] = 898,
  [1134] = 903,
  [1135] = 878,
  [1136] = 882,
  [1137] = 883,
  [1138] = 885,
  [1139] = 898,
  [1140] = 903,
  [1141] = 878,
  [1142] = 882,
  [1143] = 883,
  [1144] = 885,
  [1145] = 898,
  [1146] = 903,
  [1147] = 878,
  [1148] = 882,
  [1149] = 883,
  [1150] = 885,
  [1151] = 898,
  [1152] = 903,
  [1153] = 878,
  [1154] = 882,
  [1155] = 883,
  [1156] = 885,
  [1157] = 898,
  [1158] = 903,
  [1159] = 878,
  [1160] = 883,
  [1161] = 885,
  [1162] = 898,
  [1163] = 903,
  [1164] = 878,
  [1165] = 883,
  [1166] = 885,
  [1167] = 898,
  [1168] = 878,
  [1169] = 883,
  [1170] = 885,
  [1171] = 898,
  [1172] = 878,
  [1173] = 883,
  [1174] = 885,
  [1175] = 898,
  [1176] = 878,
  [1177] = 883,
  [1178] = 885,
  [1179] = 898,
  [1180] = 878,
  [1181] = 883,
  [1182] = 885,
  [1183] = 898,
  [1184] = 878,
  [1185] = 883,
  [1186] = 885,
  [1187] = 898,
  [1188] = 878,
  [1189] = 883,
  [1190] = 885,
  [1191] = 898,
  [1192] = 878,
  [1193] = 883,
  [1194] = 885,
  [1195] = 898,
  [1196] = 878,
  [1197] = 883,
  [1198] = 885,
  [1199] = 898,
  [1200] = 878,
  [1201] = 883,
  [1202] = 885,
  [1203] = 898,
  [1204] = 878,
  [1205] = 883,
  [1206] = 885,
  [1207] = 898,
  [1208] = 878,
  [1209] = 885,
  [1210] = 898,
  [1211] = 878,
  [1212] = 885,
  [1213] = 898,
  [1214] = 878,
  [1215] = 885,
  [1216] = 905,
  [1217] = 883,
  [1218] = 878,
  [1219] = 898,
  [1220] = 883,
  [1221] = 885,
  [1222] = 883,
  [1223] = 898,
  [1224] = 885,
  [1225] = 878,
  [1226] = 905,
  [1227] = 905,
  [1228] = 905,
  [1229] = 905,
  [1230] = 905,
  [1231] = 905,
  [1232] = 905,
  [1233] = 905,
  [1234] = 905,
  [1235] = 905,
  [1236] = 905,
  [1237] = 905,
  [1238] = 905,
  [1239] = 905,
  [1240] = 905,
  [1241] = 905,
  [1242] = 905,
  [1243] = 905,
  [1244] = 905,
  [1245] = 905,
  [1246] = 905,
  [1247] = 905,
  [1248] = 905,
  [1249] = 905,
  [1250] = 905,
  [1251] = 905,
  [1252] = 906,
  [1253] = 905,
  [1254] = 905,
  [1255] = 906,
  [1256] = 906,
  [1257] = 906,
  [1258] = 906,
  [1259] = 906,
  [1260] = 906,
  [1261] = 906,
  [1262] = 906,
  [1263] = 906,
  [1264] = 906,
  [1265] = 906,
  [1266] = 906,
  [1267] = 878,
  [1268] = 527,
  [1269] = 662,
  [1270] = 670,
  [1271] = 674,
  [1272] = 567,
  [1273] = 1273,
  [1274] = 1274,
  [1275] = 1275,
  [1276] = 1276,
  [1277] = 1277,
  [1278] = 561,
  [1279] = 533,
  [1280] = 527,
  [1281] = 1281,
  [1282] = 1282,
  [1283] = 1283,
  [1284] = 1284,
  [1285] = 670,
  [1286] = 1275,
  [1287] = 1287,
  [1288] = 1288,
  [1289] = 1289,
  [1290] = 1273,
  [1291] = 1276,
  [1292] = 1281,
  [1293] = 1282,
  [1294] = 1283,
  [1295] = 1284,
  [1296] = 1275,
  [1297] = 1287,
  [1298] = 1288,
  [1299] = 1289,
  [1300] = 1273,
  [1301] = 1281,
  [1302] = 1282,
  [1303] = 1283,
  [1304] = 1284,
  [1305] = 534,
  [1306] = 535,
  [1307] = 532,
  [1308] = 542,
  [1309] = 520,
  [1310] = 521,
  [1311] = 545,
  [1312] = 522,
  [1313] = 524,
  [1314] = 525,
  [1315] = 526,
  [1316] = 1275,
  [1317] = 1287,
  [1318] = 1288,
  [1319] = 1289,
  [1320] = 1273,
  [1321] = 1276,
  [1322] = 1281,
  [1323] = 1282,
  [1324] = 1283,
  [1325] = 1284,
  [1326] = 1275,
  [1327] = 1287,
  [1328] = 1288,
  [1329] = 1289,
  [1330] = 1273,
  [1331] = 1281,
  [1332] = 1282,
  [1333] = 1283,
  [1334] = 1284,
  [1335] = 1275,
  [1336] = 1287,
  [1337] = 1288,
  [1338] = 1289,
  [1339] = 1273,
  [1340] = 1276,
  [1341] = 1281,
  [1342] = 1282,
  [1343] = 1283,
  [1344] = 1284,
  [1345] = 1275,
  [1346] = 1287,
  [1347] = 1288,
  [1348] = 1289,
  [1349] = 1273,
  [1350] = 1276,
  [1351] = 1281,
  [1352] = 1282,
  [1353] = 1283,
  [1354] = 1284,
  [1355] = 1275,
  [1356] = 1287,
  [1357] = 1357,
  [1358] = 1288,
  [1359] = 1289,
  [1360] = 1273,
  [1361] = 1276,
  [1362] = 1281,
  [1363] = 1282,
  [1364] = 1283,
  [1365] = 1284,
  [1366] = 1275,
  [1367] = 1287,
  [1368] = 533,
  [1369] = 1289,
  [1370] = 1273,
  [1371] = 1276,
  [1372] = 1281,
  [1373] = 1282,
  [1374] = 1283,
  [1375] = 1284,
  [1376] = 1275,
  [1377] = 1287,
  [1378] = 1288,
  [1379] = 1289,
  [1380] = 1273,
  [1381] = 1276,
  [1382] = 1281,
  [1383] = 1282,
  [1384] = 1283,
  [1385] = 1284,
  [1386] = 1275,
  [1387] = 1287,
  [1388] = 1288,
  [1389] = 1289,
  [1390] = 1273,
  [1391] = 1276,
  [1392] = 1287,
  [1393] = 1281,
  [1394] = 1282,
  [1395] = 1283,
  [1396] = 1284,
  [1397] = 534,
  [1398] = 1275,
  [1399] = 535,
  [1400] = 1287,
  [1401] = 1288,
  [1402] = 1289,
  [1403] = 1273,
  [1404] = 544,
  [1405] = 1276,
  [1406] = 532,
  [1407] = 1281,
  [1408] = 1282,
  [1409] = 1283,
  [1410] = 1284,
  [1411] = 542,
  [1412] = 1275,
  [1413] = 520,
  [1414] = 521,
  [1415] = 1287,
  [1416] = 545,
  [1417] = 1288,
  [1418] = 1289,
  [1419] = 1273,
  [1420] = 1276,
  [1421] = 1281,
  [1422] = 1282,
  [1423] = 1283,
  [1424] = 1284,
  [1425] = 584,
  [1426] = 522,
  [1427] = 1427,
  [1428] = 524,
  [1429] = 525,
  [1430] = 526,
  [1431] = 1427,
  [1432] = 1427,
  [1433] = 1427,
  [1434] = 1427,
  [1435] = 1435,
  [1436] = 1427,
  [1437] = 1427,
  [1438] = 1427,
  [1439] = 1427,
  [1440] = 1427,
  [1441] = 1427,
  [1442] = 1427,
  [1443] = 1427,
  [1444] = 1288,
  [1445] = 1445,
  [1446] = 606,
  [1447] = 561,
  [1448] = 567,
  [1449] = 1289,
  [1450] = 1450,
  [1451] = 662,
  [1452] = 1288,
  [1453] = 1453,
  [1454] = 1454,
  [1455] = 1455,
  [1456] = 843,
  [1457] = 1457,
  [1458] = 706,
  [1459] = 870,
  [1460] = 709,
  [1461] = 1461,
  [1462] = 837,
  [1463] = 1463,
  [1464] = 1464,
  [1465] = 1465,
  [1466] = 841,
  [1467] = 1467,
  [1468] = 662,
  [1469] = 1469,
  [1470] = 670,
  [1471] = 674,
  [1472] = 1472,
  [1473] = 1473,
  [1474] = 567,
  [1475] = 1475,
  [1476] = 1476,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1479,
  [1480] = 1480,
  [1481] = 1481,
  [1482] = 1482,
  [1483] = 1483,
  [1484] = 1484,
  [1485] = 1485,
  [1486] = 1486,
  [1487] = 1487,
  [1488] = 1488,
  [1489] = 1489,
  [1490] = 660,
  [1491] = 1491,
  [1492] = 1492,
  [1493] = 1493,
  [1494] = 1494,
  [1495] = 1495,
  [1496] = 1494,
  [1497] = 1497,
  [1498] = 1498,
  [1499] = 1499,
  [1500] = 1500,
  [1501] = 1453,
  [1502] = 1502,
  [1503] = 1457,
  [1504] = 1464,
  [1505] = 1467,
  [1506] = 1469,
  [1507] = 1472,
  [1508] = 1477,
  [1509] = 1478,
  [1510] = 1481,
  [1511] = 1493,
  [1512] = 1512,
  [1513] = 1513,
  [1514] = 1491,
  [1515] = 1515,
  [1516] = 1495,
  [1517] = 674,
  [1518] = 1502,
  [1519] = 823,
  [1520] = 1520,
  [1521] = 1521,
  [1522] = 1522,
  [1523] = 1523,
  [1524] = 663,
  [1525] = 665,
  [1526] = 666,
  [1527] = 667,
  [1528] = 668,
  [1529] = 669,
  [1530] = 781,
  [1531] = 671,
  [1532] = 672,
  [1533] = 1522,
  [1534] = 675,
  [1535] = 681,
  [1536] = 682,
  [1537] = 683,
  [1538] = 684,
  [1539] = 1539,
  [1540] = 1491,
  [1541] = 1541,
  [1542] = 1495,
  [1543] = 1543,
  [1544] = 1544,
  [1545] = 1497,
  [1546] = 1463,
  [1547] = 1502,
  [1548] = 1539,
  [1549] = 1541,
  [1550] = 1550,
  [1551] = 786,
  [1552] = 1491,
  [1553] = 1488,
  [1554] = 1495,
  [1555] = 1498,
  [1556] = 1502,
  [1557] = 1557,
  [1558] = 790,
  [1559] = 1559,
  [1560] = 1491,
  [1561] = 1495,
  [1562] = 1502,
  [1563] = 1485,
  [1564] = 1486,
  [1565] = 1487,
  [1566] = 1488,
  [1567] = 1491,
  [1568] = 793,
  [1569] = 1494,
  [1570] = 1495,
  [1571] = 1497,
  [1572] = 1498,
  [1573] = 1573,
  [1574] = 1499,
  [1575] = 1502,
  [1576] = 1500,
  [1577] = 1577,
  [1578] = 1453,
  [1579] = 1457,
  [1580] = 1464,
  [1581] = 1467,
  [1582] = 1469,
  [1583] = 1472,
  [1584] = 1477,
  [1585] = 1491,
  [1586] = 1478,
  [1587] = 794,
  [1588] = 1481,
  [1589] = 1495,
  [1590] = 1502,
  [1591] = 1522,
  [1592] = 1499,
  [1593] = 1539,
  [1594] = 796,
  [1595] = 1539,
  [1596] = 1541,
  [1597] = 1491,
  [1598] = 1500,
  [1599] = 1495,
  [1600] = 798,
  [1601] = 1523,
  [1602] = 1602,
  [1603] = 1493,
  [1604] = 1604,
  [1605] = 1502,
  [1606] = 1453,
  [1607] = 1607,
  [1608] = 799,
  [1609] = 1491,
  [1610] = 1495,
  [1611] = 1485,
  [1612] = 1485,
  [1613] = 1486,
  [1614] = 1486,
  [1615] = 1487,
  [1616] = 1502,
  [1617] = 1488,
  [1618] = 1487,
  [1619] = 1494,
  [1620] = 1488,
  [1621] = 1497,
  [1622] = 800,
  [1623] = 1498,
  [1624] = 802,
  [1625] = 803,
  [1626] = 1494,
  [1627] = 1497,
  [1628] = 1499,
  [1629] = 1500,
  [1630] = 1491,
  [1631] = 1453,
  [1632] = 1498,
  [1633] = 1457,
  [1634] = 1495,
  [1635] = 1464,
  [1636] = 1499,
  [1637] = 1467,
  [1638] = 1500,
  [1639] = 1469,
  [1640] = 1502,
  [1641] = 1472,
  [1642] = 1453,
  [1643] = 1477,
  [1644] = 1478,
  [1645] = 1457,
  [1646] = 1481,
  [1647] = 1464,
  [1648] = 1485,
  [1649] = 1467,
  [1650] = 1469,
  [1651] = 1472,
  [1652] = 1477,
  [1653] = 1478,
  [1654] = 1481,
  [1655] = 1486,
  [1656] = 1487,
  [1657] = 1488,
  [1658] = 1491,
  [1659] = 814,
  [1660] = 1495,
  [1661] = 816,
  [1662] = 1522,
  [1663] = 1487,
  [1664] = 1539,
  [1665] = 1502,
  [1666] = 1541,
  [1667] = 818,
  [1668] = 1493,
  [1669] = 1494,
  [1670] = 1497,
  [1671] = 1498,
  [1672] = 1499,
  [1673] = 1522,
  [1674] = 1500,
  [1675] = 1494,
  [1676] = 825,
  [1677] = 1497,
  [1678] = 846,
  [1679] = 1539,
  [1680] = 1541,
  [1681] = 1453,
  [1682] = 1457,
  [1683] = 1464,
  [1684] = 1457,
  [1685] = 1491,
  [1686] = 1467,
  [1687] = 1469,
  [1688] = 1472,
  [1689] = 1498,
  [1690] = 852,
  [1691] = 853,
  [1692] = 1477,
  [1693] = 854,
  [1694] = 856,
  [1695] = 871,
  [1696] = 1478,
  [1697] = 1481,
  [1698] = 661,
  [1699] = 872,
  [1700] = 1539,
  [1701] = 873,
  [1702] = 1541,
  [1703] = 874,
  [1704] = 875,
  [1705] = 734,
  [1706] = 835,
  [1707] = 1521,
  [1708] = 1522,
  [1709] = 844,
  [1710] = 723,
  [1711] = 1491,
  [1712] = 1539,
  [1713] = 1541,
  [1714] = 1544,
  [1715] = 726,
  [1716] = 857,
  [1717] = 757,
  [1718] = 1521,
  [1719] = 728,
  [1720] = 1720,
  [1721] = 1721,
  [1722] = 730,
  [1723] = 737,
  [1724] = 1559,
  [1725] = 1725,
  [1726] = 664,
  [1727] = 742,
  [1728] = 1515,
  [1729] = 1607,
  [1730] = 1730,
  [1731] = 1731,
  [1732] = 1732,
  [1733] = 1455,
  [1734] = 1461,
  [1735] = 745,
  [1736] = 1720,
  [1737] = 1721,
  [1738] = 1485,
  [1739] = 1486,
  [1740] = 1487,
  [1741] = 1488,
  [1742] = 1515,
  [1743] = 1607,
  [1744] = 1730,
  [1745] = 1731,
  [1746] = 1732,
  [1747] = 1455,
  [1748] = 1461,
  [1749] = 747,
  [1750] = 1720,
  [1751] = 1721,
  [1752] = 1494,
  [1753] = 1497,
  [1754] = 1498,
  [1755] = 1499,
  [1756] = 1500,
  [1757] = 1453,
  [1758] = 1515,
  [1759] = 1607,
  [1760] = 1730,
  [1761] = 1731,
  [1762] = 1732,
  [1763] = 1455,
  [1764] = 1461,
  [1765] = 1765,
  [1766] = 1720,
  [1767] = 1721,
  [1768] = 1457,
  [1769] = 1464,
  [1770] = 1467,
  [1771] = 1469,
  [1772] = 1472,
  [1773] = 1477,
  [1774] = 1515,
  [1775] = 1607,
  [1776] = 1730,
  [1777] = 1731,
  [1778] = 1732,
  [1779] = 1455,
  [1780] = 1461,
  [1781] = 748,
  [1782] = 1720,
  [1783] = 1721,
  [1784] = 1478,
  [1785] = 1481,
  [1786] = 749,
  [1787] = 1464,
  [1788] = 1522,
  [1789] = 1539,
  [1790] = 1515,
  [1791] = 1607,
  [1792] = 1730,
  [1793] = 1731,
  [1794] = 1732,
  [1795] = 1455,
  [1796] = 1461,
  [1797] = 1797,
  [1798] = 1720,
  [1799] = 1721,
  [1800] = 1541,
  [1801] = 1467,
  [1802] = 1802,
  [1803] = 1485,
  [1804] = 1515,
  [1805] = 1607,
  [1806] = 1730,
  [1807] = 1731,
  [1808] = 1732,
  [1809] = 1455,
  [1810] = 750,
  [1811] = 1720,
  [1812] = 1721,
  [1813] = 1486,
  [1814] = 1487,
  [1815] = 1488,
  [1816] = 1494,
  [1817] = 1497,
  [1818] = 1498,
  [1819] = 1515,
  [1820] = 1607,
  [1821] = 1730,
  [1822] = 1731,
  [1823] = 1732,
  [1824] = 1455,
  [1825] = 1461,
  [1826] = 761,
  [1827] = 1720,
  [1828] = 1721,
  [1829] = 1499,
  [1830] = 1500,
  [1831] = 1453,
  [1832] = 1457,
  [1833] = 1464,
  [1834] = 1467,
  [1835] = 1515,
  [1836] = 1607,
  [1837] = 1730,
  [1838] = 1731,
  [1839] = 1732,
  [1840] = 1455,
  [1841] = 1461,
  [1842] = 763,
  [1843] = 1720,
  [1844] = 1721,
  [1845] = 1469,
  [1846] = 1472,
  [1847] = 1477,
  [1848] = 1478,
  [1849] = 1481,
  [1850] = 1469,
  [1851] = 1515,
  [1852] = 1607,
  [1853] = 1730,
  [1854] = 1731,
  [1855] = 1732,
  [1856] = 1455,
  [1857] = 1461,
  [1858] = 764,
  [1859] = 1720,
  [1860] = 1721,
  [1861] = 1472,
  [1862] = 1477,
  [1863] = 1522,
  [1864] = 1539,
  [1865] = 1541,
  [1866] = 673,
  [1867] = 1515,
  [1868] = 1607,
  [1869] = 1730,
  [1870] = 1731,
  [1871] = 1732,
  [1872] = 1455,
  [1873] = 1461,
  [1874] = 1874,
  [1875] = 1720,
  [1876] = 1721,
  [1877] = 1485,
  [1878] = 1486,
  [1879] = 1487,
  [1880] = 1488,
  [1881] = 1494,
  [1882] = 1515,
  [1883] = 1607,
  [1884] = 1730,
  [1885] = 1731,
  [1886] = 1732,
  [1887] = 1455,
  [1888] = 1461,
  [1889] = 1720,
  [1890] = 1721,
  [1891] = 1497,
  [1892] = 1498,
  [1893] = 1499,
  [1894] = 1500,
  [1895] = 1453,
  [1896] = 1457,
  [1897] = 1515,
  [1898] = 1607,
  [1899] = 1730,
  [1900] = 1731,
  [1901] = 1732,
  [1902] = 1455,
  [1903] = 1461,
  [1904] = 1464,
  [1905] = 1467,
  [1906] = 1469,
  [1907] = 1472,
  [1908] = 1477,
  [1909] = 1478,
  [1910] = 1730,
  [1911] = 1732,
  [1912] = 1461,
  [1913] = 1481,
  [1914] = 1914,
  [1915] = 1478,
  [1916] = 1522,
  [1917] = 792,
  [1918] = 1539,
  [1919] = 1730,
  [1920] = 1732,
  [1921] = 1461,
  [1922] = 1541,
  [1923] = 1481,
  [1924] = 1924,
  [1925] = 1485,
  [1926] = 1486,
  [1927] = 1730,
  [1928] = 1732,
  [1929] = 1461,
  [1930] = 1487,
  [1931] = 1488,
  [1932] = 1494,
  [1933] = 1497,
  [1934] = 1498,
  [1935] = 1730,
  [1936] = 1732,
  [1937] = 1461,
  [1938] = 1499,
  [1939] = 1500,
  [1940] = 1453,
  [1941] = 1457,
  [1942] = 1464,
  [1943] = 1467,
  [1944] = 1469,
  [1945] = 1472,
  [1946] = 1477,
  [1947] = 1478,
  [1948] = 1481,
  [1949] = 1949,
  [1950] = 1522,
  [1951] = 1541,
  [1952] = 1720,
  [1953] = 1539,
  [1954] = 1541,
  [1955] = 1721,
  [1956] = 1544,
  [1957] = 1957,
  [1958] = 832,
  [1959] = 1485,
  [1960] = 1486,
  [1961] = 1487,
  [1962] = 1488,
  [1963] = 1963,
  [1964] = 1964,
  [1965] = 1499,
  [1966] = 1730,
  [1967] = 1494,
  [1968] = 1497,
  [1969] = 1498,
  [1970] = 1499,
  [1971] = 1500,
  [1972] = 1453,
  [1973] = 1457,
  [1974] = 1464,
  [1975] = 1467,
  [1976] = 1469,
  [1977] = 1472,
  [1978] = 1477,
  [1979] = 1478,
  [1980] = 1481,
  [1981] = 704,
  [1982] = 1731,
  [1983] = 1485,
  [1984] = 1486,
  [1985] = 1487,
  [1986] = 1488,
  [1987] = 1493,
  [1988] = 1491,
  [1989] = 1494,
  [1990] = 1497,
  [1991] = 1498,
  [1992] = 1499,
  [1993] = 1500,
  [1994] = 1453,
  [1995] = 1457,
  [1996] = 1464,
  [1997] = 1467,
  [1998] = 1469,
  [1999] = 1472,
  [2000] = 1477,
  [2001] = 1478,
  [2002] = 1481,
  [2003] = 797,
  [2004] = 1495,
  [2005] = 1522,
  [2006] = 1557,
  [2007] = 1539,
  [2008] = 1541,
  [2009] = 1485,
  [2010] = 1486,
  [2011] = 1502,
  [2012] = 1487,
  [2013] = 1488,
  [2014] = 1500,
  [2015] = 1485,
  [2016] = 1486,
  [2017] = 1487,
  [2018] = 1488,
  [2019] = 1494,
  [2020] = 1497,
  [2021] = 1498,
  [2022] = 1499,
  [2023] = 1500,
  [2024] = 1453,
  [2025] = 1457,
  [2026] = 1464,
  [2027] = 1467,
  [2028] = 1469,
  [2029] = 1472,
  [2030] = 1477,
  [2031] = 1478,
  [2032] = 1481,
  [2033] = 1522,
  [2034] = 1539,
  [2035] = 1541,
  [2036] = 1485,
  [2037] = 1486,
  [2038] = 1487,
  [2039] = 1488,
  [2040] = 602,
  [2041] = 1494,
  [2042] = 1497,
  [2043] = 1498,
  [2044] = 1499,
  [2045] = 1500,
  [2046] = 1453,
  [2047] = 1457,
  [2048] = 1464,
  [2049] = 1467,
  [2050] = 1469,
  [2051] = 1472,
  [2052] = 1477,
  [2053] = 1478,
  [2054] = 1481,
  [2055] = 1522,
  [2056] = 1539,
  [2057] = 1541,
  [2058] = 1485,
  [2059] = 1486,
  [2060] = 1487,
  [2061] = 1488,
  [2062] = 1494,
  [2063] = 1497,
  [2064] = 1498,
  [2065] = 1499,
  [2066] = 1500,
  [2067] = 1453,
  [2068] = 1457,
  [2069] = 1464,
  [2070] = 1467,
  [2071] = 1469,
  [2072] = 1472,
  [2073] = 1477,
  [2074] = 1478,
  [2075] = 1481,
  [2076] = 1522,
  [2077] = 1539,
  [2078] = 1541,
  [2079] = 1491,
  [2080] = 1602,
  [2081] = 1491,
  [2082] = 1495,
  [2083] = 1502,
  [2084] = 1491,
  [2085] = 1493,
  [2086] = 1494,
  [2087] = 1720,
  [2088] = 1721,
  [2089] = 2089,
  [2090] = 2090,
  [2091] = 1497,
  [2092] = 1720,
  [2093] = 1721,
  [2094] = 1485,
  [2095] = 1720,
  [2096] = 1721,
  [2097] = 1486,
  [2098] = 712,
  [2099] = 2099,
  [2100] = 2100,
  [2101] = 1522,
  [2102] = 584,
  [2103] = 1539,
  [2104] = 1541,
  [2105] = 714,
  [2106] = 2106,
  [2107] = 1522,
  [2108] = 2108,
  [2109] = 717,
  [2110] = 1522,
  [2111] = 2111,
  [2112] = 2112,
  [2113] = 1502,
  [2114] = 2114,
  [2115] = 2115,
  [2116] = 1732,
  [2117] = 2117,
  [2118] = 2118,
  [2119] = 1573,
  [2120] = 2120,
  [2121] = 2121,
  [2122] = 1498,
  [2123] = 2118,
  [2124] = 1485,
  [2125] = 1499,
  [2126] = 1500,
  [2127] = 1486,
  [2128] = 1453,
  [2129] = 1492,
  [2130] = 1457,
  [2131] = 1464,
  [2132] = 1467,
  [2133] = 1469,
  [2134] = 1472,
  [2135] = 1477,
  [2136] = 1478,
  [2137] = 1481,
  [2138] = 660,
  [2139] = 1485,
  [2140] = 1486,
  [2141] = 1487,
  [2142] = 1488,
  [2143] = 1494,
  [2144] = 1497,
  [2145] = 1498,
  [2146] = 1499,
  [2147] = 1500,
  [2148] = 1453,
  [2149] = 1457,
  [2150] = 1464,
  [2151] = 1467,
  [2152] = 1469,
  [2153] = 1472,
  [2154] = 1477,
  [2155] = 1478,
  [2156] = 1481,
  [2157] = 1522,
  [2158] = 1539,
  [2159] = 1541,
  [2160] = 1720,
  [2161] = 1721,
  [2162] = 1487,
  [2163] = 1495,
  [2164] = 2118,
  [2165] = 1488,
  [2166] = 1492,
  [2167] = 2118,
  [2168] = 1492,
  [2169] = 2118,
  [2170] = 602,
  [2171] = 1492,
  [2172] = 2118,
  [2173] = 606,
  [2174] = 1492,
  [2175] = 2118,
  [2176] = 1492,
  [2177] = 2118,
  [2178] = 1492,
  [2179] = 2118,
  [2180] = 1492,
  [2181] = 2118,
  [2182] = 719,
  [2183] = 1492,
  [2184] = 2118,
  [2185] = 1492,
  [2186] = 2118,
  [2187] = 1492,
  [2188] = 2188,
  [2189] = 2118,
  [2190] = 1492,
  [2191] = 1492,
  [2192] = 1492,
  [2193] = 1492,
  [2194] = 1492,
  [2195] = 1720,
  [2196] = 1721,
  [2197] = 1802,
  [2198] = 1479,
  [2199] = 1479,
  [2200] = 1479,
  [2201] = 1479,
  [2202] = 1479,
  [2203] = 1479,
  [2204] = 1512,
  [2205] = 1963,
  [2206] = 1463,
  [2207] = 1463,
  [2208] = 1463,
  [2209] = 1463,
  [2210] = 1463,
  [2211] = 1461,
  [2212] = 813,
  [2213] = 789,
  [2214] = 765,
  [2215] = 714,
  [2216] = 691,
  [2217] = 748,
  [2218] = 766,
  [2219] = 749,
  [2220] = 756,
  [2221] = 694,
  [2222] = 752,
  [2223] = 695,
  [2224] = 767,
  [2225] = 768,
  [2226] = 769,
  [2227] = 671,
  [2228] = 786,
  [2229] = 832,
  [2230] = 819,
  [2231] = 696,
  [2232] = 697,
  [2233] = 750,
  [2234] = 825,
  [2235] = 761,
  [2236] = 770,
  [2237] = 698,
  [2238] = 746,
  [2239] = 714,
  [2240] = 738,
  [2241] = 699,
  [2242] = 771,
  [2243] = 675,
  [2244] = 683,
  [2245] = 700,
  [2246] = 773,
  [2247] = 763,
  [2248] = 704,
  [2249] = 701,
  [2250] = 777,
  [2251] = 702,
  [2252] = 764,
  [2253] = 778,
  [2254] = 852,
  [2255] = 783,
  [2256] = 853,
  [2257] = 805,
  [2258] = 806,
  [2259] = 808,
  [2260] = 809,
  [2261] = 2261,
  [2262] = 770,
  [2263] = 822,
  [2264] = 854,
  [2265] = 719,
  [2266] = 771,
  [2267] = 826,
  [2268] = 772,
  [2269] = 856,
  [2270] = 871,
  [2271] = 812,
  [2272] = 717,
  [2273] = 813,
  [2274] = 703,
  [2275] = 872,
  [2276] = 715,
  [2277] = 790,
  [2278] = 873,
  [2279] = 856,
  [2280] = 820,
  [2281] = 872,
  [2282] = 873,
  [2283] = 874,
  [2284] = 823,
  [2285] = 874,
  [2286] = 875,
  [2287] = 824,
  [2288] = 835,
  [2289] = 828,
  [2290] = 829,
  [2291] = 830,
  [2292] = 833,
  [2293] = 793,
  [2294] = 875,
  [2295] = 780,
  [2296] = 870,
  [2297] = 723,
  [2298] = 726,
  [2299] = 734,
  [2300] = 850,
  [2301] = 754,
  [2302] = 836,
  [2303] = 839,
  [2304] = 840,
  [2305] = 781,
  [2306] = 837,
  [2307] = 755,
  [2308] = 845,
  [2309] = 858,
  [2310] = 788,
  [2311] = 848,
  [2312] = 779,
  [2313] = 849,
  [2314] = 817,
  [2315] = 753,
  [2316] = 821,
  [2317] = 782,
  [2318] = 785,
  [2319] = 851,
  [2320] = 789,
  [2321] = 691,
  [2322] = 728,
  [2323] = 730,
  [2324] = 835,
  [2325] = 689,
  [2326] = 786,
  [2327] = 694,
  [2328] = 773,
  [2329] = 777,
  [2330] = 706,
  [2331] = 737,
  [2332] = 778,
  [2333] = 695,
  [2334] = 783,
  [2335] = 805,
  [2336] = 806,
  [2337] = 534,
  [2338] = 535,
  [2339] = 696,
  [2340] = 800,
  [2341] = 790,
  [2342] = 793,
  [2343] = 697,
  [2344] = 735,
  [2345] = 532,
  [2346] = 802,
  [2347] = 698,
  [2348] = 841,
  [2349] = 542,
  [2350] = 699,
  [2351] = 700,
  [2352] = 803,
  [2353] = 689,
  [2354] = 876,
  [2355] = 701,
  [2356] = 794,
  [2357] = 796,
  [2358] = 520,
  [2359] = 798,
  [2360] = 702,
  [2361] = 799,
  [2362] = 521,
  [2363] = 545,
  [2364] = 522,
  [2365] = 524,
  [2366] = 525,
  [2367] = 526,
  [2368] = 808,
  [2369] = 809,
  [2370] = 794,
  [2371] = 718,
  [2372] = 844,
  [2373] = 797,
  [2374] = 834,
  [2375] = 742,
  [2376] = 745,
  [2377] = 747,
  [2378] = 838,
  [2379] = 757,
  [2380] = 812,
  [2381] = 740,
  [2382] = 690,
  [2383] = 851,
  [2384] = 846,
  [2385] = 820,
  [2386] = 692,
  [2387] = 748,
  [2388] = 723,
  [2389] = 693,
  [2390] = 726,
  [2391] = 749,
  [2392] = 852,
  [2393] = 728,
  [2394] = 853,
  [2395] = 705,
  [2396] = 708,
  [2397] = 772,
  [2398] = 711,
  [2399] = 722,
  [2400] = 730,
  [2401] = 798,
  [2402] = 750,
  [2403] = 761,
  [2404] = 727,
  [2405] = 831,
  [2406] = 731,
  [2407] = 799,
  [2408] = 763,
  [2409] = 764,
  [2410] = 792,
  [2411] = 732,
  [2412] = 736,
  [2413] = 738,
  [2414] = 791,
  [2415] = 740,
  [2416] = 797,
  [2417] = 744,
  [2418] = 870,
  [2419] = 762,
  [2420] = 725,
  [2421] = 784,
  [2422] = 843,
  [2423] = 746,
  [2424] = 721,
  [2425] = 876,
  [2426] = 837,
  [2427] = 751,
  [2428] = 665,
  [2429] = 843,
  [2430] = 706,
  [2431] = 709,
  [2432] = 832,
  [2433] = 841,
  [2434] = 735,
  [2435] = 767,
  [2436] = 819,
  [2437] = 834,
  [2438] = 838,
  [2439] = 690,
  [2440] = 692,
  [2441] = 693,
  [2442] = 705,
  [2443] = 708,
  [2444] = 711,
  [2445] = 722,
  [2446] = 727,
  [2447] = 731,
  [2448] = 732,
  [2449] = 744,
  [2450] = 751,
  [2451] = 765,
  [2452] = 737,
  [2453] = 719,
  [2454] = 758,
  [2455] = 768,
  [2456] = 769,
  [2457] = 822,
  [2458] = 733,
  [2459] = 667,
  [2460] = 871,
  [2461] = 824,
  [2462] = 1520,
  [2463] = 759,
  [2464] = 828,
  [2465] = 800,
  [2466] = 703,
  [2467] = 752,
  [2468] = 826,
  [2469] = 829,
  [2470] = 830,
  [2471] = 802,
  [2472] = 833,
  [2473] = 717,
  [2474] = 753,
  [2475] = 736,
  [2476] = 704,
  [2477] = 713,
  [2478] = 803,
  [2479] = 814,
  [2480] = 754,
  [2481] = 715,
  [2482] = 791,
  [2483] = 816,
  [2484] = 787,
  [2485] = 718,
  [2486] = 814,
  [2487] = 836,
  [2488] = 755,
  [2489] = 839,
  [2490] = 792,
  [2491] = 840,
  [2492] = 725,
  [2493] = 816,
  [2494] = 818,
  [2495] = 742,
  [2496] = 780,
  [2497] = 734,
  [2498] = 745,
  [2499] = 756,
  [2500] = 784,
  [2501] = 712,
  [2502] = 785,
  [2503] = 781,
  [2504] = 854,
  [2505] = 2505,
  [2506] = 669,
  [2507] = 758,
  [2508] = 850,
  [2509] = 747,
  [2510] = 709,
  [2511] = 858,
  [2512] = 845,
  [2513] = 788,
  [2514] = 779,
  [2515] = 766,
  [2516] = 713,
  [2517] = 848,
  [2518] = 759,
  [2519] = 801,
  [2520] = 849,
  [2521] = 818,
  [2522] = 782,
  [2523] = 760,
  [2524] = 825,
  [2525] = 846,
  [2526] = 760,
  [2527] = 712,
  [2528] = 762,
  [2529] = 857,
  [2530] = 796,
  [2531] = 527,
  [2532] = 2532,
  [2533] = 2532,
  [2534] = 2532,
  [2535] = 2532,
  [2536] = 2532,
  [2537] = 2532,
  [2538] = 2532,
  [2539] = 2539,
  [2540] = 2532,
  [2541] = 602,
  [2542] = 2532,
  [2543] = 561,
  [2544] = 2532,
  [2545] = 2532,
  [2546] = 2546,
  [2547] = 2532,
  [2548] = 2532,
  [2549] = 663,
  [2550] = 2532,
  [2551] = 2532,
  [2552] = 2532,
  [2553] = 666,
  [2554] = 2532,
  [2555] = 668,
  [2556] = 533,
  [2557] = 672,
  [2558] = 681,
  [2559] = 682,
  [2560] = 684,
  [2561] = 2261,
  [2562] = 834,
  [2563] = 711,
  [2564] = 722,
  [2565] = 768,
  [2566] = 769,
  [2567] = 708,
  [2568] = 567,
  [2569] = 690,
  [2570] = 751,
  [2571] = 665,
  [2572] = 838,
  [2573] = 727,
  [2574] = 2574,
  [2575] = 667,
  [2576] = 669,
  [2577] = 671,
  [2578] = 731,
  [2579] = 758,
  [2580] = 683,
  [2581] = 584,
  [2582] = 732,
  [2583] = 692,
  [2584] = 662,
  [2585] = 735,
  [2586] = 713,
  [2587] = 725,
  [2588] = 693,
  [2589] = 784,
  [2590] = 670,
  [2591] = 705,
  [2592] = 2592,
  [2593] = 2593,
  [2594] = 2594,
  [2595] = 674,
  [2596] = 744,
  [2597] = 2597,
  [2598] = 2598,
  [2599] = 2599,
  [2600] = 675,
  [2601] = 717,
  [2602] = 666,
  [2603] = 745,
  [2604] = 747,
  [2605] = 792,
  [2606] = 668,
  [2607] = 844,
  [2608] = 781,
  [2609] = 728,
  [2610] = 832,
  [2611] = 672,
  [2612] = 714,
  [2613] = 846,
  [2614] = 797,
  [2615] = 681,
  [2616] = 786,
  [2617] = 682,
  [2618] = 730,
  [2619] = 757,
  [2620] = 748,
  [2621] = 870,
  [2622] = 749,
  [2623] = 660,
  [2624] = 852,
  [2625] = 790,
  [2626] = 684,
  [2627] = 704,
  [2628] = 750,
  [2629] = 761,
  [2630] = 837,
  [2631] = 814,
  [2632] = 816,
  [2633] = 818,
  [2634] = 793,
  [2635] = 853,
  [2636] = 734,
  [2637] = 742,
  [2638] = 872,
  [2639] = 796,
  [2640] = 873,
  [2641] = 798,
  [2642] = 874,
  [2643] = 799,
  [2644] = 875,
  [2645] = 602,
  [2646] = 763,
  [2647] = 712,
  [2648] = 764,
  [2649] = 843,
  [2650] = 854,
  [2651] = 856,
  [2652] = 719,
  [2653] = 825,
  [2654] = 706,
  [2655] = 871,
  [2656] = 606,
  [2657] = 709,
  [2658] = 835,
  [2659] = 737,
  [2660] = 800,
  [2661] = 802,
  [2662] = 841,
  [2663] = 663,
  [2664] = 723,
  [2665] = 726,
  [2666] = 803,
  [2667] = 794,
  [2668] = 756,
  [2669] = 823,
  [2670] = 759,
  [2671] = 824,
  [2672] = 828,
  [2673] = 829,
  [2674] = 830,
  [2675] = 833,
  [2676] = 760,
  [2677] = 836,
  [2678] = 662,
  [2679] = 533,
  [2680] = 839,
  [2681] = 670,
  [2682] = 840,
  [2683] = 762,
  [2684] = 527,
  [2685] = 845,
  [2686] = 848,
  [2687] = 849,
  [2688] = 567,
  [2689] = 851,
  [2690] = 789,
  [2691] = 691,
  [2692] = 694,
  [2693] = 752,
  [2694] = 695,
  [2695] = 696,
  [2696] = 697,
  [2697] = 754,
  [2698] = 698,
  [2699] = 772,
  [2700] = 699,
  [2701] = 700,
  [2702] = 561,
  [2703] = 701,
  [2704] = 702,
  [2705] = 765,
  [2706] = 703,
  [2707] = 715,
  [2708] = 780,
  [2709] = 785,
  [2710] = 689,
  [2711] = 2711,
  [2712] = 876,
  [2713] = 857,
  [2714] = 766,
  [2715] = 791,
  [2716] = 767,
  [2717] = 819,
  [2718] = 822,
  [2719] = 826,
  [2720] = 770,
  [2721] = 771,
  [2722] = 753,
  [2723] = 850,
  [2724] = 858,
  [2725] = 788,
  [2726] = 779,
  [2727] = 782,
  [2728] = 773,
  [2729] = 777,
  [2730] = 606,
  [2731] = 778,
  [2732] = 718,
  [2733] = 736,
  [2734] = 738,
  [2735] = 740,
  [2736] = 746,
  [2737] = 783,
  [2738] = 602,
  [2739] = 834,
  [2740] = 838,
  [2741] = 690,
  [2742] = 692,
  [2743] = 693,
  [2744] = 705,
  [2745] = 708,
  [2746] = 711,
  [2747] = 722,
  [2748] = 727,
  [2749] = 731,
  [2750] = 732,
  [2751] = 744,
  [2752] = 751,
  [2753] = 758,
  [2754] = 768,
  [2755] = 769,
  [2756] = 735,
  [2757] = 735,
  [2758] = 805,
  [2759] = 806,
  [2760] = 808,
  [2761] = 809,
  [2762] = 713,
  [2763] = 725,
  [2764] = 784,
  [2765] = 812,
  [2766] = 813,
  [2767] = 820,
  [2768] = 755,
  [2769] = 692,
  [2770] = 660,
  [2771] = 2594,
  [2772] = 751,
  [2773] = 2574,
  [2774] = 758,
  [2775] = 2546,
  [2776] = 2599,
  [2777] = 857,
  [2778] = 713,
  [2779] = 2592,
  [2780] = 725,
  [2781] = 834,
  [2782] = 838,
  [2783] = 690,
  [2784] = 674,
  [2785] = 2598,
  [2786] = 602,
  [2787] = 768,
  [2788] = 735,
  [2789] = 705,
  [2790] = 708,
  [2791] = 711,
  [2792] = 769,
  [2793] = 722,
  [2794] = 727,
  [2795] = 823,
  [2796] = 731,
  [2797] = 735,
  [2798] = 732,
  [2799] = 2593,
  [2800] = 2597,
  [2801] = 784,
  [2802] = 744,
  [2803] = 693,
  [2804] = 780,
  [2805] = 719,
  [2806] = 728,
  [2807] = 735,
  [2808] = 730,
  [2809] = 737,
  [2810] = 700,
  [2811] = 742,
  [2812] = 745,
  [2813] = 747,
  [2814] = 748,
  [2815] = 749,
  [2816] = 561,
  [2817] = 750,
  [2818] = 786,
  [2819] = 701,
  [2820] = 2820,
  [2821] = 761,
  [2822] = 704,
  [2823] = 696,
  [2824] = 763,
  [2825] = 764,
  [2826] = 798,
  [2827] = 843,
  [2828] = 799,
  [2829] = 702,
  [2830] = 697,
  [2831] = 781,
  [2832] = 814,
  [2833] = 717,
  [2834] = 816,
  [2835] = 832,
  [2836] = 772,
  [2837] = 852,
  [2838] = 714,
  [2839] = 853,
  [2840] = 854,
  [2841] = 703,
  [2842] = 856,
  [2843] = 870,
  [2844] = 713,
  [2845] = 715,
  [2846] = 718,
  [2847] = 871,
  [2848] = 725,
  [2849] = 712,
  [2850] = 784,
  [2851] = 785,
  [2852] = 803,
  [2853] = 689,
  [2854] = 876,
  [2855] = 2855,
  [2856] = 794,
  [2857] = 706,
  [2858] = 872,
  [2859] = 698,
  [2860] = 792,
  [2861] = 873,
  [2862] = 874,
  [2863] = 875,
  [2864] = 709,
  [2865] = 791,
  [2866] = 819,
  [2867] = 822,
  [2868] = 734,
  [2869] = 826,
  [2870] = 837,
  [2871] = 818,
  [2872] = 533,
  [2873] = 850,
  [2874] = 858,
  [2875] = 788,
  [2876] = 779,
  [2877] = 835,
  [2878] = 825,
  [2879] = 796,
  [2880] = 797,
  [2881] = 793,
  [2882] = 846,
  [2883] = 699,
  [2884] = 782,
  [2885] = 802,
  [2886] = 838,
  [2887] = 726,
  [2888] = 690,
  [2889] = 692,
  [2890] = 693,
  [2891] = 705,
  [2892] = 708,
  [2893] = 711,
  [2894] = 722,
  [2895] = 727,
  [2896] = 731,
  [2897] = 732,
  [2898] = 736,
  [2899] = 738,
  [2900] = 740,
  [2901] = 744,
  [2902] = 746,
  [2903] = 751,
  [2904] = 527,
  [2905] = 752,
  [2906] = 753,
  [2907] = 754,
  [2908] = 755,
  [2909] = 756,
  [2910] = 758,
  [2911] = 759,
  [2912] = 760,
  [2913] = 762,
  [2914] = 765,
  [2915] = 766,
  [2916] = 767,
  [2917] = 768,
  [2918] = 769,
  [2919] = 2820,
  [2920] = 770,
  [2921] = 771,
  [2922] = 773,
  [2923] = 777,
  [2924] = 778,
  [2925] = 783,
  [2926] = 805,
  [2927] = 806,
  [2928] = 808,
  [2929] = 809,
  [2930] = 2855,
  [2931] = 812,
  [2932] = 813,
  [2933] = 820,
  [2934] = 723,
  [2935] = 841,
  [2936] = 790,
  [2937] = 824,
  [2938] = 828,
  [2939] = 829,
  [2940] = 830,
  [2941] = 833,
  [2942] = 836,
  [2943] = 839,
  [2944] = 840,
  [2945] = 845,
  [2946] = 848,
  [2947] = 849,
  [2948] = 851,
  [2949] = 789,
  [2950] = 691,
  [2951] = 694,
  [2952] = 695,
  [2953] = 800,
  [2954] = 735,
  [2955] = 834,
  [2956] = 2956,
  [2957] = 545,
  [2958] = 669,
  [2959] = 666,
  [2960] = 522,
  [2961] = 524,
  [2962] = 527,
  [2963] = 667,
  [2964] = 532,
  [2965] = 2965,
  [2966] = 524,
  [2967] = 2956,
  [2968] = 526,
  [2969] = 681,
  [2970] = 545,
  [2971] = 542,
  [2972] = 534,
  [2973] = 525,
  [2974] = 671,
  [2975] = 672,
  [2976] = 682,
  [2977] = 542,
  [2978] = 520,
  [2979] = 606,
  [2980] = 534,
  [2981] = 535,
  [2982] = 520,
  [2983] = 521,
  [2984] = 525,
  [2985] = 683,
  [2986] = 662,
  [2987] = 535,
  [2988] = 684,
  [2989] = 534,
  [2990] = 535,
  [2991] = 544,
  [2992] = 525,
  [2993] = 522,
  [2994] = 533,
  [2995] = 663,
  [2996] = 532,
  [2997] = 542,
  [2998] = 584,
  [2999] = 526,
  [3000] = 545,
  [3001] = 670,
  [3002] = 674,
  [3003] = 532,
  [3004] = 665,
  [3005] = 2965,
  [3006] = 526,
  [3007] = 544,
  [3008] = 521,
  [3009] = 675,
  [3010] = 561,
  [3011] = 520,
  [3012] = 522,
  [3013] = 524,
  [3014] = 668,
  [3015] = 567,
  [3016] = 521,
  [3017] = 797,
  [3018] = 697,
  [3019] = 698,
  [3020] = 699,
  [3021] = 700,
  [3022] = 701,
  [3023] = 702,
  [3024] = 850,
  [3025] = 602,
  [3026] = 606,
  [3027] = 858,
  [3028] = 696,
  [3029] = 532,
  [3030] = 542,
  [3031] = 673,
  [3032] = 779,
  [3033] = 660,
  [3034] = 843,
  [3035] = 662,
  [3036] = 520,
  [3037] = 521,
  [3038] = 545,
  [3039] = 782,
  [3040] = 661,
  [3041] = 670,
  [3042] = 674,
  [3043] = 706,
  [3044] = 567,
  [3045] = 522,
  [3046] = 709,
  [3047] = 524,
  [3048] = 525,
  [3049] = 664,
  [3050] = 821,
  [3051] = 841,
  [3052] = 526,
  [3053] = 3053,
  [3054] = 736,
  [3055] = 738,
  [3056] = 740,
  [3057] = 746,
  [3058] = 733,
  [3059] = 534,
  [3060] = 535,
  [3061] = 703,
  [3062] = 661,
  [3063] = 664,
  [3064] = 752,
  [3065] = 532,
  [3066] = 542,
  [3067] = 753,
  [3068] = 754,
  [3069] = 755,
  [3070] = 602,
  [3071] = 756,
  [3072] = 520,
  [3073] = 521,
  [3074] = 545,
  [3075] = 522,
  [3076] = 524,
  [3077] = 525,
  [3078] = 870,
  [3079] = 759,
  [3080] = 526,
  [3081] = 760,
  [3082] = 762,
  [3083] = 765,
  [3084] = 766,
  [3085] = 767,
  [3086] = 534,
  [3087] = 535,
  [3088] = 532,
  [3089] = 542,
  [3090] = 520,
  [3091] = 521,
  [3092] = 545,
  [3093] = 522,
  [3094] = 524,
  [3095] = 525,
  [3096] = 704,
  [3097] = 526,
  [3098] = 712,
  [3099] = 787,
  [3100] = 844,
  [3101] = 673,
  [3102] = 714,
  [3103] = 770,
  [3104] = 757,
  [3105] = 771,
  [3106] = 717,
  [3107] = 534,
  [3108] = 837,
  [3109] = 715,
  [3110] = 718,
  [3111] = 773,
  [3112] = 777,
  [3113] = 778,
  [3114] = 783,
  [3115] = 780,
  [3116] = 805,
  [3117] = 719,
  [3118] = 806,
  [3119] = 808,
  [3120] = 809,
  [3121] = 800,
  [3122] = 802,
  [3123] = 785,
  [3124] = 689,
  [3125] = 876,
  [3126] = 761,
  [3127] = 812,
  [3128] = 813,
  [3129] = 820,
  [3130] = 823,
  [3131] = 723,
  [3132] = 544,
  [3133] = 799,
  [3134] = 814,
  [3135] = 824,
  [3136] = 828,
  [3137] = 763,
  [3138] = 829,
  [3139] = 830,
  [3140] = 833,
  [3141] = 764,
  [3142] = 791,
  [3143] = 836,
  [3144] = 839,
  [3145] = 660,
  [3146] = 772,
  [3147] = 819,
  [3148] = 840,
  [3149] = 822,
  [3150] = 826,
  [3151] = 845,
  [3152] = 848,
  [3153] = 849,
  [3154] = 750,
  [3155] = 781,
  [3156] = 663,
  [3157] = 665,
  [3158] = 584,
  [3159] = 825,
  [3160] = 666,
  [3161] = 667,
  [3162] = 668,
  [3163] = 786,
  [3164] = 669,
  [3165] = 832,
  [3166] = 852,
  [3167] = 853,
  [3168] = 671,
  [3169] = 854,
  [3170] = 856,
  [3171] = 871,
  [3172] = 672,
  [3173] = 792,
  [3174] = 675,
  [3175] = 681,
  [3176] = 682,
  [3177] = 683,
  [3178] = 684,
  [3179] = 790,
  [3180] = 872,
  [3181] = 873,
  [3182] = 874,
  [3183] = 875,
  [3184] = 835,
  [3185] = 793,
  [3186] = 801,
  [3187] = 721,
  [3188] = 726,
  [3189] = 728,
  [3190] = 730,
  [3191] = 737,
  [3192] = 851,
  [3193] = 535,
  [3194] = 789,
  [3195] = 794,
  [3196] = 735,
  [3197] = 742,
  [3198] = 745,
  [3199] = 747,
  [3200] = 796,
  [3201] = 748,
  [3202] = 749,
  [3203] = 798,
  [3204] = 691,
  [3205] = 694,
  [3206] = 695,
  [3207] = 788,
  [3208] = 692,
  [3209] = 799,
  [3210] = 699,
  [3211] = 700,
  [3212] = 763,
  [3213] = 701,
  [3214] = 683,
  [3215] = 702,
  [3216] = 764,
  [3217] = 708,
  [3218] = 142,
  [3219] = 711,
  [3220] = 722,
  [3221] = 803,
  [3222] = 727,
  [3223] = 731,
  [3224] = 732,
  [3225] = 135,
  [3226] = 140,
  [3227] = 141,
  [3228] = 792,
  [3229] = 818,
  [3230] = 744,
  [3231] = 797,
  [3232] = 791,
  [3233] = 712,
  [3234] = 831,
  [3235] = 817,
  [3236] = 751,
  [3237] = 719,
  [3238] = 142,
  [3239] = 819,
  [3240] = 665,
  [3241] = 822,
  [3242] = 846,
  [3243] = 734,
  [3244] = 803,
  [3245] = 818,
  [3246] = 725,
  [3247] = 826,
  [3248] = 534,
  [3249] = 535,
  [3250] = 532,
  [3251] = 542,
  [3252] = 520,
  [3253] = 521,
  [3254] = 545,
  [3255] = 522,
  [3256] = 524,
  [3257] = 525,
  [3258] = 526,
  [3259] = 134,
  [3260] = 667,
  [3261] = 723,
  [3262] = 140,
  [3263] = 780,
  [3264] = 814,
  [3265] = 816,
  [3266] = 841,
  [3267] = 850,
  [3268] = 858,
  [3269] = 788,
  [3270] = 779,
  [3271] = 782,
  [3272] = 834,
  [3273] = 669,
  [3274] = 714,
  [3275] = 713,
  [3276] = 758,
  [3277] = 667,
  [3278] = 838,
  [3279] = 690,
  [3280] = 692,
  [3281] = 671,
  [3282] = 693,
  [3283] = 705,
  [3284] = 708,
  [3285] = 675,
  [3286] = 711,
  [3287] = 821,
  [3288] = 843,
  [3289] = 722,
  [3290] = 683,
  [3291] = 727,
  [3292] = 731,
  [3293] = 787,
  [3294] = 768,
  [3295] = 769,
  [3296] = 717,
  [3297] = 784,
  [3298] = 732,
  [3299] = 736,
  [3300] = 738,
  [3301] = 785,
  [3302] = 3302,
  [3303] = 740,
  [3304] = 744,
  [3305] = 746,
  [3306] = 781,
  [3307] = 800,
  [3308] = 706,
  [3309] = 751,
  [3310] = 709,
  [3311] = 669,
  [3312] = 802,
  [3313] = 669,
  [3314] = 834,
  [3315] = 772,
  [3316] = 698,
  [3317] = 838,
  [3318] = 857,
  [3319] = 134,
  [3320] = 690,
  [3321] = 825,
  [3322] = 533,
  [3323] = 761,
  [3324] = 876,
  [3325] = 725,
  [3326] = 846,
  [3327] = 752,
  [3328] = 753,
  [3329] = 754,
  [3330] = 755,
  [3331] = 693,
  [3332] = 756,
  [3333] = 784,
  [3334] = 786,
  [3335] = 527,
  [3336] = 705,
  [3337] = 733,
  [3338] = 758,
  [3339] = 852,
  [3340] = 853,
  [3341] = 854,
  [3342] = 856,
  [3343] = 870,
  [3344] = 871,
  [3345] = 759,
  [3346] = 760,
  [3347] = 817,
  [3348] = 762,
  [3349] = 765,
  [3350] = 766,
  [3351] = 801,
  [3352] = 767,
  [3353] = 768,
  [3354] = 703,
  [3355] = 769,
  [3356] = 790,
  [3357] = 667,
  [3358] = 665,
  [3359] = 770,
  [3360] = 771,
  [3361] = 713,
  [3362] = 816,
  [3363] = 139,
  [3364] = 872,
  [3365] = 873,
  [3366] = 874,
  [3367] = 671,
  [3368] = 704,
  [3369] = 831,
  [3370] = 875,
  [3371] = 734,
  [3372] = 837,
  [3373] = 835,
  [3374] = 715,
  [3375] = 844,
  [3376] = 773,
  [3377] = 777,
  [3378] = 778,
  [3379] = 561,
  [3380] = 783,
  [3381] = 805,
  [3382] = 138,
  [3383] = 135,
  [3384] = 806,
  [3385] = 683,
  [3386] = 808,
  [3387] = 809,
  [3388] = 793,
  [3389] = 857,
  [3390] = 757,
  [3391] = 832,
  [3392] = 812,
  [3393] = 813,
  [3394] = 820,
  [3395] = 823,
  [3396] = 726,
  [3397] = 728,
  [3398] = 718,
  [3399] = 730,
  [3400] = 737,
  [3401] = 141,
  [3402] = 824,
  [3403] = 828,
  [3404] = 3302,
  [3405] = 829,
  [3406] = 830,
  [3407] = 833,
  [3408] = 794,
  [3409] = 836,
  [3410] = 839,
  [3411] = 840,
  [3412] = 742,
  [3413] = 745,
  [3414] = 735,
  [3415] = 671,
  [3416] = 747,
  [3417] = 845,
  [3418] = 138,
  [3419] = 139,
  [3420] = 675,
  [3421] = 848,
  [3422] = 721,
  [3423] = 849,
  [3424] = 665,
  [3425] = 796,
  [3426] = 675,
  [3427] = 851,
  [3428] = 789,
  [3429] = 691,
  [3430] = 748,
  [3431] = 749,
  [3432] = 694,
  [3433] = 798,
  [3434] = 695,
  [3435] = 696,
  [3436] = 697,
  [3437] = 750,
  [3438] = 689,
  [3439] = 520,
  [3440] = 682,
  [3441] = 584,
  [3442] = 684,
  [3443] = 662,
  [3444] = 602,
  [3445] = 684,
  [3446] = 663,
  [3447] = 606,
  [3448] = 668,
  [3449] = 533,
  [3450] = 534,
  [3451] = 535,
  [3452] = 665,
  [3453] = 667,
  [3454] = 666,
  [3455] = 532,
  [3456] = 542,
  [3457] = 141,
  [3458] = 668,
  [3459] = 673,
  [3460] = 670,
  [3461] = 674,
  [3462] = 138,
  [3463] = 520,
  [3464] = 521,
  [3465] = 669,
  [3466] = 666,
  [3467] = 142,
  [3468] = 545,
  [3469] = 661,
  [3470] = 567,
  [3471] = 534,
  [3472] = 535,
  [3473] = 522,
  [3474] = 3474,
  [3475] = 532,
  [3476] = 542,
  [3477] = 672,
  [3478] = 666,
  [3479] = 671,
  [3480] = 135,
  [3481] = 524,
  [3482] = 682,
  [3483] = 684,
  [3484] = 545,
  [3485] = 522,
  [3486] = 524,
  [3487] = 525,
  [3488] = 140,
  [3489] = 526,
  [3490] = 682,
  [3491] = 675,
  [3492] = 525,
  [3493] = 664,
  [3494] = 672,
  [3495] = 681,
  [3496] = 668,
  [3497] = 526,
  [3498] = 683,
  [3499] = 663,
  [3500] = 665,
  [3501] = 134,
  [3502] = 666,
  [3503] = 667,
  [3504] = 663,
  [3505] = 668,
  [3506] = 663,
  [3507] = 527,
  [3508] = 681,
  [3509] = 669,
  [3510] = 681,
  [3511] = 671,
  [3512] = 584,
  [3513] = 672,
  [3514] = 660,
  [3515] = 561,
  [3516] = 675,
  [3517] = 681,
  [3518] = 682,
  [3519] = 683,
  [3520] = 672,
  [3521] = 684,
  [3522] = 139,
  [3523] = 521,
  [3524] = 797,
  [3525] = 771,
  [3526] = 773,
  [3527] = 777,
  [3528] = 778,
  [3529] = 783,
  [3530] = 805,
  [3531] = 806,
  [3532] = 831,
  [3533] = 846,
  [3534] = 734,
  [3535] = 527,
  [3536] = 808,
  [3537] = 809,
  [3538] = 812,
  [3539] = 813,
  [3540] = 820,
  [3541] = 823,
  [3542] = 533,
  [3543] = 824,
  [3544] = 828,
  [3545] = 829,
  [3546] = 801,
  [3547] = 830,
  [3548] = 833,
  [3549] = 836,
  [3550] = 839,
  [3551] = 840,
  [3552] = 845,
  [3553] = 848,
  [3554] = 849,
  [3555] = 851,
  [3556] = 789,
  [3557] = 691,
  [3558] = 694,
  [3559] = 695,
  [3560] = 696,
  [3561] = 697,
  [3562] = 757,
  [3563] = 698,
  [3564] = 699,
  [3565] = 700,
  [3566] = 701,
  [3567] = 702,
  [3568] = 857,
  [3569] = 584,
  [3570] = 719,
  [3571] = 567,
  [3572] = 821,
  [3573] = 757,
  [3574] = 567,
  [3575] = 3575,
  [3576] = 781,
  [3577] = 772,
  [3578] = 663,
  [3579] = 666,
  [3580] = 668,
  [3581] = 703,
  [3582] = 786,
  [3583] = 713,
  [3584] = 715,
  [3585] = 718,
  [3586] = 672,
  [3587] = 725,
  [3588] = 790,
  [3589] = 681,
  [3590] = 682,
  [3591] = 780,
  [3592] = 784,
  [3593] = 785,
  [3594] = 793,
  [3595] = 684,
  [3596] = 662,
  [3597] = 794,
  [3598] = 796,
  [3599] = 798,
  [3600] = 799,
  [3601] = 689,
  [3602] = 876,
  [3603] = 800,
  [3604] = 802,
  [3605] = 662,
  [3606] = 533,
  [3607] = 814,
  [3608] = 791,
  [3609] = 844,
  [3610] = 819,
  [3611] = 822,
  [3612] = 704,
  [3613] = 826,
  [3614] = 825,
  [3615] = 533,
  [3616] = 561,
  [3617] = 852,
  [3618] = 853,
  [3619] = 854,
  [3620] = 856,
  [3621] = 871,
  [3622] = 735,
  [3623] = 850,
  [3624] = 770,
  [3625] = 788,
  [3626] = 872,
  [3627] = 873,
  [3628] = 874,
  [3629] = 875,
  [3630] = 779,
  [3631] = 835,
  [3632] = 782,
  [3633] = 834,
  [3634] = 838,
  [3635] = 817,
  [3636] = 527,
  [3637] = 690,
  [3638] = 832,
  [3639] = 692,
  [3640] = 693,
  [3641] = 723,
  [3642] = 726,
  [3643] = 728,
  [3644] = 730,
  [3645] = 737,
  [3646] = 705,
  [3647] = 561,
  [3648] = 708,
  [3649] = 711,
  [3650] = 722,
  [3651] = 727,
  [3652] = 731,
  [3653] = 732,
  [3654] = 736,
  [3655] = 738,
  [3656] = 740,
  [3657] = 744,
  [3658] = 742,
  [3659] = 745,
  [3660] = 747,
  [3661] = 746,
  [3662] = 712,
  [3663] = 751,
  [3664] = 748,
  [3665] = 749,
  [3666] = 750,
  [3667] = 761,
  [3668] = 735,
  [3669] = 803,
  [3670] = 816,
  [3671] = 818,
  [3672] = 763,
  [3673] = 764,
  [3674] = 752,
  [3675] = 753,
  [3676] = 754,
  [3677] = 755,
  [3678] = 756,
  [3679] = 714,
  [3680] = 758,
  [3681] = 662,
  [3682] = 735,
  [3683] = 792,
  [3684] = 561,
  [3685] = 3474,
  [3686] = 670,
  [3687] = 721,
  [3688] = 870,
  [3689] = 837,
  [3690] = 670,
  [3691] = 759,
  [3692] = 760,
  [3693] = 674,
  [3694] = 762,
  [3695] = 765,
  [3696] = 766,
  [3697] = 733,
  [3698] = 843,
  [3699] = 767,
  [3700] = 706,
  [3701] = 768,
  [3702] = 769,
  [3703] = 709,
  [3704] = 567,
  [3705] = 841,
  [3706] = 844,
  [3707] = 670,
  [3708] = 717,
  [3709] = 787,
  [3710] = 527,
  [3711] = 858,
  [3712] = 852,
  [3713] = 606,
  [3714] = 747,
  [3715] = 796,
  [3716] = 723,
  [3717] = 138,
  [3718] = 567,
  [3719] = 674,
  [3720] = 875,
  [3721] = 141,
  [3722] = 757,
  [3723] = 135,
  [3724] = 844,
  [3725] = 683,
  [3726] = 706,
  [3727] = 674,
  [3728] = 662,
  [3729] = 748,
  [3730] = 793,
  [3731] = 704,
  [3732] = 794,
  [3733] = 140,
  [3734] = 726,
  [3735] = 814,
  [3736] = 728,
  [3737] = 816,
  [3738] = 139,
  [3739] = 792,
  [3740] = 818,
  [3741] = 675,
  [3742] = 712,
  [3743] = 670,
  [3744] = 730,
  [3745] = 671,
  [3746] = 665,
  [3747] = 667,
  [3748] = 134,
  [3749] = 781,
  [3750] = 665,
  [3751] = 837,
  [3752] = 737,
  [3753] = 841,
  [3754] = 825,
  [3755] = 797,
  [3756] = 803,
  [3757] = 719,
  [3758] = 709,
  [3759] = 671,
  [3760] = 846,
  [3761] = 749,
  [3762] = 675,
  [3763] = 798,
  [3764] = 714,
  [3765] = 606,
  [3766] = 683,
  [3767] = 800,
  [3768] = 750,
  [3769] = 786,
  [3770] = 667,
  [3771] = 544,
  [3772] = 761,
  [3773] = 843,
  [3774] = 799,
  [3775] = 763,
  [3776] = 764,
  [3777] = 835,
  [3778] = 874,
  [3779] = 853,
  [3780] = 854,
  [3781] = 742,
  [3782] = 856,
  [3783] = 870,
  [3784] = 871,
  [3785] = 142,
  [3786] = 745,
  [3787] = 832,
  [3788] = 717,
  [3789] = 802,
  [3790] = 790,
  [3791] = 674,
  [3792] = 734,
  [3793] = 669,
  [3794] = 872,
  [3795] = 873,
  [3796] = 669,
  [3797] = 730,
  [3798] = 837,
  [3799] = 835,
  [3800] = 814,
  [3801] = 717,
  [3802] = 875,
  [3803] = 792,
  [3804] = 682,
  [3805] = 793,
  [3806] = 761,
  [3807] = 737,
  [3808] = 841,
  [3809] = 140,
  [3810] = 763,
  [3811] = 142,
  [3812] = 799,
  [3813] = 761,
  [3814] = 823,
  [3815] = 764,
  [3816] = 660,
  [3817] = 723,
  [3818] = 673,
  [3819] = 790,
  [3820] = 763,
  [3821] = 764,
  [3822] = 704,
  [3823] = 843,
  [3824] = 872,
  [3825] = 672,
  [3826] = 814,
  [3827] = 873,
  [3828] = 792,
  [3829] = 874,
  [3830] = 138,
  [3831] = 875,
  [3832] = 734,
  [3833] = 140,
  [3834] = 139,
  [3835] = 764,
  [3836] = 835,
  [3837] = 138,
  [3838] = 135,
  [3839] = 719,
  [3840] = 141,
  [3841] = 870,
  [3842] = 142,
  [3843] = 843,
  [3844] = 857,
  [3845] = 660,
  [3846] = 803,
  [3847] = 602,
  [3848] = 786,
  [3849] = 134,
  [3850] = 140,
  [3851] = 871,
  [3852] = 800,
  [3853] = 135,
  [3854] = 793,
  [3855] = 802,
  [3856] = 684,
  [3857] = 796,
  [3858] = 527,
  [3859] = 709,
  [3860] = 134,
  [3861] = 750,
  [3862] = 534,
  [3863] = 852,
  [3864] = 853,
  [3865] = 857,
  [3866] = 535,
  [3867] = 854,
  [3868] = 532,
  [3869] = 542,
  [3870] = 852,
  [3871] = 853,
  [3872] = 726,
  [3873] = 520,
  [3874] = 521,
  [3875] = 763,
  [3876] = 742,
  [3877] = 545,
  [3878] = 856,
  [3879] = 745,
  [3880] = 871,
  [3881] = 728,
  [3882] = 709,
  [3883] = 786,
  [3884] = 704,
  [3885] = 747,
  [3886] = 825,
  [3887] = 522,
  [3888] = 737,
  [3889] = 141,
  [3890] = 854,
  [3891] = 856,
  [3892] = 524,
  [3893] = 870,
  [3894] = 841,
  [3895] = 673,
  [3896] = 871,
  [3897] = 794,
  [3898] = 525,
  [3899] = 526,
  [3900] = 852,
  [3901] = 742,
  [3902] = 714,
  [3903] = 745,
  [3904] = 747,
  [3905] = 704,
  [3906] = 796,
  [3907] = 714,
  [3908] = 712,
  [3909] = 719,
  [3910] = 748,
  [3911] = 846,
  [3912] = 853,
  [3913] = 735,
  [3914] = 790,
  [3915] = 138,
  [3916] = 872,
  [3917] = 747,
  [3918] = 814,
  [3919] = 843,
  [3920] = 714,
  [3921] = 816,
  [3922] = 544,
  [3923] = 706,
  [3924] = 800,
  [3925] = 854,
  [3926] = 800,
  [3927] = 856,
  [3928] = 802,
  [3929] = 799,
  [3930] = 719,
  [3931] = 802,
  [3932] = 135,
  [3933] = 781,
  [3934] = 533,
  [3935] = 792,
  [3936] = 139,
  [3937] = 748,
  [3938] = 832,
  [3939] = 825,
  [3940] = 749,
  [3941] = 798,
  [3942] = 717,
  [3943] = 832,
  [3944] = 663,
  [3945] = 837,
  [3946] = 666,
  [3947] = 873,
  [3948] = 663,
  [3949] = 712,
  [3950] = 835,
  [3951] = 797,
  [3952] = 706,
  [3953] = 668,
  [3954] = 870,
  [3955] = 726,
  [3956] = 672,
  [3957] = 832,
  [3958] = 798,
  [3959] = 717,
  [3960] = 681,
  [3961] = 682,
  [3962] = 794,
  [3963] = 793,
  [3964] = 561,
  [3965] = 728,
  [3966] = 134,
  [3967] = 666,
  [3968] = 139,
  [3969] = 681,
  [3970] = 823,
  [3971] = 723,
  [3972] = 726,
  [3973] = 684,
  [3974] = 728,
  [3975] = 730,
  [3976] = 706,
  [3977] = 712,
  [3978] = 796,
  [3979] = 737,
  [3980] = 841,
  [3981] = 818,
  [3982] = 837,
  [3983] = 730,
  [3984] = 781,
  [3985] = 790,
  [3986] = 749,
  [3987] = 781,
  [3988] = 750,
  [3989] = 794,
  [3990] = 723,
  [3991] = 874,
  [3992] = 786,
  [3993] = 797,
  [3994] = 872,
  [3995] = 873,
  [3996] = 825,
  [3997] = 533,
  [3998] = 797,
  [3999] = 141,
  [4000] = 742,
  [4001] = 527,
  [4002] = 668,
  [4003] = 142,
  [4004] = 750,
  [4005] = 799,
  [4006] = 745,
  [4007] = 709,
  [4008] = 874,
  [4009] = 875,
  [4010] = 748,
  [4011] = 749,
  [4012] = 602,
  [4013] = 798,
  [4014] = 561,
  [4015] = 761,
  [4016] = 735,
  [4017] = 762,
  [4018] = 746,
  [4019] = 715,
  [4020] = 849,
  [4021] = 765,
  [4022] = 561,
  [4023] = 771,
  [4024] = 819,
  [4025] = 818,
  [4026] = 828,
  [4027] = 703,
  [4028] = 829,
  [4029] = 756,
  [4030] = 752,
  [4031] = 567,
  [4032] = 584,
  [4033] = 819,
  [4034] = 713,
  [4035] = 715,
  [4036] = 701,
  [4037] = 766,
  [4038] = 759,
  [4039] = 567,
  [4040] = 765,
  [4041] = 718,
  [4042] = 139,
  [4043] = 138,
  [4044] = 135,
  [4045] = 766,
  [4046] = 767,
  [4047] = 768,
  [4048] = 141,
  [4049] = 142,
  [4050] = 140,
  [4051] = 134,
  [4052] = 735,
  [4053] = 769,
  [4054] = 670,
  [4055] = 725,
  [4056] = 718,
  [4057] = 770,
  [4058] = 780,
  [4059] = 534,
  [4060] = 535,
  [4061] = 532,
  [4062] = 542,
  [4063] = 520,
  [4064] = 521,
  [4065] = 545,
  [4066] = 522,
  [4067] = 524,
  [4068] = 525,
  [4069] = 526,
  [4070] = 822,
  [4071] = 664,
  [4072] = 602,
  [4073] = 606,
  [4074] = 839,
  [4075] = 788,
  [4076] = 694,
  [4077] = 700,
  [4078] = 746,
  [4079] = 784,
  [4080] = 760,
  [4081] = 826,
  [4082] = 527,
  [4083] = 831,
  [4084] = 767,
  [4085] = 833,
  [4086] = 584,
  [4087] = 803,
  [4088] = 816,
  [4089] = 703,
  [4090] = 785,
  [4091] = 778,
  [4092] = 816,
  [4093] = 768,
  [4094] = 851,
  [4095] = 660,
  [4096] = 779,
  [4097] = 789,
  [4098] = 789,
  [4099] = 691,
  [4100] = 698,
  [4101] = 698,
  [4102] = 830,
  [4103] = 805,
  [4104] = 755,
  [4105] = 783,
  [4106] = 769,
  [4107] = 818,
  [4108] = 762,
  [4109] = 851,
  [4110] = 699,
  [4111] = 782,
  [4112] = 758,
  [4113] = 772,
  [4114] = 803,
  [4115] = 674,
  [4116] = 725,
  [4117] = 834,
  [4118] = 858,
  [4119] = 850,
  [4120] = 788,
  [4121] = 779,
  [4122] = 808,
  [4123] = 805,
  [4124] = 831,
  [4125] = 809,
  [4126] = 4126,
  [4127] = 838,
  [4128] = 694,
  [4129] = 735,
  [4130] = 782,
  [4131] = 791,
  [4132] = 690,
  [4133] = 673,
  [4134] = 834,
  [4135] = 838,
  [4136] = 820,
  [4137] = 690,
  [4138] = 740,
  [4139] = 806,
  [4140] = 689,
  [4141] = 692,
  [4142] = 850,
  [4143] = 663,
  [4144] = 758,
  [4145] = 692,
  [4146] = 699,
  [4147] = 858,
  [4148] = 755,
  [4149] = 780,
  [4150] = 812,
  [4151] = 826,
  [4152] = 778,
  [4153] = 666,
  [4154] = 701,
  [4155] = 784,
  [4156] = 734,
  [4157] = 840,
  [4158] = 667,
  [4159] = 662,
  [4160] = 702,
  [4161] = 773,
  [4162] = 668,
  [4163] = 669,
  [4164] = 671,
  [4165] = 672,
  [4166] = 754,
  [4167] = 756,
  [4168] = 812,
  [4169] = 693,
  [4170] = 813,
  [4171] = 675,
  [4172] = 4172,
  [4173] = 785,
  [4174] = 820,
  [4175] = 691,
  [4176] = 705,
  [4177] = 681,
  [4178] = 682,
  [4179] = 683,
  [4180] = 848,
  [4181] = 751,
  [4182] = 684,
  [4183] = 744,
  [4184] = 773,
  [4185] = 753,
  [4186] = 824,
  [4187] = 806,
  [4188] = 693,
  [4189] = 828,
  [4190] = 705,
  [4191] = 829,
  [4192] = 695,
  [4193] = 830,
  [4194] = 833,
  [4195] = 533,
  [4196] = 661,
  [4197] = 695,
  [4198] = 777,
  [4199] = 708,
  [4200] = 713,
  [4201] = 711,
  [4202] = 772,
  [4203] = 702,
  [4204] = 700,
  [4205] = 722,
  [4206] = 727,
  [4207] = 731,
  [4208] = 732,
  [4209] = 736,
  [4210] = 813,
  [4211] = 708,
  [4212] = 689,
  [4213] = 738,
  [4214] = 696,
  [4215] = 751,
  [4216] = 770,
  [4217] = 4126,
  [4218] = 696,
  [4219] = 711,
  [4220] = 722,
  [4221] = 876,
  [4222] = 836,
  [4223] = 845,
  [4224] = 846,
  [4225] = 771,
  [4226] = 839,
  [4227] = 697,
  [4228] = 606,
  [4229] = 777,
  [4230] = 662,
  [4231] = 840,
  [4232] = 2505,
  [4233] = 848,
  [4234] = 808,
  [4235] = 836,
  [4236] = 809,
  [4237] = 670,
  [4238] = 727,
  [4239] = 674,
  [4240] = 731,
  [4241] = 876,
  [4242] = 697,
  [4243] = 732,
  [4244] = 754,
  [4245] = 736,
  [4246] = 567,
  [4247] = 846,
  [4248] = 752,
  [4249] = 738,
  [4250] = 740,
  [4251] = 670,
  [4252] = 753,
  [4253] = 849,
  [4254] = 759,
  [4255] = 783,
  [4256] = 791,
  [4257] = 822,
  [4258] = 760,
  [4259] = 824,
  [4260] = 734,
  [4261] = 744,
  [4262] = 662,
  [4263] = 845,
  [4264] = 665,
  [4265] = 749,
  [4266] = 839,
  [4267] = 845,
  [4268] = 848,
  [4269] = 849,
  [4270] = 851,
  [4271] = 789,
  [4272] = 691,
  [4273] = 694,
  [4274] = 695,
  [4275] = 696,
  [4276] = 697,
  [4277] = 698,
  [4278] = 699,
  [4279] = 700,
  [4280] = 701,
  [4281] = 702,
  [4282] = 719,
  [4283] = 704,
  [4284] = 712,
  [4285] = 781,
  [4286] = 714,
  [4287] = 786,
  [4288] = 823,
  [4289] = 840,
  [4290] = 790,
  [4291] = 821,
  [4292] = 793,
  [4293] = 794,
  [4294] = 796,
  [4295] = 798,
  [4296] = 799,
  [4297] = 719,
  [4298] = 800,
  [4299] = 802,
  [4300] = 814,
  [4301] = 816,
  [4302] = 781,
  [4303] = 825,
  [4304] = 786,
  [4305] = 852,
  [4306] = 853,
  [4307] = 854,
  [4308] = 856,
  [4309] = 871,
  [4310] = 790,
  [4311] = 872,
  [4312] = 873,
  [4313] = 874,
  [4314] = 875,
  [4315] = 835,
  [4316] = 793,
  [4317] = 832,
  [4318] = 723,
  [4319] = 726,
  [4320] = 728,
  [4321] = 730,
  [4322] = 737,
  [4323] = 794,
  [4324] = 742,
  [4325] = 745,
  [4326] = 747,
  [4327] = 796,
  [4328] = 748,
  [4329] = 749,
  [4330] = 798,
  [4331] = 750,
  [4332] = 761,
  [4333] = 799,
  [4334] = 763,
  [4335] = 764,
  [4336] = 800,
  [4337] = 802,
  [4338] = 803,
  [4339] = 814,
  [4340] = 792,
  [4341] = 818,
  [4342] = 825,
  [4343] = 797,
  [4344] = 846,
  [4345] = 852,
  [4346] = 853,
  [4347] = 854,
  [4348] = 856,
  [4349] = 870,
  [4350] = 871,
  [4351] = 872,
  [4352] = 873,
  [4353] = 874,
  [4354] = 875,
  [4355] = 734,
  [4356] = 837,
  [4357] = 835,
  [4358] = 723,
  [4359] = 726,
  [4360] = 728,
  [4361] = 730,
  [4362] = 737,
  [4363] = 742,
  [4364] = 745,
  [4365] = 747,
  [4366] = 748,
  [4367] = 750,
  [4368] = 761,
  [4369] = 763,
  [4370] = 764,
  [4371] = 843,
  [4372] = 792,
  [4373] = 797,
  [4374] = 2546,
  [4375] = 706,
  [4376] = 870,
  [4377] = 709,
  [4378] = 837,
  [4379] = 140,
  [4380] = 841,
  [4381] = 843,
  [4382] = 706,
  [4383] = 709,
  [4384] = 841,
  [4385] = 142,
  [4386] = 735,
  [4387] = 735,
  [4388] = 139,
  [4389] = 138,
  [4390] = 135,
  [4391] = 141,
  [4392] = 142,
  [4393] = 134,
  [4394] = 140,
  [4395] = 857,
  [4396] = 4396,
  [4397] = 4397,
  [4398] = 721,
  [4399] = 831,
  [4400] = 844,
  [4401] = 673,
  [4402] = 733,
  [4403] = 857,
  [4404] = 757,
  [4405] = 844,
  [4406] = 757,
  [4407] = 787,
  [4408] = 2505,
  [4409] = 134,
  [4410] = 801,
  [4411] = 4411,
  [4412] = 831,
  [4413] = 602,
  [4414] = 660,
  [4415] = 772,
  [4416] = 703,
  [4417] = 713,
  [4418] = 715,
  [4419] = 718,
  [4420] = 141,
  [4421] = 725,
  [4422] = 780,
  [4423] = 784,
  [4424] = 785,
  [4425] = 689,
  [4426] = 876,
  [4427] = 674,
  [4428] = 791,
  [4429] = 817,
  [4430] = 819,
  [4431] = 822,
  [4432] = 704,
  [4433] = 826,
  [4434] = 850,
  [4435] = 858,
  [4436] = 788,
  [4437] = 779,
  [4438] = 782,
  [4439] = 834,
  [4440] = 838,
  [4441] = 816,
  [4442] = 803,
  [4443] = 818,
  [4444] = 846,
  [4445] = 734,
  [4446] = 690,
  [4447] = 692,
  [4448] = 693,
  [4449] = 705,
  [4450] = 708,
  [4451] = 711,
  [4452] = 722,
  [4453] = 661,
  [4454] = 664,
  [4455] = 727,
  [4456] = 731,
  [4457] = 732,
  [4458] = 736,
  [4459] = 738,
  [4460] = 740,
  [4461] = 744,
  [4462] = 746,
  [4463] = 712,
  [4464] = 751,
  [4465] = 4465,
  [4466] = 752,
  [4467] = 753,
  [4468] = 754,
  [4469] = 755,
  [4470] = 756,
  [4471] = 714,
  [4472] = 758,
  [4473] = 759,
  [4474] = 760,
  [4475] = 762,
  [4476] = 765,
  [4477] = 766,
  [4478] = 767,
  [4479] = 768,
  [4480] = 769,
  [4481] = 673,
  [4482] = 717,
  [4483] = 770,
  [4484] = 771,
  [4485] = 773,
  [4486] = 777,
  [4487] = 778,
  [4488] = 783,
  [4489] = 805,
  [4490] = 806,
  [4491] = 808,
  [4492] = 809,
  [4493] = 832,
  [4494] = 812,
  [4495] = 813,
  [4496] = 820,
  [4497] = 823,
  [4498] = 824,
  [4499] = 828,
  [4500] = 829,
  [4501] = 830,
  [4502] = 833,
  [4503] = 836,
  [4504] = 717,
  [4505] = 727,
  [4506] = 2574,
  [4507] = 696,
  [4508] = 697,
  [4509] = 717,
  [4510] = 783,
  [4511] = 790,
  [4512] = 750,
  [4513] = 761,
  [4514] = 805,
  [4515] = 698,
  [4516] = 797,
  [4517] = 2592,
  [4518] = 2593,
  [4519] = 2594,
  [4520] = 793,
  [4521] = 699,
  [4522] = 700,
  [4523] = 763,
  [4524] = 870,
  [4525] = 2597,
  [4526] = 2598,
  [4527] = 2599,
  [4528] = 794,
  [4529] = 806,
  [4530] = 837,
  [4531] = 796,
  [4532] = 701,
  [4533] = 735,
  [4534] = 798,
  [4535] = 702,
  [4536] = 764,
  [4537] = 799,
  [4538] = 808,
  [4539] = 602,
  [4540] = 809,
  [4541] = 718,
  [4542] = 1520,
  [4543] = 735,
  [4544] = 846,
  [4545] = 734,
  [4546] = 803,
  [4547] = 818,
  [4548] = 139,
  [4549] = 771,
  [4550] = 843,
  [4551] = 138,
  [4552] = 134,
  [4553] = 706,
  [4554] = 135,
  [4555] = 709,
  [4556] = 832,
  [4557] = 841,
  [4558] = 772,
  [4559] = 703,
  [4560] = 812,
  [4561] = 713,
  [4562] = 715,
  [4563] = 725,
  [4564] = 780,
  [4565] = 784,
  [4566] = 785,
  [4567] = 800,
  [4568] = 802,
  [4569] = 803,
  [4570] = 689,
  [4571] = 876,
  [4572] = 719,
  [4573] = 791,
  [4574] = 813,
  [4575] = 819,
  [4576] = 822,
  [4577] = 826,
  [4578] = 814,
  [4579] = 816,
  [4580] = 818,
  [4581] = 850,
  [4582] = 858,
  [4583] = 788,
  [4584] = 779,
  [4585] = 782,
  [4586] = 834,
  [4587] = 838,
  [4588] = 690,
  [4589] = 692,
  [4590] = 693,
  [4591] = 705,
  [4592] = 708,
  [4593] = 711,
  [4594] = 722,
  [4595] = 792,
  [4596] = 732,
  [4597] = 736,
  [4598] = 820,
  [4599] = 738,
  [4600] = 740,
  [4601] = 872,
  [4602] = 723,
  [4603] = 726,
  [4604] = 744,
  [4605] = 728,
  [4606] = 730,
  [4607] = 746,
  [4608] = 873,
  [4609] = 737,
  [4610] = 141,
  [4611] = 751,
  [4612] = 825,
  [4613] = 824,
  [4614] = 828,
  [4615] = 846,
  [4616] = 857,
  [4617] = 829,
  [4618] = 752,
  [4619] = 830,
  [4620] = 833,
  [4621] = 753,
  [4622] = 754,
  [4623] = 755,
  [4624] = 756,
  [4625] = 834,
  [4626] = 838,
  [4627] = 690,
  [4628] = 692,
  [4629] = 693,
  [4630] = 705,
  [4631] = 708,
  [4632] = 711,
  [4633] = 722,
  [4634] = 727,
  [4635] = 731,
  [4636] = 732,
  [4637] = 744,
  [4638] = 751,
  [4639] = 758,
  [4640] = 768,
  [4641] = 769,
  [4642] = 874,
  [4643] = 712,
  [4644] = 836,
  [4645] = 839,
  [4646] = 840,
  [4647] = 742,
  [4648] = 714,
  [4649] = 745,
  [4650] = 786,
  [4651] = 747,
  [4652] = 875,
  [4653] = 845,
  [4654] = 817,
  [4655] = 816,
  [4656] = 704,
  [4657] = 2546,
  [4658] = 848,
  [4659] = 142,
  [4660] = 758,
  [4661] = 734,
  [4662] = 852,
  [4663] = 849,
  [4664] = 853,
  [4665] = 854,
  [4666] = 856,
  [4667] = 871,
  [4668] = 770,
  [4669] = 781,
  [4670] = 851,
  [4671] = 835,
  [4672] = 773,
  [4673] = 777,
  [4674] = 831,
  [4675] = 759,
  [4676] = 760,
  [4677] = 789,
  [4678] = 713,
  [4679] = 725,
  [4680] = 784,
  [4681] = 735,
  [4682] = 691,
  [4683] = 762,
  [4684] = 140,
  [4685] = 765,
  [4686] = 766,
  [4687] = 767,
  [4688] = 768,
  [4689] = 769,
  [4690] = 748,
  [4691] = 749,
  [4692] = 694,
  [4693] = 778,
  [4694] = 695,
  [4695] = 731,
  [4696] = 711,
  [4697] = 735,
  [4698] = 735,
  [4699] = 2592,
  [4700] = 2593,
  [4701] = 135,
  [4702] = 725,
  [4703] = 784,
  [4704] = 4704,
  [4705] = 4705,
  [4706] = 2574,
  [4707] = 834,
  [4708] = 838,
  [4709] = 690,
  [4710] = 692,
  [4711] = 693,
  [4712] = 705,
  [4713] = 708,
  [4714] = 673,
  [4715] = 606,
  [4716] = 602,
  [4717] = 727,
  [4718] = 731,
  [4719] = 732,
  [4720] = 744,
  [4721] = 134,
  [4722] = 751,
  [4723] = 735,
  [4724] = 2546,
  [4725] = 140,
  [4726] = 758,
  [4727] = 768,
  [4728] = 769,
  [4729] = 602,
  [4730] = 2594,
  [4731] = 139,
  [4732] = 660,
  [4733] = 4733,
  [4734] = 2597,
  [4735] = 138,
  [4736] = 141,
  [4737] = 735,
  [4738] = 2598,
  [4739] = 2599,
  [4740] = 142,
  [4741] = 713,
  [4742] = 722,
  [4743] = 828,
  [4744] = 755,
  [4745] = 4411,
  [4746] = 758,
  [4747] = 2505,
  [4748] = 141,
  [4749] = 135,
  [4750] = 142,
  [4751] = 759,
  [4752] = 760,
  [4753] = 762,
  [4754] = 765,
  [4755] = 766,
  [4756] = 767,
  [4757] = 768,
  [4758] = 769,
  [4759] = 770,
  [4760] = 771,
  [4761] = 4396,
  [4762] = 2574,
  [4763] = 773,
  [4764] = 777,
  [4765] = 778,
  [4766] = 703,
  [4767] = 783,
  [4768] = 805,
  [4769] = 806,
  [4770] = 808,
  [4771] = 809,
  [4772] = 812,
  [4773] = 813,
  [4774] = 820,
  [4775] = 2592,
  [4776] = 2593,
  [4777] = 2594,
  [4778] = 823,
  [4779] = 824,
  [4780] = 829,
  [4781] = 830,
  [4782] = 833,
  [4783] = 2597,
  [4784] = 2598,
  [4785] = 2599,
  [4786] = 836,
  [4787] = 839,
  [4788] = 840,
  [4789] = 845,
  [4790] = 848,
  [4791] = 849,
  [4792] = 851,
  [4793] = 789,
  [4794] = 691,
  [4795] = 694,
  [4796] = 695,
  [4797] = 696,
  [4798] = 697,
  [4799] = 698,
  [4800] = 699,
  [4801] = 700,
  [4802] = 701,
  [4803] = 702,
  [4804] = 735,
  [4805] = 713,
  [4806] = 134,
  [4807] = 715,
  [4808] = 718,
  [4809] = 725,
  [4810] = 780,
  [4811] = 784,
  [4812] = 785,
  [4813] = 689,
  [4814] = 876,
  [4815] = 134,
  [4816] = 4816,
  [4817] = 138,
  [4818] = 735,
  [4819] = 831,
  [4820] = 791,
  [4821] = 141,
  [4822] = 819,
  [4823] = 834,
  [4824] = 838,
  [4825] = 690,
  [4826] = 692,
  [4827] = 693,
  [4828] = 705,
  [4829] = 708,
  [4830] = 711,
  [4831] = 722,
  [4832] = 727,
  [4833] = 731,
  [4834] = 732,
  [4835] = 744,
  [4836] = 751,
  [4837] = 822,
  [4838] = 142,
  [4839] = 758,
  [4840] = 768,
  [4841] = 769,
  [4842] = 134,
  [4843] = 139,
  [4844] = 735,
  [4845] = 141,
  [4846] = 142,
  [4847] = 673,
  [4848] = 4816,
  [4849] = 826,
  [4850] = 857,
  [4851] = 772,
  [4852] = 850,
  [4853] = 858,
  [4854] = 788,
  [4855] = 779,
  [4856] = 735,
  [4857] = 782,
  [4858] = 834,
  [4859] = 838,
  [4860] = 138,
  [4861] = 135,
  [4862] = 690,
  [4863] = 692,
  [4864] = 693,
  [4865] = 705,
  [4866] = 708,
  [4867] = 711,
  [4868] = 722,
  [4869] = 727,
  [4870] = 731,
  [4871] = 732,
  [4872] = 140,
  [4873] = 736,
  [4874] = 738,
  [4875] = 740,
  [4876] = 744,
  [4877] = 746,
  [4878] = 4816,
  [4879] = 4816,
  [4880] = 140,
  [4881] = 673,
  [4882] = 713,
  [4883] = 725,
  [4884] = 784,
  [4885] = 751,
  [4886] = 752,
  [4887] = 753,
  [4888] = 754,
  [4889] = 139,
  [4890] = 4816,
  [4891] = 756,
  [4892] = 4892,
  [4893] = 4892,
  [4894] = 140,
  [4895] = 4892,
  [4896] = 4892,
  [4897] = 4897,
  [4898] = 4898,
  [4899] = 4899,
  [4900] = 139,
  [4901] = 4897,
  [4902] = 4902,
  [4903] = 4902,
  [4904] = 4897,
  [4905] = 4902,
  [4906] = 4892,
  [4907] = 4897,
  [4908] = 4897,
  [4909] = 4396,
  [4910] = 4902,
  [4911] = 4892,
  [4912] = 4902,
  [4913] = 4892,
  [4914] = 4914,
  [4915] = 138,
  [4916] = 4902,
  [4917] = 4897,
  [4918] = 4892,
  [4919] = 4897,
  [4920] = 4902,
  [4921] = 4892,
  [4922] = 4897,
  [4923] = 4902,
  [4924] = 4897,
  [4925] = 4892,
  [4926] = 4902,
  [4927] = 4897,
  [4928] = 4892,
  [4929] = 4902,
  [4930] = 4902,
  [4931] = 4902,
  [4932] = 4902,
  [4933] = 4897,
  [4934] = 4897,
  [4935] = 4892,
  [4936] = 4411,
  [4937] = 831,
  [4938] = 4897,
  [4939] = 135,
  [4940] = 4902,
  [4941] = 4897,
  [4942] = 4897,
  [4943] = 4892,
  [4944] = 4897,
  [4945] = 4902,
  [4946] = 4892,
  [4947] = 4892,
  [4948] = 4902,
  [4949] = 4892,
  [4950] = 4897,
  [4951] = 4902,
  [4952] = 4892,
  [4953] = 4953,
  [4954] = 4954,
  [4955] = 4955,
  [4956] = 4956,
  [4957] = 4957,
  [4958] = 4958,
  [4959] = 4959,
  [4960] = 4960,
  [4961] = 4961,
  [4962] = 4962,
  [4963] = 4963,
  [4964] = 4964,
  [4965] = 4965,
  [4966] = 4966,
  [4967] = 4967,
  [4968] = 4968,
  [4969] = 4969,
  [4970] = 4970,
  [4971] = 4971,
  [4972] = 4972,
  [4973] = 4973,
  [4974] = 4974,
  [4975] = 4975,
  [4976] = 4976,
  [4977] = 4975,
  [4978] = 4972,
  [4979] = 4972,
  [4980] = 4971,
  [4981] = 4976,
  [4982] = 4982,
  [4983] = 4983,
  [4984] = 4972,
  [4985] = 4975,
  [4986] = 4986,
  [4987] = 4976,
  [4988] = 4986,
  [4989] = 4972,
  [4990] = 4982,
  [4991] = 4991,
  [4992] = 4971,
  [4993] = 4982,
  [4994] = 4976,
  [4995] = 4975,
  [4996] = 4982,
  [4997] = 4982,
  [4998] = 4976,
  [4999] = 4982,
  [5000] = 4971,
  [5001] = 4976,
  [5002] = 4972,
  [5003] = 4972,
  [5004] = 4975,
  [5005] = 4972,
  [5006] = 4972,
  [5007] = 4982,
  [5008] = 4976,
  [5009] = 4975,
  [5010] = 4975,
  [5011] = 4982,
  [5012] = 4976,
  [5013] = 4975,
  [5014] = 4982,
  [5015] = 5015,
  [5016] = 4982,
  [5017] = 4976,
  [5018] = 4975,
  [5019] = 4970,
  [5020] = 4976,
  [5021] = 4975,
  [5022] = 4971,
  [5023] = 4986,
  [5024] = 4972,
  [5025] = 4982,
  [5026] = 5026,
  [5027] = 4975,
  [5028] = 4982,
  [5029] = 4971,
  [5030] = 4982,
  [5031] = 4971,
  [5032] = 4986,
  [5033] = 4982,
  [5034] = 4976,
  [5035] = 4986,
  [5036] = 4982,
  [5037] = 4976,
  [5038] = 4975,
  [5039] = 4976,
  [5040] = 2505,
  [5041] = 4986,
  [5042] = 4972,
  [5043] = 4976,
  [5044] = 4982,
  [5045] = 4976,
  [5046] = 4986,
  [5047] = 4975,
  [5048] = 4986,
  [5049] = 4976,
  [5050] = 4982,
  [5051] = 4970,
  [5052] = 4982,
  [5053] = 4982,
  [5054] = 4970,
  [5055] = 4975,
  [5056] = 4972,
  [5057] = 4982,
  [5058] = 4970,
  [5059] = 4970,
  [5060] = 4971,
  [5061] = 4970,
  [5062] = 4970,
  [5063] = 4976,
  [5064] = 4970,
  [5065] = 4970,
  [5066] = 4975,
  [5067] = 4970,
  [5068] = 4970,
  [5069] = 4971,
  [5070] = 4975,
  [5071] = 4970,
  [5072] = 4972,
  [5073] = 4970,
  [5074] = 4972,
  [5075] = 4970,
  [5076] = 4976,
  [5077] = 4970,
  [5078] = 5078,
  [5079] = 4972,
  [5080] = 4975,
  [5081] = 4986,
  [5082] = 4976,
  [5083] = 4972,
  [5084] = 4982,
  [5085] = 4976,
  [5086] = 4986,
  [5087] = 4976,
  [5088] = 4976,
  [5089] = 4972,
  [5090] = 4975,
  [5091] = 4975,
  [5092] = 4975,
  [5093] = 4976,
  [5094] = 4975,
  [5095] = 4972,
  [5096] = 5096,
  [5097] = 4986,
  [5098] = 5098,
  [5099] = 4971,
  [5100] = 5100,
  [5101] = 4972,
  [5102] = 4975,
  [5103] = 4986,
  [5104] = 4982,
  [5105] = 4971,
  [5106] = 5106,
  [5107] = 4976,
  [5108] = 4972,
  [5109] = 4972,
  [5110] = 3474,
  [5111] = 4976,
  [5112] = 4975,
  [5113] = 4971,
  [5114] = 4982,
  [5115] = 4986,
  [5116] = 2505,
  [5117] = 4971,
  [5118] = 4971,
  [5119] = 4970,
  [5120] = 4986,
  [5121] = 4975,
  [5122] = 4976,
  [5123] = 4982,
  [5124] = 4971,
  [5125] = 5125,
  [5126] = 4976,
  [5127] = 4975,
  [5128] = 4972,
  [5129] = 4982,
  [5130] = 4971,
  [5131] = 4972,
  [5132] = 4972,
  [5133] = 4972,
  [5134] = 4982,
  [5135] = 4971,
  [5136] = 5136,
  [5137] = 4975,
  [5138] = 4976,
  [5139] = 4982,
  [5140] = 4975,
  [5141] = 4972,
  [5142] = 4975,
  [5143] = 4972,
  [5144] = 4976,
  [5145] = 5145,
  [5146] = 4976,
  [5147] = 4982,
  [5148] = 4975,
  [5149] = 4986,
  [5150] = 5150,
  [5151] = 4972,
  [5152] = 4986,
  [5153] = 4972,
  [5154] = 4976,
  [5155] = 4975,
  [5156] = 4982,
  [5157] = 4975,
  [5158] = 4982,
  [5159] = 4986,
  [5160] = 5160,
  [5161] = 4972,
  [5162] = 4982,
  [5163] = 4972,
  [5164] = 5164,
  [5165] = 5165,
  [5166] = 5166,
  [5167] = 5167,
  [5168] = 5166,
  [5169] = 5166,
  [5170] = 5166,
  [5171] = 5171,
  [5172] = 5172,
  [5173] = 5173,
  [5174] = 5174,
  [5175] = 5175,
  [5176] = 5176,
  [5177] = 5164,
  [5178] = 5178,
  [5179] = 5179,
  [5180] = 5180,
  [5181] = 5181,
  [5182] = 2592,
  [5183] = 5180,
  [5184] = 5184,
  [5185] = 5180,
  [5186] = 5164,
  [5187] = 5187,
  [5188] = 5180,
  [5189] = 5189,
  [5190] = 5181,
  [5191] = 5191,
  [5192] = 5180,
  [5193] = 5193,
  [5194] = 5180,
  [5195] = 5189,
  [5196] = 5181,
  [5197] = 5179,
  [5198] = 5175,
  [5199] = 5189,
  [5200] = 5191,
  [5201] = 5201,
  [5202] = 5202,
  [5203] = 5193,
  [5204] = 5181,
  [5205] = 5181,
  [5206] = 5180,
  [5207] = 5181,
  [5208] = 5191,
  [5209] = 5180,
  [5210] = 5189,
  [5211] = 5181,
  [5212] = 5191,
  [5213] = 5193,
  [5214] = 5180,
  [5215] = 5181,
  [5216] = 5191,
  [5217] = 5193,
  [5218] = 5180,
  [5219] = 5181,
  [5220] = 5191,
  [5221] = 5172,
  [5222] = 5172,
  [5223] = 5174,
  [5224] = 5180,
  [5225] = 5175,
  [5226] = 5226,
  [5227] = 5181,
  [5228] = 5202,
  [5229] = 5166,
  [5230] = 5174,
  [5231] = 5180,
  [5232] = 5189,
  [5233] = 5180,
  [5234] = 5189,
  [5235] = 5189,
  [5236] = 5173,
  [5237] = 5237,
  [5238] = 5181,
  [5239] = 5189,
  [5240] = 5189,
  [5241] = 5193,
  [5242] = 5180,
  [5243] = 5181,
  [5244] = 5191,
  [5245] = 5172,
  [5246] = 5174,
  [5247] = 5172,
  [5248] = 5226,
  [5249] = 5172,
  [5250] = 5166,
  [5251] = 5189,
  [5252] = 5175,
  [5253] = 5226,
  [5254] = 5193,
  [5255] = 5189,
  [5256] = 5175,
  [5257] = 5174,
  [5258] = 5226,
  [5259] = 5172,
  [5260] = 5202,
  [5261] = 5193,
  [5262] = 5189,
  [5263] = 5174,
  [5264] = 5172,
  [5265] = 5174,
  [5266] = 5172,
  [5267] = 5174,
  [5268] = 5173,
  [5269] = 5191,
  [5270] = 5178,
  [5271] = 5179,
  [5272] = 5272,
  [5273] = 5175,
  [5274] = 5226,
  [5275] = 5275,
  [5276] = 5184,
  [5277] = 5175,
  [5278] = 5164,
  [5279] = 602,
  [5280] = 5180,
  [5281] = 5189,
  [5282] = 5181,
  [5283] = 5191,
  [5284] = 5193,
  [5285] = 5175,
  [5286] = 5180,
  [5287] = 5181,
  [5288] = 5191,
  [5289] = 5189,
  [5290] = 5193,
  [5291] = 5172,
  [5292] = 5174,
  [5293] = 5175,
  [5294] = 5226,
  [5295] = 5174,
  [5296] = 5172,
  [5297] = 5173,
  [5298] = 5178,
  [5299] = 5179,
  [5300] = 5166,
  [5301] = 5301,
  [5302] = 5302,
  [5303] = 5184,
  [5304] = 5164,
  [5305] = 5226,
  [5306] = 5180,
  [5307] = 5181,
  [5308] = 5191,
  [5309] = 5189,
  [5310] = 5193,
  [5311] = 5226,
  [5312] = 5174,
  [5313] = 5172,
  [5314] = 5173,
  [5315] = 5191,
  [5316] = 5178,
  [5317] = 5179,
  [5318] = 5184,
  [5319] = 5164,
  [5320] = 5180,
  [5321] = 5181,
  [5322] = 5189,
  [5323] = 5173,
  [5324] = 5181,
  [5325] = 5202,
  [5326] = 5178,
  [5327] = 5179,
  [5328] = 5193,
  [5329] = 5202,
  [5330] = 5330,
  [5331] = 5202,
  [5332] = 5184,
  [5333] = 5164,
  [5334] = 5191,
  [5335] = 5180,
  [5336] = 5173,
  [5337] = 5337,
  [5338] = 5178,
  [5339] = 5179,
  [5340] = 5187,
  [5341] = 5184,
  [5342] = 5164,
  [5343] = 5343,
  [5344] = 5173,
  [5345] = 5345,
  [5346] = 5191,
  [5347] = 5178,
  [5348] = 5179,
  [5349] = 5172,
  [5350] = 5350,
  [5351] = 5180,
  [5352] = 5180,
  [5353] = 5181,
  [5354] = 5181,
  [5355] = 5166,
  [5356] = 5174,
  [5357] = 5184,
  [5358] = 5164,
  [5359] = 5191,
  [5360] = 5173,
  [5361] = 5302,
  [5362] = 5178,
  [5363] = 5179,
  [5364] = 5364,
  [5365] = 5202,
  [5366] = 5366,
  [5367] = 5184,
  [5368] = 5368,
  [5369] = 5164,
  [5370] = 4898,
  [5371] = 5173,
  [5372] = 5181,
  [5373] = 5178,
  [5374] = 5179,
  [5375] = 5175,
  [5376] = 5376,
  [5377] = 5191,
  [5378] = 5189,
  [5379] = 5193,
  [5380] = 5184,
  [5381] = 5193,
  [5382] = 5189,
  [5383] = 5164,
  [5384] = 5173,
  [5385] = 5385,
  [5386] = 5172,
  [5387] = 5178,
  [5388] = 5179,
  [5389] = 5389,
  [5390] = 5166,
  [5391] = 5180,
  [5392] = 5180,
  [5393] = 5191,
  [5394] = 5184,
  [5395] = 5174,
  [5396] = 5164,
  [5397] = 5397,
  [5398] = 5193,
  [5399] = 5173,
  [5400] = 5202,
  [5401] = 5401,
  [5402] = 5178,
  [5403] = 5179,
  [5404] = 5226,
  [5405] = 5181,
  [5406] = 5193,
  [5407] = 5184,
  [5408] = 5173,
  [5409] = 5191,
  [5410] = 5181,
  [5411] = 5178,
  [5412] = 5179,
  [5413] = 5184,
  [5414] = 5164,
  [5415] = 5189,
  [5416] = 5193,
  [5417] = 5180,
  [5418] = 5181,
  [5419] = 5191,
  [5420] = 5178,
  [5421] = 5179,
  [5422] = 5172,
  [5423] = 5166,
  [5424] = 5184,
  [5425] = 5174,
  [5426] = 5164,
  [5427] = 5191,
  [5428] = 5178,
  [5429] = 5179,
  [5430] = 5184,
  [5431] = 5172,
  [5432] = 5184,
  [5433] = 5164,
  [5434] = 5166,
  [5435] = 5178,
  [5436] = 5179,
  [5437] = 5184,
  [5438] = 5174,
  [5439] = 5164,
  [5440] = 5440,
  [5441] = 5178,
  [5442] = 5179,
  [5443] = 5202,
  [5444] = 5175,
  [5445] = 5226,
  [5446] = 5184,
  [5447] = 5193,
  [5448] = 5164,
  [5449] = 5179,
  [5450] = 5179,
  [5451] = 5451,
  [5452] = 5179,
  [5453] = 5453,
  [5454] = 5454,
  [5455] = 5179,
  [5456] = 5456,
  [5457] = 5179,
  [5458] = 5458,
  [5459] = 5179,
  [5460] = 5179,
  [5461] = 5461,
  [5462] = 5237,
  [5463] = 5397,
  [5464] = 5179,
  [5465] = 5179,
  [5466] = 5179,
  [5467] = 5191,
  [5468] = 5202,
  [5469] = 5469,
  [5470] = 5470,
  [5471] = 5345,
  [5472] = 5472,
  [5473] = 5175,
  [5474] = 5180,
  [5475] = 5453,
  [5476] = 5179,
  [5477] = 5477,
  [5478] = 5478,
  [5479] = 5202,
  [5480] = 5189,
  [5481] = 5180,
  [5482] = 5191,
  [5483] = 5193,
  [5484] = 5178,
  [5485] = 5485,
  [5486] = 5191,
  [5487] = 5389,
  [5488] = 5180,
  [5489] = 5489,
  [5490] = 5451,
  [5491] = 5491,
  [5492] = 5189,
  [5493] = 5493,
  [5494] = 5494,
  [5495] = 5495,
  [5496] = 5191,
  [5497] = 5181,
  [5498] = 5181,
  [5499] = 5172,
  [5500] = 5166,
  [5501] = 5174,
  [5502] = 5189,
  [5503] = 5193,
  [5504] = 5172,
  [5505] = 5505,
  [5506] = 5172,
  [5507] = 5507,
  [5508] = 5166,
  [5509] = 5202,
  [5510] = 5174,
  [5511] = 5511,
  [5512] = 5180,
  [5513] = 5166,
  [5514] = 5514,
  [5515] = 5515,
  [5516] = 5516,
  [5517] = 5516,
  [5518] = 5518,
  [5519] = 5172,
  [5520] = 5166,
  [5521] = 5174,
  [5522] = 5180,
  [5523] = 5523,
  [5524] = 5181,
  [5525] = 5191,
  [5526] = 5174,
  [5527] = 5189,
  [5528] = 5189,
  [5529] = 5193,
  [5530] = 5172,
  [5531] = 5166,
  [5532] = 5174,
  [5533] = 5181,
  [5534] = 5189,
  [5535] = 5172,
  [5536] = 5193,
  [5537] = 5166,
  [5538] = 2597,
  [5539] = 5174,
  [5540] = 5174,
  [5541] = 5193,
  [5542] = 5172,
  [5543] = 5470,
  [5544] = 5166,
  [5545] = 5189,
  [5546] = 5193,
  [5547] = 5226,
  [5548] = 5166,
  [5549] = 5175,
  [5550] = 5226,
  [5551] = 5172,
  [5552] = 5174,
  [5553] = 5172,
  [5554] = 5166,
  [5555] = 5173,
  [5556] = 5166,
  [5557] = 5180,
  [5558] = 5189,
  [5559] = 5181,
  [5560] = 5191,
  [5561] = 5193,
  [5562] = 5172,
  [5563] = 5174,
  [5564] = 5172,
  [5565] = 5179,
  [5566] = 5173,
  [5567] = 5166,
  [5568] = 5174,
  [5569] = 5173,
  [5570] = 5193,
  [5571] = 5179,
  [5572] = 5470,
  [5573] = 5345,
  [5574] = 5174,
  [5575] = 5453,
  [5576] = 5451,
  [5577] = 5491,
  [5578] = 5470,
  [5579] = 5345,
  [5580] = 5453,
  [5581] = 5202,
  [5582] = 5451,
  [5583] = 5491,
  [5584] = 5470,
  [5585] = 5345,
  [5586] = 5453,
  [5587] = 5451,
  [5588] = 5491,
  [5589] = 5470,
  [5590] = 5345,
  [5591] = 5453,
  [5592] = 5172,
  [5593] = 5451,
  [5594] = 5491,
  [5595] = 5470,
  [5596] = 5345,
  [5597] = 5166,
  [5598] = 5453,
  [5599] = 5451,
  [5600] = 5491,
  [5601] = 5470,
  [5602] = 5345,
  [5603] = 5174,
  [5604] = 5453,
  [5605] = 5491,
  [5606] = 5470,
  [5607] = 5345,
  [5608] = 5191,
  [5609] = 5453,
  [5610] = 5470,
  [5611] = 5345,
  [5612] = 5453,
  [5613] = 5470,
  [5614] = 5345,
  [5615] = 5453,
  [5616] = 5470,
  [5617] = 5345,
  [5618] = 5453,
  [5619] = 5191,
  [5620] = 5470,
  [5621] = 5345,
  [5622] = 5453,
  [5623] = 5345,
  [5624] = 5345,
  [5625] = 5166,
  [5626] = 5174,
  [5627] = 5189,
  [5628] = 5193,
  [5629] = 3474,
  [5630] = 5172,
  [5631] = 5166,
  [5632] = 5376,
  [5633] = 5174,
  [5634] = 5634,
  [5635] = 5166,
  [5636] = 5176,
  [5637] = 5191,
  [5638] = 5181,
  [5639] = 5191,
  [5640] = 5193,
  [5641] = 5166,
  [5642] = 5180,
  [5643] = 5175,
  [5644] = 5226,
  [5645] = 5166,
  [5646] = 5173,
  [5647] = 5376,
  [5648] = 5202,
  [5649] = 5176,
  [5650] = 5376,
  [5651] = 5176,
  [5652] = 5166,
  [5653] = 5376,
  [5654] = 5189,
  [5655] = 5176,
  [5656] = 2574,
  [5657] = 5376,
  [5658] = 5202,
  [5659] = 5176,
  [5660] = 5376,
  [5661] = 5176,
  [5662] = 5376,
  [5663] = 5176,
  [5664] = 5376,
  [5665] = 5176,
  [5666] = 5166,
  [5667] = 5376,
  [5668] = 5176,
  [5669] = 5193,
  [5670] = 5189,
  [5671] = 5376,
  [5672] = 5193,
  [5673] = 5176,
  [5674] = 5172,
  [5675] = 2546,
  [5676] = 5376,
  [5677] = 5166,
  [5678] = 5176,
  [5679] = 5174,
  [5680] = 5376,
  [5681] = 5176,
  [5682] = 5181,
  [5683] = 5176,
  [5684] = 5176,
  [5685] = 5176,
  [5686] = 5176,
  [5687] = 5173,
  [5688] = 5350,
  [5689] = 5350,
  [5690] = 5350,
  [5691] = 5350,
  [5692] = 5350,
  [5693] = 5350,
  [5694] = 5166,
  [5695] = 5193,
  [5696] = 5175,
  [5697] = 5226,
  [5698] = 5698,
  [5699] = 5478,
  [5700] = 5478,
  [5701] = 5478,
  [5702] = 5478,
  [5703] = 5478,
  [5704] = 5478,
  [5705] = 5478,
  [5706] = 5478,
  [5707] = 5478,
  [5708] = 5478,
  [5709] = 5478,
  [5710] = 5478,
  [5711] = 5478,
  [5712] = 5478,
  [5713] = 5478,
  [5714] = 5478,
  [5715] = 5715,
  [5716] = 5716,
  [5717] = 5717,
  [5718] = 5718,
  [5719] = 5719,
  [5720] = 5716,
  [5721] = 5721,
  [5722] = 5719,
  [5723] = 5723,
  [5724] = 5718,
  [5725] = 5719,
  [5726] = 5726,
  [5727] = 5719,
  [5728] = 5716,
  [5729] = 5726,
  [5730] = 5719,
  [5731] = 5723,
  [5732] = 5716,
  [5733] = 5718,
  [5734] = 5718,
  [5735] = 5715,
  [5736] = 5716,
  [5737] = 5723,
  [5738] = 5726,
  [5739] = 5719,
  [5740] = 5723,
  [5741] = 5716,
  [5742] = 5726,
  [5743] = 5718,
  [5744] = 5718,
  [5745] = 5745,
  [5746] = 5719,
  [5747] = 5723,
  [5748] = 5726,
  [5749] = 5718,
  [5750] = 5719,
  [5751] = 5723,
  [5752] = 5723,
  [5753] = 5753,
  [5754] = 5716,
  [5755] = 5718,
  [5756] = 5715,
  [5757] = 5726,
  [5758] = 5716,
  [5759] = 3474,
  [5760] = 5716,
  [5761] = 5726,
  [5762] = 5726,
  [5763] = 5719,
  [5764] = 5723,
  [5765] = 5716,
  [5766] = 5719,
  [5767] = 5718,
  [5768] = 5716,
  [5769] = 5726,
  [5770] = 5770,
  [5771] = 5771,
  [5772] = 5719,
  [5773] = 5719,
  [5774] = 5716,
  [5775] = 5723,
  [5776] = 5718,
  [5777] = 5723,
  [5778] = 5718,
  [5779] = 5716,
  [5780] = 5726,
  [5781] = 5723,
  [5782] = 5719,
  [5783] = 5718,
  [5784] = 5716,
  [5785] = 5723,
  [5786] = 5723,
  [5787] = 5787,
  [5788] = 5716,
  [5789] = 5718,
  [5790] = 5718,
  [5791] = 5718,
  [5792] = 5718,
  [5793] = 5726,
  [5794] = 5726,
  [5795] = 5726,
  [5796] = 5719,
  [5797] = 5723,
  [5798] = 5723,
  [5799] = 5716,
  [5800] = 5716,
  [5801] = 5718,
  [5802] = 5719,
  [5803] = 5803,
  [5804] = 5723,
  [5805] = 5726,
  [5806] = 5719,
  [5807] = 5807,
  [5808] = 5808,
  [5809] = 5726,
  [5810] = 5716,
  [5811] = 5723,
  [5812] = 5812,
  [5813] = 5719,
  [5814] = 5723,
  [5815] = 5716,
  [5816] = 5716,
  [5817] = 5726,
  [5818] = 5723,
  [5819] = 5716,
  [5820] = 5716,
  [5821] = 5718,
  [5822] = 5726,
  [5823] = 5719,
  [5824] = 5723,
  [5825] = 5717,
  [5826] = 5716,
  [5827] = 5718,
  [5828] = 5718,
  [5829] = 5718,
  [5830] = 5726,
  [5831] = 5719,
  [5832] = 5718,
  [5833] = 5719,
  [5834] = 5726,
  [5835] = 5723,
  [5836] = 5719,
  [5837] = 5716,
  [5838] = 5719,
  [5839] = 5718,
  [5840] = 5719,
  [5841] = 5723,
  [5842] = 5726,
  [5843] = 5726,
  [5844] = 5723,
  [5845] = 5726,
  [5846] = 5719,
  [5847] = 5723,
  [5848] = 5716,
  [5849] = 5716,
  [5850] = 5718,
  [5851] = 5718,
  [5852] = 5726,
  [5853] = 5726,
  [5854] = 5719,
  [5855] = 5723,
  [5856] = 5716,
  [5857] = 5717,
  [5858] = 5718,
  [5859] = 5717,
  [5860] = 5718,
  [5861] = 5726,
  [5862] = 5717,
  [5863] = 5718,
  [5864] = 5726,
  [5865] = 5717,
  [5866] = 5716,
  [5867] = 5719,
  [5868] = 5717,
  [5869] = 5723,
  [5870] = 5717,
  [5871] = 5716,
  [5872] = 5716,
  [5873] = 5718,
  [5874] = 5717,
  [5875] = 5718,
  [5876] = 5717,
  [5877] = 5717,
  [5878] = 5719,
  [5879] = 5719,
  [5880] = 5719,
  [5881] = 5726,
  [5882] = 5717,
  [5883] = 5717,
  [5884] = 5726,
  [5885] = 5723,
  [5886] = 5719,
  [5887] = 5726,
  [5888] = 5723,
  [5889] = 5716,
  [5890] = 5718,
  [5891] = 5716,
  [5892] = 5719,
  [5893] = 5723,
  [5894] = 5723,
  [5895] = 5723,
  [5896] = 5726,
  [5897] = 5897,
  [5898] = 5718,
  [5899] = 5726,
  [5900] = 5719,
  [5901] = 5901,
  [5902] = 5902,
  [5903] = 735,
  [5904] = 735,
  [5905] = 735,
  [5906] = 5906,
  [5907] = 735,
  [5908] = 5906,
  [5909] = 5906,
  [5910] = 5910,
  [5911] = 735,
  [5912] = 5912,
  [5913] = 5913,
  [5914] = 735,
  [5915] = 5915,
  [5916] = 735,
  [5917] = 5906,
  [5918] = 735,
  [5919] = 5915,
  [5920] = 735,
  [5921] = 5910,
  [5922] = 5922,
  [5923] = 5906,
  [5924] = 5924,
  [5925] = 5912,
  [5926] = 5915,
  [5927] = 735,
  [5928] = 5928,
  [5929] = 5906,
  [5930] = 735,
  [5931] = 5915,
  [5932] = 5906,
  [5933] = 735,
  [5934] = 5906,
  [5935] = 5906,
  [5936] = 5906,
  [5937] = 5915,
  [5938] = 5915,
  [5939] = 5913,
  [5940] = 5906,
  [5941] = 5915,
  [5942] = 5942,
  [5943] = 5913,
  [5944] = 4968,
  [5945] = 5915,
  [5946] = 5913,
  [5947] = 5906,
  [5948] = 5928,
  [5949] = 5906,
  [5950] = 5906,
  [5951] = 5951,
  [5952] = 735,
  [5953] = 5906,
  [5954] = 5915,
  [5955] = 735,
  [5956] = 5906,
  [5957] = 735,
  [5958] = 5915,
  [5959] = 5915,
  [5960] = 5915,
  [5961] = 5913,
  [5962] = 4956,
  [5963] = 735,
  [5964] = 5913,
  [5965] = 5915,
  [5966] = 5906,
  [5967] = 5967,
  [5968] = 5968,
  [5969] = 5969,
  [5970] = 5970,
  [5971] = 4959,
  [5972] = 5972,
  [5973] = 5972,
  [5974] = 5970,
  [5975] = 5968,
  [5976] = 5976,
  [5977] = 5977,
  [5978] = 5976,
  [5979] = 5976,
  [5980] = 5968,
  [5981] = 5976,
  [5982] = 5982,
  [5983] = 4956,
  [5984] = 5984,
  [5985] = 5984,
  [5986] = 5977,
  [5987] = 5969,
  [5988] = 5969,
  [5989] = 5967,
  [5990] = 5977,
  [5991] = 5967,
  [5992] = 4954,
  [5993] = 5969,
  [5994] = 5994,
  [5995] = 5977,
  [5996] = 5996,
  [5997] = 5970,
  [5998] = 5970,
  [5999] = 5977,
  [6000] = 6000,
  [6001] = 3474,
  [6002] = 5970,
  [6003] = 6003,
  [6004] = 6004,
  [6005] = 5972,
  [6006] = 6006,
  [6007] = 6003,
  [6008] = 5976,
  [6009] = 6009,
  [6010] = 5984,
  [6011] = 5977,
  [6012] = 5970,
  [6013] = 6003,
  [6014] = 5968,
  [6015] = 6003,
  [6016] = 6016,
  [6017] = 5977,
  [6018] = 6003,
  [6019] = 5984,
  [6020] = 5976,
  [6021] = 6021,
  [6022] = 5984,
  [6023] = 6004,
  [6024] = 5968,
  [6025] = 6004,
  [6026] = 5967,
  [6027] = 6003,
  [6028] = 5970,
  [6029] = 6004,
  [6030] = 5967,
  [6031] = 5977,
  [6032] = 4953,
  [6033] = 4961,
  [6034] = 5976,
  [6035] = 5984,
  [6036] = 4966,
  [6037] = 5984,
  [6038] = 6004,
  [6039] = 6003,
  [6040] = 6040,
  [6041] = 5994,
  [6042] = 5970,
  [6043] = 4968,
  [6044] = 5972,
  [6045] = 5967,
  [6046] = 6046,
  [6047] = 6003,
  [6048] = 5969,
  [6049] = 5969,
  [6050] = 6050,
  [6051] = 4960,
  [6052] = 5970,
  [6053] = 5972,
  [6054] = 5967,
  [6055] = 6055,
  [6056] = 6056,
  [6057] = 5968,
  [6058] = 6003,
  [6059] = 5967,
  [6060] = 5968,
  [6061] = 5969,
  [6062] = 5970,
  [6063] = 5969,
  [6064] = 4957,
  [6065] = 5984,
  [6066] = 5977,
  [6067] = 5972,
  [6068] = 5969,
  [6069] = 6069,
  [6070] = 5968,
  [6071] = 6004,
  [6072] = 5976,
  [6073] = 5976,
  [6074] = 5977,
  [6075] = 6004,
  [6076] = 5972,
  [6077] = 5977,
  [6078] = 5970,
  [6079] = 5968,
  [6080] = 5976,
  [6081] = 673,
  [6082] = 5967,
  [6083] = 5967,
  [6084] = 5977,
  [6085] = 5977,
  [6086] = 5969,
  [6087] = 5970,
  [6088] = 5972,
  [6089] = 5968,
  [6090] = 4963,
  [6091] = 5970,
  [6092] = 5970,
  [6093] = 6003,
  [6094] = 5984,
  [6095] = 5984,
  [6096] = 5970,
  [6097] = 5967,
  [6098] = 5969,
  [6099] = 5977,
  [6100] = 6003,
  [6101] = 6101,
  [6102] = 5968,
  [6103] = 5968,
  [6104] = 5976,
  [6105] = 6105,
  [6106] = 5967,
  [6107] = 6004,
  [6108] = 5977,
  [6109] = 6004,
  [6110] = 6021,
  [6111] = 5984,
  [6112] = 5984,
  [6113] = 6004,
  [6114] = 6004,
  [6115] = 6003,
  [6116] = 5972,
  [6117] = 5984,
  [6118] = 5967,
  [6119] = 5970,
  [6120] = 6004,
  [6121] = 4967,
  [6122] = 6122,
  [6123] = 6101,
  [6124] = 5972,
  [6125] = 6125,
  [6126] = 5977,
  [6127] = 5996,
  [6128] = 6128,
  [6129] = 5969,
  [6130] = 6130,
  [6131] = 5967,
  [6132] = 5968,
  [6133] = 5972,
  [6134] = 6000,
  [6135] = 5976,
  [6136] = 5967,
  [6137] = 6004,
  [6138] = 5972,
  [6139] = 5969,
  [6140] = 5970,
  [6141] = 6003,
  [6142] = 5967,
  [6143] = 5977,
  [6144] = 5967,
  [6145] = 5976,
  [6146] = 5972,
  [6147] = 6147,
  [6148] = 6148,
  [6149] = 6149,
  [6150] = 6150,
  [6151] = 6148,
  [6152] = 602,
  [6153] = 6153,
  [6154] = 6148,
  [6155] = 6148,
  [6156] = 6156,
  [6157] = 6148,
  [6158] = 6156,
  [6159] = 602,
  [6160] = 6148,
  [6161] = 6156,
  [6162] = 6162,
  [6163] = 602,
  [6164] = 6156,
  [6165] = 6148,
  [6166] = 602,
  [6167] = 6156,
  [6168] = 6156,
  [6169] = 6156,
  [6170] = 6148,
  [6171] = 6156,
  [6172] = 6156,
  [6173] = 6173,
  [6174] = 6156,
  [6175] = 6175,
  [6176] = 6156,
  [6177] = 6156,
  [6178] = 6156,
  [6179] = 602,
  [6180] = 6180,
  [6181] = 6148,
  [6182] = 602,
  [6183] = 831,
  [6184] = 6148,
  [6185] = 602,
  [6186] = 6148,
  [6187] = 6148,
  [6188] = 6188,
  [6189] = 6189,
  [6190] = 6148,
  [6191] = 6191,
  [6192] = 602,
  [6193] = 6148,
  [6194] = 602,
  [6195] = 6195,
  [6196] = 6196,
  [6197] = 602,
  [6198] = 6198,
  [6199] = 4983,
  [6200] = 6200,
  [6201] = 6201,
  [6202] = 6202,
  [6203] = 602,
  [6204] = 6148,
  [6205] = 6205,
  [6206] = 6153,
  [6207] = 602,
  [6208] = 6148,
  [6209] = 602,
  [6210] = 6148,
  [6211] = 602,
  [6212] = 6212,
  [6213] = 6213,
  [6214] = 6214,
  [6215] = 6215,
  [6216] = 6216,
  [6217] = 6213,
  [6218] = 6218,
  [6219] = 6219,
  [6220] = 6220,
  [6221] = 6218,
  [6222] = 6220,
  [6223] = 6223,
  [6224] = 6224,
  [6225] = 6225,
  [6226] = 6218,
  [6227] = 6227,
  [6228] = 6228,
  [6229] = 6225,
  [6230] = 6219,
  [6231] = 6218,
  [6232] = 6232,
  [6233] = 6233,
  [6234] = 6218,
  [6235] = 6235,
  [6236] = 6236,
  [6237] = 6216,
  [6238] = 6215,
  [6239] = 6227,
  [6240] = 6224,
  [6241] = 6228,
  [6242] = 6242,
  [6243] = 6218,
  [6244] = 6232,
  [6245] = 6213,
  [6246] = 6246,
  [6247] = 6233,
  [6248] = 6219,
  [6249] = 6235,
  [6250] = 6218,
  [6251] = 6251,
  [6252] = 6215,
  [6253] = 6224,
  [6254] = 6215,
  [6255] = 6216,
  [6256] = 6242,
  [6257] = 6236,
  [6258] = 6224,
  [6259] = 6242,
  [6260] = 6232,
  [6261] = 6213,
  [6262] = 6233,
  [6263] = 6235,
  [6264] = 6219,
  [6265] = 6224,
  [6266] = 6215,
  [6267] = 6242,
  [6268] = 6251,
  [6269] = 6213,
  [6270] = 6218,
  [6271] = 6232,
  [6272] = 6219,
  [6273] = 6233,
  [6274] = 6235,
  [6275] = 6224,
  [6276] = 6251,
  [6277] = 6215,
  [6278] = 6236,
  [6279] = 6228,
  [6280] = 6232,
  [6281] = 6216,
  [6282] = 6242,
  [6283] = 6232,
  [6284] = 6233,
  [6285] = 6235,
  [6286] = 6236,
  [6287] = 6219,
  [6288] = 6215,
  [6289] = 6213,
  [6290] = 6242,
  [6291] = 6224,
  [6292] = 6228,
  [6293] = 6218,
  [6294] = 6232,
  [6295] = 6233,
  [6296] = 6235,
  [6297] = 6215,
  [6298] = 6298,
  [6299] = 6223,
  [6300] = 6225,
  [6301] = 6232,
  [6302] = 6302,
  [6303] = 6233,
  [6304] = 6235,
  [6305] = 6215,
  [6306] = 6213,
  [6307] = 6219,
  [6308] = 6220,
  [6309] = 6232,
  [6310] = 6227,
  [6311] = 6233,
  [6312] = 6235,
  [6313] = 6215,
  [6314] = 6220,
  [6315] = 6219,
  [6316] = 6216,
  [6317] = 6242,
  [6318] = 6232,
  [6319] = 6233,
  [6320] = 6235,
  [6321] = 6215,
  [6322] = 6215,
  [6323] = 6228,
  [6324] = 6224,
  [6325] = 6325,
  [6326] = 6219,
  [6327] = 6232,
  [6328] = 6232,
  [6329] = 6233,
  [6330] = 6235,
  [6331] = 6215,
  [6332] = 6219,
  [6333] = 6223,
  [6334] = 6218,
  [6335] = 6225,
  [6336] = 6223,
  [6337] = 6232,
  [6338] = 6233,
  [6339] = 6233,
  [6340] = 6235,
  [6341] = 6215,
  [6342] = 6242,
  [6343] = 6219,
  [6344] = 6232,
  [6345] = 6224,
  [6346] = 6233,
  [6347] = 6215,
  [6348] = 6224,
  [6349] = 6232,
  [6350] = 6227,
  [6351] = 6233,
  [6352] = 6215,
  [6353] = 6213,
  [6354] = 6228,
  [6355] = 6233,
  [6356] = 6215,
  [6357] = 6251,
  [6358] = 6233,
  [6359] = 6215,
  [6360] = 6216,
  [6361] = 6215,
  [6362] = 6362,
  [6363] = 6215,
  [6364] = 6218,
  [6365] = 6215,
  [6366] = 6224,
  [6367] = 6215,
  [6368] = 6215,
  [6369] = 6227,
  [6370] = 6215,
  [6371] = 6251,
  [6372] = 6215,
  [6373] = 6228,
  [6374] = 6215,
  [6375] = 6236,
  [6376] = 6235,
  [6377] = 6218,
  [6378] = 6242,
  [6379] = 6251,
  [6380] = 6246,
  [6381] = 6219,
  [6382] = 6228,
  [6383] = 6215,
  [6384] = 6325,
  [6385] = 6236,
  [6386] = 6225,
  [6387] = 6224,
  [6388] = 6242,
  [6389] = 6251,
  [6390] = 6236,
  [6391] = 6391,
  [6392] = 6213,
  [6393] = 6227,
  [6394] = 6213,
  [6395] = 6220,
  [6396] = 6213,
  [6397] = 6397,
  [6398] = 6216,
  [6399] = 6219,
  [6400] = 6223,
  [6401] = 6213,
  [6402] = 6224,
  [6403] = 6227,
  [6404] = 6223,
  [6405] = 6225,
  [6406] = 6227,
  [6407] = 6251,
  [6408] = 6236,
  [6409] = 6225,
  [6410] = 6242,
  [6411] = 6223,
  [6412] = 6218,
  [6413] = 6227,
  [6414] = 6219,
  [6415] = 6227,
  [6416] = 6227,
  [6417] = 6242,
  [6418] = 6227,
  [6419] = 6242,
  [6420] = 6218,
  [6421] = 6251,
  [6422] = 6236,
  [6423] = 6224,
  [6424] = 6216,
  [6425] = 6213,
  [6426] = 6242,
  [6427] = 6218,
  [6428] = 6223,
  [6429] = 6218,
  [6430] = 6227,
  [6431] = 6242,
  [6432] = 6219,
  [6433] = 6225,
  [6434] = 6224,
  [6435] = 6218,
  [6436] = 6219,
  [6437] = 6227,
  [6438] = 6213,
  [6439] = 6228,
  [6440] = 6224,
  [6441] = 6242,
  [6442] = 6224,
  [6443] = 6218,
  [6444] = 6220,
  [6445] = 6224,
  [6446] = 6219,
  [6447] = 6213,
  [6448] = 6242,
  [6449] = 6224,
  [6450] = 6219,
  [6451] = 6213,
  [6452] = 6213,
  [6453] = 6227,
  [6454] = 6233,
  [6455] = 6227,
  [6456] = 6216,
  [6457] = 6228,
  [6458] = 6227,
  [6459] = 6220,
  [6460] = 6216,
  [6461] = 6218,
  [6462] = 6218,
  [6463] = 6251,
  [6464] = 6236,
  [6465] = 6215,
  [6466] = 6223,
  [6467] = 6218,
  [6468] = 6225,
  [6469] = 6219,
  [6470] = 6219,
  [6471] = 6246,
  [6472] = 6224,
  [6473] = 6227,
  [6474] = 6213,
  [6475] = 6218,
  [6476] = 6224,
  [6477] = 6397,
  [6478] = 6219,
  [6479] = 6218,
  [6480] = 6246,
  [6481] = 6225,
  [6482] = 6213,
  [6483] = 6219,
  [6484] = 6397,
  [6485] = 6219,
  [6486] = 6213,
  [6487] = 6246,
  [6488] = 6213,
  [6489] = 6215,
  [6490] = 6224,
  [6491] = 6242,
  [6492] = 6397,
  [6493] = 6213,
  [6494] = 6219,
  [6495] = 6246,
  [6496] = 6242,
  [6497] = 6227,
  [6498] = 6251,
  [6499] = 6220,
  [6500] = 6220,
  [6501] = 6397,
  [6502] = 6216,
  [6503] = 6228,
  [6504] = 6246,
  [6505] = 6224,
  [6506] = 6218,
  [6507] = 6213,
  [6508] = 6508,
  [6509] = 6218,
  [6510] = 6397,
  [6511] = 6219,
  [6512] = 6216,
  [6513] = 6246,
  [6514] = 6251,
  [6515] = 6224,
  [6516] = 6236,
  [6517] = 6218,
  [6518] = 6242,
  [6519] = 6224,
  [6520] = 6246,
  [6521] = 6213,
  [6522] = 6224,
  [6523] = 6242,
  [6524] = 6227,
  [6525] = 6224,
  [6526] = 6242,
  [6527] = 6246,
  [6528] = 6213,
  [6529] = 6325,
  [6530] = 6223,
  [6531] = 6246,
  [6532] = 6216,
  [6533] = 6220,
  [6534] = 6227,
  [6535] = 6223,
  [6536] = 6216,
  [6537] = 6224,
  [6538] = 6227,
  [6539] = 6246,
  [6540] = 6225,
  [6541] = 6218,
  [6542] = 6213,
  [6543] = 6242,
  [6544] = 6220,
  [6545] = 6242,
  [6546] = 6246,
  [6547] = 6227,
  [6548] = 6220,
  [6549] = 6220,
  [6550] = 6227,
  [6551] = 6235,
  [6552] = 6227,
  [6553] = 6227,
  [6554] = 6223,
  [6555] = 6219,
  [6556] = 6251,
  [6557] = 6218,
  [6558] = 6225,
  [6559] = 6236,
  [6560] = 6236,
  [6561] = 6227,
  [6562] = 6224,
  [6563] = 6242,
  [6564] = 6219,
  [6565] = 6242,
  [6566] = 6213,
  [6567] = 6225,
  [6568] = 6251,
  [6569] = 6213,
  [6570] = 6236,
  [6571] = 6224,
  [6572] = 6224,
  [6573] = 6219,
  [6574] = 6213,
  [6575] = 6218,
  [6576] = 6224,
  [6577] = 6213,
  [6578] = 6218,
  [6579] = 6242,
  [6580] = 6218,
  [6581] = 6581,
  [6582] = 6227,
  [6583] = 6242,
  [6584] = 6242,
  [6585] = 6391,
  [6586] = 6391,
  [6587] = 6391,
  [6588] = 6391,
  [6589] = 6391,
  [6590] = 6391,
  [6591] = 6227,
  [6592] = 6219,
  [6593] = 6227,
  [6594] = 6223,
  [6595] = 6228,
  [6596] = 6242,
  [6597] = 6227,
  [6598] = 6213,
  [6599] = 6251,
  [6600] = 6251,
  [6601] = 6236,
  [6602] = 6219,
  [6603] = 6215,
  [6604] = 6213,
  [6605] = 6218,
  [6606] = 6228,
  [6607] = 6216,
  [6608] = 6251,
  [6609] = 6219,
  [6610] = 6236,
  [6611] = 6236,
  [6612] = 6251,
  [6613] = 6236,
  [6614] = 6397,
  [6615] = 6615,
  [6616] = 6616,
  [6617] = 6617,
  [6618] = 6618,
  [6619] = 6619,
  [6620] = 6620,
  [6621] = 6621,
  [6622] = 6621,
  [6623] = 6621,
  [6624] = 6621,
  [6625] = 6621,
  [6626] = 6621,
  [6627] = 6621,
  [6628] = 6628,
  [6629] = 6628,
  [6630] = 6630,
  [6631] = 6631,
  [6632] = 535,
  [6633] = 6633,
  [6634] = 6634,
  [6635] = 6634,
  [6636] = 534,
  [6637] = 6633,
  [6638] = 6634,
  [6639] = 6639,
  [6640] = 6639,
  [6641] = 6633,
  [6642] = 6639,
  [6643] = 535,
  [6644] = 6633,
  [6645] = 6639,
  [6646] = 6634,
  [6647] = 534,
  [6648] = 534,
  [6649] = 535,
  [6650] = 6639,
  [6651] = 6651,
  [6652] = 544,
  [6653] = 6633,
  [6654] = 6634,
  [6655] = 6639,
  [6656] = 6634,
  [6657] = 6633,
  [6658] = 522,
  [6659] = 526,
  [6660] = 6660,
  [6661] = 534,
  [6662] = 535,
  [6663] = 532,
  [6664] = 542,
  [6665] = 520,
  [6666] = 521,
  [6667] = 545,
  [6668] = 522,
  [6669] = 524,
  [6670] = 525,
  [6671] = 526,
  [6672] = 534,
  [6673] = 532,
  [6674] = 542,
  [6675] = 521,
  [6676] = 545,
  [6677] = 524,
  [6678] = 525,
  [6679] = 526,
  [6680] = 6680,
  [6681] = 544,
  [6682] = 535,
  [6683] = 532,
  [6684] = 542,
  [6685] = 520,
  [6686] = 521,
  [6687] = 545,
  [6688] = 522,
  [6689] = 524,
  [6690] = 525,
  [6691] = 520,
  [6692] = 535,
  [6693] = 532,
  [6694] = 542,
  [6695] = 520,
  [6696] = 521,
  [6697] = 545,
  [6698] = 522,
  [6699] = 524,
  [6700] = 525,
  [6701] = 526,
  [6702] = 661,
  [6703] = 664,
  [6704] = 522,
  [6705] = 524,
  [6706] = 525,
  [6707] = 544,
  [6708] = 532,
  [6709] = 542,
  [6710] = 532,
  [6711] = 520,
  [6712] = 661,
  [6713] = 522,
  [6714] = 664,
  [6715] = 526,
  [6716] = 520,
  [6717] = 521,
  [6718] = 545,
  [6719] = 534,
  [6720] = 817,
  [6721] = 521,
  [6722] = 545,
  [6723] = 522,
  [6724] = 534,
  [6725] = 664,
  [6726] = 6726,
  [6727] = 535,
  [6728] = 524,
  [6729] = 525,
  [6730] = 526,
  [6731] = 734,
  [6732] = 816,
  [6733] = 817,
  [6734] = 542,
  [6735] = 803,
  [6736] = 846,
  [6737] = 661,
  [6738] = 846,
  [6739] = 734,
  [6740] = 803,
  [6741] = 818,
  [6742] = 520,
  [6743] = 816,
  [6744] = 818,
  [6745] = 532,
  [6746] = 526,
  [6747] = 6747,
  [6748] = 803,
  [6749] = 846,
  [6750] = 6750,
  [6751] = 542,
  [6752] = 817,
  [6753] = 6753,
  [6754] = 521,
  [6755] = 545,
  [6756] = 544,
  [6757] = 818,
  [6758] = 816,
  [6759] = 524,
  [6760] = 6760,
  [6761] = 525,
  [6762] = 535,
  [6763] = 734,
  [6764] = 534,
  [6765] = 6765,
  [6766] = 6765,
  [6767] = 6765,
  [6768] = 6765,
  [6769] = 6765,
  [6770] = 6765,
  [6771] = 6765,
  [6772] = 534,
  [6773] = 6765,
  [6774] = 535,
  [6775] = 6765,
  [6776] = 6765,
  [6777] = 6765,
  [6778] = 6765,
  [6779] = 6765,
  [6780] = 6765,
  [6781] = 534,
  [6782] = 535,
  [6783] = 6765,
  [6784] = 6784,
  [6785] = 535,
  [6786] = 6786,
  [6787] = 6765,
  [6788] = 6765,
  [6789] = 534,
  [6790] = 535,
  [6791] = 6765,
  [6792] = 6765,
  [6793] = 6793,
  [6794] = 534,
  [6795] = 535,
  [6796] = 6765,
  [6797] = 6765,
  [6798] = 6765,
  [6799] = 6765,
  [6800] = 6765,
  [6801] = 544,
  [6802] = 6765,
  [6803] = 6765,
  [6804] = 6804,
  [6805] = 6765,
  [6806] = 6765,
  [6807] = 544,
  [6808] = 6765,
  [6809] = 6765,
  [6810] = 534,
  [6811] = 6765,
  [6812] = 532,
  [6813] = 542,
  [6814] = 520,
  [6815] = 521,
  [6816] = 545,
  [6817] = 522,
  [6818] = 524,
  [6819] = 525,
  [6820] = 526,
  [6821] = 522,
  [6822] = 545,
  [6823] = 520,
  [6824] = 521,
  [6825] = 522,
  [6826] = 524,
  [6827] = 525,
  [6828] = 545,
  [6829] = 526,
  [6830] = 520,
  [6831] = 532,
  [6832] = 521,
  [6833] = 542,
  [6834] = 532,
  [6835] = 520,
  [6836] = 542,
  [6837] = 521,
  [6838] = 545,
  [6839] = 524,
  [6840] = 525,
  [6841] = 526,
  [6842] = 534,
  [6843] = 535,
  [6844] = 520,
  [6845] = 521,
  [6846] = 542,
  [6847] = 522,
  [6848] = 520,
  [6849] = 521,
  [6850] = 545,
  [6851] = 524,
  [6852] = 522,
  [6853] = 6853,
  [6854] = 524,
  [6855] = 522,
  [6856] = 525,
  [6857] = 524,
  [6858] = 525,
  [6859] = 526,
  [6860] = 532,
  [6861] = 542,
  [6862] = 526,
  [6863] = 6863,
  [6864] = 525,
  [6865] = 664,
  [6866] = 545,
  [6867] = 526,
  [6868] = 6868,
  [6869] = 661,
  [6870] = 532,
  [6871] = 542,
  [6872] = 532,
  [6873] = 532,
  [6874] = 803,
  [6875] = 818,
  [6876] = 846,
  [6877] = 734,
  [6878] = 817,
  [6879] = 816,
  [6880] = 818,
  [6881] = 542,
  [6882] = 520,
  [6883] = 521,
  [6884] = 545,
  [6885] = 661,
  [6886] = 664,
  [6887] = 661,
  [6888] = 664,
  [6889] = 522,
  [6890] = 524,
  [6891] = 525,
  [6892] = 846,
  [6893] = 526,
  [6894] = 734,
  [6895] = 803,
  [6896] = 816,
  [6897] = 816,
  [6898] = 6898,
  [6899] = 6899,
  [6900] = 803,
  [6901] = 6901,
  [6902] = 818,
  [6903] = 6903,
  [6904] = 846,
  [6905] = 6905,
  [6906] = 803,
  [6907] = 846,
  [6908] = 734,
  [6909] = 803,
  [6910] = 816,
  [6911] = 818,
  [6912] = 6912,
  [6913] = 669,
  [6914] = 675,
  [6915] = 846,
  [6916] = 6916,
  [6917] = 671,
  [6918] = 734,
  [6919] = 683,
  [6920] = 817,
  [6921] = 816,
  [6922] = 734,
  [6923] = 665,
  [6924] = 817,
  [6925] = 6925,
  [6926] = 816,
  [6927] = 803,
  [6928] = 6928,
  [6929] = 667,
  [6930] = 818,
  [6931] = 818,
  [6932] = 6932,
  [6933] = 846,
  [6934] = 734,
  [6935] = 6935,
  [6936] = 6936,
  [6937] = 668,
  [6938] = 832,
  [6939] = 6939,
  [6940] = 6940,
  [6941] = 6941,
  [6942] = 6942,
  [6943] = 6943,
  [6944] = 6944,
  [6945] = 6945,
  [6946] = 6946,
  [6947] = 6947,
  [6948] = 6948,
  [6949] = 6949,
  [6950] = 6950,
  [6951] = 709,
  [6952] = 663,
  [6953] = 6953,
  [6954] = 6954,
  [6955] = 6955,
  [6956] = 6956,
  [6957] = 6957,
  [6958] = 6958,
  [6959] = 6959,
  [6960] = 6960,
  [6961] = 6961,
  [6962] = 6962,
  [6963] = 681,
  [6964] = 843,
  [6965] = 682,
  [6966] = 6966,
  [6967] = 6967,
  [6968] = 6968,
  [6969] = 6969,
  [6970] = 6970,
  [6971] = 706,
  [6972] = 666,
  [6973] = 6973,
  [6974] = 6974,
  [6975] = 6975,
  [6976] = 684,
  [6977] = 6977,
  [6978] = 6978,
  [6979] = 6979,
  [6980] = 6980,
  [6981] = 841,
  [6982] = 6982,
  [6983] = 6983,
  [6984] = 6984,
  [6985] = 6985,
  [6986] = 6986,
  [6987] = 672,
  [6988] = 6988,
  [6989] = 6989,
  [6990] = 6990,
  [6991] = 6942,
  [6992] = 6984,
  [6993] = 6950,
  [6994] = 6994,
  [6995] = 533,
  [6996] = 6943,
  [6997] = 6997,
  [6998] = 6998,
  [6999] = 6999,
  [7000] = 7000,
  [7001] = 6944,
  [7002] = 7002,
  [7003] = 6628,
  [7004] = 567,
  [7005] = 6945,
  [7006] = 7006,
  [7007] = 7007,
  [7008] = 7008,
  [7009] = 6968,
  [7010] = 7010,
  [7011] = 561,
  [7012] = 7012,
  [7013] = 7013,
  [7014] = 7014,
  [7015] = 6982,
  [7016] = 7016,
  [7017] = 7017,
  [7018] = 6956,
  [7019] = 7019,
  [7020] = 6957,
  [7021] = 7021,
  [7022] = 7022,
  [7023] = 7023,
  [7024] = 7024,
  [7025] = 7025,
  [7026] = 7026,
  [7027] = 7027,
  [7028] = 6986,
  [7029] = 6970,
  [7030] = 7030,
  [7031] = 6974,
  [7032] = 670,
  [7033] = 7033,
  [7034] = 7034,
  [7035] = 662,
  [7036] = 6966,
  [7037] = 6961,
  [7038] = 7038,
  [7039] = 527,
  [7040] = 7040,
  [7041] = 6940,
  [7042] = 6969,
  [7043] = 7043,
  [7044] = 6978,
  [7045] = 7045,
  [7046] = 6979,
  [7047] = 6946,
  [7048] = 6947,
  [7049] = 6948,
  [7050] = 6949,
  [7051] = 6941,
  [7052] = 7052,
  [7053] = 7053,
  [7054] = 7054,
  [7055] = 7055,
  [7056] = 7056,
  [7057] = 7057,
  [7058] = 7058,
  [7059] = 7059,
  [7060] = 6903,
  [7061] = 816,
  [7062] = 7062,
  [7063] = 7063,
  [7064] = 7064,
  [7065] = 674,
  [7066] = 7066,
  [7067] = 7067,
  [7068] = 7068,
  [7069] = 7069,
  [7070] = 846,
  [7071] = 7071,
  [7072] = 7072,
  [7073] = 7073,
  [7074] = 7074,
  [7075] = 7075,
  [7076] = 803,
  [7077] = 7077,
  [7078] = 6898,
  [7079] = 818,
  [7080] = 734,
  [7081] = 7081,
  [7082] = 6628,
  [7083] = 7083,
  [7084] = 7084,
  [7085] = 7085,
  [7086] = 7086,
  [7087] = 7087,
  [7088] = 7088,
  [7089] = 7089,
  [7090] = 846,
  [7091] = 734,
  [7092] = 7092,
  [7093] = 7089,
  [7094] = 7094,
  [7095] = 7095,
  [7096] = 7096,
  [7097] = 7097,
  [7098] = 7098,
  [7099] = 7099,
  [7100] = 7100,
  [7101] = 7101,
  [7102] = 843,
  [7103] = 6628,
  [7104] = 843,
  [7105] = 7089,
  [7106] = 7106,
  [7107] = 7107,
  [7108] = 7108,
  [7109] = 7109,
  [7110] = 7110,
  [7111] = 7111,
  [7112] = 7112,
  [7113] = 7113,
  [7114] = 7089,
  [7115] = 719,
  [7116] = 7116,
  [7117] = 7117,
  [7118] = 7118,
  [7119] = 7092,
  [7120] = 7120,
  [7121] = 7121,
  [7122] = 7122,
  [7123] = 7089,
  [7124] = 7124,
  [7125] = 7092,
  [7126] = 7126,
  [7127] = 7127,
  [7128] = 7128,
  [7129] = 706,
  [7130] = 7130,
  [7131] = 7131,
  [7132] = 7132,
  [7133] = 7133,
  [7134] = 7134,
  [7135] = 781,
  [7136] = 7136,
  [7137] = 7137,
  [7138] = 7138,
  [7139] = 7139,
  [7140] = 7140,
  [7141] = 7141,
  [7142] = 7142,
  [7143] = 7143,
  [7144] = 786,
  [7145] = 7145,
  [7146] = 7146,
  [7147] = 7147,
  [7148] = 7148,
  [7149] = 7149,
  [7150] = 7150,
  [7151] = 7089,
  [7152] = 7152,
  [7153] = 7153,
  [7154] = 7154,
  [7155] = 7092,
  [7156] = 7156,
  [7157] = 7157,
  [7158] = 7158,
  [7159] = 790,
  [7160] = 7160,
  [7161] = 7161,
  [7162] = 709,
  [7163] = 7163,
  [7164] = 7164,
  [7165] = 7165,
  [7166] = 7166,
  [7167] = 7167,
  [7168] = 7168,
  [7169] = 7169,
  [7170] = 7170,
  [7171] = 7171,
  [7172] = 7172,
  [7173] = 7173,
  [7174] = 7174,
  [7175] = 793,
  [7176] = 7176,
  [7177] = 7177,
  [7178] = 7178,
  [7179] = 7089,
  [7180] = 7180,
  [7181] = 794,
  [7182] = 7182,
  [7183] = 7092,
  [7184] = 832,
  [7185] = 7185,
  [7186] = 796,
  [7187] = 798,
  [7188] = 7188,
  [7189] = 7092,
  [7190] = 799,
  [7191] = 7092,
  [7192] = 841,
  [7193] = 7089,
  [7194] = 7194,
  [7195] = 7195,
  [7196] = 7092,
  [7197] = 7197,
  [7198] = 800,
  [7199] = 802,
  [7200] = 7200,
  [7201] = 803,
  [7202] = 7202,
  [7203] = 7203,
  [7204] = 7204,
  [7205] = 7205,
  [7206] = 837,
  [7207] = 7207,
  [7208] = 7208,
  [7209] = 7209,
  [7210] = 7210,
  [7211] = 7211,
  [7212] = 704,
  [7213] = 7213,
  [7214] = 7214,
  [7215] = 7215,
  [7216] = 7216,
  [7217] = 7217,
  [7218] = 7218,
  [7219] = 7219,
  [7220] = 814,
  [7221] = 816,
  [7222] = 7222,
  [7223] = 818,
  [7224] = 7224,
  [7225] = 7225,
  [7226] = 7226,
  [7227] = 7227,
  [7228] = 7228,
  [7229] = 7229,
  [7230] = 7230,
  [7231] = 7089,
  [7232] = 7232,
  [7233] = 7233,
  [7234] = 7234,
  [7235] = 797,
  [7236] = 7089,
  [7237] = 7237,
  [7238] = 7238,
  [7239] = 7092,
  [7240] = 7092,
  [7241] = 7241,
  [7242] = 7089,
  [7243] = 825,
  [7244] = 7092,
  [7245] = 7245,
  [7246] = 846,
  [7247] = 7247,
  [7248] = 717,
  [7249] = 7249,
  [7250] = 7250,
  [7251] = 7251,
  [7252] = 7252,
  [7253] = 7253,
  [7254] = 7254,
  [7255] = 712,
  [7256] = 7256,
  [7257] = 7257,
  [7258] = 7258,
  [7259] = 852,
  [7260] = 853,
  [7261] = 854,
  [7262] = 7262,
  [7263] = 856,
  [7264] = 7264,
  [7265] = 7265,
  [7266] = 871,
  [7267] = 7267,
  [7268] = 7268,
  [7269] = 7269,
  [7270] = 7270,
  [7271] = 7271,
  [7272] = 7272,
  [7273] = 7273,
  [7274] = 7089,
  [7275] = 7275,
  [7276] = 7276,
  [7277] = 7277,
  [7278] = 7278,
  [7279] = 7092,
  [7280] = 803,
  [7281] = 816,
  [7282] = 818,
  [7283] = 7283,
  [7284] = 872,
  [7285] = 873,
  [7286] = 874,
  [7287] = 875,
  [7288] = 734,
  [7289] = 7289,
  [7290] = 835,
  [7291] = 7291,
  [7292] = 7292,
  [7293] = 7293,
  [7294] = 7294,
  [7295] = 7089,
  [7296] = 832,
  [7297] = 7297,
  [7298] = 723,
  [7299] = 726,
  [7300] = 728,
  [7301] = 7301,
  [7302] = 730,
  [7303] = 737,
  [7304] = 7304,
  [7305] = 7305,
  [7306] = 7306,
  [7307] = 742,
  [7308] = 745,
  [7309] = 747,
  [7310] = 7310,
  [7311] = 709,
  [7312] = 7092,
  [7313] = 7089,
  [7314] = 748,
  [7315] = 749,
  [7316] = 7316,
  [7317] = 7317,
  [7318] = 7092,
  [7319] = 7319,
  [7320] = 750,
  [7321] = 761,
  [7322] = 7322,
  [7323] = 7323,
  [7324] = 763,
  [7325] = 764,
  [7326] = 7326,
  [7327] = 7327,
  [7328] = 7328,
  [7329] = 870,
  [7330] = 7330,
  [7331] = 7331,
  [7332] = 7332,
  [7333] = 7333,
  [7334] = 7334,
  [7335] = 7089,
  [7336] = 714,
  [7337] = 7337,
  [7338] = 7338,
  [7339] = 7339,
  [7340] = 7340,
  [7341] = 7341,
  [7342] = 7089,
  [7343] = 7343,
  [7344] = 792,
  [7345] = 7092,
  [7346] = 7089,
  [7347] = 7347,
  [7348] = 7092,
  [7349] = 7092,
  [7350] = 7350,
  [7351] = 7351,
  [7352] = 7352,
  [7353] = 7353,
  [7354] = 7354,
  [7355] = 7355,
  [7356] = 7356,
  [7357] = 706,
  [7358] = 7358,
  [7359] = 7359,
  [7360] = 7359,
  [7361] = 7361,
  [7362] = 7362,
  [7363] = 792,
  [7364] = 7364,
  [7365] = 7365,
  [7366] = 7358,
  [7367] = 7367,
  [7368] = 6903,
  [7369] = 7362,
  [7370] = 7359,
  [7371] = 7361,
  [7372] = 7362,
  [7373] = 841,
  [7374] = 7374,
  [7375] = 7358,
  [7376] = 7376,
  [7377] = 7377,
  [7378] = 7359,
  [7379] = 7379,
  [7380] = 7379,
  [7381] = 7361,
  [7382] = 7362,
  [7383] = 7358,
  [7384] = 7359,
  [7385] = 837,
  [7386] = 7386,
  [7387] = 7379,
  [7388] = 7388,
  [7389] = 7389,
  [7390] = 7359,
  [7391] = 7377,
  [7392] = 7392,
  [7393] = 7393,
  [7394] = 7394,
  [7395] = 7358,
  [7396] = 7379,
  [7397] = 7358,
  [7398] = 7398,
  [7399] = 7399,
  [7400] = 7400,
  [7401] = 857,
  [7402] = 7402,
  [7403] = 7358,
  [7404] = 7404,
  [7405] = 7405,
  [7406] = 7406,
  [7407] = 6898,
  [7408] = 797,
  [7409] = 7045,
  [7410] = 7377,
  [7411] = 7361,
  [7412] = 7412,
  [7413] = 7374,
  [7414] = 7377,
  [7415] = 7374,
  [7416] = 7362,
  [7417] = 7379,
  [7418] = 7377,
  [7419] = 7361,
  [7420] = 7362,
  [7421] = 7421,
  [7422] = 7359,
  [7423] = 7374,
  [7424] = 7361,
  [7425] = 7425,
  [7426] = 7362,
  [7427] = 7361,
  [7428] = 7379,
  [7429] = 7362,
  [7430] = 7359,
  [7431] = 7379,
  [7432] = 7359,
  [7433] = 7433,
  [7434] = 7361,
  [7435] = 7358,
  [7436] = 7379,
  [7437] = 7379,
  [7438] = 7358,
  [7439] = 7439,
  [7440] = 6925,
  [7441] = 7377,
  [7442] = 7374,
  [7443] = 846,
  [7444] = 734,
  [7445] = 7379,
  [7446] = 7358,
  [7447] = 7359,
  [7448] = 7361,
  [7449] = 803,
  [7450] = 7450,
  [7451] = 818,
  [7452] = 7362,
  [7453] = 6899,
  [7454] = 7377,
  [7455] = 7374,
  [7456] = 7358,
  [7457] = 7377,
  [7458] = 7359,
  [7459] = 7379,
  [7460] = 7361,
  [7461] = 7362,
  [7462] = 7377,
  [7463] = 7358,
  [7464] = 7359,
  [7465] = 7358,
  [7466] = 7379,
  [7467] = 7467,
  [7468] = 7468,
  [7469] = 7469,
  [7470] = 7379,
  [7471] = 7471,
  [7472] = 6935,
  [7473] = 7377,
  [7474] = 7377,
  [7475] = 7475,
  [7476] = 7476,
  [7477] = 7359,
  [7478] = 7359,
  [7479] = 7377,
  [7480] = 7040,
  [7481] = 7374,
  [7482] = 7374,
  [7483] = 7361,
  [7484] = 7362,
  [7485] = 7361,
  [7486] = 7362,
  [7487] = 7362,
  [7488] = 7488,
  [7489] = 7359,
  [7490] = 7377,
  [7491] = 7358,
  [7492] = 7359,
  [7493] = 7379,
  [7494] = 7358,
  [7495] = 7495,
  [7496] = 817,
  [7497] = 7497,
  [7498] = 7358,
  [7499] = 7379,
  [7500] = 7361,
  [7501] = 7374,
  [7502] = 7361,
  [7503] = 7503,
  [7504] = 870,
  [7505] = 7361,
  [7506] = 7362,
  [7507] = 7507,
  [7508] = 7508,
  [7509] = 7509,
  [7510] = 7510,
  [7511] = 7377,
  [7512] = 7512,
  [7513] = 7362,
  [7514] = 7377,
  [7515] = 6936,
  [7516] = 7516,
  [7517] = 7377,
  [7518] = 7361,
  [7519] = 7362,
  [7520] = 7374,
  [7521] = 7359,
  [7522] = 7358,
  [7523] = 7523,
  [7524] = 7379,
  [7525] = 7377,
  [7526] = 7361,
  [7527] = 7362,
  [7528] = 7374,
  [7529] = 7379,
  [7530] = 816,
  [7531] = 7531,
  [7532] = 7532,
  [7533] = 7533,
  [7534] = 7534,
  [7535] = 7535,
  [7536] = 7536,
  [7537] = 7537,
  [7538] = 7538,
  [7539] = 7539,
  [7540] = 7540,
  [7541] = 7541,
  [7542] = 7542,
  [7543] = 7543,
  [7544] = 7537,
  [7545] = 7532,
  [7546] = 7546,
  [7547] = 7547,
  [7548] = 7548,
  [7549] = 7538,
  [7550] = 6628,
  [7551] = 7551,
  [7552] = 7539,
  [7553] = 7553,
  [7554] = 7539,
  [7555] = 7538,
  [7556] = 7556,
  [7557] = 7537,
  [7558] = 7558,
  [7559] = 7538,
  [7560] = 7560,
  [7561] = 7532,
  [7562] = 7536,
  [7563] = 7563,
  [7564] = 7558,
  [7565] = 7536,
  [7566] = 7532,
  [7567] = 7537,
  [7568] = 7568,
  [7569] = 7531,
  [7570] = 7542,
  [7571] = 7539,
  [7572] = 7558,
  [7573] = 7568,
  [7574] = 7574,
  [7575] = 7568,
  [7576] = 7542,
  [7577] = 7538,
  [7578] = 7568,
  [7579] = 7579,
  [7580] = 7568,
  [7581] = 7531,
  [7582] = 7532,
  [7583] = 7583,
  [7584] = 7534,
  [7585] = 7533,
  [7586] = 7551,
  [7587] = 7010,
  [7588] = 7532,
  [7589] = 7551,
  [7590] = 7531,
  [7591] = 7591,
  [7592] = 7532,
  [7593] = 7536,
  [7594] = 7531,
  [7595] = 7558,
  [7596] = 7568,
  [7597] = 7539,
  [7598] = 7536,
  [7599] = 7531,
  [7600] = 7600,
  [7601] = 7558,
  [7602] = 7602,
  [7603] = 7542,
  [7604] = 7551,
  [7605] = 7605,
  [7606] = 7606,
  [7607] = 7607,
  [7608] = 7608,
  [7609] = 7558,
  [7610] = 7551,
  [7611] = 7558,
  [7612] = 7537,
  [7613] = 7613,
  [7614] = 7536,
  [7615] = 7532,
  [7616] = 7537,
  [7617] = 7617,
  [7618] = 7536,
  [7619] = 7538,
  [7620] = 7542,
  [7621] = 7621,
  [7622] = 7622,
  [7623] = 7531,
  [7624] = 7624,
  [7625] = 7539,
  [7626] = 7568,
  [7627] = 7627,
  [7628] = 7537,
  [7629] = 7583,
  [7630] = 7532,
  [7631] = 7631,
  [7632] = 7532,
  [7633] = 7536,
  [7634] = 7560,
  [7635] = 7539,
  [7636] = 7542,
  [7637] = 7536,
  [7638] = 7560,
  [7639] = 7568,
  [7640] = 7542,
  [7641] = 7532,
  [7642] = 7536,
  [7643] = 7536,
  [7644] = 7531,
  [7645] = 7568,
  [7646] = 7533,
  [7647] = 7568,
  [7648] = 7532,
  [7649] = 7568,
  [7650] = 7542,
  [7651] = 7560,
  [7652] = 7542,
  [7653] = 7653,
  [7654] = 7531,
  [7655] = 7551,
  [7656] = 7656,
  [7657] = 7657,
  [7658] = 7658,
  [7659] = 7551,
  [7660] = 7558,
  [7661] = 7560,
  [7662] = 7662,
  [7663] = 7558,
  [7664] = 7664,
  [7665] = 7542,
  [7666] = 7666,
  [7667] = 7558,
  [7668] = 6990,
  [7669] = 7669,
  [7670] = 7670,
  [7671] = 7531,
  [7672] = 7558,
  [7673] = 7537,
  [7674] = 7542,
  [7675] = 7675,
  [7676] = 7676,
  [7677] = 7537,
  [7678] = 7532,
  [7679] = 7542,
  [7680] = 7680,
  [7681] = 7568,
  [7682] = 7682,
  [7683] = 7531,
  [7684] = 7536,
  [7685] = 7558,
  [7686] = 7686,
  [7687] = 7687,
  [7688] = 7542,
  [7689] = 7537,
  [7690] = 7568,
  [7691] = 7531,
  [7692] = 7536,
  [7693] = 7533,
  [7694] = 7537,
  [7695] = 7537,
  [7696] = 7539,
  [7697] = 7539,
  [7698] = 7551,
  [7699] = 7531,
  [7700] = 7533,
  [7701] = 7539,
  [7702] = 7532,
  [7703] = 7536,
  [7704] = 7531,
  [7705] = 7705,
  [7706] = 7706,
  [7707] = 7551,
  [7708] = 7542,
  [7709] = 7551,
  [7710] = 7539,
  [7711] = 7537,
  [7712] = 7539,
  [7713] = 7713,
  [7714] = 7539,
  [7715] = 7532,
  [7716] = 7664,
  [7717] = 7568,
  [7718] = 7532,
  [7719] = 7531,
  [7720] = 7720,
  [7721] = 7536,
  [7722] = 7538,
  [7723] = 7536,
  [7724] = 7724,
  [7725] = 7558,
  [7726] = 7558,
  [7727] = 7551,
  [7728] = 7542,
  [7729] = 7558,
  [7730] = 7551,
  [7731] = 7542,
  [7732] = 7732,
  [7733] = 7560,
  [7734] = 7551,
  [7735] = 7533,
  [7736] = 7542,
  [7737] = 7737,
  [7738] = 7558,
  [7739] = 7568,
  [7740] = 7532,
  [7741] = 7568,
  [7742] = 7536,
  [7743] = 7531,
  [7744] = 7558,
  [7745] = 7535,
  [7746] = 7568,
  [7747] = 7531,
  [7748] = 7748,
  [7749] = 7627,
  [7750] = 7750,
  [7751] = 7751,
  [7752] = 7752,
  [7753] = 7753,
  [7754] = 7025,
  [7755] = 7755,
  [7756] = 7756,
  [7757] = 7757,
  [7758] = 7753,
  [7759] = 7759,
  [7760] = 7760,
  [7761] = 7761,
  [7762] = 7753,
  [7763] = 7763,
  [7764] = 7764,
  [7765] = 7765,
  [7766] = 7766,
  [7767] = 7767,
  [7768] = 7756,
  [7769] = 7753,
  [7770] = 7770,
  [7771] = 7771,
  [7772] = 7772,
  [7773] = 7773,
  [7774] = 7751,
  [7775] = 7775,
  [7776] = 7776,
  [7777] = 7000,
  [7778] = 7757,
  [7779] = 7779,
  [7780] = 7779,
  [7781] = 7012,
  [7782] = 7782,
  [7783] = 6990,
  [7784] = 7784,
  [7785] = 7785,
  [7786] = 7786,
  [7787] = 7787,
  [7788] = 7788,
  [7789] = 7789,
  [7790] = 7761,
  [7791] = 7791,
  [7792] = 7772,
  [7793] = 7785,
  [7794] = 7794,
  [7795] = 7795,
  [7796] = 7753,
  [7797] = 7797,
  [7798] = 7798,
  [7799] = 7795,
  [7800] = 7800,
  [7801] = 7782,
  [7802] = 7802,
  [7803] = 7803,
  [7804] = 7770,
  [7805] = 7771,
  [7806] = 7806,
  [7807] = 7807,
  [7808] = 7808,
  [7809] = 7775,
  [7810] = 7810,
  [7811] = 7784,
  [7812] = 7812,
  [7813] = 7789,
  [7814] = 7791,
  [7815] = 7815,
  [7816] = 7816,
  [7817] = 7817,
  [7818] = 7755,
  [7819] = 7752,
  [7820] = 7787,
  [7821] = 7788,
  [7822] = 7797,
  [7823] = 7770,
  [7824] = 7757,
  [7825] = 7798,
  [7826] = 7826,
  [7827] = 7779,
  [7828] = 7828,
  [7829] = 7829,
  [7830] = 7776,
  [7831] = 7770,
  [7832] = 7771,
  [7833] = 7803,
  [7834] = 7785,
  [7835] = 7835,
  [7836] = 7795,
  [7837] = 7775,
  [7838] = 7838,
  [7839] = 7802,
  [7840] = 7755,
  [7841] = 7791,
  [7842] = 7842,
  [7843] = 7843,
  [7844] = 7787,
  [7845] = 7788,
  [7846] = 7846,
  [7847] = 7847,
  [7848] = 7043,
  [7849] = 7849,
  [7850] = 7770,
  [7851] = 7771,
  [7852] = 7846,
  [7853] = 7787,
  [7854] = 7843,
  [7855] = 7775,
  [7856] = 7027,
  [7857] = 7802,
  [7858] = 7858,
  [7859] = 7008,
  [7860] = 7786,
  [7861] = 7861,
  [7862] = 7862,
  [7863] = 7010,
  [7864] = 7771,
  [7865] = 7806,
  [7866] = 7807,
  [7867] = 7787,
  [7868] = 7788,
  [7869] = 7869,
  [7870] = 7756,
  [7871] = 7753,
  [7872] = 7770,
  [7873] = 7771,
  [7874] = 7874,
  [7875] = 7875,
  [7876] = 7786,
  [7877] = 7775,
  [7878] = 7878,
  [7879] = 7869,
  [7880] = 7880,
  [7881] = 7880,
  [7882] = 7882,
  [7883] = 7883,
  [7884] = 7884,
  [7885] = 7842,
  [7886] = 7886,
  [7887] = 7887,
  [7888] = 7888,
  [7889] = 7889,
  [7890] = 7890,
  [7891] = 7891,
  [7892] = 7770,
  [7893] = 7771,
  [7894] = 7810,
  [7895] = 7784,
  [7896] = 7816,
  [7897] = 7775,
  [7898] = 7882,
  [7899] = 7026,
  [7900] = 7752,
  [7901] = 7789,
  [7902] = 7016,
  [7903] = 7903,
  [7904] = 7759,
  [7905] = 7760,
  [7906] = 7017,
  [7907] = 7907,
  [7908] = 7764,
  [7909] = 7791,
  [7910] = 7910,
  [7911] = 7911,
  [7912] = 7773,
  [7913] = 7751,
  [7914] = 7914,
  [7915] = 7770,
  [7916] = 7771,
  [7917] = 7757,
  [7918] = 7775,
  [7919] = 7919,
  [7920] = 7779,
  [7921] = 7788,
  [7922] = 7782,
  [7923] = 7033,
  [7924] = 7782,
  [7925] = 6998,
  [7926] = 6997,
  [7927] = 7761,
  [7928] = 7772,
  [7929] = 7785,
  [7930] = 7795,
  [7931] = 7759,
  [7932] = 7797,
  [7933] = 7798,
  [7934] = 7770,
  [7935] = 7771,
  [7936] = 7936,
  [7937] = 7756,
  [7938] = 7775,
  [7939] = 7802,
  [7940] = 7806,
  [7941] = 7021,
  [7942] = 7807,
  [7943] = 7013,
  [7944] = 7944,
  [7945] = 7846,
  [7946] = 7753,
  [7947] = 7784,
  [7948] = 7789,
  [7949] = 7791,
  [7950] = 7950,
  [7951] = 7951,
  [7952] = 7776,
  [7953] = 7803,
  [7954] = 7770,
  [7955] = 7771,
  [7956] = 7956,
  [7957] = 7775,
  [7958] = 7958,
  [7959] = 7802,
  [7960] = 7960,
  [7961] = 7755,
  [7962] = 7962,
  [7963] = 7888,
  [7964] = 7847,
  [7965] = 7842,
  [7966] = 7760,
  [7967] = 7846,
  [7968] = 7847,
  [7969] = 7842,
  [7970] = 7847,
  [7971] = 7770,
  [7972] = 7771,
  [7973] = 7973,
  [7974] = 7761,
  [7975] = 7775,
  [7976] = 7843,
  [7977] = 7806,
  [7978] = 7978,
  [7979] = 7786,
  [7980] = 7775,
  [7981] = 7771,
  [7982] = 7982,
  [7983] = 7756,
  [7984] = 7753,
  [7985] = 7869,
  [7986] = 7843,
  [7987] = 7786,
  [7988] = 7869,
  [7989] = 7880,
  [7990] = 7990,
  [7991] = 7771,
  [7992] = 7882,
  [7993] = 7880,
  [7994] = 7756,
  [7995] = 7995,
  [7996] = 7753,
  [7997] = 7997,
  [7998] = 7891,
  [7999] = 7776,
  [8000] = 7803,
  [8001] = 7810,
  [8002] = 7807,
  [8003] = 7816,
  [8004] = 8004,
  [8005] = 8005,
  [8006] = 7752,
  [8007] = 8007,
  [8008] = 7759,
  [8009] = 7760,
  [8010] = 7882,
  [8011] = 8011,
  [8012] = 8012,
  [8013] = 7891,
  [8014] = 7773,
  [8015] = 7751,
  [8016] = 7786,
  [8017] = 7755,
  [8018] = 7757,
  [8019] = 8019,
  [8020] = 7779,
  [8021] = 7782,
  [8022] = 8022,
  [8023] = 7772,
  [8024] = 7761,
  [8025] = 7842,
  [8026] = 7772,
  [8027] = 7785,
  [8028] = 7761,
  [8029] = 7795,
  [8030] = 7797,
  [8031] = 7798,
  [8032] = 7772,
  [8033] = 7802,
  [8034] = 8034,
  [8035] = 7806,
  [8036] = 7846,
  [8037] = 7807,
  [8038] = 8038,
  [8039] = 7810,
  [8040] = 7784,
  [8041] = 7789,
  [8042] = 7791,
  [8043] = 8043,
  [8044] = 7810,
  [8045] = 7847,
  [8046] = 7776,
  [8047] = 7803,
  [8048] = 8048,
  [8049] = 7807,
  [8050] = 8050,
  [8051] = 7847,
  [8052] = 7785,
  [8053] = 7755,
  [8054] = 7846,
  [8055] = 7888,
  [8056] = 7816,
  [8057] = 7842,
  [8058] = 7846,
  [8059] = 7816,
  [8060] = 7843,
  [8061] = 7847,
  [8062] = 7958,
  [8063] = 8063,
  [8064] = 8064,
  [8065] = 7752,
  [8066] = 7776,
  [8067] = 7843,
  [8068] = 7764,
  [8069] = 7795,
  [8070] = 7765,
  [8071] = 7861,
  [8072] = 7757,
  [8073] = 8034,
  [8074] = 7779,
  [8075] = 7756,
  [8076] = 7785,
  [8077] = 7803,
  [8078] = 7753,
  [8079] = 8079,
  [8080] = 7795,
  [8081] = 7786,
  [8082] = 7869,
  [8083] = 7880,
  [8084] = 7802,
  [8085] = 7756,
  [8086] = 7753,
  [8087] = 7882,
  [8088] = 7797,
  [8089] = 7752,
  [8090] = 7791,
  [8091] = 7786,
  [8092] = 8063,
  [8093] = 7869,
  [8094] = 7880,
  [8095] = 8095,
  [8096] = 7798,
  [8097] = 7766,
  [8098] = 7882,
  [8099] = 7784,
  [8100] = 7785,
  [8101] = 7789,
  [8102] = 7756,
  [8103] = 7753,
  [8104] = 7891,
  [8105] = 8105,
  [8106] = 7810,
  [8107] = 7759,
  [8108] = 7760,
  [8109] = 7816,
  [8110] = 8110,
  [8111] = 8111,
  [8112] = 7752,
  [8113] = 8113,
  [8114] = 7888,
  [8115] = 8115,
  [8116] = 7759,
  [8117] = 7760,
  [8118] = 8118,
  [8119] = 7847,
  [8120] = 7773,
  [8121] = 7751,
  [8122] = 8122,
  [8123] = 7847,
  [8124] = 8124,
  [8125] = 7757,
  [8126] = 7779,
  [8127] = 7782,
  [8128] = 7791,
  [8129] = 7891,
  [8130] = 7786,
  [8131] = 7776,
  [8132] = 7803,
  [8133] = 7761,
  [8134] = 7770,
  [8135] = 7772,
  [8136] = 7785,
  [8137] = 7771,
  [8138] = 7795,
  [8139] = 7797,
  [8140] = 7798,
  [8141] = 7810,
  [8142] = 7764,
  [8143] = 7802,
  [8144] = 7806,
  [8145] = 7807,
  [8146] = 7765,
  [8147] = 7816,
  [8148] = 7755,
  [8149] = 7784,
  [8150] = 7789,
  [8151] = 7791,
  [8152] = 8152,
  [8153] = 8153,
  [8154] = 7842,
  [8155] = 7869,
  [8156] = 7776,
  [8157] = 7803,
  [8158] = 7880,
  [8159] = 7766,
  [8160] = 7752,
  [8161] = 7775,
  [8162] = 7755,
  [8163] = 8163,
  [8164] = 7757,
  [8165] = 7846,
  [8166] = 8166,
  [8167] = 7842,
  [8168] = 7753,
  [8169] = 7846,
  [8170] = 8170,
  [8171] = 7759,
  [8172] = 7760,
  [8173] = 7847,
  [8174] = 8174,
  [8175] = 7882,
  [8176] = 7847,
  [8177] = 7764,
  [8178] = 7843,
  [8179] = 8179,
  [8180] = 7765,
  [8181] = 7766,
  [8182] = 7756,
  [8183] = 7843,
  [8184] = 8184,
  [8185] = 7753,
  [8186] = 7773,
  [8187] = 7751,
  [8188] = 7795,
  [8189] = 7756,
  [8190] = 7753,
  [8191] = 7787,
  [8192] = 7788,
  [8193] = 8193,
  [8194] = 7786,
  [8195] = 7869,
  [8196] = 7880,
  [8197] = 7861,
  [8198] = 7882,
  [8199] = 7786,
  [8200] = 7757,
  [8201] = 7843,
  [8202] = 7773,
  [8203] = 7846,
  [8204] = 7891,
  [8205] = 8205,
  [8206] = 7810,
  [8207] = 7751,
  [8208] = 8208,
  [8209] = 7816,
  [8210] = 7779,
  [8211] = 8211,
  [8212] = 7752,
  [8213] = 7810,
  [8214] = 7846,
  [8215] = 7891,
  [8216] = 7756,
  [8217] = 7816,
  [8218] = 7782,
  [8219] = 8219,
  [8220] = 8220,
  [8221] = 7759,
  [8222] = 7760,
  [8223] = 7753,
  [8224] = 7773,
  [8225] = 7751,
  [8226] = 7752,
  [8227] = 7753,
  [8228] = 7786,
  [8229] = 7846,
  [8230] = 7757,
  [8231] = 7779,
  [8232] = 7869,
  [8233] = 7782,
  [8234] = 7880,
  [8235] = 7757,
  [8236] = 7757,
  [8237] = 7882,
  [8238] = 7761,
  [8239] = 7779,
  [8240] = 7779,
  [8241] = 7772,
  [8242] = 7785,
  [8243] = 7772,
  [8244] = 7795,
  [8245] = 7797,
  [8246] = 7798,
  [8247] = 7785,
  [8248] = 7785,
  [8249] = 7795,
  [8250] = 7802,
  [8251] = 8251,
  [8252] = 7806,
  [8253] = 7753,
  [8254] = 7797,
  [8255] = 7807,
  [8256] = 7798,
  [8257] = 7795,
  [8258] = 7888,
  [8259] = 7784,
  [8260] = 7789,
  [8261] = 7791,
  [8262] = 7802,
  [8263] = 8263,
  [8264] = 7891,
  [8265] = 7776,
  [8266] = 7802,
  [8267] = 7803,
  [8268] = 8268,
  [8269] = 7806,
  [8270] = 7891,
  [8271] = 7958,
  [8272] = 8064,
  [8273] = 8034,
  [8274] = 7807,
  [8275] = 8079,
  [8276] = 7784,
  [8277] = 8063,
  [8278] = 7755,
  [8279] = 7791,
  [8280] = 7779,
  [8281] = 8281,
  [8282] = 7810,
  [8283] = 7782,
  [8284] = 8079,
  [8285] = 7842,
  [8286] = 7784,
  [8287] = 7958,
  [8288] = 8064,
  [8289] = 8034,
  [8290] = 7816,
  [8291] = 8079,
  [8292] = 7846,
  [8293] = 7810,
  [8294] = 8063,
  [8295] = 7789,
  [8296] = 8296,
  [8297] = 7789,
  [8298] = 7776,
  [8299] = 7847,
  [8300] = 7791,
  [8301] = 7958,
  [8302] = 7843,
  [8303] = 8064,
  [8304] = 8034,
  [8305] = 8079,
  [8306] = 7752,
  [8307] = 8307,
  [8308] = 8063,
  [8309] = 7816,
  [8310] = 7803,
  [8311] = 7847,
  [8312] = 7759,
  [8313] = 7760,
  [8314] = 8314,
  [8315] = 7958,
  [8316] = 8316,
  [8317] = 8064,
  [8318] = 8034,
  [8319] = 8079,
  [8320] = 7753,
  [8321] = 8063,
  [8322] = 8322,
  [8323] = 8323,
  [8324] = 7756,
  [8325] = 7753,
  [8326] = 7764,
  [8327] = 7958,
  [8328] = 7765,
  [8329] = 8064,
  [8330] = 8034,
  [8331] = 8079,
  [8332] = 8063,
  [8333] = 7786,
  [8334] = 7766,
  [8335] = 7869,
  [8336] = 7880,
  [8337] = 7752,
  [8338] = 7882,
  [8339] = 7958,
  [8340] = 7861,
  [8341] = 8064,
  [8342] = 8034,
  [8343] = 8079,
  [8344] = 8063,
  [8345] = 7797,
  [8346] = 8346,
  [8347] = 661,
  [8348] = 7891,
  [8349] = 7773,
  [8350] = 7958,
  [8351] = 8064,
  [8352] = 8034,
  [8353] = 8079,
  [8354] = 7759,
  [8355] = 8063,
  [8356] = 7810,
  [8357] = 7791,
  [8358] = 7751,
  [8359] = 7816,
  [8360] = 7756,
  [8361] = 7958,
  [8362] = 8064,
  [8363] = 8034,
  [8364] = 8079,
  [8365] = 7752,
  [8366] = 7753,
  [8367] = 8063,
  [8368] = 7760,
  [8369] = 7759,
  [8370] = 7760,
  [8371] = 7757,
  [8372] = 7958,
  [8373] = 7776,
  [8374] = 8064,
  [8375] = 8034,
  [8376] = 8079,
  [8377] = 7803,
  [8378] = 7773,
  [8379] = 8063,
  [8380] = 7779,
  [8381] = 7751,
  [8382] = 7761,
  [8383] = 7782,
  [8384] = 7002,
  [8385] = 7958,
  [8386] = 8064,
  [8387] = 8034,
  [8388] = 8079,
  [8389] = 7757,
  [8390] = 8390,
  [8391] = 8063,
  [8392] = 7779,
  [8393] = 8393,
  [8394] = 7782,
  [8395] = 8395,
  [8396] = 7958,
  [8397] = 8064,
  [8398] = 8064,
  [8399] = 8034,
  [8400] = 8079,
  [8401] = 7761,
  [8402] = 8063,
  [8403] = 7772,
  [8404] = 7785,
  [8405] = 7786,
  [8406] = 7958,
  [8407] = 7795,
  [8408] = 8063,
  [8409] = 7773,
  [8410] = 664,
  [8411] = 7797,
  [8412] = 7798,
  [8413] = 7958,
  [8414] = 8414,
  [8415] = 7761,
  [8416] = 8063,
  [8417] = 7755,
  [8418] = 7958,
  [8419] = 7802,
  [8420] = 8063,
  [8421] = 7772,
  [8422] = 7806,
  [8423] = 7958,
  [8424] = 7807,
  [8425] = 8063,
  [8426] = 7785,
  [8427] = 7795,
  [8428] = 7784,
  [8429] = 7789,
  [8430] = 7791,
  [8431] = 8431,
  [8432] = 7797,
  [8433] = 7798,
  [8434] = 8184,
  [8435] = 7751,
  [8436] = 8436,
  [8437] = 7776,
  [8438] = 7803,
  [8439] = 7842,
  [8440] = 7772,
  [8441] = 7846,
  [8442] = 7785,
  [8443] = 7755,
  [8444] = 7846,
  [8445] = 7802,
  [8446] = 8446,
  [8447] = 7806,
  [8448] = 7907,
  [8449] = 7842,
  [8450] = 7773,
  [8451] = 7753,
  [8452] = 7846,
  [8453] = 7858,
  [8454] = 7847,
  [8455] = 8455,
  [8456] = 7847,
  [8457] = 7810,
  [8458] = 8458,
  [8459] = 7973,
  [8460] = 8460,
  [8461] = 7807,
  [8462] = 7990,
  [8463] = 7795,
  [8464] = 7843,
  [8465] = 7936,
  [8466] = 7944,
  [8467] = 7816,
  [8468] = 8468,
  [8469] = 7751,
  [8470] = 8316,
  [8471] = 8458,
  [8472] = 7784,
  [8473] = 7843,
  [8474] = 7797,
  [8475] = 8475,
  [8476] = 7789,
  [8477] = 7791,
  [8478] = 7752,
  [8479] = 7753,
  [8480] = 7798,
  [8481] = 7753,
  [8482] = 7756,
  [8483] = 7753,
  [8484] = 8484,
  [8485] = 8485,
  [8486] = 7786,
  [8487] = 7753,
  [8488] = 7869,
  [8489] = 7880,
  [8490] = 7757,
  [8491] = 7882,
  [8492] = 7861,
  [8493] = 7810,
  [8494] = 7779,
  [8495] = 7861,
  [8496] = 7891,
  [8497] = 7816,
  [8498] = 7810,
  [8499] = 8499,
  [8500] = 7816,
  [8501] = 7753,
  [8502] = 7752,
  [8503] = 7846,
  [8504] = 8504,
  [8505] = 8505,
  [8506] = 7759,
  [8507] = 7760,
  [8508] = 8508,
  [8509] = 7785,
  [8510] = 8510,
  [8511] = 7773,
  [8512] = 7751,
  [8513] = 7802,
  [8514] = 8458,
  [8515] = 7757,
  [8516] = 7779,
  [8517] = 8517,
  [8518] = 7782,
  [8519] = 8458,
  [8520] = 8520,
  [8521] = 7753,
  [8522] = 7761,
  [8523] = 7772,
  [8524] = 7785,
  [8525] = 8525,
  [8526] = 8458,
  [8527] = 7795,
  [8528] = 7795,
  [8529] = 7797,
  [8530] = 7798,
  [8531] = 8531,
  [8532] = 8458,
  [8533] = 7802,
  [8534] = 7802,
  [8535] = 7806,
  [8536] = 7807,
  [8537] = 8458,
  [8538] = 7806,
  [8539] = 7784,
  [8540] = 7756,
  [8541] = 7789,
  [8542] = 7791,
  [8543] = 7753,
  [8544] = 7776,
  [8545] = 7803,
  [8546] = 8546,
  [8547] = 8547,
  [8548] = 8548,
  [8549] = 7791,
  [8550] = 7755,
  [8551] = 7770,
  [8552] = 7771,
  [8553] = 8553,
  [8554] = 7842,
  [8555] = 7786,
  [8556] = 7846,
  [8557] = 8557,
  [8558] = 7869,
  [8559] = 7847,
  [8560] = 7880,
  [8561] = 7775,
  [8562] = 8562,
  [8563] = 7843,
  [8564] = 7755,
  [8565] = 7882,
  [8566] = 7798,
  [8567] = 8567,
  [8568] = 8568,
  [8569] = 7802,
  [8570] = 7756,
  [8571] = 7753,
  [8572] = 7888,
  [8573] = 7786,
  [8574] = 7869,
  [8575] = 7880,
  [8576] = 8576,
  [8577] = 7882,
  [8578] = 7806,
  [8579] = 7757,
  [8580] = 7787,
  [8581] = 7788,
  [8582] = 7779,
  [8583] = 7891,
  [8584] = 7891,
  [8585] = 7847,
  [8586] = 7978,
  [8587] = 7978,
  [8588] = 7810,
  [8589] = 7978,
  [8590] = 7842,
  [8591] = 7978,
  [8592] = 7978,
  [8593] = 7816,
  [8594] = 7978,
  [8595] = 7978,
  [8596] = 7978,
  [8597] = 7978,
  [8598] = 7978,
  [8599] = 7978,
  [8600] = 7978,
  [8601] = 7978,
  [8602] = 7978,
  [8603] = 7978,
  [8604] = 7978,
  [8605] = 7752,
  [8606] = 7810,
  [8607] = 7752,
  [8608] = 8608,
  [8609] = 7759,
  [8610] = 7760,
  [8611] = 8611,
  [8612] = 7816,
  [8613] = 7782,
  [8614] = 7773,
  [8615] = 7807,
  [8616] = 7761,
  [8617] = 8617,
  [8618] = 8618,
  [8619] = 8617,
  [8620] = 8620,
  [8621] = 8621,
  [8622] = 8622,
  [8623] = 8621,
  [8624] = 8624,
  [8625] = 8625,
  [8626] = 8621,
  [8627] = 8617,
  [8628] = 8628,
  [8629] = 8629,
  [8630] = 8628,
  [8631] = 8631,
  [8632] = 8632,
  [8633] = 8633,
  [8634] = 8621,
  [8635] = 8635,
  [8636] = 8636,
  [8637] = 8637,
  [8638] = 8617,
  [8639] = 8629,
  [8640] = 8629,
  [8641] = 8641,
  [8642] = 8642,
  [8643] = 8643,
  [8644] = 8633,
  [8645] = 8621,
  [8646] = 8625,
  [8647] = 8647,
  [8648] = 8648,
  [8649] = 8649,
  [8650] = 8650,
  [8651] = 8621,
  [8652] = 8625,
  [8653] = 8628,
  [8654] = 8650,
  [8655] = 8618,
  [8656] = 8618,
  [8657] = 8657,
  [8658] = 8658,
  [8659] = 8629,
  [8660] = 8642,
  [8661] = 8633,
  [8662] = 8642,
  [8663] = 8642,
  [8664] = 8633,
  [8665] = 8625,
  [8666] = 8633,
  [8667] = 8667,
  [8668] = 8629,
  [8669] = 8669,
  [8670] = 8670,
  [8671] = 8636,
  [8672] = 8670,
  [8673] = 8670,
  [8674] = 8636,
  [8675] = 8631,
  [8676] = 8637,
  [8677] = 8677,
  [8678] = 8636,
  [8679] = 8679,
  [8680] = 8618,
  [8681] = 8621,
  [8682] = 8631,
  [8683] = 8637,
  [8684] = 8621,
  [8685] = 8624,
  [8686] = 8617,
  [8687] = 8631,
  [8688] = 8637,
  [8689] = 8629,
  [8690] = 8690,
  [8691] = 8621,
  [8692] = 8618,
  [8693] = 8625,
  [8694] = 8628,
  [8695] = 8618,
  [8696] = 8624,
  [8697] = 8621,
  [8698] = 8617,
  [8699] = 8699,
  [8700] = 8650,
  [8701] = 8650,
  [8702] = 8628,
  [8703] = 8690,
  [8704] = 8704,
  [8705] = 8621,
  [8706] = 8618,
  [8707] = 8624,
  [8708] = 8708,
  [8709] = 8709,
  [8710] = 8650,
  [8711] = 8624,
  [8712] = 8712,
  [8713] = 8621,
  [8714] = 8690,
  [8715] = 8715,
  [8716] = 8629,
  [8717] = 8629,
  [8718] = 8617,
  [8719] = 8621,
  [8720] = 8720,
  [8721] = 8690,
  [8722] = 8722,
  [8723] = 8621,
  [8724] = 8724,
  [8725] = 8690,
  [8726] = 8617,
  [8727] = 8629,
  [8728] = 8629,
  [8729] = 8642,
  [8730] = 8633,
  [8731] = 8690,
  [8732] = 8642,
  [8733] = 8733,
  [8734] = 8734,
  [8735] = 8624,
  [8736] = 8690,
  [8737] = 8636,
  [8738] = 8670,
  [8739] = 8650,
  [8740] = 8624,
  [8741] = 8670,
  [8742] = 8690,
  [8743] = 8636,
  [8744] = 8744,
  [8745] = 8642,
  [8746] = 8618,
  [8747] = 8747,
  [8748] = 8642,
  [8749] = 8633,
  [8750] = 8621,
  [8751] = 8690,
  [8752] = 8650,
  [8753] = 8625,
  [8754] = 8629,
  [8755] = 8631,
  [8756] = 8637,
  [8757] = 8625,
  [8758] = 8758,
  [8759] = 8628,
  [8760] = 8633,
  [8761] = 8618,
  [8762] = 8690,
  [8763] = 8642,
  [8764] = 8633,
  [8765] = 8765,
  [8766] = 8628,
  [8767] = 8624,
  [8768] = 8768,
  [8769] = 8650,
  [8770] = 8770,
  [8771] = 8690,
  [8772] = 8772,
  [8773] = 8617,
  [8774] = 8774,
  [8775] = 8618,
  [8776] = 8670,
  [8777] = 8777,
  [8778] = 8636,
  [8779] = 8650,
  [8780] = 8690,
  [8781] = 8670,
  [8782] = 8631,
  [8783] = 8637,
  [8784] = 8670,
  [8785] = 8670,
  [8786] = 8636,
  [8787] = 8618,
  [8788] = 8636,
  [8789] = 8628,
  [8790] = 8790,
  [8791] = 8624,
  [8792] = 8670,
  [8793] = 8617,
  [8794] = 8621,
  [8795] = 8670,
  [8796] = 8670,
  [8797] = 8621,
  [8798] = 8798,
  [8799] = 8631,
  [8800] = 8621,
  [8801] = 8621,
  [8802] = 8636,
  [8803] = 8637,
  [8804] = 8621,
  [8805] = 8621,
  [8806] = 821,
  [8807] = 8636,
  [8808] = 8650,
  [8809] = 8642,
  [8810] = 8633,
  [8811] = 8811,
  [8812] = 8812,
  [8813] = 8618,
  [8814] = 8670,
  [8815] = 8815,
  [8816] = 8624,
  [8817] = 8817,
  [8818] = 8625,
  [8819] = 8624,
  [8820] = 8636,
  [8821] = 8629,
  [8822] = 8636,
  [8823] = 8617,
  [8824] = 8628,
  [8825] = 8629,
  [8826] = 8642,
  [8827] = 8633,
  [8828] = 8631,
  [8829] = 8637,
  [8830] = 8650,
  [8831] = 8618,
  [8832] = 8670,
  [8833] = 8833,
  [8834] = 8621,
  [8835] = 8625,
  [8836] = 8650,
  [8837] = 8629,
  [8838] = 8838,
  [8839] = 8839,
  [8840] = 8624,
  [8841] = 8631,
  [8842] = 8617,
  [8843] = 8843,
  [8844] = 8631,
  [8845] = 8637,
  [8846] = 8642,
  [8847] = 8633,
  [8848] = 8642,
  [8849] = 8849,
  [8850] = 8633,
  [8851] = 8636,
  [8852] = 8621,
  [8853] = 8853,
  [8854] = 8637,
  [8855] = 8670,
  [8856] = 8628,
  [8857] = 8636,
  [8858] = 8618,
  [8859] = 8859,
  [8860] = 8631,
  [8861] = 8637,
  [8862] = 8650,
  [8863] = 8631,
  [8864] = 8637,
  [8865] = 8642,
  [8866] = 8625,
  [8867] = 8618,
  [8868] = 8617,
  [8869] = 8618,
  [8870] = 8628,
  [8871] = 8624,
  [8872] = 8624,
  [8873] = 8617,
  [8874] = 8624,
  [8875] = 8624,
  [8876] = 8629,
  [8877] = 8877,
  [8878] = 8625,
  [8879] = 8621,
  [8880] = 8621,
  [8881] = 8628,
  [8882] = 8621,
  [8883] = 8629,
  [8884] = 8650,
  [8885] = 8617,
  [8886] = 8621,
  [8887] = 8670,
  [8888] = 8625,
  [8889] = 8633,
  [8890] = 8642,
  [8891] = 8633,
  [8892] = 8628,
  [8893] = 8893,
  [8894] = 8636,
  [8895] = 8895,
  [8896] = 8896,
  [8897] = 8631,
  [8898] = 8642,
  [8899] = 8637,
  [8900] = 8900,
  [8901] = 8617,
  [8902] = 8629,
  [8903] = 8633,
  [8904] = 8642,
  [8905] = 8621,
  [8906] = 8621,
  [8907] = 8907,
  [8908] = 8650,
  [8909] = 8621,
  [8910] = 8633,
  [8911] = 8670,
  [8912] = 8631,
  [8913] = 8636,
  [8914] = 8690,
  [8915] = 8650,
  [8916] = 8631,
  [8917] = 8631,
  [8918] = 7067,
  [8919] = 8637,
  [8920] = 8631,
  [8921] = 8637,
  [8922] = 8922,
  [8923] = 8618,
  [8924] = 8637,
  [8925] = 8650,
  [8926] = 8926,
  [8927] = 8625,
  [8928] = 8624,
  [8929] = 8637,
  [8930] = 8617,
  [8931] = 8621,
  [8932] = 8932,
  [8933] = 8933,
  [8934] = 8934,
  [8935] = 8935,
  [8936] = 8936,
  [8937] = 8937,
  [8938] = 8938,
  [8939] = 8939,
  [8940] = 8940,
  [8941] = 8941,
  [8942] = 8942,
  [8943] = 8943,
  [8944] = 8944,
  [8945] = 8945,
  [8946] = 8946,
  [8947] = 8942,
  [8948] = 8940,
  [8949] = 8935,
  [8950] = 8950,
  [8951] = 8934,
  [8952] = 8939,
  [8953] = 8953,
  [8954] = 8954,
  [8955] = 8955,
  [8956] = 8956,
  [8957] = 8957,
  [8958] = 8940,
  [8959] = 8936,
  [8960] = 8937,
  [8961] = 8938,
  [8962] = 8962,
  [8963] = 8953,
  [8964] = 8964,
  [8965] = 8964,
  [8966] = 8943,
  [8967] = 8962,
  [8968] = 8964,
  [8969] = 8942,
  [8970] = 8942,
  [8971] = 8940,
  [8972] = 8962,
  [8973] = 8940,
  [8974] = 8962,
  [8975] = 8953,
  [8976] = 8955,
  [8977] = 8977,
  [8978] = 8978,
  [8979] = 8979,
  [8980] = 8936,
  [8981] = 8937,
  [8982] = 8938,
  [8983] = 8950,
  [8984] = 8942,
  [8985] = 8935,
  [8986] = 8940,
  [8987] = 8943,
  [8988] = 8988,
  [8989] = 8950,
  [8990] = 8950,
  [8991] = 8978,
  [8992] = 8992,
  [8993] = 8977,
  [8994] = 8935,
  [8995] = 8940,
  [8996] = 8996,
  [8997] = 8955,
  [8998] = 8934,
  [8999] = 8999,
  [9000] = 8978,
  [9001] = 8936,
  [9002] = 8937,
  [9003] = 8938,
  [9004] = 8940,
  [9005] = 8950,
  [9006] = 8942,
  [9007] = 8934,
  [9008] = 8943,
  [9009] = 8940,
  [9010] = 8950,
  [9011] = 8935,
  [9012] = 8935,
  [9013] = 8934,
  [9014] = 8977,
  [9015] = 8962,
  [9016] = 8940,
  [9017] = 8978,
  [9018] = 8955,
  [9019] = 8996,
  [9020] = 8933,
  [9021] = 8954,
  [9022] = 8936,
  [9023] = 8937,
  [9024] = 8938,
  [9025] = 8935,
  [9026] = 8945,
  [9027] = 8933,
  [9028] = 8988,
  [9029] = 8943,
  [9030] = 8942,
  [9031] = 8940,
  [9032] = 8933,
  [9033] = 8950,
  [9034] = 8977,
  [9035] = 8988,
  [9036] = 8934,
  [9037] = 8940,
  [9038] = 8978,
  [9039] = 8955,
  [9040] = 8945,
  [9041] = 8978,
  [9042] = 8942,
  [9043] = 8936,
  [9044] = 8937,
  [9045] = 8938,
  [9046] = 8942,
  [9047] = 8935,
  [9048] = 8950,
  [9049] = 8941,
  [9050] = 8943,
  [9051] = 8940,
  [9052] = 8942,
  [9053] = 9053,
  [9054] = 9054,
  [9055] = 8996,
  [9056] = 9056,
  [9057] = 8953,
  [9058] = 8940,
  [9059] = 8935,
  [9060] = 8955,
  [9061] = 8999,
  [9062] = 8934,
  [9063] = 8940,
  [9064] = 8936,
  [9065] = 8937,
  [9066] = 8938,
  [9067] = 8933,
  [9068] = 8962,
  [9069] = 9069,
  [9070] = 8939,
  [9071] = 8943,
  [9072] = 8933,
  [9073] = 8950,
  [9074] = 8962,
  [9075] = 8940,
  [9076] = 8996,
  [9077] = 8954,
  [9078] = 8934,
  [9079] = 8934,
  [9080] = 8955,
  [9081] = 8955,
  [9082] = 9082,
  [9083] = 8996,
  [9084] = 8936,
  [9085] = 8937,
  [9086] = 8938,
  [9087] = 8977,
  [9088] = 8943,
  [9089] = 8935,
  [9090] = 8962,
  [9091] = 8935,
  [9092] = 8978,
  [9093] = 8935,
  [9094] = 8955,
  [9095] = 8939,
  [9096] = 8942,
  [9097] = 8936,
  [9098] = 8937,
  [9099] = 8938,
  [9100] = 8936,
  [9101] = 8943,
  [9102] = 8937,
  [9103] = 8938,
  [9104] = 8999,
  [9105] = 8945,
  [9106] = 8978,
  [9107] = 8955,
  [9108] = 8944,
  [9109] = 8936,
  [9110] = 8937,
  [9111] = 8938,
  [9112] = 8943,
  [9113] = 8954,
  [9114] = 8977,
  [9115] = 8978,
  [9116] = 9116,
  [9117] = 8964,
  [9118] = 8941,
  [9119] = 8936,
  [9120] = 8937,
  [9121] = 8938,
  [9122] = 8943,
  [9123] = 8945,
  [9124] = 8999,
  [9125] = 8942,
  [9126] = 8988,
  [9127] = 8988,
  [9128] = 8937,
  [9129] = 8943,
  [9130] = 8933,
  [9131] = 8964,
  [9132] = 8937,
  [9133] = 8943,
  [9134] = 8956,
  [9135] = 8934,
  [9136] = 8937,
  [9137] = 8943,
  [9138] = 8962,
  [9139] = 8941,
  [9140] = 8937,
  [9141] = 8943,
  [9142] = 8933,
  [9143] = 8962,
  [9144] = 8937,
  [9145] = 8943,
  [9146] = 8962,
  [9147] = 8962,
  [9148] = 8937,
  [9149] = 8943,
  [9150] = 8941,
  [9151] = 8954,
  [9152] = 8937,
  [9153] = 8943,
  [9154] = 8934,
  [9155] = 8939,
  [9156] = 8937,
  [9157] = 8943,
  [9158] = 8934,
  [9159] = 8942,
  [9160] = 8937,
  [9161] = 8943,
  [9162] = 8978,
  [9163] = 8937,
  [9164] = 8943,
  [9165] = 8956,
  [9166] = 8937,
  [9167] = 8943,
  [9168] = 8999,
  [9169] = 8937,
  [9170] = 8943,
  [9171] = 8942,
  [9172] = 9172,
  [9173] = 8943,
  [9174] = 8939,
  [9175] = 8950,
  [9176] = 8940,
  [9177] = 9177,
  [9178] = 8939,
  [9179] = 9179,
  [9180] = 8978,
  [9181] = 8953,
  [9182] = 8937,
  [9183] = 8979,
  [9184] = 8996,
  [9185] = 8996,
  [9186] = 9186,
  [9187] = 9187,
  [9188] = 8940,
  [9189] = 8962,
  [9190] = 8943,
  [9191] = 8964,
  [9192] = 8988,
  [9193] = 8933,
  [9194] = 9194,
  [9195] = 9195,
  [9196] = 8940,
  [9197] = 8932,
  [9198] = 8978,
  [9199] = 8962,
  [9200] = 8962,
  [9201] = 8934,
  [9202] = 8950,
  [9203] = 8939,
  [9204] = 8950,
  [9205] = 8996,
  [9206] = 8939,
  [9207] = 8977,
  [9208] = 8950,
  [9209] = 8935,
  [9210] = 8942,
  [9211] = 9211,
  [9212] = 9212,
  [9213] = 8935,
  [9214] = 8933,
  [9215] = 8942,
  [9216] = 8978,
  [9217] = 9217,
  [9218] = 9218,
  [9219] = 8950,
  [9220] = 8933,
  [9221] = 8962,
  [9222] = 8934,
  [9223] = 8988,
  [9224] = 9224,
  [9225] = 8999,
  [9226] = 8934,
  [9227] = 8956,
  [9228] = 8950,
  [9229] = 8934,
  [9230] = 8999,
  [9231] = 8962,
  [9232] = 8942,
  [9233] = 8935,
  [9234] = 9234,
  [9235] = 8934,
  [9236] = 8941,
  [9237] = 8937,
  [9238] = 8935,
  [9239] = 8942,
  [9240] = 8978,
  [9241] = 8962,
  [9242] = 8940,
  [9243] = 8941,
  [9244] = 8955,
  [9245] = 8956,
  [9246] = 8935,
  [9247] = 8962,
  [9248] = 8950,
  [9249] = 8954,
  [9250] = 8956,
  [9251] = 8955,
  [9252] = 8954,
  [9253] = 8978,
  [9254] = 8954,
  [9255] = 8935,
  [9256] = 8935,
  [9257] = 8940,
  [9258] = 9258,
  [9259] = 8941,
  [9260] = 8945,
  [9261] = 8935,
  [9262] = 8950,
  [9263] = 8936,
  [9264] = 8937,
  [9265] = 8962,
  [9266] = 8938,
  [9267] = 8950,
  [9268] = 8978,
  [9269] = 8939,
  [9270] = 8962,
  [9271] = 8978,
  [9272] = 8934,
  [9273] = 8934,
  [9274] = 9274,
  [9275] = 8953,
  [9276] = 8950,
  [9277] = 8939,
  [9278] = 8943,
  [9279] = 9279,
  [9280] = 8956,
  [9281] = 9281,
  [9282] = 8942,
  [9283] = 8988,
  [9284] = 9284,
  [9285] = 8953,
  [9286] = 8934,
  [9287] = 8934,
  [9288] = 8940,
  [9289] = 9289,
  [9290] = 8939,
  [9291] = 8942,
  [9292] = 8935,
  [9293] = 8977,
  [9294] = 8950,
  [9295] = 8934,
  [9296] = 8962,
  [9297] = 9297,
  [9298] = 8950,
  [9299] = 8996,
  [9300] = 8955,
  [9301] = 8944,
  [9302] = 9172,
  [9303] = 8935,
  [9304] = 8932,
  [9305] = 8933,
  [9306] = 8940,
  [9307] = 8950,
  [9308] = 8979,
  [9309] = 8962,
  [9310] = 8953,
  [9311] = 8945,
  [9312] = 9312,
  [9313] = 8941,
  [9314] = 8939,
  [9315] = 9172,
  [9316] = 8996,
  [9317] = 8932,
  [9318] = 8978,
  [9319] = 8964,
  [9320] = 8954,
  [9321] = 8979,
  [9322] = 8978,
  [9323] = 9323,
  [9324] = 8945,
  [9325] = 8934,
  [9326] = 8941,
  [9327] = 8962,
  [9328] = 9172,
  [9329] = 8988,
  [9330] = 8932,
  [9331] = 8964,
  [9332] = 8956,
  [9333] = 8988,
  [9334] = 8979,
  [9335] = 8955,
  [9336] = 8962,
  [9337] = 8945,
  [9338] = 8953,
  [9339] = 8978,
  [9340] = 8941,
  [9341] = 9172,
  [9342] = 8950,
  [9343] = 8932,
  [9344] = 8939,
  [9345] = 8950,
  [9346] = 8936,
  [9347] = 8979,
  [9348] = 8937,
  [9349] = 8938,
  [9350] = 8978,
  [9351] = 8978,
  [9352] = 8977,
  [9353] = 8942,
  [9354] = 9172,
  [9355] = 8941,
  [9356] = 8932,
  [9357] = 8953,
  [9358] = 8935,
  [9359] = 8962,
  [9360] = 8979,
  [9361] = 8964,
  [9362] = 8943,
  [9363] = 9363,
  [9364] = 9364,
  [9365] = 8999,
  [9366] = 8962,
  [9367] = 9172,
  [9368] = 8935,
  [9369] = 8932,
  [9370] = 8934,
  [9371] = 8934,
  [9372] = 8978,
  [9373] = 8979,
  [9374] = 8978,
  [9375] = 8996,
  [9376] = 8939,
  [9377] = 8935,
  [9378] = 9172,
  [9379] = 8962,
  [9380] = 8932,
  [9381] = 8934,
  [9382] = 8945,
  [9383] = 8962,
  [9384] = 8979,
  [9385] = 9385,
  [9386] = 8977,
  [9387] = 8940,
  [9388] = 8950,
  [9389] = 9172,
  [9390] = 8999,
  [9391] = 8932,
  [9392] = 8950,
  [9393] = 8939,
  [9394] = 8935,
  [9395] = 8979,
  [9396] = 8978,
  [9397] = 8940,
  [9398] = 9398,
  [9399] = 8940,
  [9400] = 9172,
  [9401] = 8978,
  [9402] = 8932,
  [9403] = 8964,
  [9404] = 8996,
  [9405] = 8935,
  [9406] = 8979,
  [9407] = 8996,
  [9408] = 8942,
  [9409] = 8934,
  [9410] = 8955,
  [9411] = 9172,
  [9412] = 9412,
  [9413] = 8932,
  [9414] = 8935,
  [9415] = 8977,
  [9416] = 9416,
  [9417] = 8979,
  [9418] = 8940,
  [9419] = 8954,
  [9420] = 8933,
  [9421] = 9421,
  [9422] = 9172,
  [9423] = 8942,
  [9424] = 8932,
  [9425] = 8936,
  [9426] = 9426,
  [9427] = 8933,
  [9428] = 8979,
  [9429] = 8937,
  [9430] = 8988,
  [9431] = 8938,
  [9432] = 9172,
  [9433] = 8942,
  [9434] = 8979,
  [9435] = 9435,
  [9436] = 9436,
  [9437] = 9172,
  [9438] = 8978,
  [9439] = 8979,
  [9440] = 9440,
  [9441] = 8941,
  [9442] = 8979,
  [9443] = 8964,
  [9444] = 8945,
  [9445] = 8979,
  [9446] = 8934,
  [9447] = 8942,
  [9448] = 8979,
  [9449] = 8979,
  [9450] = 8979,
  [9451] = 8979,
  [9452] = 8979,
  [9453] = 8979,
  [9454] = 8979,
  [9455] = 8979,
  [9456] = 8979,
  [9457] = 8979,
  [9458] = 8979,
  [9459] = 8979,
  [9460] = 9460,
  [9461] = 9363,
  [9462] = 9279,
  [9463] = 8962,
  [9464] = 8979,
  [9465] = 8943,
  [9466] = 8935,
  [9467] = 8953,
  [9468] = 8945,
  [9469] = 9116,
  [9470] = 8996,
  [9471] = 8942,
  [9472] = 8942,
  [9473] = 8943,
  [9474] = 8999,
  [9475] = 9281,
  [9476] = 9172,
  [9477] = 8999,
  [9478] = 8941,
  [9479] = 8934,
  [9480] = 9363,
  [9481] = 9279,
  [9482] = 9281,
  [9483] = 8935,
  [9484] = 8977,
  [9485] = 9363,
  [9486] = 9279,
  [9487] = 9281,
  [9488] = 8935,
  [9489] = 8964,
  [9490] = 9363,
  [9491] = 9279,
  [9492] = 9281,
  [9493] = 8999,
  [9494] = 8950,
  [9495] = 9363,
  [9496] = 9279,
  [9497] = 9281,
  [9498] = 8941,
  [9499] = 8938,
  [9500] = 9363,
  [9501] = 9279,
  [9502] = 9281,
  [9503] = 8954,
  [9504] = 8945,
  [9505] = 9363,
  [9506] = 9279,
  [9507] = 9281,
  [9508] = 9363,
  [9509] = 9279,
  [9510] = 9281,
  [9511] = 9363,
  [9512] = 9279,
  [9513] = 9281,
  [9514] = 9363,
  [9515] = 9279,
  [9516] = 9281,
  [9517] = 9363,
  [9518] = 9279,
  [9519] = 9281,
  [9520] = 9363,
  [9521] = 9279,
  [9522] = 9281,
  [9523] = 9279,
  [9524] = 9281,
  [9525] = 9279,
  [9526] = 9281,
  [9527] = 9281,
  [9528] = 9281,
  [9529] = 8955,
  [9530] = 8955,
  [9531] = 8940,
  [9532] = 8956,
  [9533] = 8978,
  [9534] = 8940,
  [9535] = 8950,
  [9536] = 9224,
  [9537] = 9053,
  [9538] = 9186,
  [9539] = 8978,
  [9540] = 9053,
  [9541] = 9186,
  [9542] = 8956,
  [9543] = 9053,
  [9544] = 9186,
  [9545] = 8978,
  [9546] = 9053,
  [9547] = 9186,
  [9548] = 8936,
  [9549] = 9053,
  [9550] = 9186,
  [9551] = 8996,
  [9552] = 9053,
  [9553] = 9186,
  [9554] = 8950,
  [9555] = 9053,
  [9556] = 9053,
  [9557] = 9053,
  [9558] = 9053,
  [9559] = 9053,
  [9560] = 9053,
  [9561] = 9053,
  [9562] = 9053,
  [9563] = 9053,
  [9564] = 9053,
  [9565] = 8937,
  [9566] = 8938,
  [9567] = 8940,
  [9568] = 8996,
  [9569] = 9569,
  [9570] = 8953,
  [9571] = 8962,
  [9572] = 8939,
  [9573] = 8950,
  [9574] = 8936,
  [9575] = 8954,
  [9576] = 8934,
  [9577] = 8962,
  [9578] = 8943,
  [9579] = 8940,
  [9580] = 8933,
  [9581] = 8996,
  [9582] = 8942,
  [9583] = 8977,
  [9584] = 8988,
  [9585] = 8933,
  [9586] = 8978,
  [9587] = 8988,
  [9588] = 8942,
  [9589] = 9195,
  [9590] = 8934,
  [9591] = 9195,
  [9592] = 8942,
  [9593] = 9195,
  [9594] = 8942,
  [9595] = 9195,
  [9596] = 8941,
  [9597] = 9195,
  [9598] = 8999,
  [9599] = 9195,
  [9600] = 8964,
  [9601] = 8934,
  [9602] = 8956,
  [9603] = 8939,
  [9604] = 8954,
  [9605] = 9056,
  [9606] = 8933,
  [9607] = 8941,
  [9608] = 8953,
  [9609] = 8955,
  [9610] = 8978,
};

static TSCharacterRange sym_identifier_character_set_1[] = {
  {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xba}, {0xc0, 0xd6}, {0xd8, 0xf6},
  {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374}, {0x376, 0x377}, {0x37b, 0x37d},
  {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481}, {0x48a, 0x52f},
  {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a}, {0x66e, 0x66f}, {0x671, 0x6d3},
  {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710}, {0x712, 0x72f}, {0x74d, 0x7a5},
  {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a}, {0x824, 0x824}, {0x828, 0x828},
  {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939}, {0x93d, 0x93d}, {0x950, 0x950},
  {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9},
  {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc}, {0xa05, 0xa0a}, {0xa0f, 0xa10},
  {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e}, {0xa72, 0xa74},
  {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd}, {0xad0, 0xad0},
  {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39},
  {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90}, {0xb92, 0xb95},
  {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0}, {0xc05, 0xc0c},
  {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61}, {0xc80, 0xc80},
  {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd}, {0xcdd, 0xcde}, {0xce0, 0xce1},
  {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56}, {0xd5f, 0xd61},
  {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xe01, 0xe30}, {0xe32, 0xe32},
  {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0}, {0xeb2, 0xeb2},
  {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47}, {0xf49, 0xf6c}, {0xf88, 0xf8c},
  {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070}, {0x1075, 0x1081},
  {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256},
  {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0},
  {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f}, {0x13a0, 0x13f5}, {0x13f8, 0x13fd},
  {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711}, {0x171f, 0x1731}, {0x1740, 0x1751},
  {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878}, {0x1880, 0x18a8}, {0x18aa, 0x18aa},
  {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x1a00, 0x1a16}, {0x1a20, 0x1a54},
  {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5}, {0x1c00, 0x1c23}, {0x1c4d, 0x1c4f},
  {0x1c5a, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3}, {0x1cf5, 0x1cf6}, {0x1cfa, 0x1cfa},
  {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b},
  {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3},
  {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c}, {0x2102, 0x2102},
  {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x2139},
  {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25},
  {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6},
  {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x3005, 0x3007}, {0x3021, 0x3029}, {0x3031, 0x3035},
  {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf},
  {0x31f0, 0x31ff}, {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f}, {0xa62a, 0xa62b}, {0xa640, 0xa66e},
  {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9},
  {0xa7f2, 0xa801}, {0xa803, 0xa805}, {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb},
  {0xa8fd, 0xa8fe}, {0xa90a, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf}, {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef},
  {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a}, {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1},
  {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4}, {0xab01, 0xab06},
  {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2}, {0xac00, 0xd7a3},
  {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb28},
  {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d},
  {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77}, {0xfe79, 0xfe79}, {0xfe7b, 0xfe7b},
  {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0xff66, 0xff9d}, {0xffa0, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf},
  {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d},
  {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x10375}, {0x10380, 0x1039d},
  {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563},
  {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc},
  {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808},
  {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5},
  {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf}, {0x10a00, 0x10a00}, {0x10a10, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35},
  {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae4}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91},
  {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d23}, {0x10e80, 0x10ea9}, {0x10eb0, 0x10eb1}, {0x10f00, 0x10f1c}, {0x10f27, 0x10f27},
  {0x10f30, 0x10f45}, {0x10f70, 0x10f81}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11003, 0x11037}, {0x11071, 0x11072}, {0x11075, 0x11075}, {0x11083, 0x110af},
  {0x110d0, 0x110e8}, {0x11103, 0x11126}, {0x11144, 0x11144}, {0x11147, 0x11147}, {0x11150, 0x11172}, {0x11176, 0x11176}, {0x11183, 0x111b2}, {0x111c1, 0x111c4},
  {0x111da, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x1122b}, {0x1123f, 0x11240}, {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d},
  {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112de}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333},
  {0x11335, 0x11339}, {0x1133d, 0x1133d}, {0x11350, 0x11350}, {0x1135d, 0x11361}, {0x11400, 0x11434}, {0x11447, 0x1144a}, {0x1145f, 0x11461}, {0x11480, 0x114af},
  {0x114c4, 0x114c5}, {0x114c7, 0x114c7}, {0x11580, 0x115ae}, {0x115d8, 0x115db}, {0x11600, 0x1162f}, {0x11644, 0x11644}, {0x11680, 0x116aa}, {0x116b8, 0x116b8},
  {0x11700, 0x1171a}, {0x11740, 0x11746}, {0x11800, 0x1182b}, {0x118a0, 0x118df}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916},
  {0x11918, 0x1192f}, {0x1193f, 0x1193f}, {0x11941, 0x11941}, {0x119a0, 0x119a7}, {0x119aa, 0x119d0}, {0x119e1, 0x119e1}, {0x119e3, 0x119e3}, {0x11a00, 0x11a00},
  {0x11a0b, 0x11a32}, {0x11a3a, 0x11a3a}, {0x11a50, 0x11a50}, {0x11a5c, 0x11a89}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c2e},
  {0x11c40, 0x11c40}, {0x11c72, 0x11c8f}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d30}, {0x11d46, 0x11d46}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68},
  {0x11d6a, 0x11d89}, {0x11d98, 0x11d98}, {0x11ee0, 0x11ef2}, {0x11f02, 0x11f02}, {0x11f04, 0x11f10}, {0x11f12, 0x11f33}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399},
  {0x12400, 0x1246e}, {0x12480, 0x12543}, {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13441, 0x13446}, {0x14400, 0x14646}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e},
  {0x16a70, 0x16abe}, {0x16ad0, 0x16aed}, {0x16b00, 0x16b2f}, {0x16b40, 0x16b43}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16e40, 0x16e7f}, {0x16f00, 0x16f4a},
  {0x16f50, 0x16f50}, {0x16f93, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe3}, {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18d00, 0x18d08}, {0x1aff0, 0x1aff3},
  {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152}, {0x1b155, 0x1b155}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb},
  {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2},
  {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514},
  {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0},
  {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8},
  {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e030, 0x1e06d}, {0x1e100, 0x1e12c}, {0x1e137, 0x1e13d}, {0x1e14e, 0x1e14e},
  {0x1e290, 0x1e2ad}, {0x1e2c0, 0x1e2eb}, {0x1e4d0, 0x1e4eb}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4},
  {0x1e900, 0x1e943}, {0x1e94b, 0x1e94b}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32},
  {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f},
  {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62},
  {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b},
  {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0},
  {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
};

static TSCharacterRange sym_identifier_character_set_2[] = {
  {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xb7, 0xb7}, {0xba, 0xba},
  {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x300, 0x374},
  {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481},
  {0x483, 0x487}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x591, 0x5bd}, {0x5bf, 0x5bf}, {0x5c1, 0x5c2},
  {0x5c4, 0x5c5}, {0x5c7, 0x5c7}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x610, 0x61a}, {0x620, 0x669}, {0x66e, 0x6d3}, {0x6d5, 0x6dc},
  {0x6df, 0x6e8}, {0x6ea, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x74a}, {0x74d, 0x7b1}, {0x7c0, 0x7f5}, {0x7fa, 0x7fa}, {0x7fd, 0x7fd},
  {0x800, 0x82d}, {0x840, 0x85b}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x898, 0x8e1}, {0x8e3, 0x963}, {0x966, 0x96f},
  {0x971, 0x983}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9}, {0x9bc, 0x9c4},
  {0x9c7, 0x9c8}, {0x9cb, 0x9ce}, {0x9d7, 0x9d7}, {0x9dc, 0x9dd}, {0x9df, 0x9e3}, {0x9e6, 0x9f1}, {0x9fc, 0x9fc}, {0x9fe, 0x9fe},
  {0xa01, 0xa03}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39},
  {0xa3c, 0xa3c}, {0xa3e, 0xa42}, {0xa47, 0xa48}, {0xa4b, 0xa4d}, {0xa51, 0xa51}, {0xa59, 0xa5c}, {0xa5e, 0xa5e}, {0xa66, 0xa75},
  {0xa81, 0xa83}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabc, 0xac5},
  {0xac7, 0xac9}, {0xacb, 0xacd}, {0xad0, 0xad0}, {0xae0, 0xae3}, {0xae6, 0xaef}, {0xaf9, 0xaff}, {0xb01, 0xb03}, {0xb05, 0xb0c},
  {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3c, 0xb44}, {0xb47, 0xb48}, {0xb4b, 0xb4d},
  {0xb55, 0xb57}, {0xb5c, 0xb5d}, {0xb5f, 0xb63}, {0xb66, 0xb6f}, {0xb71, 0xb71}, {0xb82, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90},
  {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbbe, 0xbc2},
  {0xbc6, 0xbc8}, {0xbca, 0xbcd}, {0xbd0, 0xbd0}, {0xbd7, 0xbd7}, {0xbe6, 0xbef}, {0xc00, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28},
  {0xc2a, 0xc39}, {0xc3c, 0xc44}, {0xc46, 0xc48}, {0xc4a, 0xc4d}, {0xc55, 0xc56}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc63},
  {0xc66, 0xc6f}, {0xc80, 0xc83}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbc, 0xcc4},
  {0xcc6, 0xcc8}, {0xcca, 0xccd}, {0xcd5, 0xcd6}, {0xcdd, 0xcde}, {0xce0, 0xce3}, {0xce6, 0xcef}, {0xcf1, 0xcf3}, {0xd00, 0xd0c},
  {0xd0e, 0xd10}, {0xd12, 0xd44}, {0xd46, 0xd48}, {0xd4a, 0xd4e}, {0xd54, 0xd57}, {0xd5f, 0xd63}, {0xd66, 0xd6f}, {0xd7a, 0xd7f},
  {0xd81, 0xd83}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xdca, 0xdca}, {0xdcf, 0xdd4},
  {0xdd6, 0xdd6}, {0xdd8, 0xddf}, {0xde6, 0xdef}, {0xdf2, 0xdf3}, {0xe01, 0xe3a}, {0xe40, 0xe4e}, {0xe50, 0xe59}, {0xe81, 0xe82},
  {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xec8, 0xece},
  {0xed0, 0xed9}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf18, 0xf19}, {0xf20, 0xf29}, {0xf35, 0xf35}, {0xf37, 0xf37}, {0xf39, 0xf39},
  {0xf3e, 0xf47}, {0xf49, 0xf6c}, {0xf71, 0xf84}, {0xf86, 0xf97}, {0xf99, 0xfbc}, {0xfc6, 0xfc6}, {0x1000, 0x1049}, {0x1050, 0x109d},
  {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256}, {0x1258, 0x1258},
  {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0}, {0x12c2, 0x12c5},
  {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x135d, 0x135f}, {0x1369, 0x1371}, {0x1380, 0x138f}, {0x13a0, 0x13f5},
  {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1715}, {0x171f, 0x1734},
  {0x1740, 0x1753}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1772, 0x1773}, {0x1780, 0x17d3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dd}, {0x17e0, 0x17e9},
  {0x180b, 0x180d}, {0x180f, 0x1819}, {0x1820, 0x1878}, {0x1880, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1920, 0x192b}, {0x1930, 0x193b},
  {0x1946, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19d0, 0x19da}, {0x1a00, 0x1a1b}, {0x1a20, 0x1a5e}, {0x1a60, 0x1a7c},
  {0x1a7f, 0x1a89}, {0x1a90, 0x1a99}, {0x1aa7, 0x1aa7}, {0x1ab0, 0x1abd}, {0x1abf, 0x1ace}, {0x1b00, 0x1b4c}, {0x1b50, 0x1b59}, {0x1b6b, 0x1b73},
  {0x1b80, 0x1bf3}, {0x1c00, 0x1c37}, {0x1c40, 0x1c49}, {0x1c4d, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1cd0, 0x1cd2},
  {0x1cd4, 0x1cfa}, {0x1d00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b},
  {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3},
  {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x200c, 0x200d}, {0x203f, 0x2040}, {0x2054, 0x2054}, {0x2071, 0x2071},
  {0x207f, 0x207f}, {0x2090, 0x209c}, {0x20d0, 0x20dc}, {0x20e1, 0x20e1}, {0x20e5, 0x20f0}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113},
  {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149},
  {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67},
  {0x2d6f, 0x2d6f}, {0x2d7f, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce},
  {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2de0, 0x2dff}, {0x3005, 0x3007}, {0x3021, 0x302f}, {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096},
  {0x3099, 0x309a}, {0x309d, 0x309f}, {0x30a1, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x4dbf},
  {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa62b}, {0xa640, 0xa66f}, {0xa674, 0xa67d}, {0xa67f, 0xa6f1}, {0xa717, 0xa71f},
  {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa827}, {0xa82c, 0xa82c}, {0xa840, 0xa873},
  {0xa880, 0xa8c5}, {0xa8d0, 0xa8d9}, {0xa8e0, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa92d}, {0xa930, 0xa953}, {0xa960, 0xa97c}, {0xa980, 0xa9c0},
  {0xa9cf, 0xa9d9}, {0xa9e0, 0xa9fe}, {0xaa00, 0xaa36}, {0xaa40, 0xaa4d}, {0xaa50, 0xaa59}, {0xaa60, 0xaa76}, {0xaa7a, 0xaac2}, {0xaadb, 0xaadd},
  {0xaae0, 0xaaef}, {0xaaf2, 0xaaf6}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a},
  {0xab5c, 0xab69}, {0xab70, 0xabea}, {0xabec, 0xabed}, {0xabf0, 0xabf9}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d},
  {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41},
  {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9}, {0xfe00, 0xfe0f},
  {0xfe20, 0xfe2f}, {0xfe33, 0xfe34}, {0xfe4d, 0xfe4f}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77}, {0xfe79, 0xfe79}, {0xfe7b, 0xfe7b},
  {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff3f, 0xff3f}, {0xff41, 0xff5a}, {0xff65, 0xffbe}, {0xffc2, 0xffc7},
  {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d},
  {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x101fd, 0x101fd}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x102e0, 0x102e0}, {0x10300, 0x1031f},
  {0x1032d, 0x1034a}, {0x10350, 0x1037a}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104a0, 0x104a9},
  {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595},
  {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785},
  {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855},
  {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf},
  {0x10a00, 0x10a03}, {0x10a05, 0x10a06}, {0x10a0c, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a38, 0x10a3a}, {0x10a3f, 0x10a3f}, {0x10a60, 0x10a7c},
  {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae6}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91}, {0x10c00, 0x10c48},
  {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d27}, {0x10d30, 0x10d39}, {0x10e80, 0x10ea9}, {0x10eab, 0x10eac}, {0x10eb0, 0x10eb1}, {0x10efd, 0x10f1c},
  {0x10f27, 0x10f27}, {0x10f30, 0x10f50}, {0x10f70, 0x10f85}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11000, 0x11046}, {0x11066, 0x11075}, {0x1107f, 0x110ba},
  {0x110c2, 0x110c2}, {0x110d0, 0x110e8}, {0x110f0, 0x110f9}, {0x11100, 0x11134}, {0x11136, 0x1113f}, {0x11144, 0x11147}, {0x11150, 0x11173}, {0x11176, 0x11176},
  {0x11180, 0x111c4}, {0x111c9, 0x111cc}, {0x111ce, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x11237}, {0x1123e, 0x11241}, {0x11280, 0x11286},
  {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112ea}, {0x112f0, 0x112f9}, {0x11300, 0x11303}, {0x11305, 0x1130c},
  {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133b, 0x11344}, {0x11347, 0x11348}, {0x1134b, 0x1134d},
  {0x11350, 0x11350}, {0x11357, 0x11357}, {0x1135d, 0x11363}, {0x11366, 0x1136c}, {0x11370, 0x11374}, {0x11400, 0x1144a}, {0x11450, 0x11459}, {0x1145e, 0x11461},
  {0x11480, 0x114c5}, {0x114c7, 0x114c7}, {0x114d0, 0x114d9}, {0x11580, 0x115b5}, {0x115b8, 0x115c0}, {0x115d8, 0x115dd}, {0x11600, 0x11640}, {0x11644, 0x11644},
  {0x11650, 0x11659}, {0x11680, 0x116b8}, {0x116c0, 0x116c9}, {0x11700, 0x1171a}, {0x1171d, 0x1172b}, {0x11730, 0x11739}, {0x11740, 0x11746}, {0x11800, 0x1183a},
  {0x118a0, 0x118e9}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x11935}, {0x11937, 0x11938}, {0x1193b, 0x11943},
  {0x11950, 0x11959}, {0x119a0, 0x119a7}, {0x119aa, 0x119d7}, {0x119da, 0x119e1}, {0x119e3, 0x119e4}, {0x11a00, 0x11a3e}, {0x11a47, 0x11a47}, {0x11a50, 0x11a99},
  {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c36}, {0x11c38, 0x11c40}, {0x11c50, 0x11c59}, {0x11c72, 0x11c8f}, {0x11c92, 0x11ca7},
  {0x11ca9, 0x11cb6}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d36}, {0x11d3a, 0x11d3a}, {0x11d3c, 0x11d3d}, {0x11d3f, 0x11d47}, {0x11d50, 0x11d59},
  {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d8e}, {0x11d90, 0x11d91}, {0x11d93, 0x11d98}, {0x11da0, 0x11da9}, {0x11ee0, 0x11ef6}, {0x11f00, 0x11f10},
  {0x11f12, 0x11f3a}, {0x11f3e, 0x11f42}, {0x11f50, 0x11f59}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543}, {0x12f90, 0x12ff0},
  {0x13000, 0x1342f}, {0x13440, 0x13455}, {0x14400, 0x14646}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a60, 0x16a69}, {0x16a70, 0x16abe}, {0x16ac0, 0x16ac9},
  {0x16ad0, 0x16aed}, {0x16af0, 0x16af4}, {0x16b00, 0x16b36}, {0x16b40, 0x16b43}, {0x16b50, 0x16b59}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16e40, 0x16e7f},
  {0x16f00, 0x16f4a}, {0x16f4f, 0x16f87}, {0x16f8f, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe4}, {0x16ff0, 0x16ff1}, {0x17000, 0x187f7}, {0x18800, 0x18cd5},
  {0x18d00, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152}, {0x1b155, 0x1b155},
  {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1bc9d, 0x1bc9e}, {0x1cf00, 0x1cf2d},
  {0x1cf30, 0x1cf46}, {0x1d165, 0x1d169}, {0x1d16d, 0x1d172}, {0x1d17b, 0x1d182}, {0x1d185, 0x1d18b}, {0x1d1aa, 0x1d1ad}, {0x1d242, 0x1d244}, {0x1d400, 0x1d454},
  {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3},
  {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546},
  {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e},
  {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1d7ce, 0x1d7ff}, {0x1da00, 0x1da36}, {0x1da3b, 0x1da6c},
  {0x1da75, 0x1da75}, {0x1da84, 0x1da84}, {0x1da9b, 0x1da9f}, {0x1daa1, 0x1daaf}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e000, 0x1e006}, {0x1e008, 0x1e018},
  {0x1e01b, 0x1e021}, {0x1e023, 0x1e024}, {0x1e026, 0x1e02a}, {0x1e030, 0x1e06d}, {0x1e08f, 0x1e08f}, {0x1e100, 0x1e12c}, {0x1e130, 0x1e13d}, {0x1e140, 0x1e149},
  {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ae}, {0x1e2c0, 0x1e2f9}, {0x1e4d0, 0x1e4f9}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe},
  {0x1e800, 0x1e8c4}, {0x1e8d0, 0x1e8d6}, {0x1e900, 0x1e94b}, {0x1e950, 0x1e959}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24},
  {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49},
  {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d},
  {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e},
  {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x1fbf0, 0x1fbf9}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739},
  {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af}, {0xe0100, 0xe01ef},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 159,
        '"', 214,
        '#', 18,
        '$', 131,
        '%', 187,
        '&', 161,
        '\'', 216,
        '(', 129,
        ')', 130,
        '*', 183,
        '+', 148,
        ',', 106,
        '-', 149,
        '.', 206,
        '/', 185,
        '0', 209,
        ':', 122,
        ';', 145,
        '<', 171,
        '=', 120,
        '>', 167,
        '?', 146,
        '@', 128,
        '[', 194,
        '\\', 29,
        ']', 195,
        '^', 203,
        '`', 215,
        '{', 99,
        '|', 124,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(79);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(1);
      if (lookahead == '/') ADVANCE(104);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(103);
      if (lookahead != 0) ADVANCE(105);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 158,
        '"', 214,
        '#', 58,
        '&', 160,
        '\'', 216,
        '(', 129,
        '+', 147,
        '-', 151,
        '.', 191,
        '/', 23,
        '0', 209,
        '?', 146,
        '[', 194,
        '^', 202,
        '`', 215,
        '{', 99,
        '~', 156,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 3:
      if (lookahead == '"') ADVANCE(214);
      if (lookahead == '/') ADVANCE(221);
      if (lookahead == '\\') ADVANCE(29);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(220);
      if (lookahead != 0) ADVANCE(223);
      END_STATE();
    case 4:
      if (lookahead == '"') ADVANCE(114);
      if (lookahead == 'd') ADVANCE(37);
      if (lookahead == 'o') ADVANCE(50);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(112);
      if (lookahead == 'c') ADVANCE(31);
      END_STATE();
    case 6:
      if (lookahead == '"') ADVANCE(116);
      if (lookahead == 'c') ADVANCE(32);
      END_STATE();
    case 7:
      if (lookahead == '"') ADVANCE(117);
      END_STATE();
    case 8:
      if (lookahead == '"') ADVANCE(109);
      END_STATE();
    case 9:
      if (lookahead == '"') ADVANCE(113);
      END_STATE();
    case 10:
      if (lookahead == '"') ADVANCE(118);
      END_STATE();
    case 11:
      if (lookahead == '"') ADVANCE(111);
      END_STATE();
    case 12:
      if (lookahead == '"') ADVANCE(115);
      END_STATE();
    case 13:
      if (lookahead == '"') ADVANCE(110);
      END_STATE();
    case 14:
      if (lookahead == '(') ADVANCE(129);
      if (lookahead == ')') ADVANCE(130);
      if (lookahead == ',') ADVANCE(106);
      if (lookahead == '.') ADVANCE(205);
      if (lookahead == '/') ADVANCE(184);
      if (lookahead == '{') ADVANCE(99);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      END_STATE();
    case 15:
      if (lookahead == '(') ADVANCE(129);
      if (lookahead == ')') ADVANCE(130);
      if (lookahead == ',') ADVANCE(106);
      if (lookahead == '.') ADVANCE(189);
      if (lookahead == '/') ADVANCE(184);
      if (lookahead == '{') ADVANCE(99);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      END_STATE();
    case 16:
      if (lookahead == '(') ADVANCE(129);
      if (lookahead == '.') ADVANCE(189);
      if (lookahead == '/') ADVANCE(23);
      if (lookahead == '{') ADVANCE(99);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      END_STATE();
    case 17:
      if (lookahead == ')') ADVANCE(233);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(17);
      END_STATE();
    case 18:
      if (lookahead == '+') ADVANCE(101);
      if (lookahead == 't') ADVANCE(236);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(237);
      END_STATE();
    case 19:
      if (lookahead == '+') ADVANCE(101);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(237);
      END_STATE();
    case 20:
      if (lookahead == '-') ADVANCE(21);
      if (lookahead == '0') ADVANCE(209);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      END_STATE();
    case 21:
      if (lookahead == '-') ADVANCE(232);
      END_STATE();
    case 22:
      if (lookahead == '.') ADVANCE(199);
      END_STATE();
    case 23:
      if (lookahead == '/') ADVANCE(239);
      END_STATE();
    case 24:
      if (lookahead == '/') ADVANCE(225);
      if (lookahead == '`') ADVANCE(215);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(224);
      if (lookahead != 0) ADVANCE(227);
      END_STATE();
    case 25:
      if (lookahead == '/') ADVANCE(218);
      if (lookahead == '\\') ADVANCE(29);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(219);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(217);
      END_STATE();
    case 26:
      if (lookahead == '<') ADVANCE(197);
      if (lookahead == '=') ADVANCE(196);
      END_STATE();
    case 27:
      if (lookahead == '=') ADVANCE(174);
      END_STATE();
    case 28:
      if (lookahead == '=') ADVANCE(173);
      END_STATE();
    case 29:
      if (lookahead == 'U') ADVANCE(231);
      if (lookahead == 'u') ADVANCE(65);
      if (lookahead == 'x') ADVANCE(72);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(230);
      if (lookahead != 0) ADVANCE(228);
      END_STATE();
    case 30:
      if (lookahead == 'a') ADVANCE(54);
      END_STATE();
    case 31:
      if (lookahead == 'a') ADVANCE(47);
      END_STATE();
    case 32:
      if (lookahead == 'a') ADVANCE(48);
      END_STATE();
    case 33:
      if (lookahead == 'c') ADVANCE(4);
      if (lookahead == 'f') ADVANCE(30);
      if (lookahead == 'n') ADVANCE(53);
      if (lookahead == 'o') ADVANCE(35);
      if (lookahead == 's') ADVANCE(59);
      END_STATE();
    case 34:
      if (lookahead == 'c') ADVANCE(43);
      END_STATE();
    case 35:
      if (lookahead == 'd') ADVANCE(42);
      END_STATE();
    case 36:
      if (lookahead == 'd') ADVANCE(5);
      END_STATE();
    case 37:
      if (lookahead == 'e') ADVANCE(34);
      END_STATE();
    case 38:
      if (lookahead == 'e') ADVANCE(7);
      END_STATE();
    case 39:
      if (lookahead == 'e') ADVANCE(64);
      END_STATE();
    case 40:
      if (lookahead == 'e') ADVANCE(49);
      END_STATE();
    case 41:
      if (lookahead == 'e') ADVANCE(55);
      END_STATE();
    case 42:
      if (lookahead == 'i') ADVANCE(52);
      END_STATE();
    case 43:
      if (lookahead == 'l') ADVANCE(9);
      END_STATE();
    case 44:
      if (lookahead == 'l') ADVANCE(41);
      END_STATE();
    case 45:
      if (lookahead == 'l') ADVANCE(11);
      END_STATE();
    case 46:
      if (lookahead == 'l') ADVANCE(12);
      END_STATE();
    case 47:
      if (lookahead == 'l') ADVANCE(45);
      END_STATE();
    case 48:
      if (lookahead == 'l') ADVANCE(46);
      END_STATE();
    case 49:
      if (lookahead == 'm') ADVANCE(10);
      END_STATE();
    case 50:
      if (lookahead == 'n') ADVANCE(61);
      END_STATE();
    case 51:
      if (lookahead == 'n') ADVANCE(38);
      END_STATE();
    case 52:
      if (lookahead == 'n') ADVANCE(8);
      END_STATE();
    case 53:
      if (lookahead == 'o') ADVANCE(51);
      END_STATE();
    case 54:
      if (lookahead == 's') ADVANCE(60);
      END_STATE();
    case 55:
      if (lookahead == 's') ADVANCE(56);
      END_STATE();
    case 56:
      if (lookahead == 's') ADVANCE(13);
      END_STATE();
    case 57:
      if (lookahead == 's') ADVANCE(63);
      END_STATE();
    case 58:
      if (lookahead == 't') ADVANCE(236);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(237);
      END_STATE();
    case 59:
      if (lookahead == 't') ADVANCE(36);
      if (lookahead == 'y') ADVANCE(57);
      END_STATE();
    case 60:
      if (lookahead == 't') ADVANCE(6);
      END_STATE();
    case 61:
      if (lookahead == 't') ADVANCE(39);
      END_STATE();
    case 62:
      if (lookahead == 't') ADVANCE(44);
      END_STATE();
    case 63:
      if (lookahead == 't') ADVANCE(40);
      END_STATE();
    case 64:
      if (lookahead == 'x') ADVANCE(62);
      END_STATE();
    case 65:
      if (lookahead == '{') ADVANCE(71);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(69);
      END_STATE();
    case 66:
      if (lookahead == '}') ADVANCE(228);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(66);
      END_STATE();
    case 67:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(210);
      END_STATE();
    case 68:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(211);
      END_STATE();
    case 69:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(72);
      END_STATE();
    case 70:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(228);
      END_STATE();
    case 71:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(66);
      END_STATE();
    case 72:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(70);
      END_STATE();
    case 73:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(69);
      END_STATE();
    case 74:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(73);
      END_STATE();
    case 75:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(74);
      END_STATE();
    case 76:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(75);
      END_STATE();
    case 77:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(213);
      END_STATE();
    case 78:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(237);
      END_STATE();
    case 79:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 159,
        '"', 214,
        '#', 18,
        '$', 131,
        '%', 187,
        '&', 161,
        '\'', 216,
        '(', 129,
        ')', 130,
        '*', 183,
        '+', 148,
        ',', 106,
        '-', 149,
        '.', 190,
        '/', 185,
        '0', 209,
        ':', 122,
        ';', 145,
        '<', 171,
        '=', 120,
        '>', 167,
        '?', 146,
        '@', 128,
        '[', 194,
        ']', 195,
        '^', 203,
        '`', 215,
        '{', 99,
        '|', 124,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(79);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 80:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 159,
        '"', 214,
        '#', 78,
        '$', 131,
        '%', 186,
        '&', 162,
        '(', 129,
        ')', 130,
        '*', 182,
        '+', 147,
        ',', 106,
        '-', 153,
        '.', 190,
        '/', 184,
        ':', 122,
        ';', 145,
        '<', 172,
        '=', 120,
        '>', 168,
        '?', 146,
        '[', 194,
        ']', 195,
        '^', 202,
        '`', 215,
        '{', 99,
        '|', 125,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(80);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 81:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 159,
        '"', 214,
        '#', 78,
        '%', 187,
        '&', 161,
        '\'', 216,
        '(', 129,
        '*', 183,
        '+', 148,
        ',', 106,
        '-', 149,
        '.', 192,
        '/', 185,
        '0', 209,
        ':', 122,
        ';', 145,
        '<', 171,
        '=', 120,
        '>', 167,
        '?', 146,
        '@', 128,
        '[', 194,
        '^', 203,
        '`', 215,
        '{', 99,
        '|', 124,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(81);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 82:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 159,
        '"', 214,
        '#', 78,
        '%', 186,
        '&', 162,
        '\'', 216,
        '(', 129,
        ')', 130,
        '*', 182,
        '+', 147,
        ',', 106,
        '-', 150,
        '.', 192,
        '/', 184,
        '0', 209,
        ':', 122,
        ';', 145,
        '<', 172,
        '=', 120,
        '>', 168,
        '?', 146,
        '[', 194,
        ']', 195,
        '^', 202,
        '`', 215,
        '{', 99,
        '|', 125,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(82);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 83:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 159,
        '"', 214,
        '#', 58,
        '%', 186,
        '&', 162,
        '\'', 216,
        '(', 129,
        '*', 182,
        '+', 147,
        ',', 106,
        '-', 150,
        '.', 192,
        '/', 184,
        '0', 209,
        ';', 145,
        '<', 172,
        '=', 28,
        '>', 168,
        '?', 146,
        '[', 194,
        '^', 202,
        '`', 215,
        '{', 99,
        '|', 125,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(83);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 84:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 159,
        '"', 33,
        '#', 78,
        '$', 131,
        '%', 187,
        '&', 161,
        '(', 129,
        '*', 183,
        '+', 148,
        ',', 106,
        '-', 152,
        '.', 190,
        '/', 185,
        ':', 122,
        ';', 145,
        '<', 171,
        '=', 120,
        '>', 167,
        '?', 146,
        '[', 194,
        '^', 203,
        '{', 99,
        '|', 124,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(84);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 85:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 159,
        '#', 78,
        '$', 131,
        '%', 187,
        '&', 161,
        '(', 129,
        '*', 183,
        '+', 148,
        ',', 106,
        '-', 154,
        '.', 190,
        '/', 185,
        ':', 122,
        ';', 145,
        '<', 171,
        '=', 120,
        '>', 167,
        '?', 146,
        '[', 194,
        '^', 203,
        '{', 99,
        '|', 124,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(85);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 86:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 159,
        '#', 78,
        '$', 131,
        '%', 186,
        '&', 162,
        '(', 129,
        ')', 130,
        '*', 182,
        '+', 147,
        ',', 106,
        '-', 155,
        '.', 190,
        '/', 184,
        ':', 122,
        ';', 145,
        '<', 172,
        '=', 120,
        '>', 168,
        '?', 146,
        '[', 194,
        ']', 195,
        '^', 202,
        '{', 99,
        '|', 125,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(86);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 87:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 158,
        '"', 214,
        '#', 19,
        '$', 131,
        '&', 160,
        '\'', 216,
        '(', 129,
        ')', 130,
        '+', 147,
        ',', 106,
        '-', 150,
        '.', 191,
        '/', 184,
        '0', 209,
        ':', 121,
        ';', 145,
        '=', 119,
        '?', 146,
        '@', 128,
        '[', 194,
        ']', 195,
        '^', 202,
        '`', 215,
        '{', 99,
        '|', 123,
        '}', 100,
        '~', 156,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(87);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 88:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 158,
        '"', 214,
        '#', 78,
        '$', 131,
        '\'', 216,
        '(', 129,
        ')', 130,
        ',', 106,
        '-', 20,
        '.', 22,
        '/', 184,
        '0', 209,
        ':', 121,
        ';', 145,
        '=', 119,
        '[', 194,
        ']', 195,
        '^', 202,
        '`', 215,
        '{', 99,
        '|', 123,
        '}', 100,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(88);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 89:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 27,
        '"', 214,
        '#', 78,
        '%', 187,
        '&', 161,
        '(', 129,
        ')', 130,
        '*', 183,
        '+', 148,
        ',', 106,
        '-', 152,
        '.', 207,
        '/', 185,
        ':', 122,
        ';', 145,
        '<', 171,
        '=', 120,
        '>', 167,
        '?', 146,
        '[', 194,
        ']', 195,
        '^', 203,
        '`', 215,
        '{', 99,
        '|', 124,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(90);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 90:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 27,
        '"', 214,
        '#', 78,
        '%', 187,
        '&', 161,
        '(', 129,
        ')', 130,
        '*', 183,
        '+', 148,
        ',', 106,
        '-', 152,
        '.', 193,
        '/', 185,
        ':', 122,
        ';', 145,
        '<', 171,
        '=', 120,
        '>', 167,
        '?', 146,
        '[', 194,
        ']', 195,
        '^', 203,
        '`', 215,
        '{', 99,
        '|', 124,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(90);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 91:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 27,
        '"', 214,
        '#', 78,
        '%', 186,
        '&', 162,
        '(', 129,
        ')', 130,
        '*', 182,
        '+', 147,
        ',', 106,
        '-', 153,
        '.', 207,
        '/', 184,
        ':', 122,
        ';', 145,
        '<', 172,
        '=', 120,
        '>', 168,
        '?', 146,
        '[', 194,
        ']', 195,
        '^', 202,
        '`', 215,
        '{', 99,
        '|', 125,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(92);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 92:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 27,
        '"', 214,
        '#', 78,
        '%', 186,
        '&', 162,
        '(', 129,
        ')', 130,
        '*', 182,
        '+', 147,
        ',', 106,
        '-', 153,
        '.', 193,
        '/', 184,
        ':', 122,
        ';', 145,
        '<', 172,
        '=', 120,
        '>', 168,
        '?', 146,
        '[', 194,
        ']', 195,
        '^', 202,
        '`', 215,
        '{', 99,
        '|', 125,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(92);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 93:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 27,
        '#', 78,
        '%', 187,
        '&', 161,
        '(', 129,
        '*', 183,
        '+', 148,
        ',', 106,
        '-', 152,
        '.', 193,
        '/', 185,
        ':', 122,
        ';', 145,
        '<', 171,
        '=', 120,
        '>', 167,
        '?', 146,
        '[', 194,
        '^', 203,
        '{', 99,
        '|', 124,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(93);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 94:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 27,
        '%', 187,
        '&', 161,
        '(', 129,
        '*', 183,
        '+', 148,
        ',', 106,
        '-', 154,
        '.', 207,
        '/', 185,
        ':', 122,
        ';', 145,
        '<', 171,
        '=', 120,
        '>', 167,
        '?', 146,
        '[', 194,
        '^', 203,
        '{', 99,
        '|', 124,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(95);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 95:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 27,
        '%', 187,
        '&', 161,
        '(', 129,
        '*', 183,
        '+', 148,
        ',', 106,
        '-', 154,
        '.', 193,
        '/', 185,
        ':', 122,
        ';', 145,
        '<', 171,
        '=', 120,
        '>', 167,
        '?', 146,
        '[', 194,
        '^', 203,
        '{', 99,
        '|', 124,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(95);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 96:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 27,
        '%', 186,
        '&', 162,
        '(', 129,
        ')', 130,
        '*', 182,
        '+', 147,
        ',', 106,
        '-', 155,
        '.', 207,
        '/', 184,
        ':', 122,
        ';', 145,
        '<', 172,
        '=', 120,
        '>', 168,
        '?', 146,
        '[', 194,
        ']', 195,
        '^', 202,
        '{', 99,
        '|', 125,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(97);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 97:
      if (eof) ADVANCE(98);
      ADVANCE_MAP(
        '!', 27,
        '%', 186,
        '&', 162,
        '(', 129,
        ')', 130,
        '*', 182,
        '+', 147,
        ',', 106,
        '-', 155,
        '.', 193,
        '/', 184,
        ':', 122,
        ';', 145,
        '<', 172,
        '=', 120,
        '>', 168,
        '?', 146,
        '[', 194,
        ']', 195,
        '^', 202,
        '{', 99,
        '|', 125,
        '}', 100,
        '~', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(97);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(238);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_POUND_PLUS);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(aux_sym_build_tag_token1);
      if (lookahead == '\r') ADVANCE(105);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(102);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(aux_sym_build_tag_token1);
      if (lookahead == '/') ADVANCE(104);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(103);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(105);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(aux_sym_build_tag_token1);
      if (lookahead == '/') ADVANCE(102);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(105);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(aux_sym_build_tag_token1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(105);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_DQUOTEodin_DQUOTE);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_DQUOTEcontextless_DQUOTE);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_DQUOTEstdcall_DQUOTE);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_DQUOTEstd_DQUOTE);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_DQUOTEcdecl_DQUOTE);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_DQUOTEc_DQUOTE);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_DQUOTEfastcall_DQUOTE);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_DQUOTEfast_DQUOTE);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_DQUOTEnone_DQUOTE);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_DQUOTEsystem_DQUOTE);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(173);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(107);
      if (lookahead == '=') ADVANCE(126);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(138);
      if (lookahead == '|') ADVANCE(164);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(163);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_POUNDtype);
      if (lookahead == '(') ADVANCE(17);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(237);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE_EQ);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_AMP_AMP_EQ);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_AMP_TILDE_EQ);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(132);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(21);
      if (lookahead == '0') ADVANCE(209);
      if (lookahead == '=') ADVANCE(133);
      if (lookahead == '>') ADVANCE(108);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(21);
      if (lookahead == '0') ADVANCE(209);
      if (lookahead == '>') ADVANCE(108);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(21);
      if (lookahead == '0') ADVANCE(209);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(212);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(21);
      if (lookahead == '=') ADVANCE(133);
      if (lookahead == '>') ADVANCE(108);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(21);
      if (lookahead == '>') ADVANCE(108);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(133);
      if (lookahead == '>') ADVANCE(108);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '>') ADVANCE(108);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '=') ADVANCE(175);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(174);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(166);
      if (lookahead == '=') ADVANCE(137);
      if (lookahead == '~') ADVANCE(177);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(165);
      if (lookahead == '~') ADVANCE(176);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      if (lookahead == '=') ADVANCE(142);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      if (lookahead == '=') ADVANCE(143);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(169);
      if (lookahead == '>') ADVANCE(181);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(169);
      if (lookahead == '>') ADVANCE(180);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(179);
      if (lookahead == '=') ADVANCE(170);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(178);
      if (lookahead == '=') ADVANCE(170);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(anon_sym_TILDE_EQ);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(anon_sym_AMP_TILDE);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_AMP_TILDE);
      if (lookahead == '=') ADVANCE(144);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(140);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(141);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(134);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(239);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(239);
      if (lookahead == '=') ADVANCE(135);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '%') ADVANCE(188);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '%') ADVANCE(188);
      if (lookahead == '=') ADVANCE(136);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_PERCENT_PERCENT);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(200);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(198);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(201);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(26);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_EQ);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_LT);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      if (lookahead == '.') ADVANCE(204);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      if (lookahead == '.') ADVANCE(204);
      if (lookahead == '<') ADVANCE(197);
      if (lookahead == '=') ADVANCE(196);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      if (lookahead == '<') ADVANCE(197);
      if (lookahead == '=') ADVANCE(196);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(139);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_DOT2);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_DOT2);
      if (lookahead == '.') ADVANCE(200);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(anon_sym_DOT2);
      if (lookahead == '.') ADVANCE(26);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(sym_number);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'b') ADVANCE(67);
      if (lookahead == 'o') ADVANCE(68);
      if (lookahead == 'h' ||
          lookahead == 'x') ADVANCE(77);
      if (('i' <= lookahead && lookahead <= 'k')) ADVANCE(208);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(212);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '_') ADVANCE(210);
      if (('i' <= lookahead && lookahead <= 'k')) ADVANCE(208);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(sym_number);
      if (('i' <= lookahead && lookahead <= 'k')) ADVANCE(208);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(211);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(sym_number);
      if (('i' <= lookahead && lookahead <= 'k')) ADVANCE(208);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(212);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(sym_number);
      if (('i' <= lookahead && lookahead <= 'k')) ADVANCE(208);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(213);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(aux_sym_character_token1);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(aux_sym_character_token1);
      if (lookahead == '/') ADVANCE(239);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(aux_sym_character_token1);
      if (lookahead == '/') ADVANCE(218);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(219);
      if (lookahead != 0 &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(217);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '/') ADVANCE(221);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(220);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(223);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '/') ADVANCE(222);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(223);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(223);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(222);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(223);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(sym__raw_string_content);
      if (lookahead == '/') ADVANCE(225);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(224);
      if (lookahead != 0 &&
          lookahead != '`') ADVANCE(227);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(sym__raw_string_content);
      if (lookahead == '/') ADVANCE(226);
      if (lookahead != 0 &&
          lookahead != '`') ADVANCE(227);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(sym__raw_string_content);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(227);
      if (lookahead != 0 &&
          lookahead != '`') ADVANCE(226);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(sym__raw_string_content);
      if (lookahead != 0 &&
          lookahead != '`') ADVANCE(227);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(228);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(229);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(76);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(sym_uninitialized);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(sym_tag);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(sym_tag);
      if (lookahead == '(') ADVANCE(17);
      if (lookahead == 'e') ADVANCE(127);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(237);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(sym_tag);
      if (lookahead == '(') ADVANCE(17);
      if (lookahead == 'p') ADVANCE(234);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(237);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(sym_tag);
      if (lookahead == '(') ADVANCE(17);
      if (lookahead == 'y') ADVANCE(235);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(237);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(sym_tag);
      if (lookahead == '(') ADVANCE(17);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(237);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(sym_identifier);
      if (set_contains(sym_identifier_character_set_2, 776, lookahead)) ADVANCE(238);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(239);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'a', 1,
        'b', 2,
        'c', 3,
        'd', 4,
        'e', 5,
        'f', 6,
        'i', 7,
        'm', 8,
        'n', 9,
        'o', 10,
        'p', 11,
        'r', 12,
        's', 13,
        't', 14,
        'u', 15,
        'w', 16,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'u') ADVANCE(17);
      END_STATE();
    case 2:
      if (lookahead == 'i') ADVANCE(18);
      if (lookahead == 'r') ADVANCE(19);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(20);
      if (lookahead == 'o') ADVANCE(21);
      END_STATE();
    case 4:
      if (lookahead == 'e') ADVANCE(22);
      if (lookahead == 'i') ADVANCE(23);
      if (lookahead == 'o') ADVANCE(24);
      if (lookahead == 'y') ADVANCE(25);
      END_STATE();
    case 5:
      if (lookahead == 'l') ADVANCE(26);
      if (lookahead == 'n') ADVANCE(27);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(28);
      if (lookahead == 'o') ADVANCE(29);
      END_STATE();
    case 7:
      if (lookahead == 'f') ADVANCE(30);
      if (lookahead == 'm') ADVANCE(31);
      if (lookahead == 'n') ADVANCE(32);
      END_STATE();
    case 8:
      if (lookahead == 'a') ADVANCE(33);
      END_STATE();
    case 9:
      if (lookahead == 'i') ADVANCE(34);
      if (lookahead == 'o') ADVANCE(35);
      END_STATE();
    case 10:
      if (lookahead == 'r') ADVANCE(36);
      END_STATE();
    case 11:
      if (lookahead == 'a') ADVANCE(37);
      if (lookahead == 'r') ADVANCE(38);
      END_STATE();
    case 12:
      if (lookahead == 'e') ADVANCE(39);
      END_STATE();
    case 13:
      if (lookahead == 't') ADVANCE(40);
      if (lookahead == 'w') ADVANCE(41);
      END_STATE();
    case 14:
      if (lookahead == 'r') ADVANCE(42);
      END_STATE();
    case 15:
      if (lookahead == 'n') ADVANCE(43);
      if (lookahead == 's') ADVANCE(44);
      END_STATE();
    case 16:
      if (lookahead == 'h') ADVANCE(45);
      END_STATE();
    case 17:
      if (lookahead == 't') ADVANCE(46);
      END_STATE();
    case 18:
      if (lookahead == 't') ADVANCE(47);
      END_STATE();
    case 19:
      if (lookahead == 'e') ADVANCE(48);
      END_STATE();
    case 20:
      if (lookahead == 's') ADVANCE(49);
      END_STATE();
    case 21:
      if (lookahead == 'n') ADVANCE(50);
      END_STATE();
    case 22:
      if (lookahead == 'f') ADVANCE(51);
      END_STATE();
    case 23:
      if (lookahead == 's') ADVANCE(52);
      END_STATE();
    case 24:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 25:
      if (lookahead == 'n') ADVANCE(53);
      END_STATE();
    case 26:
      if (lookahead == 's') ADVANCE(54);
      END_STATE();
    case 27:
      if (lookahead == 'u') ADVANCE(55);
      END_STATE();
    case 28:
      if (lookahead == 'l') ADVANCE(56);
      END_STATE();
    case 29:
      if (lookahead == 'r') ADVANCE(57);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 31:
      if (lookahead == 'p') ADVANCE(58);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 33:
      if (lookahead == 'p') ADVANCE(59);
      if (lookahead == 't') ADVANCE(60);
      END_STATE();
    case 34:
      if (lookahead == 'l') ADVANCE(61);
      END_STATE();
    case 35:
      if (lookahead == 't') ADVANCE(62);
      END_STATE();
    case 36:
      if (lookahead == '_') ADVANCE(63);
      END_STATE();
    case 37:
      if (lookahead == 'c') ADVANCE(64);
      END_STATE();
    case 38:
      if (lookahead == 'o') ADVANCE(65);
      END_STATE();
    case 39:
      if (lookahead == 't') ADVANCE(66);
      END_STATE();
    case 40:
      if (lookahead == 'r') ADVANCE(67);
      END_STATE();
    case 41:
      if (lookahead == 'i') ADVANCE(68);
      END_STATE();
    case 42:
      if (lookahead == 'a') ADVANCE(69);
      if (lookahead == 'u') ADVANCE(70);
      END_STATE();
    case 43:
      if (lookahead == 'i') ADVANCE(71);
      END_STATE();
    case 44:
      if (lookahead == 'i') ADVANCE(72);
      END_STATE();
    case 45:
      if (lookahead == 'e') ADVANCE(73);
      END_STATE();
    case 46:
      if (lookahead == 'o') ADVANCE(74);
      END_STATE();
    case 47:
      if (lookahead == '_') ADVANCE(75);
      END_STATE();
    case 48:
      if (lookahead == 'a') ADVANCE(76);
      END_STATE();
    case 49:
      if (lookahead == 'e') ADVANCE(77);
      if (lookahead == 't') ADVANCE(78);
      END_STATE();
    case 50:
      if (lookahead == 't') ADVANCE(79);
      END_STATE();
    case 51:
      if (lookahead == 'e') ADVANCE(80);
      END_STATE();
    case 52:
      if (lookahead == 't') ADVANCE(81);
      END_STATE();
    case 53:
      if (lookahead == 'a') ADVANCE(82);
      END_STATE();
    case 54:
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 55:
      if (lookahead == 'm') ADVANCE(84);
      END_STATE();
    case 56:
      if (lookahead == 'l') ADVANCE(85);
      if (lookahead == 's') ADVANCE(86);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == 'e') ADVANCE(87);
      END_STATE();
    case 58:
      if (lookahead == 'o') ADVANCE(88);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_map);
      END_STATE();
    case 60:
      if (lookahead == 'r') ADVANCE(89);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(sym_nil);
      END_STATE();
    case 62:
      if (lookahead == '_') ADVANCE(90);
      END_STATE();
    case 63:
      if (lookahead == 'b') ADVANCE(91);
      if (lookahead == 'c') ADVANCE(92);
      if (lookahead == 'e') ADVANCE(93);
      if (lookahead == 'r') ADVANCE(94);
      END_STATE();
    case 64:
      if (lookahead == 'k') ADVANCE(95);
      END_STATE();
    case 65:
      if (lookahead == 'c') ADVANCE(96);
      END_STATE();
    case 66:
      if (lookahead == 'u') ADVANCE(97);
      END_STATE();
    case 67:
      if (lookahead == 'u') ADVANCE(98);
      END_STATE();
    case 68:
      if (lookahead == 't') ADVANCE(99);
      END_STATE();
    case 69:
      if (lookahead == 'n') ADVANCE(100);
      END_STATE();
    case 70:
      if (lookahead == 'e') ADVANCE(101);
      END_STATE();
    case 71:
      if (lookahead == 'o') ADVANCE(102);
      END_STATE();
    case 72:
      if (lookahead == 'n') ADVANCE(103);
      END_STATE();
    case 73:
      if (lookahead == 'n') ADVANCE(104);
      if (lookahead == 'r') ADVANCE(105);
      END_STATE();
    case 74:
      if (lookahead == '_') ADVANCE(106);
      END_STATE();
    case 75:
      if (lookahead == 'f') ADVANCE(107);
      if (lookahead == 's') ADVANCE(108);
      END_STATE();
    case 76:
      if (lookahead == 'k') ADVANCE(109);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_cast);
      END_STATE();
    case 79:
      if (lookahead == 'i') ADVANCE(110);
      END_STATE();
    case 80:
      if (lookahead == 'r') ADVANCE(111);
      END_STATE();
    case 81:
      if (lookahead == 'i') ADVANCE(112);
      END_STATE();
    case 82:
      if (lookahead == 'm') ADVANCE(113);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 85:
      if (lookahead == 't') ADVANCE(114);
      END_STATE();
    case 86:
      if (lookahead == 'e') ADVANCE(115);
      END_STATE();
    case 87:
      if (lookahead == 'i') ADVANCE(116);
      END_STATE();
    case 88:
      if (lookahead == 'r') ADVANCE(117);
      END_STATE();
    case 89:
      if (lookahead == 'i') ADVANCE(118);
      END_STATE();
    case 90:
      if (lookahead == 'i') ADVANCE(119);
      END_STATE();
    case 91:
      if (lookahead == 'r') ADVANCE(120);
      END_STATE();
    case 92:
      if (lookahead == 'o') ADVANCE(121);
      END_STATE();
    case 93:
      if (lookahead == 'l') ADVANCE(122);
      END_STATE();
    case 94:
      if (lookahead == 'e') ADVANCE(123);
      END_STATE();
    case 95:
      if (lookahead == 'a') ADVANCE(124);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_proc);
      END_STATE();
    case 97:
      if (lookahead == 'r') ADVANCE(125);
      END_STATE();
    case 98:
      if (lookahead == 'c') ADVANCE(126);
      END_STATE();
    case 99:
      if (lookahead == 'c') ADVANCE(127);
      END_STATE();
    case 100:
      if (lookahead == 's') ADVANCE(128);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 102:
      if (lookahead == 'n') ADVANCE(129);
      END_STATE();
    case 103:
      if (lookahead == 'g') ADVANCE(130);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_when);
      END_STATE();
    case 105:
      if (lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 106:
      if (lookahead == 'c') ADVANCE(132);
      END_STATE();
    case 107:
      if (lookahead == 'i') ADVANCE(133);
      END_STATE();
    case 108:
      if (lookahead == 'e') ADVANCE(134);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 110:
      if (lookahead == 'n') ADVANCE(135);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_defer);
      END_STATE();
    case 112:
      if (lookahead == 'n') ADVANCE(136);
      END_STATE();
    case 113:
      if (lookahead == 'i') ADVANCE(137);
      END_STATE();
    case 114:
      if (lookahead == 'h') ADVANCE(138);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 116:
      if (lookahead == 'g') ADVANCE(139);
      END_STATE();
    case 117:
      if (lookahead == 't') ADVANCE(140);
      END_STATE();
    case 118:
      if (lookahead == 'x') ADVANCE(141);
      END_STATE();
    case 119:
      if (lookahead == 'n') ADVANCE(142);
      END_STATE();
    case 120:
      if (lookahead == 'e') ADVANCE(143);
      END_STATE();
    case 121:
      if (lookahead == 'n') ADVANCE(144);
      END_STATE();
    case 122:
      if (lookahead == 's') ADVANCE(145);
      END_STATE();
    case 123:
      if (lookahead == 't') ADVANCE(146);
      END_STATE();
    case 124:
      if (lookahead == 'g') ADVANCE(147);
      END_STATE();
    case 125:
      if (lookahead == 'n') ADVANCE(148);
      END_STATE();
    case 126:
      if (lookahead == 't') ADVANCE(149);
      END_STATE();
    case 127:
      if (lookahead == 'h') ADVANCE(150);
      END_STATE();
    case 128:
      if (lookahead == 'm') ADVANCE(151);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_using);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_where);
      END_STATE();
    case 132:
      if (lookahead == 'a') ADVANCE(152);
      END_STATE();
    case 133:
      if (lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 134:
      if (lookahead == 't') ADVANCE(154);
      END_STATE();
    case 135:
      if (lookahead == 'u') ADVANCE(155);
      END_STATE();
    case 136:
      if (lookahead == 'c') ADVANCE(156);
      END_STATE();
    case 137:
      if (lookahead == 'c') ADVANCE(157);
      END_STATE();
    case 138:
      if (lookahead == 'r') ADVANCE(158);
      END_STATE();
    case 139:
      if (lookahead == 'n') ADVANCE(159);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_matrix);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_not_in);
      END_STATE();
    case 143:
      if (lookahead == 'a') ADVANCE(160);
      END_STATE();
    case 144:
      if (lookahead == 't') ADVANCE(161);
      END_STATE();
    case 145:
      if (lookahead == 'e') ADVANCE(162);
      END_STATE();
    case 146:
      if (lookahead == 'u') ADVANCE(163);
      END_STATE();
    case 147:
      if (lookahead == 'e') ADVANCE(164);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 151:
      if (lookahead == 'u') ADVANCE(165);
      END_STATE();
    case 152:
      if (lookahead == 's') ADVANCE(166);
      END_STATE();
    case 153:
      if (lookahead == 'l') ADVANCE(167);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_bit_set);
      END_STATE();
    case 155:
      if (lookahead == 'e') ADVANCE(168);
      END_STATE();
    case 156:
      if (lookahead == 't') ADVANCE(169);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_dynamic);
      END_STATE();
    case 158:
      if (lookahead == 'o') ADVANCE(170);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_foreign);
      END_STATE();
    case 160:
      if (lookahead == 'k') ADVANCE(171);
      END_STATE();
    case 161:
      if (lookahead == 'i') ADVANCE(172);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_or_else);
      END_STATE();
    case 163:
      if (lookahead == 'r') ADVANCE(173);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_package);
      END_STATE();
    case 165:
      if (lookahead == 't') ADVANCE(174);
      END_STATE();
    case 166:
      if (lookahead == 't') ADVANCE(175);
      END_STATE();
    case 167:
      if (lookahead == 'd') ADVANCE(176);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_distinct);
      END_STATE();
    case 170:
      if (lookahead == 'u') ADVANCE(177);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_or_break);
      END_STATE();
    case 172:
      if (lookahead == 'n') ADVANCE(178);
      END_STATE();
    case 173:
      if (lookahead == 'n') ADVANCE(179);
      END_STATE();
    case 174:
      if (lookahead == 'e') ADVANCE(180);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(anon_sym_auto_cast);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(anon_sym_bit_field);
      END_STATE();
    case 177:
      if (lookahead == 'g') ADVANCE(181);
      END_STATE();
    case 178:
      if (lookahead == 'u') ADVANCE(182);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_or_return);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_transmute);
      END_STATE();
    case 181:
      if (lookahead == 'h') ADVANCE(183);
      END_STATE();
    case 182:
      if (lookahead == 'e') ADVANCE(184);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(sym_fallthrough_statement);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_or_continue);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 87, .external_lex_state = 2},
  [2] = {.lex_state = 81, .external_lex_state = 2},
  [3] = {.lex_state = 81, .external_lex_state = 2},
  [4] = {.lex_state = 81, .external_lex_state = 2},
  [5] = {.lex_state = 81, .external_lex_state = 2},
  [6] = {.lex_state = 81, .external_lex_state = 2},
  [7] = {.lex_state = 81, .external_lex_state = 2},
  [8] = {.lex_state = 81, .external_lex_state = 2},
  [9] = {.lex_state = 81, .external_lex_state = 2},
  [10] = {.lex_state = 81, .external_lex_state = 2},
  [11] = {.lex_state = 81, .external_lex_state = 2},
  [12] = {.lex_state = 81, .external_lex_state = 2},
  [13] = {.lex_state = 81, .external_lex_state = 2},
  [14] = {.lex_state = 81, .external_lex_state = 2},
  [15] = {.lex_state = 81, .external_lex_state = 2},
  [16] = {.lex_state = 81, .external_lex_state = 2},
  [17] = {.lex_state = 81, .external_lex_state = 2},
  [18] = {.lex_state = 81, .external_lex_state = 2},
  [19] = {.lex_state = 81, .external_lex_state = 2},
  [20] = {.lex_state = 81, .external_lex_state = 2},
  [21] = {.lex_state = 81, .external_lex_state = 2},
  [22] = {.lex_state = 81, .external_lex_state = 2},
  [23] = {.lex_state = 81, .external_lex_state = 2},
  [24] = {.lex_state = 81, .external_lex_state = 3},
  [25] = {.lex_state = 81, .external_lex_state = 3},
  [26] = {.lex_state = 81, .external_lex_state = 3},
  [27] = {.lex_state = 81, .external_lex_state = 3},
  [28] = {.lex_state = 81, .external_lex_state = 3},
  [29] = {.lex_state = 81, .external_lex_state = 3},
  [30] = {.lex_state = 81, .external_lex_state = 3},
  [31] = {.lex_state = 81, .external_lex_state = 2},
  [32] = {.lex_state = 81, .external_lex_state = 2},
  [33] = {.lex_state = 81, .external_lex_state = 2},
  [34] = {.lex_state = 81, .external_lex_state = 2},
  [35] = {.lex_state = 81, .external_lex_state = 2},
  [36] = {.lex_state = 81, .external_lex_state = 2},
  [37] = {.lex_state = 81, .external_lex_state = 2},
  [38] = {.lex_state = 81, .external_lex_state = 2},
  [39] = {.lex_state = 81, .external_lex_state = 2},
  [40] = {.lex_state = 87, .external_lex_state = 3},
  [41] = {.lex_state = 81, .external_lex_state = 2},
  [42] = {.lex_state = 81, .external_lex_state = 2},
  [43] = {.lex_state = 87, .external_lex_state = 2},
  [44] = {.lex_state = 87, .external_lex_state = 2},
  [45] = {.lex_state = 87, .external_lex_state = 2},
  [46] = {.lex_state = 87, .external_lex_state = 2},
  [47] = {.lex_state = 87, .external_lex_state = 2},
  [48] = {.lex_state = 87, .external_lex_state = 2},
  [49] = {.lex_state = 87, .external_lex_state = 2},
  [50] = {.lex_state = 87, .external_lex_state = 2},
  [51] = {.lex_state = 87, .external_lex_state = 2},
  [52] = {.lex_state = 87, .external_lex_state = 2},
  [53] = {.lex_state = 87, .external_lex_state = 2},
  [54] = {.lex_state = 87, .external_lex_state = 2},
  [55] = {.lex_state = 87, .external_lex_state = 2},
  [56] = {.lex_state = 87, .external_lex_state = 2},
  [57] = {.lex_state = 87, .external_lex_state = 2},
  [58] = {.lex_state = 87, .external_lex_state = 2},
  [59] = {.lex_state = 87, .external_lex_state = 2},
  [60] = {.lex_state = 87, .external_lex_state = 2},
  [61] = {.lex_state = 87, .external_lex_state = 2},
  [62] = {.lex_state = 87, .external_lex_state = 2},
  [63] = {.lex_state = 87, .external_lex_state = 2},
  [64] = {.lex_state = 87, .external_lex_state = 2},
  [65] = {.lex_state = 87, .external_lex_state = 2},
  [66] = {.lex_state = 87, .external_lex_state = 2},
  [67] = {.lex_state = 87, .external_lex_state = 2},
  [68] = {.lex_state = 87, .external_lex_state = 2},
  [69] = {.lex_state = 87, .external_lex_state = 2},
  [70] = {.lex_state = 87, .external_lex_state = 2},
  [71] = {.lex_state = 87, .external_lex_state = 2},
  [72] = {.lex_state = 87, .external_lex_state = 2},
  [73] = {.lex_state = 87, .external_lex_state = 2},
  [74] = {.lex_state = 87, .external_lex_state = 2},
  [75] = {.lex_state = 87, .external_lex_state = 2},
  [76] = {.lex_state = 87, .external_lex_state = 2},
  [77] = {.lex_state = 87, .external_lex_state = 2},
  [78] = {.lex_state = 87, .external_lex_state = 2},
  [79] = {.lex_state = 87, .external_lex_state = 2},
  [80] = {.lex_state = 87, .external_lex_state = 2},
  [81] = {.lex_state = 87, .external_lex_state = 2},
  [82] = {.lex_state = 87, .external_lex_state = 2},
  [83] = {.lex_state = 87, .external_lex_state = 2},
  [84] = {.lex_state = 87, .external_lex_state = 2},
  [85] = {.lex_state = 87, .external_lex_state = 2},
  [86] = {.lex_state = 87, .external_lex_state = 2},
  [87] = {.lex_state = 87, .external_lex_state = 2},
  [88] = {.lex_state = 87, .external_lex_state = 2},
  [89] = {.lex_state = 87, .external_lex_state = 2},
  [90] = {.lex_state = 87, .external_lex_state = 2},
  [91] = {.lex_state = 87, .external_lex_state = 2},
  [92] = {.lex_state = 87, .external_lex_state = 2},
  [93] = {.lex_state = 82, .external_lex_state = 2},
  [94] = {.lex_state = 82, .external_lex_state = 2},
  [95] = {.lex_state = 82, .external_lex_state = 3},
  [96] = {.lex_state = 82, .external_lex_state = 3},
  [97] = {.lex_state = 87, .external_lex_state = 2},
  [98] = {.lex_state = 87, .external_lex_state = 2},
  [99] = {.lex_state = 87, .external_lex_state = 2},
  [100] = {.lex_state = 87, .external_lex_state = 2},
  [101] = {.lex_state = 87, .external_lex_state = 2},
  [102] = {.lex_state = 87, .external_lex_state = 2},
  [103] = {.lex_state = 87, .external_lex_state = 2},
  [104] = {.lex_state = 87, .external_lex_state = 2},
  [105] = {.lex_state = 87, .external_lex_state = 2},
  [106] = {.lex_state = 87, .external_lex_state = 2},
  [107] = {.lex_state = 87, .external_lex_state = 2},
  [108] = {.lex_state = 87, .external_lex_state = 2},
  [109] = {.lex_state = 87, .external_lex_state = 2},
  [110] = {.lex_state = 87, .external_lex_state = 2},
  [111] = {.lex_state = 87, .external_lex_state = 2},
  [112] = {.lex_state = 87, .external_lex_state = 2},
  [113] = {.lex_state = 87, .external_lex_state = 2},
  [114] = {.lex_state = 87, .external_lex_state = 2},
  [115] = {.lex_state = 87, .external_lex_state = 2},
  [116] = {.lex_state = 87, .external_lex_state = 2},
  [117] = {.lex_state = 87, .external_lex_state = 2},
  [118] = {.lex_state = 87, .external_lex_state = 2},
  [119] = {.lex_state = 87, .external_lex_state = 2},
  [120] = {.lex_state = 87, .external_lex_state = 2},
  [121] = {.lex_state = 87, .external_lex_state = 2},
  [122] = {.lex_state = 87, .external_lex_state = 2},
  [123] = {.lex_state = 87, .external_lex_state = 2},
  [124] = {.lex_state = 87, .external_lex_state = 2},
  [125] = {.lex_state = 83, .external_lex_state = 3},
  [126] = {.lex_state = 83, .external_lex_state = 3},
  [127] = {.lex_state = 82, .external_lex_state = 1},
  [128] = {.lex_state = 82, .external_lex_state = 3},
  [129] = {.lex_state = 82, .external_lex_state = 2},
  [130] = {.lex_state = 82, .external_lex_state = 2},
  [131] = {.lex_state = 82, .external_lex_state = 3},
  [132] = {.lex_state = 82, .external_lex_state = 1},
  [133] = {.lex_state = 82, .external_lex_state = 1},
  [134] = {.lex_state = 84, .external_lex_state = 4},
  [135] = {.lex_state = 84, .external_lex_state = 4},
  [136] = {.lex_state = 83, .external_lex_state = 3},
  [137] = {.lex_state = 83, .external_lex_state = 3},
  [138] = {.lex_state = 84, .external_lex_state = 4},
  [139] = {.lex_state = 84, .external_lex_state = 4},
  [140] = {.lex_state = 84, .external_lex_state = 4},
  [141] = {.lex_state = 84, .external_lex_state = 4},
  [142] = {.lex_state = 84, .external_lex_state = 4},
  [143] = {.lex_state = 82, .external_lex_state = 1},
  [144] = {.lex_state = 82, .external_lex_state = 1},
  [145] = {.lex_state = 82, .external_lex_state = 1},
  [146] = {.lex_state = 82, .external_lex_state = 3},
  [147] = {.lex_state = 82, .external_lex_state = 3},
  [148] = {.lex_state = 82, .external_lex_state = 3},
  [149] = {.lex_state = 82, .external_lex_state = 3},
  [150] = {.lex_state = 82, .external_lex_state = 3},
  [151] = {.lex_state = 85, .external_lex_state = 4},
  [152] = {.lex_state = 85, .external_lex_state = 4},
  [153] = {.lex_state = 85, .external_lex_state = 4},
  [154] = {.lex_state = 85, .external_lex_state = 4},
  [155] = {.lex_state = 82, .external_lex_state = 3},
  [156] = {.lex_state = 82, .external_lex_state = 3},
  [157] = {.lex_state = 85, .external_lex_state = 4},
  [158] = {.lex_state = 85, .external_lex_state = 4},
  [159] = {.lex_state = 85, .external_lex_state = 4},
  [160] = {.lex_state = 85, .external_lex_state = 5},
  [161] = {.lex_state = 82, .external_lex_state = 2},
  [162] = {.lex_state = 85, .external_lex_state = 5},
  [163] = {.lex_state = 85, .external_lex_state = 5},
  [164] = {.lex_state = 85, .external_lex_state = 5},
  [165] = {.lex_state = 82, .external_lex_state = 2},
  [166] = {.lex_state = 85, .external_lex_state = 5},
  [167] = {.lex_state = 85, .external_lex_state = 5},
  [168] = {.lex_state = 82, .external_lex_state = 2},
  [169] = {.lex_state = 85, .external_lex_state = 5},
  [170] = {.lex_state = 84, .external_lex_state = 6},
  [171] = {.lex_state = 84, .external_lex_state = 6},
  [172] = {.lex_state = 82, .external_lex_state = 2},
  [173] = {.lex_state = 84, .external_lex_state = 6},
  [174] = {.lex_state = 84, .external_lex_state = 6},
  [175] = {.lex_state = 84, .external_lex_state = 6},
  [176] = {.lex_state = 82, .external_lex_state = 2},
  [177] = {.lex_state = 84, .external_lex_state = 6},
  [178] = {.lex_state = 84, .external_lex_state = 6},
  [179] = {.lex_state = 82, .external_lex_state = 2},
  [180] = {.lex_state = 82, .external_lex_state = 2},
  [181] = {.lex_state = 82, .external_lex_state = 2},
  [182] = {.lex_state = 82, .external_lex_state = 2},
  [183] = {.lex_state = 85, .external_lex_state = 6},
  [184] = {.lex_state = 85, .external_lex_state = 6},
  [185] = {.lex_state = 85, .external_lex_state = 6},
  [186] = {.lex_state = 85, .external_lex_state = 6},
  [187] = {.lex_state = 85, .external_lex_state = 6},
  [188] = {.lex_state = 82, .external_lex_state = 2},
  [189] = {.lex_state = 85, .external_lex_state = 6},
  [190] = {.lex_state = 85, .external_lex_state = 6},
  [191] = {.lex_state = 82, .external_lex_state = 2},
  [192] = {.lex_state = 82, .external_lex_state = 2},
  [193] = {.lex_state = 82, .external_lex_state = 2},
  [194] = {.lex_state = 82, .external_lex_state = 2},
  [195] = {.lex_state = 82, .external_lex_state = 2},
  [196] = {.lex_state = 82, .external_lex_state = 2},
  [197] = {.lex_state = 85, .external_lex_state = 7},
  [198] = {.lex_state = 85, .external_lex_state = 7},
  [199] = {.lex_state = 85, .external_lex_state = 7},
  [200] = {.lex_state = 85, .external_lex_state = 7},
  [201] = {.lex_state = 85, .external_lex_state = 7},
  [202] = {.lex_state = 85, .external_lex_state = 7},
  [203] = {.lex_state = 85, .external_lex_state = 7},
  [204] = {.lex_state = 87, .external_lex_state = 2},
  [205] = {.lex_state = 87, .external_lex_state = 2},
  [206] = {.lex_state = 82, .external_lex_state = 2},
  [207] = {.lex_state = 82, .external_lex_state = 2},
  [208] = {.lex_state = 82, .external_lex_state = 2},
  [209] = {.lex_state = 82, .external_lex_state = 2},
  [210] = {.lex_state = 80, .external_lex_state = 4},
  [211] = {.lex_state = 80, .external_lex_state = 4},
  [212] = {.lex_state = 80, .external_lex_state = 4},
  [213] = {.lex_state = 80, .external_lex_state = 6},
  [214] = {.lex_state = 80, .external_lex_state = 6},
  [215] = {.lex_state = 80, .external_lex_state = 4},
  [216] = {.lex_state = 80, .external_lex_state = 4},
  [217] = {.lex_state = 80, .external_lex_state = 4},
  [218] = {.lex_state = 80, .external_lex_state = 6},
  [219] = {.lex_state = 80, .external_lex_state = 6},
  [220] = {.lex_state = 80, .external_lex_state = 4},
  [221] = {.lex_state = 80, .external_lex_state = 6},
  [222] = {.lex_state = 80, .external_lex_state = 6},
  [223] = {.lex_state = 80, .external_lex_state = 6},
  [224] = {.lex_state = 86, .external_lex_state = 6},
  [225] = {.lex_state = 86, .external_lex_state = 6},
  [226] = {.lex_state = 80, .external_lex_state = 8},
  [227] = {.lex_state = 80, .external_lex_state = 8},
  [228] = {.lex_state = 80, .external_lex_state = 8},
  [229] = {.lex_state = 80, .external_lex_state = 8},
  [230] = {.lex_state = 80, .external_lex_state = 8},
  [231] = {.lex_state = 80, .external_lex_state = 8},
  [232] = {.lex_state = 86, .external_lex_state = 6},
  [233] = {.lex_state = 86, .external_lex_state = 6},
  [234] = {.lex_state = 86, .external_lex_state = 6},
  [235] = {.lex_state = 86, .external_lex_state = 6},
  [236] = {.lex_state = 86, .external_lex_state = 6},
  [237] = {.lex_state = 80, .external_lex_state = 8},
  [238] = {.lex_state = 86, .external_lex_state = 4},
  [239] = {.lex_state = 86, .external_lex_state = 4},
  [240] = {.lex_state = 86, .external_lex_state = 4},
  [241] = {.lex_state = 86, .external_lex_state = 4},
  [242] = {.lex_state = 86, .external_lex_state = 4},
  [243] = {.lex_state = 86, .external_lex_state = 4},
  [244] = {.lex_state = 86, .external_lex_state = 4},
  [245] = {.lex_state = 86, .external_lex_state = 5},
  [246] = {.lex_state = 86, .external_lex_state = 5},
  [247] = {.lex_state = 86, .external_lex_state = 7},
  [248] = {.lex_state = 86, .external_lex_state = 7},
  [249] = {.lex_state = 86, .external_lex_state = 5},
  [250] = {.lex_state = 86, .external_lex_state = 7},
  [251] = {.lex_state = 86, .external_lex_state = 5},
  [252] = {.lex_state = 86, .external_lex_state = 5},
  [253] = {.lex_state = 86, .external_lex_state = 7},
  [254] = {.lex_state = 86, .external_lex_state = 7},
  [255] = {.lex_state = 86, .external_lex_state = 7},
  [256] = {.lex_state = 86, .external_lex_state = 7},
  [257] = {.lex_state = 86, .external_lex_state = 5},
  [258] = {.lex_state = 86, .external_lex_state = 5},
  [259] = {.lex_state = 86, .external_lex_state = 8},
  [260] = {.lex_state = 86, .external_lex_state = 8},
  [261] = {.lex_state = 86, .external_lex_state = 8},
  [262] = {.lex_state = 86, .external_lex_state = 8},
  [263] = {.lex_state = 86, .external_lex_state = 8},
  [264] = {.lex_state = 86, .external_lex_state = 8},
  [265] = {.lex_state = 86, .external_lex_state = 8},
  [266] = {.lex_state = 80, .external_lex_state = 9},
  [267] = {.lex_state = 80, .external_lex_state = 9},
  [268] = {.lex_state = 80, .external_lex_state = 9},
  [269] = {.lex_state = 80, .external_lex_state = 9},
  [270] = {.lex_state = 80, .external_lex_state = 9},
  [271] = {.lex_state = 80, .external_lex_state = 9},
  [272] = {.lex_state = 80, .external_lex_state = 9},
  [273] = {.lex_state = 86, .external_lex_state = 10},
  [274] = {.lex_state = 86, .external_lex_state = 10},
  [275] = {.lex_state = 86, .external_lex_state = 10},
  [276] = {.lex_state = 86, .external_lex_state = 10},
  [277] = {.lex_state = 86, .external_lex_state = 10},
  [278] = {.lex_state = 86, .external_lex_state = 10},
  [279] = {.lex_state = 86, .external_lex_state = 10},
  [280] = {.lex_state = 80, .external_lex_state = 6},
  [281] = {.lex_state = 80, .external_lex_state = 6},
  [282] = {.lex_state = 80, .external_lex_state = 6},
  [283] = {.lex_state = 80, .external_lex_state = 6},
  [284] = {.lex_state = 80, .external_lex_state = 6},
  [285] = {.lex_state = 80, .external_lex_state = 6},
  [286] = {.lex_state = 80, .external_lex_state = 6},
  [287] = {.lex_state = 87, .external_lex_state = 2},
  [288] = {.lex_state = 87, .external_lex_state = 2},
  [289] = {.lex_state = 2, .external_lex_state = 2},
  [290] = {.lex_state = 2, .external_lex_state = 2},
  [291] = {.lex_state = 87, .external_lex_state = 2},
  [292] = {.lex_state = 87, .external_lex_state = 3},
  [293] = {.lex_state = 87, .external_lex_state = 3},
  [294] = {.lex_state = 87, .external_lex_state = 2},
  [295] = {.lex_state = 87, .external_lex_state = 2},
  [296] = {.lex_state = 87, .external_lex_state = 2},
  [297] = {.lex_state = 87, .external_lex_state = 3},
  [298] = {.lex_state = 87, .external_lex_state = 2},
  [299] = {.lex_state = 87, .external_lex_state = 3},
  [300] = {.lex_state = 87, .external_lex_state = 2},
  [301] = {.lex_state = 87, .external_lex_state = 2},
  [302] = {.lex_state = 87, .external_lex_state = 2},
  [303] = {.lex_state = 87, .external_lex_state = 2},
  [304] = {.lex_state = 87, .external_lex_state = 2},
  [305] = {.lex_state = 87, .external_lex_state = 2},
  [306] = {.lex_state = 87, .external_lex_state = 2},
  [307] = {.lex_state = 87, .external_lex_state = 2},
  [308] = {.lex_state = 87, .external_lex_state = 2},
  [309] = {.lex_state = 87, .external_lex_state = 2},
  [310] = {.lex_state = 87, .external_lex_state = 2},
  [311] = {.lex_state = 87, .external_lex_state = 2},
  [312] = {.lex_state = 87, .external_lex_state = 2},
  [313] = {.lex_state = 87, .external_lex_state = 2},
  [314] = {.lex_state = 87, .external_lex_state = 2},
  [315] = {.lex_state = 87, .external_lex_state = 2},
  [316] = {.lex_state = 87, .external_lex_state = 2},
  [317] = {.lex_state = 87, .external_lex_state = 2},
  [318] = {.lex_state = 87, .external_lex_state = 2},
  [319] = {.lex_state = 87, .external_lex_state = 2},
  [320] = {.lex_state = 87, .external_lex_state = 2},
  [321] = {.lex_state = 87, .external_lex_state = 2},
  [322] = {.lex_state = 87, .external_lex_state = 2},
  [323] = {.lex_state = 87, .external_lex_state = 2},
  [324] = {.lex_state = 87, .external_lex_state = 2},
  [325] = {.lex_state = 87, .external_lex_state = 2},
  [326] = {.lex_state = 87, .external_lex_state = 2},
  [327] = {.lex_state = 87, .external_lex_state = 2},
  [328] = {.lex_state = 87, .external_lex_state = 2},
  [329] = {.lex_state = 87, .external_lex_state = 2},
  [330] = {.lex_state = 87, .external_lex_state = 2},
  [331] = {.lex_state = 87, .external_lex_state = 2},
  [332] = {.lex_state = 87, .external_lex_state = 2},
  [333] = {.lex_state = 87, .external_lex_state = 2},
  [334] = {.lex_state = 87, .external_lex_state = 2},
  [335] = {.lex_state = 87, .external_lex_state = 2},
  [336] = {.lex_state = 87, .external_lex_state = 2},
  [337] = {.lex_state = 87, .external_lex_state = 2},
  [338] = {.lex_state = 87, .external_lex_state = 2},
  [339] = {.lex_state = 87, .external_lex_state = 2},
  [340] = {.lex_state = 87, .external_lex_state = 2},
  [341] = {.lex_state = 87, .external_lex_state = 2},
  [342] = {.lex_state = 87, .external_lex_state = 2},
  [343] = {.lex_state = 87, .external_lex_state = 2},
  [344] = {.lex_state = 87, .external_lex_state = 2},
  [345] = {.lex_state = 87, .external_lex_state = 2},
  [346] = {.lex_state = 87, .external_lex_state = 2},
  [347] = {.lex_state = 87, .external_lex_state = 2},
  [348] = {.lex_state = 87, .external_lex_state = 2},
  [349] = {.lex_state = 87, .external_lex_state = 2},
  [350] = {.lex_state = 87, .external_lex_state = 2},
  [351] = {.lex_state = 87, .external_lex_state = 2},
  [352] = {.lex_state = 87, .external_lex_state = 2},
  [353] = {.lex_state = 87, .external_lex_state = 2},
  [354] = {.lex_state = 87, .external_lex_state = 2},
  [355] = {.lex_state = 87, .external_lex_state = 2},
  [356] = {.lex_state = 87, .external_lex_state = 2},
  [357] = {.lex_state = 87, .external_lex_state = 2},
  [358] = {.lex_state = 87, .external_lex_state = 2},
  [359] = {.lex_state = 87, .external_lex_state = 2},
  [360] = {.lex_state = 87, .external_lex_state = 2},
  [361] = {.lex_state = 87, .external_lex_state = 2},
  [362] = {.lex_state = 87, .external_lex_state = 2},
  [363] = {.lex_state = 87, .external_lex_state = 2},
  [364] = {.lex_state = 87, .external_lex_state = 2},
  [365] = {.lex_state = 87, .external_lex_state = 2},
  [366] = {.lex_state = 87, .external_lex_state = 2},
  [367] = {.lex_state = 87, .external_lex_state = 2},
  [368] = {.lex_state = 87, .external_lex_state = 2},
  [369] = {.lex_state = 87, .external_lex_state = 2},
  [370] = {.lex_state = 87, .external_lex_state = 2},
  [371] = {.lex_state = 87, .external_lex_state = 2},
  [372] = {.lex_state = 87, .external_lex_state = 2},
  [373] = {.lex_state = 87, .external_lex_state = 2},
  [374] = {.lex_state = 87, .external_lex_state = 2},
  [375] = {.lex_state = 87, .external_lex_state = 2},
  [376] = {.lex_state = 87, .external_lex_state = 2},
  [377] = {.lex_state = 87, .external_lex_state = 2},
  [378] = {.lex_state = 87, .external_lex_state = 2},
  [379] = {.lex_state = 87, .external_lex_state = 2},
  [380] = {.lex_state = 87, .external_lex_state = 2},
  [381] = {.lex_state = 87, .external_lex_state = 2},
  [382] = {.lex_state = 87, .external_lex_state = 2},
  [383] = {.lex_state = 87, .external_lex_state = 2},
  [384] = {.lex_state = 87, .external_lex_state = 2},
  [385] = {.lex_state = 87, .external_lex_state = 2},
  [386] = {.lex_state = 87, .external_lex_state = 2},
  [387] = {.lex_state = 87, .external_lex_state = 2},
  [388] = {.lex_state = 87, .external_lex_state = 2},
  [389] = {.lex_state = 87, .external_lex_state = 2},
  [390] = {.lex_state = 87, .external_lex_state = 2},
  [391] = {.lex_state = 87, .external_lex_state = 2},
  [392] = {.lex_state = 87, .external_lex_state = 2},
  [393] = {.lex_state = 87, .external_lex_state = 2},
  [394] = {.lex_state = 87, .external_lex_state = 2},
  [395] = {.lex_state = 87, .external_lex_state = 2},
  [396] = {.lex_state = 87, .external_lex_state = 2},
  [397] = {.lex_state = 87, .external_lex_state = 2},
  [398] = {.lex_state = 87, .external_lex_state = 2},
  [399] = {.lex_state = 87, .external_lex_state = 2},
  [400] = {.lex_state = 87, .external_lex_state = 2},
  [401] = {.lex_state = 87, .external_lex_state = 2},
  [402] = {.lex_state = 87, .external_lex_state = 2},
  [403] = {.lex_state = 87, .external_lex_state = 2},
  [404] = {.lex_state = 87, .external_lex_state = 2},
  [405] = {.lex_state = 87, .external_lex_state = 2},
  [406] = {.lex_state = 87, .external_lex_state = 2},
  [407] = {.lex_state = 87, .external_lex_state = 2},
  [408] = {.lex_state = 87, .external_lex_state = 2},
  [409] = {.lex_state = 87, .external_lex_state = 2},
  [410] = {.lex_state = 87, .external_lex_state = 2},
  [411] = {.lex_state = 87, .external_lex_state = 2},
  [412] = {.lex_state = 87, .external_lex_state = 2},
  [413] = {.lex_state = 87, .external_lex_state = 2},
  [414] = {.lex_state = 87, .external_lex_state = 2},
  [415] = {.lex_state = 87, .external_lex_state = 2},
  [416] = {.lex_state = 87, .external_lex_state = 2},
  [417] = {.lex_state = 87, .external_lex_state = 2},
  [418] = {.lex_state = 87, .external_lex_state = 2},
  [419] = {.lex_state = 87, .external_lex_state = 2},
  [420] = {.lex_state = 87, .external_lex_state = 2},
  [421] = {.lex_state = 87, .external_lex_state = 2},
  [422] = {.lex_state = 87, .external_lex_state = 2},
  [423] = {.lex_state = 87, .external_lex_state = 2},
  [424] = {.lex_state = 87, .external_lex_state = 2},
  [425] = {.lex_state = 87, .external_lex_state = 2},
  [426] = {.lex_state = 87, .external_lex_state = 2},
  [427] = {.lex_state = 87, .external_lex_state = 2},
  [428] = {.lex_state = 87, .external_lex_state = 2},
  [429] = {.lex_state = 87, .external_lex_state = 2},
  [430] = {.lex_state = 87, .external_lex_state = 2},
  [431] = {.lex_state = 87, .external_lex_state = 2},
  [432] = {.lex_state = 87, .external_lex_state = 2},
  [433] = {.lex_state = 87, .external_lex_state = 2},
  [434] = {.lex_state = 87, .external_lex_state = 2},
  [435] = {.lex_state = 87, .external_lex_state = 2},
  [436] = {.lex_state = 87, .external_lex_state = 2},
  [437] = {.lex_state = 87, .external_lex_state = 2},
  [438] = {.lex_state = 87, .external_lex_state = 2},
  [439] = {.lex_state = 87, .external_lex_state = 2},
  [440] = {.lex_state = 87, .external_lex_state = 2},
  [441] = {.lex_state = 87, .external_lex_state = 2},
  [442] = {.lex_state = 87, .external_lex_state = 2},
  [443] = {.lex_state = 87, .external_lex_state = 2},
  [444] = {.lex_state = 87, .external_lex_state = 2},
  [445] = {.lex_state = 87, .external_lex_state = 2},
  [446] = {.lex_state = 87, .external_lex_state = 2},
  [447] = {.lex_state = 87, .external_lex_state = 2},
  [448] = {.lex_state = 87, .external_lex_state = 2},
  [449] = {.lex_state = 87, .external_lex_state = 2},
  [450] = {.lex_state = 87, .external_lex_state = 2},
  [451] = {.lex_state = 87, .external_lex_state = 2},
  [452] = {.lex_state = 87, .external_lex_state = 2},
  [453] = {.lex_state = 87, .external_lex_state = 2},
  [454] = {.lex_state = 87, .external_lex_state = 2},
  [455] = {.lex_state = 87, .external_lex_state = 2},
  [456] = {.lex_state = 87, .external_lex_state = 2},
  [457] = {.lex_state = 87, .external_lex_state = 2},
  [458] = {.lex_state = 87, .external_lex_state = 2},
  [459] = {.lex_state = 87, .external_lex_state = 2},
  [460] = {.lex_state = 87, .external_lex_state = 2},
  [461] = {.lex_state = 87, .external_lex_state = 2},
  [462] = {.lex_state = 87, .external_lex_state = 2},
  [463] = {.lex_state = 87, .external_lex_state = 2},
  [464] = {.lex_state = 87, .external_lex_state = 2},
  [465] = {.lex_state = 87, .external_lex_state = 2},
  [466] = {.lex_state = 87, .external_lex_state = 2},
  [467] = {.lex_state = 87, .external_lex_state = 2},
  [468] = {.lex_state = 87, .external_lex_state = 2},
  [469] = {.lex_state = 87, .external_lex_state = 2},
  [470] = {.lex_state = 87, .external_lex_state = 2},
  [471] = {.lex_state = 87, .external_lex_state = 2},
  [472] = {.lex_state = 87, .external_lex_state = 2},
  [473] = {.lex_state = 87, .external_lex_state = 2},
  [474] = {.lex_state = 87, .external_lex_state = 2},
  [475] = {.lex_state = 87, .external_lex_state = 2},
  [476] = {.lex_state = 87, .external_lex_state = 2},
  [477] = {.lex_state = 87, .external_lex_state = 2},
  [478] = {.lex_state = 87, .external_lex_state = 2},
  [479] = {.lex_state = 87, .external_lex_state = 2},
  [480] = {.lex_state = 87, .external_lex_state = 2},
  [481] = {.lex_state = 87, .external_lex_state = 2},
  [482] = {.lex_state = 87, .external_lex_state = 2},
  [483] = {.lex_state = 87, .external_lex_state = 2},
  [484] = {.lex_state = 87, .external_lex_state = 2},
  [485] = {.lex_state = 87, .external_lex_state = 2},
  [486] = {.lex_state = 87, .external_lex_state = 2},
  [487] = {.lex_state = 87, .external_lex_state = 2},
  [488] = {.lex_state = 87, .external_lex_state = 2},
  [489] = {.lex_state = 87, .external_lex_state = 2},
  [490] = {.lex_state = 87, .external_lex_state = 2},
  [491] = {.lex_state = 87, .external_lex_state = 2},
  [492] = {.lex_state = 87, .external_lex_state = 2},
  [493] = {.lex_state = 87, .external_lex_state = 2},
  [494] = {.lex_state = 87, .external_lex_state = 2},
  [495] = {.lex_state = 87, .external_lex_state = 2},
  [496] = {.lex_state = 87, .external_lex_state = 2},
  [497] = {.lex_state = 87, .external_lex_state = 2},
  [498] = {.lex_state = 87, .external_lex_state = 2},
  [499] = {.lex_state = 87, .external_lex_state = 2},
  [500] = {.lex_state = 87, .external_lex_state = 2},
  [501] = {.lex_state = 87, .external_lex_state = 2},
  [502] = {.lex_state = 87, .external_lex_state = 2},
  [503] = {.lex_state = 87, .external_lex_state = 2},
  [504] = {.lex_state = 87, .external_lex_state = 2},
  [505] = {.lex_state = 87, .external_lex_state = 2},
  [506] = {.lex_state = 87, .external_lex_state = 2},
  [507] = {.lex_state = 87, .external_lex_state = 2},
  [508] = {.lex_state = 87, .external_lex_state = 2},
  [509] = {.lex_state = 87, .external_lex_state = 2},
  [510] = {.lex_state = 87, .external_lex_state = 2},
  [511] = {.lex_state = 87, .external_lex_state = 2},
  [512] = {.lex_state = 87, .external_lex_state = 2},
  [513] = {.lex_state = 87, .external_lex_state = 2},
  [514] = {.lex_state = 87, .external_lex_state = 2},
  [515] = {.lex_state = 87, .external_lex_state = 2},
  [516] = {.lex_state = 87, .external_lex_state = 2},
  [517] = {.lex_state = 87, .external_lex_state = 2},
  [518] = {.lex_state = 2, .external_lex_state = 2},
  [519] = {.lex_state = 87, .external_lex_state = 3},
  [520] = {.lex_state = 93, .external_lex_state = 4},
  [521] = {.lex_state = 93, .external_lex_state = 4},
  [522] = {.lex_state = 93, .external_lex_state = 4},
  [523] = {.lex_state = 93, .external_lex_state = 4},
  [524] = {.lex_state = 93, .external_lex_state = 4},
  [525] = {.lex_state = 93, .external_lex_state = 4},
  [526] = {.lex_state = 93, .external_lex_state = 4},
  [527] = {.lex_state = 89, .external_lex_state = 4},
  [528] = {.lex_state = 87, .external_lex_state = 3},
  [529] = {.lex_state = 2, .external_lex_state = 2},
  [530] = {.lex_state = 2, .external_lex_state = 2},
  [531] = {.lex_state = 93, .external_lex_state = 4},
  [532] = {.lex_state = 93, .external_lex_state = 4},
  [533] = {.lex_state = 89, .external_lex_state = 4},
  [534] = {.lex_state = 93, .external_lex_state = 4},
  [535] = {.lex_state = 93, .external_lex_state = 4},
  [536] = {.lex_state = 87, .external_lex_state = 2},
  [537] = {.lex_state = 93, .external_lex_state = 4},
  [538] = {.lex_state = 93, .external_lex_state = 4},
  [539] = {.lex_state = 87, .external_lex_state = 2},
  [540] = {.lex_state = 93, .external_lex_state = 4},
  [541] = {.lex_state = 93, .external_lex_state = 4},
  [542] = {.lex_state = 93, .external_lex_state = 4},
  [543] = {.lex_state = 93, .external_lex_state = 4},
  [544] = {.lex_state = 89, .external_lex_state = 4},
  [545] = {.lex_state = 93, .external_lex_state = 4},
  [546] = {.lex_state = 87, .external_lex_state = 2},
  [547] = {.lex_state = 93, .external_lex_state = 4},
  [548] = {.lex_state = 93, .external_lex_state = 4},
  [549] = {.lex_state = 93, .external_lex_state = 4},
  [550] = {.lex_state = 93, .external_lex_state = 4},
  [551] = {.lex_state = 93, .external_lex_state = 4},
  [552] = {.lex_state = 93, .external_lex_state = 4},
  [553] = {.lex_state = 87, .external_lex_state = 3},
  [554] = {.lex_state = 87, .external_lex_state = 3},
  [555] = {.lex_state = 87, .external_lex_state = 2},
  [556] = {.lex_state = 93, .external_lex_state = 4},
  [557] = {.lex_state = 93, .external_lex_state = 4},
  [558] = {.lex_state = 93, .external_lex_state = 4},
  [559] = {.lex_state = 93, .external_lex_state = 4},
  [560] = {.lex_state = 93, .external_lex_state = 4},
  [561] = {.lex_state = 89, .external_lex_state = 4},
  [562] = {.lex_state = 93, .external_lex_state = 4},
  [563] = {.lex_state = 93, .external_lex_state = 4},
  [564] = {.lex_state = 93, .external_lex_state = 4},
  [565] = {.lex_state = 93, .external_lex_state = 4},
  [566] = {.lex_state = 87, .external_lex_state = 2},
  [567] = {.lex_state = 93, .external_lex_state = 4},
  [568] = {.lex_state = 87, .external_lex_state = 2},
  [569] = {.lex_state = 87, .external_lex_state = 2},
  [570] = {.lex_state = 87, .external_lex_state = 2},
  [571] = {.lex_state = 87, .external_lex_state = 2},
  [572] = {.lex_state = 87, .external_lex_state = 2},
  [573] = {.lex_state = 87, .external_lex_state = 2},
  [574] = {.lex_state = 87, .external_lex_state = 2},
  [575] = {.lex_state = 87, .external_lex_state = 2},
  [576] = {.lex_state = 87, .external_lex_state = 2},
  [577] = {.lex_state = 87, .external_lex_state = 2},
  [578] = {.lex_state = 87, .external_lex_state = 2},
  [579] = {.lex_state = 87, .external_lex_state = 2},
  [580] = {.lex_state = 87, .external_lex_state = 2},
  [581] = {.lex_state = 87, .external_lex_state = 2},
  [582] = {.lex_state = 87, .external_lex_state = 2},
  [583] = {.lex_state = 87, .external_lex_state = 2},
  [584] = {.lex_state = 93, .external_lex_state = 4},
  [585] = {.lex_state = 87, .external_lex_state = 2},
  [586] = {.lex_state = 87, .external_lex_state = 2},
  [587] = {.lex_state = 87, .external_lex_state = 2},
  [588] = {.lex_state = 87, .external_lex_state = 2},
  [589] = {.lex_state = 87, .external_lex_state = 2},
  [590] = {.lex_state = 87, .external_lex_state = 2},
  [591] = {.lex_state = 87, .external_lex_state = 2},
  [592] = {.lex_state = 87, .external_lex_state = 2},
  [593] = {.lex_state = 87, .external_lex_state = 2},
  [594] = {.lex_state = 87, .external_lex_state = 2},
  [595] = {.lex_state = 87, .external_lex_state = 2},
  [596] = {.lex_state = 87, .external_lex_state = 2},
  [597] = {.lex_state = 87, .external_lex_state = 2},
  [598] = {.lex_state = 87, .external_lex_state = 2},
  [599] = {.lex_state = 87, .external_lex_state = 2},
  [600] = {.lex_state = 87, .external_lex_state = 2},
  [601] = {.lex_state = 87, .external_lex_state = 2},
  [602] = {.lex_state = 93, .external_lex_state = 4},
  [603] = {.lex_state = 87, .external_lex_state = 2},
  [604] = {.lex_state = 87, .external_lex_state = 2},
  [605] = {.lex_state = 87, .external_lex_state = 2},
  [606] = {.lex_state = 93, .external_lex_state = 4},
  [607] = {.lex_state = 87, .external_lex_state = 2},
  [608] = {.lex_state = 87, .external_lex_state = 2},
  [609] = {.lex_state = 87, .external_lex_state = 2},
  [610] = {.lex_state = 87, .external_lex_state = 2},
  [611] = {.lex_state = 87, .external_lex_state = 2},
  [612] = {.lex_state = 87, .external_lex_state = 2},
  [613] = {.lex_state = 87, .external_lex_state = 2},
  [614] = {.lex_state = 87, .external_lex_state = 2},
  [615] = {.lex_state = 87, .external_lex_state = 2},
  [616] = {.lex_state = 87, .external_lex_state = 2},
  [617] = {.lex_state = 87, .external_lex_state = 2},
  [618] = {.lex_state = 87, .external_lex_state = 2},
  [619] = {.lex_state = 87, .external_lex_state = 2},
  [620] = {.lex_state = 87, .external_lex_state = 2},
  [621] = {.lex_state = 87, .external_lex_state = 2},
  [622] = {.lex_state = 87, .external_lex_state = 2},
  [623] = {.lex_state = 87, .external_lex_state = 2},
  [624] = {.lex_state = 87, .external_lex_state = 2},
  [625] = {.lex_state = 87, .external_lex_state = 2},
  [626] = {.lex_state = 87, .external_lex_state = 2},
  [627] = {.lex_state = 87, .external_lex_state = 2},
  [628] = {.lex_state = 87, .external_lex_state = 2},
  [629] = {.lex_state = 87, .external_lex_state = 2},
  [630] = {.lex_state = 87, .external_lex_state = 2},
  [631] = {.lex_state = 87, .external_lex_state = 2},
  [632] = {.lex_state = 87, .external_lex_state = 2},
  [633] = {.lex_state = 87, .external_lex_state = 2},
  [634] = {.lex_state = 87, .external_lex_state = 2},
  [635] = {.lex_state = 87, .external_lex_state = 2},
  [636] = {.lex_state = 87, .external_lex_state = 2},
  [637] = {.lex_state = 87, .external_lex_state = 2},
  [638] = {.lex_state = 87, .external_lex_state = 2},
  [639] = {.lex_state = 87, .external_lex_state = 2},
  [640] = {.lex_state = 87, .external_lex_state = 2},
  [641] = {.lex_state = 87, .external_lex_state = 2},
  [642] = {.lex_state = 87, .external_lex_state = 2},
  [643] = {.lex_state = 87, .external_lex_state = 2},
  [644] = {.lex_state = 87, .external_lex_state = 2},
  [645] = {.lex_state = 87, .external_lex_state = 2},
  [646] = {.lex_state = 87, .external_lex_state = 2},
  [647] = {.lex_state = 87, .external_lex_state = 2},
  [648] = {.lex_state = 87, .external_lex_state = 2},
  [649] = {.lex_state = 87, .external_lex_state = 2},
  [650] = {.lex_state = 87, .external_lex_state = 2},
  [651] = {.lex_state = 87, .external_lex_state = 2},
  [652] = {.lex_state = 87, .external_lex_state = 2},
  [653] = {.lex_state = 87, .external_lex_state = 2},
  [654] = {.lex_state = 87, .external_lex_state = 2},
  [655] = {.lex_state = 87, .external_lex_state = 2},
  [656] = {.lex_state = 87, .external_lex_state = 2},
  [657] = {.lex_state = 87, .external_lex_state = 2},
  [658] = {.lex_state = 87, .external_lex_state = 2},
  [659] = {.lex_state = 87, .external_lex_state = 2},
  [660] = {.lex_state = 93, .external_lex_state = 4},
  [661] = {.lex_state = 93, .external_lex_state = 4},
  [662] = {.lex_state = 93, .external_lex_state = 4},
  [663] = {.lex_state = 93, .external_lex_state = 4},
  [664] = {.lex_state = 93, .external_lex_state = 4},
  [665] = {.lex_state = 93, .external_lex_state = 4},
  [666] = {.lex_state = 93, .external_lex_state = 4},
  [667] = {.lex_state = 93, .external_lex_state = 4},
  [668] = {.lex_state = 93, .external_lex_state = 4},
  [669] = {.lex_state = 93, .external_lex_state = 4},
  [670] = {.lex_state = 93, .external_lex_state = 4},
  [671] = {.lex_state = 93, .external_lex_state = 4},
  [672] = {.lex_state = 93, .external_lex_state = 4},
  [673] = {.lex_state = 93, .external_lex_state = 4},
  [674] = {.lex_state = 89, .external_lex_state = 4},
  [675] = {.lex_state = 93, .external_lex_state = 4},
  [676] = {.lex_state = 87, .external_lex_state = 2},
  [677] = {.lex_state = 87, .external_lex_state = 2},
  [678] = {.lex_state = 87, .external_lex_state = 2},
  [679] = {.lex_state = 87, .external_lex_state = 2},
  [680] = {.lex_state = 87, .external_lex_state = 2},
  [681] = {.lex_state = 93, .external_lex_state = 4},
  [682] = {.lex_state = 93, .external_lex_state = 4},
  [683] = {.lex_state = 93, .external_lex_state = 4},
  [684] = {.lex_state = 93, .external_lex_state = 4},
  [685] = {.lex_state = 87, .external_lex_state = 2},
  [686] = {.lex_state = 87, .external_lex_state = 2},
  [687] = {.lex_state = 87, .external_lex_state = 2},
  [688] = {.lex_state = 87, .external_lex_state = 2},
  [689] = {.lex_state = 93, .external_lex_state = 4},
  [690] = {.lex_state = 93, .external_lex_state = 4},
  [691] = {.lex_state = 93, .external_lex_state = 4},
  [692] = {.lex_state = 93, .external_lex_state = 4},
  [693] = {.lex_state = 93, .external_lex_state = 4},
  [694] = {.lex_state = 93, .external_lex_state = 4},
  [695] = {.lex_state = 93, .external_lex_state = 4},
  [696] = {.lex_state = 93, .external_lex_state = 4},
  [697] = {.lex_state = 93, .external_lex_state = 4},
  [698] = {.lex_state = 93, .external_lex_state = 4},
  [699] = {.lex_state = 93, .external_lex_state = 4},
  [700] = {.lex_state = 93, .external_lex_state = 4},
  [701] = {.lex_state = 93, .external_lex_state = 4},
  [702] = {.lex_state = 93, .external_lex_state = 4},
  [703] = {.lex_state = 93, .external_lex_state = 4},
  [704] = {.lex_state = 93, .external_lex_state = 4},
  [705] = {.lex_state = 93, .external_lex_state = 4},
  [706] = {.lex_state = 93, .external_lex_state = 4},
  [707] = {.lex_state = 93, .external_lex_state = 4},
  [708] = {.lex_state = 93, .external_lex_state = 4},
  [709] = {.lex_state = 93, .external_lex_state = 4},
  [710] = {.lex_state = 93, .external_lex_state = 4},
  [711] = {.lex_state = 93, .external_lex_state = 4},
  [712] = {.lex_state = 93, .external_lex_state = 4},
  [713] = {.lex_state = 93, .external_lex_state = 4},
  [714] = {.lex_state = 93, .external_lex_state = 4},
  [715] = {.lex_state = 93, .external_lex_state = 4},
  [716] = {.lex_state = 93, .external_lex_state = 4},
  [717] = {.lex_state = 93, .external_lex_state = 4},
  [718] = {.lex_state = 93, .external_lex_state = 4},
  [719] = {.lex_state = 93, .external_lex_state = 4},
  [720] = {.lex_state = 93, .external_lex_state = 4},
  [721] = {.lex_state = 93, .external_lex_state = 4},
  [722] = {.lex_state = 93, .external_lex_state = 4},
  [723] = {.lex_state = 93, .external_lex_state = 4},
  [724] = {.lex_state = 87, .external_lex_state = 2},
  [725] = {.lex_state = 93, .external_lex_state = 4},
  [726] = {.lex_state = 93, .external_lex_state = 4},
  [727] = {.lex_state = 93, .external_lex_state = 4},
  [728] = {.lex_state = 93, .external_lex_state = 4},
  [729] = {.lex_state = 93, .external_lex_state = 4},
  [730] = {.lex_state = 93, .external_lex_state = 4},
  [731] = {.lex_state = 93, .external_lex_state = 4},
  [732] = {.lex_state = 93, .external_lex_state = 4},
  [733] = {.lex_state = 93, .external_lex_state = 4},
  [734] = {.lex_state = 93, .external_lex_state = 4},
  [735] = {.lex_state = 93, .external_lex_state = 4},
  [736] = {.lex_state = 93, .external_lex_state = 4},
  [737] = {.lex_state = 93, .external_lex_state = 4},
  [738] = {.lex_state = 93, .external_lex_state = 4},
  [739] = {.lex_state = 87, .external_lex_state = 2},
  [740] = {.lex_state = 93, .external_lex_state = 4},
  [741] = {.lex_state = 87, .external_lex_state = 2},
  [742] = {.lex_state = 93, .external_lex_state = 4},
  [743] = {.lex_state = 87, .external_lex_state = 2},
  [744] = {.lex_state = 93, .external_lex_state = 4},
  [745] = {.lex_state = 93, .external_lex_state = 4},
  [746] = {.lex_state = 93, .external_lex_state = 4},
  [747] = {.lex_state = 93, .external_lex_state = 4},
  [748] = {.lex_state = 93, .external_lex_state = 4},
  [749] = {.lex_state = 93, .external_lex_state = 4},
  [750] = {.lex_state = 93, .external_lex_state = 4},
  [751] = {.lex_state = 93, .external_lex_state = 4},
  [752] = {.lex_state = 93, .external_lex_state = 4},
  [753] = {.lex_state = 93, .external_lex_state = 4},
  [754] = {.lex_state = 93, .external_lex_state = 4},
  [755] = {.lex_state = 93, .external_lex_state = 4},
  [756] = {.lex_state = 93, .external_lex_state = 4},
  [757] = {.lex_state = 93, .external_lex_state = 4},
  [758] = {.lex_state = 93, .external_lex_state = 4},
  [759] = {.lex_state = 93, .external_lex_state = 4},
  [760] = {.lex_state = 93, .external_lex_state = 4},
  [761] = {.lex_state = 93, .external_lex_state = 4},
  [762] = {.lex_state = 93, .external_lex_state = 4},
  [763] = {.lex_state = 93, .external_lex_state = 4},
  [764] = {.lex_state = 93, .external_lex_state = 4},
  [765] = {.lex_state = 93, .external_lex_state = 4},
  [766] = {.lex_state = 93, .external_lex_state = 4},
  [767] = {.lex_state = 93, .external_lex_state = 4},
  [768] = {.lex_state = 93, .external_lex_state = 4},
  [769] = {.lex_state = 93, .external_lex_state = 4},
  [770] = {.lex_state = 93, .external_lex_state = 4},
  [771] = {.lex_state = 93, .external_lex_state = 4},
  [772] = {.lex_state = 93, .external_lex_state = 4},
  [773] = {.lex_state = 93, .external_lex_state = 4},
  [774] = {.lex_state = 93, .external_lex_state = 4},
  [775] = {.lex_state = 93, .external_lex_state = 4},
  [776] = {.lex_state = 93, .external_lex_state = 4},
  [777] = {.lex_state = 93, .external_lex_state = 4},
  [778] = {.lex_state = 93, .external_lex_state = 4},
  [779] = {.lex_state = 93, .external_lex_state = 4},
  [780] = {.lex_state = 93, .external_lex_state = 4},
  [781] = {.lex_state = 93, .external_lex_state = 4},
  [782] = {.lex_state = 93, .external_lex_state = 4},
  [783] = {.lex_state = 93, .external_lex_state = 4},
  [784] = {.lex_state = 93, .external_lex_state = 4},
  [785] = {.lex_state = 93, .external_lex_state = 4},
  [786] = {.lex_state = 93, .external_lex_state = 4},
  [787] = {.lex_state = 93, .external_lex_state = 4},
  [788] = {.lex_state = 93, .external_lex_state = 4},
  [789] = {.lex_state = 93, .external_lex_state = 4},
  [790] = {.lex_state = 93, .external_lex_state = 4},
  [791] = {.lex_state = 93, .external_lex_state = 4},
  [792] = {.lex_state = 93, .external_lex_state = 4},
  [793] = {.lex_state = 93, .external_lex_state = 4},
  [794] = {.lex_state = 93, .external_lex_state = 4},
  [795] = {.lex_state = 93, .external_lex_state = 4},
  [796] = {.lex_state = 93, .external_lex_state = 4},
  [797] = {.lex_state = 93, .external_lex_state = 4},
  [798] = {.lex_state = 93, .external_lex_state = 4},
  [799] = {.lex_state = 93, .external_lex_state = 4},
  [800] = {.lex_state = 93, .external_lex_state = 4},
  [801] = {.lex_state = 93, .external_lex_state = 4},
  [802] = {.lex_state = 93, .external_lex_state = 4},
  [803] = {.lex_state = 93, .external_lex_state = 4},
  [804] = {.lex_state = 87, .external_lex_state = 2},
  [805] = {.lex_state = 93, .external_lex_state = 4},
  [806] = {.lex_state = 93, .external_lex_state = 4},
  [807] = {.lex_state = 93, .external_lex_state = 4},
  [808] = {.lex_state = 93, .external_lex_state = 4},
  [809] = {.lex_state = 93, .external_lex_state = 4},
  [810] = {.lex_state = 93, .external_lex_state = 4},
  [811] = {.lex_state = 93, .external_lex_state = 4},
  [812] = {.lex_state = 93, .external_lex_state = 4},
  [813] = {.lex_state = 93, .external_lex_state = 4},
  [814] = {.lex_state = 93, .external_lex_state = 4},
  [815] = {.lex_state = 87, .external_lex_state = 2},
  [816] = {.lex_state = 93, .external_lex_state = 4},
  [817] = {.lex_state = 93, .external_lex_state = 4},
  [818] = {.lex_state = 93, .external_lex_state = 4},
  [819] = {.lex_state = 93, .external_lex_state = 4},
  [820] = {.lex_state = 93, .external_lex_state = 4},
  [821] = {.lex_state = 93, .external_lex_state = 4},
  [822] = {.lex_state = 93, .external_lex_state = 4},
  [823] = {.lex_state = 93, .external_lex_state = 4},
  [824] = {.lex_state = 93, .external_lex_state = 4},
  [825] = {.lex_state = 93, .external_lex_state = 4},
  [826] = {.lex_state = 93, .external_lex_state = 4},
  [827] = {.lex_state = 87, .external_lex_state = 2},
  [828] = {.lex_state = 93, .external_lex_state = 4},
  [829] = {.lex_state = 93, .external_lex_state = 4},
  [830] = {.lex_state = 93, .external_lex_state = 4},
  [831] = {.lex_state = 93, .external_lex_state = 4},
  [832] = {.lex_state = 93, .external_lex_state = 4},
  [833] = {.lex_state = 93, .external_lex_state = 4},
  [834] = {.lex_state = 93, .external_lex_state = 4},
  [835] = {.lex_state = 93, .external_lex_state = 4},
  [836] = {.lex_state = 93, .external_lex_state = 4},
  [837] = {.lex_state = 93, .external_lex_state = 4},
  [838] = {.lex_state = 93, .external_lex_state = 4},
  [839] = {.lex_state = 93, .external_lex_state = 4},
  [840] = {.lex_state = 93, .external_lex_state = 4},
  [841] = {.lex_state = 93, .external_lex_state = 4},
  [842] = {.lex_state = 87, .external_lex_state = 2},
  [843] = {.lex_state = 93, .external_lex_state = 4},
  [844] = {.lex_state = 93, .external_lex_state = 4},
  [845] = {.lex_state = 93, .external_lex_state = 4},
  [846] = {.lex_state = 93, .external_lex_state = 4},
  [847] = {.lex_state = 87, .external_lex_state = 2},
  [848] = {.lex_state = 93, .external_lex_state = 4},
  [849] = {.lex_state = 93, .external_lex_state = 4},
  [850] = {.lex_state = 93, .external_lex_state = 4},
  [851] = {.lex_state = 93, .external_lex_state = 4},
  [852] = {.lex_state = 93, .external_lex_state = 4},
  [853] = {.lex_state = 93, .external_lex_state = 4},
  [854] = {.lex_state = 93, .external_lex_state = 4},
  [855] = {.lex_state = 87, .external_lex_state = 2},
  [856] = {.lex_state = 93, .external_lex_state = 4},
  [857] = {.lex_state = 93, .external_lex_state = 4},
  [858] = {.lex_state = 93, .external_lex_state = 4},
  [859] = {.lex_state = 87, .external_lex_state = 2},
  [860] = {.lex_state = 87, .external_lex_state = 2},
  [861] = {.lex_state = 87, .external_lex_state = 2},
  [862] = {.lex_state = 87, .external_lex_state = 2},
  [863] = {.lex_state = 87, .external_lex_state = 2},
  [864] = {.lex_state = 87, .external_lex_state = 2},
  [865] = {.lex_state = 87, .external_lex_state = 2},
  [866] = {.lex_state = 87, .external_lex_state = 2},
  [867] = {.lex_state = 87, .external_lex_state = 2},
  [868] = {.lex_state = 87, .external_lex_state = 2},
  [869] = {.lex_state = 87, .external_lex_state = 2},
  [870] = {.lex_state = 93, .external_lex_state = 4},
  [871] = {.lex_state = 93, .external_lex_state = 4},
  [872] = {.lex_state = 93, .external_lex_state = 4},
  [873] = {.lex_state = 93, .external_lex_state = 4},
  [874] = {.lex_state = 93, .external_lex_state = 4},
  [875] = {.lex_state = 93, .external_lex_state = 4},
  [876] = {.lex_state = 93, .external_lex_state = 4},
  [877] = {.lex_state = 94, .external_lex_state = 4},
  [878] = {.lex_state = 87, .external_lex_state = 2},
  [879] = {.lex_state = 93, .external_lex_state = 4},
  [880] = {.lex_state = 87, .external_lex_state = 2},
  [881] = {.lex_state = 93, .external_lex_state = 4},
  [882] = {.lex_state = 87, .external_lex_state = 2},
  [883] = {.lex_state = 87, .external_lex_state = 2},
  [884] = {.lex_state = 93, .external_lex_state = 4},
  [885] = {.lex_state = 87, .external_lex_state = 2},
  [886] = {.lex_state = 87, .external_lex_state = 2},
  [887] = {.lex_state = 93, .external_lex_state = 4},
  [888] = {.lex_state = 93, .external_lex_state = 4},
  [889] = {.lex_state = 93, .external_lex_state = 4},
  [890] = {.lex_state = 93, .external_lex_state = 4},
  [891] = {.lex_state = 87, .external_lex_state = 2},
  [892] = {.lex_state = 87, .external_lex_state = 2},
  [893] = {.lex_state = 87, .external_lex_state = 2},
  [894] = {.lex_state = 87, .external_lex_state = 2},
  [895] = {.lex_state = 87, .external_lex_state = 2},
  [896] = {.lex_state = 87, .external_lex_state = 2},
  [897] = {.lex_state = 87, .external_lex_state = 2},
  [898] = {.lex_state = 87, .external_lex_state = 2},
  [899] = {.lex_state = 87, .external_lex_state = 2},
  [900] = {.lex_state = 87, .external_lex_state = 2},
  [901] = {.lex_state = 87, .external_lex_state = 2},
  [902] = {.lex_state = 87, .external_lex_state = 2},
  [903] = {.lex_state = 87, .external_lex_state = 2},
  [904] = {.lex_state = 94, .external_lex_state = 4},
  [905] = {.lex_state = 87, .external_lex_state = 2},
  [906] = {.lex_state = 87, .external_lex_state = 2},
  [907] = {.lex_state = 94, .external_lex_state = 4},
  [908] = {.lex_state = 87, .external_lex_state = 2},
  [909] = {.lex_state = 87, .external_lex_state = 2},
  [910] = {.lex_state = 87, .external_lex_state = 2},
  [911] = {.lex_state = 87, .external_lex_state = 2},
  [912] = {.lex_state = 87, .external_lex_state = 2},
  [913] = {.lex_state = 87, .external_lex_state = 2},
  [914] = {.lex_state = 87, .external_lex_state = 2},
  [915] = {.lex_state = 87, .external_lex_state = 2},
  [916] = {.lex_state = 87, .external_lex_state = 2},
  [917] = {.lex_state = 87, .external_lex_state = 2},
  [918] = {.lex_state = 87, .external_lex_state = 2},
  [919] = {.lex_state = 87, .external_lex_state = 2},
  [920] = {.lex_state = 87, .external_lex_state = 2},
  [921] = {.lex_state = 87, .external_lex_state = 2},
  [922] = {.lex_state = 87, .external_lex_state = 2},
  [923] = {.lex_state = 87, .external_lex_state = 2},
  [924] = {.lex_state = 87, .external_lex_state = 2},
  [925] = {.lex_state = 87, .external_lex_state = 2},
  [926] = {.lex_state = 87, .external_lex_state = 2},
  [927] = {.lex_state = 93, .external_lex_state = 4},
  [928] = {.lex_state = 93, .external_lex_state = 4},
  [929] = {.lex_state = 93, .external_lex_state = 4},
  [930] = {.lex_state = 93, .external_lex_state = 4},
  [931] = {.lex_state = 93, .external_lex_state = 4},
  [932] = {.lex_state = 93, .external_lex_state = 4},
  [933] = {.lex_state = 93, .external_lex_state = 4},
  [934] = {.lex_state = 87, .external_lex_state = 2},
  [935] = {.lex_state = 87, .external_lex_state = 2},
  [936] = {.lex_state = 87, .external_lex_state = 2},
  [937] = {.lex_state = 87, .external_lex_state = 2},
  [938] = {.lex_state = 87, .external_lex_state = 2},
  [939] = {.lex_state = 87, .external_lex_state = 2},
  [940] = {.lex_state = 87, .external_lex_state = 2},
  [941] = {.lex_state = 87, .external_lex_state = 2},
  [942] = {.lex_state = 87, .external_lex_state = 2},
  [943] = {.lex_state = 87, .external_lex_state = 2},
  [944] = {.lex_state = 87, .external_lex_state = 2},
  [945] = {.lex_state = 87, .external_lex_state = 2},
  [946] = {.lex_state = 87, .external_lex_state = 2},
  [947] = {.lex_state = 87, .external_lex_state = 2},
  [948] = {.lex_state = 87, .external_lex_state = 2},
  [949] = {.lex_state = 87, .external_lex_state = 2},
  [950] = {.lex_state = 87, .external_lex_state = 2},
  [951] = {.lex_state = 87, .external_lex_state = 2},
  [952] = {.lex_state = 87, .external_lex_state = 2},
  [953] = {.lex_state = 87, .external_lex_state = 2},
  [954] = {.lex_state = 87, .external_lex_state = 2},
  [955] = {.lex_state = 87, .external_lex_state = 2},
  [956] = {.lex_state = 87, .external_lex_state = 2},
  [957] = {.lex_state = 87, .external_lex_state = 2},
  [958] = {.lex_state = 87, .external_lex_state = 2},
  [959] = {.lex_state = 87, .external_lex_state = 2},
  [960] = {.lex_state = 87, .external_lex_state = 2},
  [961] = {.lex_state = 87, .external_lex_state = 2},
  [962] = {.lex_state = 87, .external_lex_state = 2},
  [963] = {.lex_state = 87, .external_lex_state = 2},
  [964] = {.lex_state = 87, .external_lex_state = 2},
  [965] = {.lex_state = 87, .external_lex_state = 2},
  [966] = {.lex_state = 87, .external_lex_state = 2},
  [967] = {.lex_state = 87, .external_lex_state = 2},
  [968] = {.lex_state = 87, .external_lex_state = 2},
  [969] = {.lex_state = 87, .external_lex_state = 2},
  [970] = {.lex_state = 87, .external_lex_state = 2},
  [971] = {.lex_state = 87, .external_lex_state = 2},
  [972] = {.lex_state = 87, .external_lex_state = 2},
  [973] = {.lex_state = 87, .external_lex_state = 2},
  [974] = {.lex_state = 87, .external_lex_state = 2},
  [975] = {.lex_state = 87, .external_lex_state = 2},
  [976] = {.lex_state = 87, .external_lex_state = 2},
  [977] = {.lex_state = 87, .external_lex_state = 2},
  [978] = {.lex_state = 87, .external_lex_state = 2},
  [979] = {.lex_state = 87, .external_lex_state = 2},
  [980] = {.lex_state = 87, .external_lex_state = 2},
  [981] = {.lex_state = 87, .external_lex_state = 2},
  [982] = {.lex_state = 87, .external_lex_state = 2},
  [983] = {.lex_state = 87, .external_lex_state = 2},
  [984] = {.lex_state = 87, .external_lex_state = 2},
  [985] = {.lex_state = 87, .external_lex_state = 2},
  [986] = {.lex_state = 87, .external_lex_state = 2},
  [987] = {.lex_state = 87, .external_lex_state = 2},
  [988] = {.lex_state = 87, .external_lex_state = 2},
  [989] = {.lex_state = 87, .external_lex_state = 2},
  [990] = {.lex_state = 87, .external_lex_state = 2},
  [991] = {.lex_state = 87, .external_lex_state = 2},
  [992] = {.lex_state = 87, .external_lex_state = 2},
  [993] = {.lex_state = 87, .external_lex_state = 2},
  [994] = {.lex_state = 87, .external_lex_state = 2},
  [995] = {.lex_state = 87, .external_lex_state = 2},
  [996] = {.lex_state = 87, .external_lex_state = 2},
  [997] = {.lex_state = 87, .external_lex_state = 2},
  [998] = {.lex_state = 87, .external_lex_state = 2},
  [999] = {.lex_state = 87, .external_lex_state = 2},
  [1000] = {.lex_state = 87, .external_lex_state = 2},
  [1001] = {.lex_state = 87, .external_lex_state = 2},
  [1002] = {.lex_state = 87, .external_lex_state = 2},
  [1003] = {.lex_state = 87, .external_lex_state = 2},
  [1004] = {.lex_state = 87, .external_lex_state = 2},
  [1005] = {.lex_state = 87, .external_lex_state = 2},
  [1006] = {.lex_state = 87, .external_lex_state = 2},
  [1007] = {.lex_state = 87, .external_lex_state = 2},
  [1008] = {.lex_state = 87, .external_lex_state = 2},
  [1009] = {.lex_state = 87, .external_lex_state = 2},
  [1010] = {.lex_state = 87, .external_lex_state = 2},
  [1011] = {.lex_state = 87, .external_lex_state = 2},
  [1012] = {.lex_state = 87, .external_lex_state = 2},
  [1013] = {.lex_state = 87, .external_lex_state = 2},
  [1014] = {.lex_state = 87, .external_lex_state = 2},
  [1015] = {.lex_state = 87, .external_lex_state = 2},
  [1016] = {.lex_state = 87, .external_lex_state = 2},
  [1017] = {.lex_state = 87, .external_lex_state = 2},
  [1018] = {.lex_state = 87, .external_lex_state = 2},
  [1019] = {.lex_state = 87, .external_lex_state = 2},
  [1020] = {.lex_state = 87, .external_lex_state = 2},
  [1021] = {.lex_state = 87, .external_lex_state = 2},
  [1022] = {.lex_state = 87, .external_lex_state = 2},
  [1023] = {.lex_state = 87, .external_lex_state = 2},
  [1024] = {.lex_state = 87, .external_lex_state = 2},
  [1025] = {.lex_state = 87, .external_lex_state = 2},
  [1026] = {.lex_state = 87, .external_lex_state = 2},
  [1027] = {.lex_state = 87, .external_lex_state = 2},
  [1028] = {.lex_state = 87, .external_lex_state = 2},
  [1029] = {.lex_state = 87, .external_lex_state = 2},
  [1030] = {.lex_state = 87, .external_lex_state = 2},
  [1031] = {.lex_state = 87, .external_lex_state = 2},
  [1032] = {.lex_state = 87, .external_lex_state = 2},
  [1033] = {.lex_state = 87, .external_lex_state = 2},
  [1034] = {.lex_state = 87, .external_lex_state = 2},
  [1035] = {.lex_state = 87, .external_lex_state = 2},
  [1036] = {.lex_state = 87, .external_lex_state = 2},
  [1037] = {.lex_state = 87, .external_lex_state = 2},
  [1038] = {.lex_state = 87, .external_lex_state = 2},
  [1039] = {.lex_state = 87, .external_lex_state = 2},
  [1040] = {.lex_state = 87, .external_lex_state = 2},
  [1041] = {.lex_state = 87, .external_lex_state = 2},
  [1042] = {.lex_state = 87, .external_lex_state = 2},
  [1043] = {.lex_state = 87, .external_lex_state = 2},
  [1044] = {.lex_state = 87, .external_lex_state = 2},
  [1045] = {.lex_state = 87, .external_lex_state = 2},
  [1046] = {.lex_state = 87, .external_lex_state = 2},
  [1047] = {.lex_state = 87, .external_lex_state = 2},
  [1048] = {.lex_state = 87, .external_lex_state = 2},
  [1049] = {.lex_state = 87, .external_lex_state = 2},
  [1050] = {.lex_state = 87, .external_lex_state = 2},
  [1051] = {.lex_state = 87, .external_lex_state = 2},
  [1052] = {.lex_state = 87, .external_lex_state = 2},
  [1053] = {.lex_state = 87, .external_lex_state = 2},
  [1054] = {.lex_state = 87, .external_lex_state = 2},
  [1055] = {.lex_state = 87, .external_lex_state = 2},
  [1056] = {.lex_state = 87, .external_lex_state = 2},
  [1057] = {.lex_state = 87, .external_lex_state = 2},
  [1058] = {.lex_state = 87, .external_lex_state = 2},
  [1059] = {.lex_state = 87, .external_lex_state = 2},
  [1060] = {.lex_state = 87, .external_lex_state = 2},
  [1061] = {.lex_state = 87, .external_lex_state = 2},
  [1062] = {.lex_state = 87, .external_lex_state = 2},
  [1063] = {.lex_state = 87, .external_lex_state = 2},
  [1064] = {.lex_state = 87, .external_lex_state = 2},
  [1065] = {.lex_state = 87, .external_lex_state = 2},
  [1066] = {.lex_state = 87, .external_lex_state = 2},
  [1067] = {.lex_state = 87, .external_lex_state = 2},
  [1068] = {.lex_state = 87, .external_lex_state = 2},
  [1069] = {.lex_state = 87, .external_lex_state = 2},
  [1070] = {.lex_state = 87, .external_lex_state = 2},
  [1071] = {.lex_state = 87, .external_lex_state = 2},
  [1072] = {.lex_state = 87, .external_lex_state = 2},
  [1073] = {.lex_state = 87, .external_lex_state = 2},
  [1074] = {.lex_state = 87, .external_lex_state = 2},
  [1075] = {.lex_state = 87, .external_lex_state = 2},
  [1076] = {.lex_state = 87, .external_lex_state = 2},
  [1077] = {.lex_state = 87, .external_lex_state = 2},
  [1078] = {.lex_state = 87, .external_lex_state = 2},
  [1079] = {.lex_state = 87, .external_lex_state = 2},
  [1080] = {.lex_state = 87, .external_lex_state = 2},
  [1081] = {.lex_state = 87, .external_lex_state = 2},
  [1082] = {.lex_state = 87, .external_lex_state = 2},
  [1083] = {.lex_state = 87, .external_lex_state = 2},
  [1084] = {.lex_state = 87, .external_lex_state = 2},
  [1085] = {.lex_state = 87, .external_lex_state = 2},
  [1086] = {.lex_state = 87, .external_lex_state = 2},
  [1087] = {.lex_state = 87, .external_lex_state = 2},
  [1088] = {.lex_state = 87, .external_lex_state = 2},
  [1089] = {.lex_state = 87, .external_lex_state = 2},
  [1090] = {.lex_state = 87, .external_lex_state = 2},
  [1091] = {.lex_state = 87, .external_lex_state = 2},
  [1092] = {.lex_state = 87, .external_lex_state = 2},
  [1093] = {.lex_state = 87, .external_lex_state = 2},
  [1094] = {.lex_state = 87, .external_lex_state = 2},
  [1095] = {.lex_state = 87, .external_lex_state = 2},
  [1096] = {.lex_state = 87, .external_lex_state = 2},
  [1097] = {.lex_state = 87, .external_lex_state = 2},
  [1098] = {.lex_state = 87, .external_lex_state = 2},
  [1099] = {.lex_state = 87, .external_lex_state = 2},
  [1100] = {.lex_state = 87, .external_lex_state = 2},
  [1101] = {.lex_state = 87, .external_lex_state = 2},
  [1102] = {.lex_state = 87, .external_lex_state = 2},
  [1103] = {.lex_state = 87, .external_lex_state = 2},
  [1104] = {.lex_state = 87, .external_lex_state = 2},
  [1105] = {.lex_state = 87, .external_lex_state = 2},
  [1106] = {.lex_state = 87, .external_lex_state = 2},
  [1107] = {.lex_state = 87, .external_lex_state = 2},
  [1108] = {.lex_state = 87, .external_lex_state = 2},
  [1109] = {.lex_state = 87, .external_lex_state = 2},
  [1110] = {.lex_state = 87, .external_lex_state = 2},
  [1111] = {.lex_state = 87, .external_lex_state = 2},
  [1112] = {.lex_state = 87, .external_lex_state = 2},
  [1113] = {.lex_state = 87, .external_lex_state = 2},
  [1114] = {.lex_state = 87, .external_lex_state = 2},
  [1115] = {.lex_state = 87, .external_lex_state = 2},
  [1116] = {.lex_state = 87, .external_lex_state = 2},
  [1117] = {.lex_state = 87, .external_lex_state = 2},
  [1118] = {.lex_state = 87, .external_lex_state = 2},
  [1119] = {.lex_state = 87, .external_lex_state = 2},
  [1120] = {.lex_state = 87, .external_lex_state = 2},
  [1121] = {.lex_state = 87, .external_lex_state = 2},
  [1122] = {.lex_state = 87, .external_lex_state = 2},
  [1123] = {.lex_state = 87, .external_lex_state = 2},
  [1124] = {.lex_state = 87, .external_lex_state = 2},
  [1125] = {.lex_state = 87, .external_lex_state = 2},
  [1126] = {.lex_state = 87, .external_lex_state = 2},
  [1127] = {.lex_state = 87, .external_lex_state = 2},
  [1128] = {.lex_state = 87, .external_lex_state = 2},
  [1129] = {.lex_state = 87, .external_lex_state = 2},
  [1130] = {.lex_state = 87, .external_lex_state = 2},
  [1131] = {.lex_state = 87, .external_lex_state = 2},
  [1132] = {.lex_state = 87, .external_lex_state = 2},
  [1133] = {.lex_state = 87, .external_lex_state = 2},
  [1134] = {.lex_state = 87, .external_lex_state = 2},
  [1135] = {.lex_state = 87, .external_lex_state = 2},
  [1136] = {.lex_state = 87, .external_lex_state = 2},
  [1137] = {.lex_state = 87, .external_lex_state = 2},
  [1138] = {.lex_state = 87, .external_lex_state = 2},
  [1139] = {.lex_state = 87, .external_lex_state = 2},
  [1140] = {.lex_state = 87, .external_lex_state = 2},
  [1141] = {.lex_state = 87, .external_lex_state = 2},
  [1142] = {.lex_state = 87, .external_lex_state = 2},
  [1143] = {.lex_state = 87, .external_lex_state = 2},
  [1144] = {.lex_state = 87, .external_lex_state = 2},
  [1145] = {.lex_state = 87, .external_lex_state = 2},
  [1146] = {.lex_state = 87, .external_lex_state = 2},
  [1147] = {.lex_state = 87, .external_lex_state = 2},
  [1148] = {.lex_state = 87, .external_lex_state = 2},
  [1149] = {.lex_state = 87, .external_lex_state = 2},
  [1150] = {.lex_state = 87, .external_lex_state = 2},
  [1151] = {.lex_state = 87, .external_lex_state = 2},
  [1152] = {.lex_state = 87, .external_lex_state = 2},
  [1153] = {.lex_state = 87, .external_lex_state = 2},
  [1154] = {.lex_state = 87, .external_lex_state = 2},
  [1155] = {.lex_state = 87, .external_lex_state = 2},
  [1156] = {.lex_state = 87, .external_lex_state = 2},
  [1157] = {.lex_state = 87, .external_lex_state = 2},
  [1158] = {.lex_state = 87, .external_lex_state = 2},
  [1159] = {.lex_state = 87, .external_lex_state = 2},
  [1160] = {.lex_state = 87, .external_lex_state = 2},
  [1161] = {.lex_state = 87, .external_lex_state = 2},
  [1162] = {.lex_state = 87, .external_lex_state = 2},
  [1163] = {.lex_state = 87, .external_lex_state = 2},
  [1164] = {.lex_state = 87, .external_lex_state = 2},
  [1165] = {.lex_state = 87, .external_lex_state = 2},
  [1166] = {.lex_state = 87, .external_lex_state = 2},
  [1167] = {.lex_state = 87, .external_lex_state = 2},
  [1168] = {.lex_state = 87, .external_lex_state = 2},
  [1169] = {.lex_state = 87, .external_lex_state = 2},
  [1170] = {.lex_state = 87, .external_lex_state = 2},
  [1171] = {.lex_state = 87, .external_lex_state = 2},
  [1172] = {.lex_state = 87, .external_lex_state = 2},
  [1173] = {.lex_state = 87, .external_lex_state = 2},
  [1174] = {.lex_state = 87, .external_lex_state = 2},
  [1175] = {.lex_state = 87, .external_lex_state = 2},
  [1176] = {.lex_state = 87, .external_lex_state = 2},
  [1177] = {.lex_state = 87, .external_lex_state = 2},
  [1178] = {.lex_state = 87, .external_lex_state = 2},
  [1179] = {.lex_state = 87, .external_lex_state = 2},
  [1180] = {.lex_state = 87, .external_lex_state = 2},
  [1181] = {.lex_state = 87, .external_lex_state = 2},
  [1182] = {.lex_state = 87, .external_lex_state = 2},
  [1183] = {.lex_state = 87, .external_lex_state = 2},
  [1184] = {.lex_state = 87, .external_lex_state = 2},
  [1185] = {.lex_state = 87, .external_lex_state = 2},
  [1186] = {.lex_state = 87, .external_lex_state = 2},
  [1187] = {.lex_state = 87, .external_lex_state = 2},
  [1188] = {.lex_state = 87, .external_lex_state = 2},
  [1189] = {.lex_state = 87, .external_lex_state = 2},
  [1190] = {.lex_state = 87, .external_lex_state = 2},
  [1191] = {.lex_state = 87, .external_lex_state = 2},
  [1192] = {.lex_state = 87, .external_lex_state = 2},
  [1193] = {.lex_state = 87, .external_lex_state = 2},
  [1194] = {.lex_state = 87, .external_lex_state = 2},
  [1195] = {.lex_state = 87, .external_lex_state = 2},
  [1196] = {.lex_state = 87, .external_lex_state = 2},
  [1197] = {.lex_state = 87, .external_lex_state = 2},
  [1198] = {.lex_state = 87, .external_lex_state = 2},
  [1199] = {.lex_state = 87, .external_lex_state = 2},
  [1200] = {.lex_state = 87, .external_lex_state = 2},
  [1201] = {.lex_state = 87, .external_lex_state = 2},
  [1202] = {.lex_state = 87, .external_lex_state = 2},
  [1203] = {.lex_state = 87, .external_lex_state = 2},
  [1204] = {.lex_state = 87, .external_lex_state = 2},
  [1205] = {.lex_state = 87, .external_lex_state = 2},
  [1206] = {.lex_state = 87, .external_lex_state = 2},
  [1207] = {.lex_state = 87, .external_lex_state = 2},
  [1208] = {.lex_state = 87, .external_lex_state = 2},
  [1209] = {.lex_state = 87, .external_lex_state = 2},
  [1210] = {.lex_state = 87, .external_lex_state = 2},
  [1211] = {.lex_state = 87, .external_lex_state = 2},
  [1212] = {.lex_state = 87, .external_lex_state = 2},
  [1213] = {.lex_state = 87, .external_lex_state = 2},
  [1214] = {.lex_state = 87, .external_lex_state = 2},
  [1215] = {.lex_state = 87, .external_lex_state = 2},
  [1216] = {.lex_state = 87, .external_lex_state = 2},
  [1217] = {.lex_state = 87, .external_lex_state = 2},
  [1218] = {.lex_state = 87, .external_lex_state = 2},
  [1219] = {.lex_state = 87, .external_lex_state = 2},
  [1220] = {.lex_state = 87, .external_lex_state = 2},
  [1221] = {.lex_state = 87, .external_lex_state = 2},
  [1222] = {.lex_state = 87, .external_lex_state = 2},
  [1223] = {.lex_state = 87, .external_lex_state = 2},
  [1224] = {.lex_state = 87, .external_lex_state = 2},
  [1225] = {.lex_state = 87, .external_lex_state = 2},
  [1226] = {.lex_state = 87, .external_lex_state = 2},
  [1227] = {.lex_state = 87, .external_lex_state = 2},
  [1228] = {.lex_state = 87, .external_lex_state = 2},
  [1229] = {.lex_state = 87, .external_lex_state = 2},
  [1230] = {.lex_state = 87, .external_lex_state = 2},
  [1231] = {.lex_state = 87, .external_lex_state = 2},
  [1232] = {.lex_state = 87, .external_lex_state = 2},
  [1233] = {.lex_state = 87, .external_lex_state = 2},
  [1234] = {.lex_state = 87, .external_lex_state = 2},
  [1235] = {.lex_state = 87, .external_lex_state = 2},
  [1236] = {.lex_state = 87, .external_lex_state = 2},
  [1237] = {.lex_state = 87, .external_lex_state = 2},
  [1238] = {.lex_state = 87, .external_lex_state = 2},
  [1239] = {.lex_state = 87, .external_lex_state = 2},
  [1240] = {.lex_state = 87, .external_lex_state = 2},
  [1241] = {.lex_state = 87, .external_lex_state = 2},
  [1242] = {.lex_state = 87, .external_lex_state = 2},
  [1243] = {.lex_state = 87, .external_lex_state = 2},
  [1244] = {.lex_state = 87, .external_lex_state = 2},
  [1245] = {.lex_state = 87, .external_lex_state = 2},
  [1246] = {.lex_state = 87, .external_lex_state = 2},
  [1247] = {.lex_state = 87, .external_lex_state = 2},
  [1248] = {.lex_state = 87, .external_lex_state = 2},
  [1249] = {.lex_state = 87, .external_lex_state = 2},
  [1250] = {.lex_state = 87, .external_lex_state = 2},
  [1251] = {.lex_state = 87, .external_lex_state = 2},
  [1252] = {.lex_state = 87, .external_lex_state = 2},
  [1253] = {.lex_state = 87, .external_lex_state = 2},
  [1254] = {.lex_state = 87, .external_lex_state = 2},
  [1255] = {.lex_state = 87, .external_lex_state = 2},
  [1256] = {.lex_state = 87, .external_lex_state = 2},
  [1257] = {.lex_state = 87, .external_lex_state = 2},
  [1258] = {.lex_state = 87, .external_lex_state = 2},
  [1259] = {.lex_state = 87, .external_lex_state = 2},
  [1260] = {.lex_state = 87, .external_lex_state = 2},
  [1261] = {.lex_state = 87, .external_lex_state = 2},
  [1262] = {.lex_state = 87, .external_lex_state = 2},
  [1263] = {.lex_state = 87, .external_lex_state = 2},
  [1264] = {.lex_state = 87, .external_lex_state = 2},
  [1265] = {.lex_state = 87, .external_lex_state = 2},
  [1266] = {.lex_state = 87, .external_lex_state = 2},
  [1267] = {.lex_state = 87, .external_lex_state = 2},
  [1268] = {.lex_state = 94, .external_lex_state = 5},
  [1269] = {.lex_state = 95, .external_lex_state = 4},
  [1270] = {.lex_state = 95, .external_lex_state = 4},
  [1271] = {.lex_state = 94, .external_lex_state = 4},
  [1272] = {.lex_state = 95, .external_lex_state = 4},
  [1273] = {.lex_state = 87, .external_lex_state = 2},
  [1274] = {.lex_state = 87, .external_lex_state = 2},
  [1275] = {.lex_state = 87, .external_lex_state = 2},
  [1276] = {.lex_state = 87, .external_lex_state = 2},
  [1277] = {.lex_state = 87, .external_lex_state = 2},
  [1278] = {.lex_state = 89, .external_lex_state = 6},
  [1279] = {.lex_state = 89, .external_lex_state = 6},
  [1280] = {.lex_state = 89, .external_lex_state = 6},
  [1281] = {.lex_state = 87, .external_lex_state = 2},
  [1282] = {.lex_state = 87, .external_lex_state = 2},
  [1283] = {.lex_state = 87, .external_lex_state = 2},
  [1284] = {.lex_state = 87, .external_lex_state = 2},
  [1285] = {.lex_state = 95, .external_lex_state = 4},
  [1286] = {.lex_state = 87, .external_lex_state = 2},
  [1287] = {.lex_state = 87, .external_lex_state = 2},
  [1288] = {.lex_state = 87, .external_lex_state = 2},
  [1289] = {.lex_state = 87, .external_lex_state = 2},
  [1290] = {.lex_state = 87, .external_lex_state = 2},
  [1291] = {.lex_state = 87, .external_lex_state = 2},
  [1292] = {.lex_state = 87, .external_lex_state = 2},
  [1293] = {.lex_state = 87, .external_lex_state = 2},
  [1294] = {.lex_state = 87, .external_lex_state = 2},
  [1295] = {.lex_state = 87, .external_lex_state = 2},
  [1296] = {.lex_state = 87, .external_lex_state = 2},
  [1297] = {.lex_state = 87, .external_lex_state = 2},
  [1298] = {.lex_state = 87, .external_lex_state = 2},
  [1299] = {.lex_state = 87, .external_lex_state = 2},
  [1300] = {.lex_state = 87, .external_lex_state = 2},
  [1301] = {.lex_state = 87, .external_lex_state = 2},
  [1302] = {.lex_state = 87, .external_lex_state = 2},
  [1303] = {.lex_state = 87, .external_lex_state = 2},
  [1304] = {.lex_state = 87, .external_lex_state = 2},
  [1305] = {.lex_state = 93, .external_lex_state = 6},
  [1306] = {.lex_state = 93, .external_lex_state = 6},
  [1307] = {.lex_state = 93, .external_lex_state = 6},
  [1308] = {.lex_state = 93, .external_lex_state = 6},
  [1309] = {.lex_state = 93, .external_lex_state = 6},
  [1310] = {.lex_state = 93, .external_lex_state = 6},
  [1311] = {.lex_state = 93, .external_lex_state = 6},
  [1312] = {.lex_state = 93, .external_lex_state = 6},
  [1313] = {.lex_state = 93, .external_lex_state = 6},
  [1314] = {.lex_state = 93, .external_lex_state = 6},
  [1315] = {.lex_state = 93, .external_lex_state = 6},
  [1316] = {.lex_state = 87, .external_lex_state = 2},
  [1317] = {.lex_state = 87, .external_lex_state = 2},
  [1318] = {.lex_state = 87, .external_lex_state = 2},
  [1319] = {.lex_state = 87, .external_lex_state = 2},
  [1320] = {.lex_state = 87, .external_lex_state = 2},
  [1321] = {.lex_state = 87, .external_lex_state = 2},
  [1322] = {.lex_state = 87, .external_lex_state = 2},
  [1323] = {.lex_state = 87, .external_lex_state = 2},
  [1324] = {.lex_state = 87, .external_lex_state = 2},
  [1325] = {.lex_state = 87, .external_lex_state = 2},
  [1326] = {.lex_state = 87, .external_lex_state = 2},
  [1327] = {.lex_state = 87, .external_lex_state = 2},
  [1328] = {.lex_state = 87, .external_lex_state = 2},
  [1329] = {.lex_state = 87, .external_lex_state = 2},
  [1330] = {.lex_state = 87, .external_lex_state = 2},
  [1331] = {.lex_state = 87, .external_lex_state = 2},
  [1332] = {.lex_state = 87, .external_lex_state = 2},
  [1333] = {.lex_state = 87, .external_lex_state = 2},
  [1334] = {.lex_state = 87, .external_lex_state = 2},
  [1335] = {.lex_state = 87, .external_lex_state = 2},
  [1336] = {.lex_state = 87, .external_lex_state = 2},
  [1337] = {.lex_state = 87, .external_lex_state = 2},
  [1338] = {.lex_state = 87, .external_lex_state = 2},
  [1339] = {.lex_state = 87, .external_lex_state = 2},
  [1340] = {.lex_state = 87, .external_lex_state = 2},
  [1341] = {.lex_state = 87, .external_lex_state = 2},
  [1342] = {.lex_state = 87, .external_lex_state = 2},
  [1343] = {.lex_state = 87, .external_lex_state = 2},
  [1344] = {.lex_state = 87, .external_lex_state = 2},
  [1345] = {.lex_state = 87, .external_lex_state = 2},
  [1346] = {.lex_state = 87, .external_lex_state = 2},
  [1347] = {.lex_state = 87, .external_lex_state = 2},
  [1348] = {.lex_state = 87, .external_lex_state = 2},
  [1349] = {.lex_state = 87, .external_lex_state = 2},
  [1350] = {.lex_state = 87, .external_lex_state = 2},
  [1351] = {.lex_state = 87, .external_lex_state = 2},
  [1352] = {.lex_state = 87, .external_lex_state = 2},
  [1353] = {.lex_state = 87, .external_lex_state = 2},
  [1354] = {.lex_state = 87, .external_lex_state = 2},
  [1355] = {.lex_state = 87, .external_lex_state = 2},
  [1356] = {.lex_state = 87, .external_lex_state = 2},
  [1357] = {.lex_state = 87, .external_lex_state = 2},
  [1358] = {.lex_state = 87, .external_lex_state = 2},
  [1359] = {.lex_state = 87, .external_lex_state = 2},
  [1360] = {.lex_state = 87, .external_lex_state = 2},
  [1361] = {.lex_state = 87, .external_lex_state = 2},
  [1362] = {.lex_state = 87, .external_lex_state = 2},
  [1363] = {.lex_state = 87, .external_lex_state = 2},
  [1364] = {.lex_state = 87, .external_lex_state = 2},
  [1365] = {.lex_state = 87, .external_lex_state = 2},
  [1366] = {.lex_state = 87, .external_lex_state = 2},
  [1367] = {.lex_state = 87, .external_lex_state = 2},
  [1368] = {.lex_state = 94, .external_lex_state = 5},
  [1369] = {.lex_state = 87, .external_lex_state = 2},
  [1370] = {.lex_state = 87, .external_lex_state = 2},
  [1371] = {.lex_state = 87, .external_lex_state = 2},
  [1372] = {.lex_state = 87, .external_lex_state = 2},
  [1373] = {.lex_state = 87, .external_lex_state = 2},
  [1374] = {.lex_state = 87, .external_lex_state = 2},
  [1375] = {.lex_state = 87, .external_lex_state = 2},
  [1376] = {.lex_state = 87, .external_lex_state = 2},
  [1377] = {.lex_state = 87, .external_lex_state = 2},
  [1378] = {.lex_state = 87, .external_lex_state = 2},
  [1379] = {.lex_state = 87, .external_lex_state = 2},
  [1380] = {.lex_state = 87, .external_lex_state = 2},
  [1381] = {.lex_state = 87, .external_lex_state = 2},
  [1382] = {.lex_state = 87, .external_lex_state = 2},
  [1383] = {.lex_state = 87, .external_lex_state = 2},
  [1384] = {.lex_state = 87, .external_lex_state = 2},
  [1385] = {.lex_state = 87, .external_lex_state = 2},
  [1386] = {.lex_state = 87, .external_lex_state = 2},
  [1387] = {.lex_state = 87, .external_lex_state = 2},
  [1388] = {.lex_state = 87, .external_lex_state = 2},
  [1389] = {.lex_state = 87, .external_lex_state = 2},
  [1390] = {.lex_state = 87, .external_lex_state = 2},
  [1391] = {.lex_state = 87, .external_lex_state = 2},
  [1392] = {.lex_state = 87, .external_lex_state = 2},
  [1393] = {.lex_state = 87, .external_lex_state = 2},
  [1394] = {.lex_state = 87, .external_lex_state = 2},
  [1395] = {.lex_state = 87, .external_lex_state = 2},
  [1396] = {.lex_state = 87, .external_lex_state = 2},
  [1397] = {.lex_state = 93, .external_lex_state = 6},
  [1398] = {.lex_state = 87, .external_lex_state = 2},
  [1399] = {.lex_state = 93, .external_lex_state = 6},
  [1400] = {.lex_state = 87, .external_lex_state = 2},
  [1401] = {.lex_state = 87, .external_lex_state = 2},
  [1402] = {.lex_state = 87, .external_lex_state = 2},
  [1403] = {.lex_state = 87, .external_lex_state = 2},
  [1404] = {.lex_state = 89, .external_lex_state = 6},
  [1405] = {.lex_state = 87, .external_lex_state = 2},
  [1406] = {.lex_state = 93, .external_lex_state = 6},
  [1407] = {.lex_state = 87, .external_lex_state = 2},
  [1408] = {.lex_state = 87, .external_lex_state = 2},
  [1409] = {.lex_state = 87, .external_lex_state = 2},
  [1410] = {.lex_state = 87, .external_lex_state = 2},
  [1411] = {.lex_state = 93, .external_lex_state = 6},
  [1412] = {.lex_state = 87, .external_lex_state = 2},
  [1413] = {.lex_state = 93, .external_lex_state = 6},
  [1414] = {.lex_state = 93, .external_lex_state = 6},
  [1415] = {.lex_state = 87, .external_lex_state = 2},
  [1416] = {.lex_state = 93, .external_lex_state = 6},
  [1417] = {.lex_state = 87, .external_lex_state = 2},
  [1418] = {.lex_state = 87, .external_lex_state = 2},
  [1419] = {.lex_state = 87, .external_lex_state = 2},
  [1420] = {.lex_state = 87, .external_lex_state = 2},
  [1421] = {.lex_state = 87, .external_lex_state = 2},
  [1422] = {.lex_state = 87, .external_lex_state = 2},
  [1423] = {.lex_state = 87, .external_lex_state = 2},
  [1424] = {.lex_state = 87, .external_lex_state = 2},
  [1425] = {.lex_state = 95, .external_lex_state = 4},
  [1426] = {.lex_state = 93, .external_lex_state = 6},
  [1427] = {.lex_state = 87, .external_lex_state = 2},
  [1428] = {.lex_state = 93, .external_lex_state = 6},
  [1429] = {.lex_state = 93, .external_lex_state = 6},
  [1430] = {.lex_state = 93, .external_lex_state = 6},
  [1431] = {.lex_state = 87, .external_lex_state = 2},
  [1432] = {.lex_state = 87, .external_lex_state = 2},
  [1433] = {.lex_state = 87, .external_lex_state = 2},
  [1434] = {.lex_state = 87, .external_lex_state = 2},
  [1435] = {.lex_state = 87, .external_lex_state = 2},
  [1436] = {.lex_state = 87, .external_lex_state = 2},
  [1437] = {.lex_state = 87, .external_lex_state = 2},
  [1438] = {.lex_state = 87, .external_lex_state = 2},
  [1439] = {.lex_state = 87, .external_lex_state = 2},
  [1440] = {.lex_state = 87, .external_lex_state = 2},
  [1441] = {.lex_state = 87, .external_lex_state = 2},
  [1442] = {.lex_state = 87, .external_lex_state = 2},
  [1443] = {.lex_state = 87, .external_lex_state = 2},
  [1444] = {.lex_state = 87, .external_lex_state = 2},
  [1445] = {.lex_state = 87, .external_lex_state = 2},
  [1446] = {.lex_state = 95, .external_lex_state = 4},
  [1447] = {.lex_state = 94, .external_lex_state = 5},
  [1448] = {.lex_state = 95, .external_lex_state = 4},
  [1449] = {.lex_state = 87, .external_lex_state = 2},
  [1450] = {.lex_state = 87, .external_lex_state = 2},
  [1451] = {.lex_state = 95, .external_lex_state = 4},
  [1452] = {.lex_state = 87, .external_lex_state = 2},
  [1453] = {.lex_state = 87, .external_lex_state = 2},
  [1454] = {.lex_state = 87, .external_lex_state = 2},
  [1455] = {.lex_state = 87, .external_lex_state = 2},
  [1456] = {.lex_state = 95, .external_lex_state = 4},
  [1457] = {.lex_state = 87, .external_lex_state = 2},
  [1458] = {.lex_state = 95, .external_lex_state = 4},
  [1459] = {.lex_state = 95, .external_lex_state = 4},
  [1460] = {.lex_state = 95, .external_lex_state = 4},
  [1461] = {.lex_state = 87, .external_lex_state = 2},
  [1462] = {.lex_state = 95, .external_lex_state = 4},
  [1463] = {.lex_state = 87, .external_lex_state = 2},
  [1464] = {.lex_state = 87, .external_lex_state = 2},
  [1465] = {.lex_state = 87, .external_lex_state = 2},
  [1466] = {.lex_state = 95, .external_lex_state = 4},
  [1467] = {.lex_state = 87, .external_lex_state = 2},
  [1468] = {.lex_state = 93, .external_lex_state = 6},
  [1469] = {.lex_state = 87, .external_lex_state = 2},
  [1470] = {.lex_state = 93, .external_lex_state = 6},
  [1471] = {.lex_state = 89, .external_lex_state = 6},
  [1472] = {.lex_state = 87, .external_lex_state = 2},
  [1473] = {.lex_state = 87, .external_lex_state = 2},
  [1474] = {.lex_state = 93, .external_lex_state = 6},
  [1475] = {.lex_state = 87, .external_lex_state = 2},
  [1476] = {.lex_state = 87, .external_lex_state = 2},
  [1477] = {.lex_state = 87, .external_lex_state = 2},
  [1478] = {.lex_state = 87, .external_lex_state = 2},
  [1479] = {.lex_state = 87, .external_lex_state = 2},
  [1480] = {.lex_state = 87, .external_lex_state = 2},
  [1481] = {.lex_state = 87, .external_lex_state = 2},
  [1482] = {.lex_state = 87, .external_lex_state = 2},
  [1483] = {.lex_state = 87, .external_lex_state = 2},
  [1484] = {.lex_state = 87, .external_lex_state = 2},
  [1485] = {.lex_state = 87, .external_lex_state = 2},
  [1486] = {.lex_state = 87, .external_lex_state = 2},
  [1487] = {.lex_state = 87, .external_lex_state = 2},
  [1488] = {.lex_state = 87, .external_lex_state = 2},
  [1489] = {.lex_state = 87, .external_lex_state = 2},
  [1490] = {.lex_state = 93, .external_lex_state = 6},
  [1491] = {.lex_state = 87, .external_lex_state = 2},
  [1492] = {.lex_state = 87, .external_lex_state = 2},
  [1493] = {.lex_state = 87, .external_lex_state = 2},
  [1494] = {.lex_state = 87, .external_lex_state = 2},
  [1495] = {.lex_state = 87, .external_lex_state = 2},
  [1496] = {.lex_state = 87, .external_lex_state = 2},
  [1497] = {.lex_state = 87, .external_lex_state = 2},
  [1498] = {.lex_state = 87, .external_lex_state = 2},
  [1499] = {.lex_state = 87, .external_lex_state = 2},
  [1500] = {.lex_state = 87, .external_lex_state = 2},
  [1501] = {.lex_state = 87, .external_lex_state = 2},
  [1502] = {.lex_state = 87, .external_lex_state = 2},
  [1503] = {.lex_state = 87, .external_lex_state = 2},
  [1504] = {.lex_state = 87, .external_lex_state = 2},
  [1505] = {.lex_state = 87, .external_lex_state = 2},
  [1506] = {.lex_state = 87, .external_lex_state = 2},
  [1507] = {.lex_state = 87, .external_lex_state = 2},
  [1508] = {.lex_state = 87, .external_lex_state = 2},
  [1509] = {.lex_state = 87, .external_lex_state = 2},
  [1510] = {.lex_state = 87, .external_lex_state = 2},
  [1511] = {.lex_state = 87, .external_lex_state = 2},
  [1512] = {.lex_state = 87, .external_lex_state = 2},
  [1513] = {.lex_state = 87, .external_lex_state = 2},
  [1514] = {.lex_state = 87, .external_lex_state = 2},
  [1515] = {.lex_state = 87, .external_lex_state = 2},
  [1516] = {.lex_state = 87, .external_lex_state = 2},
  [1517] = {.lex_state = 94, .external_lex_state = 5},
  [1518] = {.lex_state = 87, .external_lex_state = 2},
  [1519] = {.lex_state = 95, .external_lex_state = 4},
  [1520] = {.lex_state = 95, .external_lex_state = 4},
  [1521] = {.lex_state = 87, .external_lex_state = 2},
  [1522] = {.lex_state = 87, .external_lex_state = 2},
  [1523] = {.lex_state = 87, .external_lex_state = 2},
  [1524] = {.lex_state = 93, .external_lex_state = 6},
  [1525] = {.lex_state = 93, .external_lex_state = 6},
  [1526] = {.lex_state = 93, .external_lex_state = 6},
  [1527] = {.lex_state = 93, .external_lex_state = 6},
  [1528] = {.lex_state = 93, .external_lex_state = 6},
  [1529] = {.lex_state = 93, .external_lex_state = 6},
  [1530] = {.lex_state = 95, .external_lex_state = 4},
  [1531] = {.lex_state = 93, .external_lex_state = 6},
  [1532] = {.lex_state = 93, .external_lex_state = 6},
  [1533] = {.lex_state = 87, .external_lex_state = 2},
  [1534] = {.lex_state = 93, .external_lex_state = 6},
  [1535] = {.lex_state = 93, .external_lex_state = 6},
  [1536] = {.lex_state = 93, .external_lex_state = 6},
  [1537] = {.lex_state = 93, .external_lex_state = 6},
  [1538] = {.lex_state = 93, .external_lex_state = 6},
  [1539] = {.lex_state = 87, .external_lex_state = 2},
  [1540] = {.lex_state = 87, .external_lex_state = 2},
  [1541] = {.lex_state = 87, .external_lex_state = 2},
  [1542] = {.lex_state = 87, .external_lex_state = 2},
  [1543] = {.lex_state = 87, .external_lex_state = 2},
  [1544] = {.lex_state = 87, .external_lex_state = 2},
  [1545] = {.lex_state = 87, .external_lex_state = 2},
  [1546] = {.lex_state = 87, .external_lex_state = 2},
  [1547] = {.lex_state = 87, .external_lex_state = 2},
  [1548] = {.lex_state = 87, .external_lex_state = 2},
  [1549] = {.lex_state = 87, .external_lex_state = 2},
  [1550] = {.lex_state = 87, .external_lex_state = 2},
  [1551] = {.lex_state = 95, .external_lex_state = 4},
  [1552] = {.lex_state = 87, .external_lex_state = 2},
  [1553] = {.lex_state = 87, .external_lex_state = 2},
  [1554] = {.lex_state = 87, .external_lex_state = 2},
  [1555] = {.lex_state = 87, .external_lex_state = 2},
  [1556] = {.lex_state = 87, .external_lex_state = 2},
  [1557] = {.lex_state = 87, .external_lex_state = 2},
  [1558] = {.lex_state = 95, .external_lex_state = 4},
  [1559] = {.lex_state = 87, .external_lex_state = 2},
  [1560] = {.lex_state = 87, .external_lex_state = 2},
  [1561] = {.lex_state = 87, .external_lex_state = 2},
  [1562] = {.lex_state = 87, .external_lex_state = 2},
  [1563] = {.lex_state = 87, .external_lex_state = 2},
  [1564] = {.lex_state = 87, .external_lex_state = 2},
  [1565] = {.lex_state = 87, .external_lex_state = 2},
  [1566] = {.lex_state = 87, .external_lex_state = 2},
  [1567] = {.lex_state = 87, .external_lex_state = 2},
  [1568] = {.lex_state = 95, .external_lex_state = 4},
  [1569] = {.lex_state = 87, .external_lex_state = 2},
  [1570] = {.lex_state = 87, .external_lex_state = 2},
  [1571] = {.lex_state = 87, .external_lex_state = 2},
  [1572] = {.lex_state = 87, .external_lex_state = 2},
  [1573] = {.lex_state = 87, .external_lex_state = 2},
  [1574] = {.lex_state = 87, .external_lex_state = 2},
  [1575] = {.lex_state = 87, .external_lex_state = 2},
  [1576] = {.lex_state = 87, .external_lex_state = 2},
  [1577] = {.lex_state = 87, .external_lex_state = 2},
  [1578] = {.lex_state = 87, .external_lex_state = 2},
  [1579] = {.lex_state = 87, .external_lex_state = 2},
  [1580] = {.lex_state = 87, .external_lex_state = 2},
  [1581] = {.lex_state = 87, .external_lex_state = 2},
  [1582] = {.lex_state = 87, .external_lex_state = 2},
  [1583] = {.lex_state = 87, .external_lex_state = 2},
  [1584] = {.lex_state = 87, .external_lex_state = 2},
  [1585] = {.lex_state = 87, .external_lex_state = 2},
  [1586] = {.lex_state = 87, .external_lex_state = 2},
  [1587] = {.lex_state = 95, .external_lex_state = 4},
  [1588] = {.lex_state = 87, .external_lex_state = 2},
  [1589] = {.lex_state = 87, .external_lex_state = 2},
  [1590] = {.lex_state = 87, .external_lex_state = 2},
  [1591] = {.lex_state = 87, .external_lex_state = 2},
  [1592] = {.lex_state = 87, .external_lex_state = 2},
  [1593] = {.lex_state = 87, .external_lex_state = 2},
  [1594] = {.lex_state = 95, .external_lex_state = 4},
  [1595] = {.lex_state = 87, .external_lex_state = 2},
  [1596] = {.lex_state = 87, .external_lex_state = 2},
  [1597] = {.lex_state = 87, .external_lex_state = 2},
  [1598] = {.lex_state = 87, .external_lex_state = 2},
  [1599] = {.lex_state = 87, .external_lex_state = 2},
  [1600] = {.lex_state = 95, .external_lex_state = 4},
  [1601] = {.lex_state = 87, .external_lex_state = 2},
  [1602] = {.lex_state = 87, .external_lex_state = 2},
  [1603] = {.lex_state = 87, .external_lex_state = 2},
  [1604] = {.lex_state = 87, .external_lex_state = 2},
  [1605] = {.lex_state = 87, .external_lex_state = 2},
  [1606] = {.lex_state = 87, .external_lex_state = 2},
  [1607] = {.lex_state = 87, .external_lex_state = 2},
  [1608] = {.lex_state = 95, .external_lex_state = 4},
  [1609] = {.lex_state = 87, .external_lex_state = 2},
  [1610] = {.lex_state = 87, .external_lex_state = 2},
  [1611] = {.lex_state = 87, .external_lex_state = 2},
  [1612] = {.lex_state = 87, .external_lex_state = 2},
  [1613] = {.lex_state = 87, .external_lex_state = 2},
  [1614] = {.lex_state = 87, .external_lex_state = 2},
  [1615] = {.lex_state = 87, .external_lex_state = 2},
  [1616] = {.lex_state = 87, .external_lex_state = 2},
  [1617] = {.lex_state = 87, .external_lex_state = 2},
  [1618] = {.lex_state = 87, .external_lex_state = 2},
  [1619] = {.lex_state = 87, .external_lex_state = 2},
  [1620] = {.lex_state = 87, .external_lex_state = 2},
  [1621] = {.lex_state = 87, .external_lex_state = 2},
  [1622] = {.lex_state = 95, .external_lex_state = 4},
  [1623] = {.lex_state = 87, .external_lex_state = 2},
  [1624] = {.lex_state = 95, .external_lex_state = 4},
  [1625] = {.lex_state = 95, .external_lex_state = 4},
  [1626] = {.lex_state = 87, .external_lex_state = 2},
  [1627] = {.lex_state = 87, .external_lex_state = 2},
  [1628] = {.lex_state = 87, .external_lex_state = 2},
  [1629] = {.lex_state = 87, .external_lex_state = 2},
  [1630] = {.lex_state = 87, .external_lex_state = 2},
  [1631] = {.lex_state = 87, .external_lex_state = 2},
  [1632] = {.lex_state = 87, .external_lex_state = 2},
  [1633] = {.lex_state = 87, .external_lex_state = 2},
  [1634] = {.lex_state = 87, .external_lex_state = 2},
  [1635] = {.lex_state = 87, .external_lex_state = 2},
  [1636] = {.lex_state = 87, .external_lex_state = 2},
  [1637] = {.lex_state = 87, .external_lex_state = 2},
  [1638] = {.lex_state = 87, .external_lex_state = 2},
  [1639] = {.lex_state = 87, .external_lex_state = 2},
  [1640] = {.lex_state = 87, .external_lex_state = 2},
  [1641] = {.lex_state = 87, .external_lex_state = 2},
  [1642] = {.lex_state = 87, .external_lex_state = 2},
  [1643] = {.lex_state = 87, .external_lex_state = 2},
  [1644] = {.lex_state = 87, .external_lex_state = 2},
  [1645] = {.lex_state = 87, .external_lex_state = 2},
  [1646] = {.lex_state = 87, .external_lex_state = 2},
  [1647] = {.lex_state = 87, .external_lex_state = 2},
  [1648] = {.lex_state = 87, .external_lex_state = 2},
  [1649] = {.lex_state = 87, .external_lex_state = 2},
  [1650] = {.lex_state = 87, .external_lex_state = 2},
  [1651] = {.lex_state = 87, .external_lex_state = 2},
  [1652] = {.lex_state = 87, .external_lex_state = 2},
  [1653] = {.lex_state = 87, .external_lex_state = 2},
  [1654] = {.lex_state = 87, .external_lex_state = 2},
  [1655] = {.lex_state = 87, .external_lex_state = 2},
  [1656] = {.lex_state = 87, .external_lex_state = 2},
  [1657] = {.lex_state = 87, .external_lex_state = 2},
  [1658] = {.lex_state = 87, .external_lex_state = 2},
  [1659] = {.lex_state = 95, .external_lex_state = 4},
  [1660] = {.lex_state = 87, .external_lex_state = 2},
  [1661] = {.lex_state = 95, .external_lex_state = 4},
  [1662] = {.lex_state = 87, .external_lex_state = 2},
  [1663] = {.lex_state = 87, .external_lex_state = 2},
  [1664] = {.lex_state = 87, .external_lex_state = 2},
  [1665] = {.lex_state = 87, .external_lex_state = 2},
  [1666] = {.lex_state = 87, .external_lex_state = 2},
  [1667] = {.lex_state = 95, .external_lex_state = 4},
  [1668] = {.lex_state = 87, .external_lex_state = 2},
  [1669] = {.lex_state = 87, .external_lex_state = 2},
  [1670] = {.lex_state = 87, .external_lex_state = 2},
  [1671] = {.lex_state = 87, .external_lex_state = 2},
  [1672] = {.lex_state = 87, .external_lex_state = 2},
  [1673] = {.lex_state = 87, .external_lex_state = 2},
  [1674] = {.lex_state = 87, .external_lex_state = 2},
  [1675] = {.lex_state = 87, .external_lex_state = 2},
  [1676] = {.lex_state = 95, .external_lex_state = 4},
  [1677] = {.lex_state = 87, .external_lex_state = 2},
  [1678] = {.lex_state = 95, .external_lex_state = 4},
  [1679] = {.lex_state = 87, .external_lex_state = 2},
  [1680] = {.lex_state = 87, .external_lex_state = 2},
  [1681] = {.lex_state = 87, .external_lex_state = 2},
  [1682] = {.lex_state = 87, .external_lex_state = 2},
  [1683] = {.lex_state = 87, .external_lex_state = 2},
  [1684] = {.lex_state = 87, .external_lex_state = 2},
  [1685] = {.lex_state = 87, .external_lex_state = 2},
  [1686] = {.lex_state = 87, .external_lex_state = 2},
  [1687] = {.lex_state = 87, .external_lex_state = 2},
  [1688] = {.lex_state = 87, .external_lex_state = 2},
  [1689] = {.lex_state = 87, .external_lex_state = 2},
  [1690] = {.lex_state = 95, .external_lex_state = 4},
  [1691] = {.lex_state = 95, .external_lex_state = 4},
  [1692] = {.lex_state = 87, .external_lex_state = 2},
  [1693] = {.lex_state = 95, .external_lex_state = 4},
  [1694] = {.lex_state = 95, .external_lex_state = 4},
  [1695] = {.lex_state = 95, .external_lex_state = 4},
  [1696] = {.lex_state = 87, .external_lex_state = 2},
  [1697] = {.lex_state = 87, .external_lex_state = 2},
  [1698] = {.lex_state = 93, .external_lex_state = 6},
  [1699] = {.lex_state = 95, .external_lex_state = 4},
  [1700] = {.lex_state = 87, .external_lex_state = 2},
  [1701] = {.lex_state = 95, .external_lex_state = 4},
  [1702] = {.lex_state = 87, .external_lex_state = 2},
  [1703] = {.lex_state = 95, .external_lex_state = 4},
  [1704] = {.lex_state = 95, .external_lex_state = 4},
  [1705] = {.lex_state = 95, .external_lex_state = 4},
  [1706] = {.lex_state = 95, .external_lex_state = 4},
  [1707] = {.lex_state = 87, .external_lex_state = 2},
  [1708] = {.lex_state = 87, .external_lex_state = 2},
  [1709] = {.lex_state = 95, .external_lex_state = 4},
  [1710] = {.lex_state = 95, .external_lex_state = 4},
  [1711] = {.lex_state = 87, .external_lex_state = 2},
  [1712] = {.lex_state = 87, .external_lex_state = 2},
  [1713] = {.lex_state = 87, .external_lex_state = 2},
  [1714] = {.lex_state = 87, .external_lex_state = 2},
  [1715] = {.lex_state = 95, .external_lex_state = 4},
  [1716] = {.lex_state = 95, .external_lex_state = 4},
  [1717] = {.lex_state = 95, .external_lex_state = 4},
  [1718] = {.lex_state = 87, .external_lex_state = 2},
  [1719] = {.lex_state = 95, .external_lex_state = 4},
  [1720] = {.lex_state = 87, .external_lex_state = 2},
  [1721] = {.lex_state = 87, .external_lex_state = 2},
  [1722] = {.lex_state = 95, .external_lex_state = 4},
  [1723] = {.lex_state = 95, .external_lex_state = 4},
  [1724] = {.lex_state = 87, .external_lex_state = 2},
  [1725] = {.lex_state = 87, .external_lex_state = 2},
  [1726] = {.lex_state = 93, .external_lex_state = 6},
  [1727] = {.lex_state = 95, .external_lex_state = 4},
  [1728] = {.lex_state = 87, .external_lex_state = 2},
  [1729] = {.lex_state = 87, .external_lex_state = 2},
  [1730] = {.lex_state = 87, .external_lex_state = 2},
  [1731] = {.lex_state = 87, .external_lex_state = 2},
  [1732] = {.lex_state = 87, .external_lex_state = 2},
  [1733] = {.lex_state = 87, .external_lex_state = 2},
  [1734] = {.lex_state = 87, .external_lex_state = 2},
  [1735] = {.lex_state = 95, .external_lex_state = 4},
  [1736] = {.lex_state = 87, .external_lex_state = 2},
  [1737] = {.lex_state = 87, .external_lex_state = 2},
  [1738] = {.lex_state = 87, .external_lex_state = 2},
  [1739] = {.lex_state = 87, .external_lex_state = 2},
  [1740] = {.lex_state = 87, .external_lex_state = 2},
  [1741] = {.lex_state = 87, .external_lex_state = 2},
  [1742] = {.lex_state = 87, .external_lex_state = 2},
  [1743] = {.lex_state = 87, .external_lex_state = 2},
  [1744] = {.lex_state = 87, .external_lex_state = 2},
  [1745] = {.lex_state = 87, .external_lex_state = 2},
  [1746] = {.lex_state = 87, .external_lex_state = 2},
  [1747] = {.lex_state = 87, .external_lex_state = 2},
  [1748] = {.lex_state = 87, .external_lex_state = 2},
  [1749] = {.lex_state = 95, .external_lex_state = 4},
  [1750] = {.lex_state = 87, .external_lex_state = 2},
  [1751] = {.lex_state = 87, .external_lex_state = 2},
  [1752] = {.lex_state = 87, .external_lex_state = 2},
  [1753] = {.lex_state = 87, .external_lex_state = 2},
  [1754] = {.lex_state = 87, .external_lex_state = 2},
  [1755] = {.lex_state = 87, .external_lex_state = 2},
  [1756] = {.lex_state = 87, .external_lex_state = 2},
  [1757] = {.lex_state = 87, .external_lex_state = 2},
  [1758] = {.lex_state = 87, .external_lex_state = 2},
  [1759] = {.lex_state = 87, .external_lex_state = 2},
  [1760] = {.lex_state = 87, .external_lex_state = 2},
  [1761] = {.lex_state = 87, .external_lex_state = 2},
  [1762] = {.lex_state = 87, .external_lex_state = 2},
  [1763] = {.lex_state = 87, .external_lex_state = 2},
  [1764] = {.lex_state = 87, .external_lex_state = 2},
  [1765] = {.lex_state = 87, .external_lex_state = 2},
  [1766] = {.lex_state = 87, .external_lex_state = 2},
  [1767] = {.lex_state = 87, .external_lex_state = 2},
  [1768] = {.lex_state = 87, .external_lex_state = 2},
  [1769] = {.lex_state = 87, .external_lex_state = 2},
  [1770] = {.lex_state = 87, .external_lex_state = 2},
  [1771] = {.lex_state = 87, .external_lex_state = 2},
  [1772] = {.lex_state = 87, .external_lex_state = 2},
  [1773] = {.lex_state = 87, .external_lex_state = 2},
  [1774] = {.lex_state = 87, .external_lex_state = 2},
  [1775] = {.lex_state = 87, .external_lex_state = 2},
  [1776] = {.lex_state = 87, .external_lex_state = 2},
  [1777] = {.lex_state = 87, .external_lex_state = 2},
  [1778] = {.lex_state = 87, .external_lex_state = 2},
  [1779] = {.lex_state = 87, .external_lex_state = 2},
  [1780] = {.lex_state = 87, .external_lex_state = 2},
  [1781] = {.lex_state = 95, .external_lex_state = 4},
  [1782] = {.lex_state = 87, .external_lex_state = 2},
  [1783] = {.lex_state = 87, .external_lex_state = 2},
  [1784] = {.lex_state = 87, .external_lex_state = 2},
  [1785] = {.lex_state = 87, .external_lex_state = 2},
  [1786] = {.lex_state = 95, .external_lex_state = 4},
  [1787] = {.lex_state = 87, .external_lex_state = 2},
  [1788] = {.lex_state = 87, .external_lex_state = 2},
  [1789] = {.lex_state = 87, .external_lex_state = 2},
  [1790] = {.lex_state = 87, .external_lex_state = 2},
  [1791] = {.lex_state = 87, .external_lex_state = 2},
  [1792] = {.lex_state = 87, .external_lex_state = 2},
  [1793] = {.lex_state = 87, .external_lex_state = 2},
  [1794] = {.lex_state = 87, .external_lex_state = 2},
  [1795] = {.lex_state = 87, .external_lex_state = 2},
  [1796] = {.lex_state = 87, .external_lex_state = 2},
  [1797] = {.lex_state = 87, .external_lex_state = 2},
  [1798] = {.lex_state = 87, .external_lex_state = 2},
  [1799] = {.lex_state = 87, .external_lex_state = 2},
  [1800] = {.lex_state = 87, .external_lex_state = 2},
  [1801] = {.lex_state = 87, .external_lex_state = 2},
  [1802] = {.lex_state = 87, .external_lex_state = 2},
  [1803] = {.lex_state = 87, .external_lex_state = 2},
  [1804] = {.lex_state = 87, .external_lex_state = 2},
  [1805] = {.lex_state = 87, .external_lex_state = 2},
  [1806] = {.lex_state = 87, .external_lex_state = 2},
  [1807] = {.lex_state = 87, .external_lex_state = 2},
  [1808] = {.lex_state = 87, .external_lex_state = 2},
  [1809] = {.lex_state = 87, .external_lex_state = 2},
  [1810] = {.lex_state = 95, .external_lex_state = 4},
  [1811] = {.lex_state = 87, .external_lex_state = 2},
  [1812] = {.lex_state = 87, .external_lex_state = 2},
  [1813] = {.lex_state = 87, .external_lex_state = 2},
  [1814] = {.lex_state = 87, .external_lex_state = 2},
  [1815] = {.lex_state = 87, .external_lex_state = 2},
  [1816] = {.lex_state = 87, .external_lex_state = 2},
  [1817] = {.lex_state = 87, .external_lex_state = 2},
  [1818] = {.lex_state = 87, .external_lex_state = 2},
  [1819] = {.lex_state = 87, .external_lex_state = 2},
  [1820] = {.lex_state = 87, .external_lex_state = 2},
  [1821] = {.lex_state = 87, .external_lex_state = 2},
  [1822] = {.lex_state = 87, .external_lex_state = 2},
  [1823] = {.lex_state = 87, .external_lex_state = 2},
  [1824] = {.lex_state = 87, .external_lex_state = 2},
  [1825] = {.lex_state = 87, .external_lex_state = 2},
  [1826] = {.lex_state = 95, .external_lex_state = 4},
  [1827] = {.lex_state = 87, .external_lex_state = 2},
  [1828] = {.lex_state = 87, .external_lex_state = 2},
  [1829] = {.lex_state = 87, .external_lex_state = 2},
  [1830] = {.lex_state = 87, .external_lex_state = 2},
  [1831] = {.lex_state = 87, .external_lex_state = 2},
  [1832] = {.lex_state = 87, .external_lex_state = 2},
  [1833] = {.lex_state = 87, .external_lex_state = 2},
  [1834] = {.lex_state = 87, .external_lex_state = 2},
  [1835] = {.lex_state = 87, .external_lex_state = 2},
  [1836] = {.lex_state = 87, .external_lex_state = 2},
  [1837] = {.lex_state = 87, .external_lex_state = 2},
  [1838] = {.lex_state = 87, .external_lex_state = 2},
  [1839] = {.lex_state = 87, .external_lex_state = 2},
  [1840] = {.lex_state = 87, .external_lex_state = 2},
  [1841] = {.lex_state = 87, .external_lex_state = 2},
  [1842] = {.lex_state = 95, .external_lex_state = 4},
  [1843] = {.lex_state = 87, .external_lex_state = 2},
  [1844] = {.lex_state = 87, .external_lex_state = 2},
  [1845] = {.lex_state = 87, .external_lex_state = 2},
  [1846] = {.lex_state = 87, .external_lex_state = 2},
  [1847] = {.lex_state = 87, .external_lex_state = 2},
  [1848] = {.lex_state = 87, .external_lex_state = 2},
  [1849] = {.lex_state = 87, .external_lex_state = 2},
  [1850] = {.lex_state = 87, .external_lex_state = 2},
  [1851] = {.lex_state = 87, .external_lex_state = 2},
  [1852] = {.lex_state = 87, .external_lex_state = 2},
  [1853] = {.lex_state = 87, .external_lex_state = 2},
  [1854] = {.lex_state = 87, .external_lex_state = 2},
  [1855] = {.lex_state = 87, .external_lex_state = 2},
  [1856] = {.lex_state = 87, .external_lex_state = 2},
  [1857] = {.lex_state = 87, .external_lex_state = 2},
  [1858] = {.lex_state = 95, .external_lex_state = 4},
  [1859] = {.lex_state = 87, .external_lex_state = 2},
  [1860] = {.lex_state = 87, .external_lex_state = 2},
  [1861] = {.lex_state = 87, .external_lex_state = 2},
  [1862] = {.lex_state = 87, .external_lex_state = 2},
  [1863] = {.lex_state = 87, .external_lex_state = 2},
  [1864] = {.lex_state = 87, .external_lex_state = 2},
  [1865] = {.lex_state = 87, .external_lex_state = 2},
  [1866] = {.lex_state = 93, .external_lex_state = 6},
  [1867] = {.lex_state = 87, .external_lex_state = 2},
  [1868] = {.lex_state = 87, .external_lex_state = 2},
  [1869] = {.lex_state = 87, .external_lex_state = 2},
  [1870] = {.lex_state = 87, .external_lex_state = 2},
  [1871] = {.lex_state = 87, .external_lex_state = 2},
  [1872] = {.lex_state = 87, .external_lex_state = 2},
  [1873] = {.lex_state = 87, .external_lex_state = 2},
  [1874] = {.lex_state = 87, .external_lex_state = 2},
  [1875] = {.lex_state = 87, .external_lex_state = 2},
  [1876] = {.lex_state = 87, .external_lex_state = 2},
  [1877] = {.lex_state = 87, .external_lex_state = 2},
  [1878] = {.lex_state = 87, .external_lex_state = 2},
  [1879] = {.lex_state = 87, .external_lex_state = 2},
  [1880] = {.lex_state = 87, .external_lex_state = 2},
  [1881] = {.lex_state = 87, .external_lex_state = 2},
  [1882] = {.lex_state = 87, .external_lex_state = 2},
  [1883] = {.lex_state = 87, .external_lex_state = 2},
  [1884] = {.lex_state = 87, .external_lex_state = 2},
  [1885] = {.lex_state = 87, .external_lex_state = 2},
  [1886] = {.lex_state = 87, .external_lex_state = 2},
  [1887] = {.lex_state = 87, .external_lex_state = 2},
  [1888] = {.lex_state = 87, .external_lex_state = 2},
  [1889] = {.lex_state = 87, .external_lex_state = 2},
  [1890] = {.lex_state = 87, .external_lex_state = 2},
  [1891] = {.lex_state = 87, .external_lex_state = 2},
  [1892] = {.lex_state = 87, .external_lex_state = 2},
  [1893] = {.lex_state = 87, .external_lex_state = 2},
  [1894] = {.lex_state = 87, .external_lex_state = 2},
  [1895] = {.lex_state = 87, .external_lex_state = 2},
  [1896] = {.lex_state = 87, .external_lex_state = 2},
  [1897] = {.lex_state = 87, .external_lex_state = 2},
  [1898] = {.lex_state = 87, .external_lex_state = 2},
  [1899] = {.lex_state = 87, .external_lex_state = 2},
  [1900] = {.lex_state = 87, .external_lex_state = 2},
  [1901] = {.lex_state = 87, .external_lex_state = 2},
  [1902] = {.lex_state = 87, .external_lex_state = 2},
  [1903] = {.lex_state = 87, .external_lex_state = 2},
  [1904] = {.lex_state = 87, .external_lex_state = 2},
  [1905] = {.lex_state = 87, .external_lex_state = 2},
  [1906] = {.lex_state = 87, .external_lex_state = 2},
  [1907] = {.lex_state = 87, .external_lex_state = 2},
  [1908] = {.lex_state = 87, .external_lex_state = 2},
  [1909] = {.lex_state = 87, .external_lex_state = 2},
  [1910] = {.lex_state = 87, .external_lex_state = 2},
  [1911] = {.lex_state = 87, .external_lex_state = 2},
  [1912] = {.lex_state = 87, .external_lex_state = 2},
  [1913] = {.lex_state = 87, .external_lex_state = 2},
  [1914] = {.lex_state = 87, .external_lex_state = 2},
  [1915] = {.lex_state = 87, .external_lex_state = 2},
  [1916] = {.lex_state = 87, .external_lex_state = 2},
  [1917] = {.lex_state = 95, .external_lex_state = 4},
  [1918] = {.lex_state = 87, .external_lex_state = 2},
  [1919] = {.lex_state = 87, .external_lex_state = 2},
  [1920] = {.lex_state = 87, .external_lex_state = 2},
  [1921] = {.lex_state = 87, .external_lex_state = 2},
  [1922] = {.lex_state = 87, .external_lex_state = 2},
  [1923] = {.lex_state = 87, .external_lex_state = 2},
  [1924] = {.lex_state = 87, .external_lex_state = 2},
  [1925] = {.lex_state = 87, .external_lex_state = 2},
  [1926] = {.lex_state = 87, .external_lex_state = 2},
  [1927] = {.lex_state = 87, .external_lex_state = 2},
  [1928] = {.lex_state = 87, .external_lex_state = 2},
  [1929] = {.lex_state = 87, .external_lex_state = 2},
  [1930] = {.lex_state = 87, .external_lex_state = 2},
  [1931] = {.lex_state = 87, .external_lex_state = 2},
  [1932] = {.lex_state = 87, .external_lex_state = 2},
  [1933] = {.lex_state = 87, .external_lex_state = 2},
  [1934] = {.lex_state = 87, .external_lex_state = 2},
  [1935] = {.lex_state = 87, .external_lex_state = 2},
  [1936] = {.lex_state = 87, .external_lex_state = 2},
  [1937] = {.lex_state = 87, .external_lex_state = 2},
  [1938] = {.lex_state = 87, .external_lex_state = 2},
  [1939] = {.lex_state = 87, .external_lex_state = 2},
  [1940] = {.lex_state = 87, .external_lex_state = 2},
  [1941] = {.lex_state = 87, .external_lex_state = 2},
  [1942] = {.lex_state = 87, .external_lex_state = 2},
  [1943] = {.lex_state = 87, .external_lex_state = 2},
  [1944] = {.lex_state = 87, .external_lex_state = 2},
  [1945] = {.lex_state = 87, .external_lex_state = 2},
  [1946] = {.lex_state = 87, .external_lex_state = 2},
  [1947] = {.lex_state = 87, .external_lex_state = 2},
  [1948] = {.lex_state = 87, .external_lex_state = 2},
  [1949] = {.lex_state = 87, .external_lex_state = 2},
  [1950] = {.lex_state = 87, .external_lex_state = 2},
  [1951] = {.lex_state = 87, .external_lex_state = 2},
  [1952] = {.lex_state = 87, .external_lex_state = 2},
  [1953] = {.lex_state = 87, .external_lex_state = 2},
  [1954] = {.lex_state = 87, .external_lex_state = 2},
  [1955] = {.lex_state = 87, .external_lex_state = 2},
  [1956] = {.lex_state = 87, .external_lex_state = 2},
  [1957] = {.lex_state = 87, .external_lex_state = 2},
  [1958] = {.lex_state = 95, .external_lex_state = 4},
  [1959] = {.lex_state = 87, .external_lex_state = 2},
  [1960] = {.lex_state = 87, .external_lex_state = 2},
  [1961] = {.lex_state = 87, .external_lex_state = 2},
  [1962] = {.lex_state = 87, .external_lex_state = 2},
  [1963] = {.lex_state = 87, .external_lex_state = 2},
  [1964] = {.lex_state = 87, .external_lex_state = 2},
  [1965] = {.lex_state = 87, .external_lex_state = 2},
  [1966] = {.lex_state = 87, .external_lex_state = 2},
  [1967] = {.lex_state = 87, .external_lex_state = 2},
  [1968] = {.lex_state = 87, .external_lex_state = 2},
  [1969] = {.lex_state = 87, .external_lex_state = 2},
  [1970] = {.lex_state = 87, .external_lex_state = 2},
  [1971] = {.lex_state = 87, .external_lex_state = 2},
  [1972] = {.lex_state = 87, .external_lex_state = 2},
  [1973] = {.lex_state = 87, .external_lex_state = 2},
  [1974] = {.lex_state = 87, .external_lex_state = 2},
  [1975] = {.lex_state = 87, .external_lex_state = 2},
  [1976] = {.lex_state = 87, .external_lex_state = 2},
  [1977] = {.lex_state = 87, .external_lex_state = 2},
  [1978] = {.lex_state = 87, .external_lex_state = 2},
  [1979] = {.lex_state = 87, .external_lex_state = 2},
  [1980] = {.lex_state = 87, .external_lex_state = 2},
  [1981] = {.lex_state = 95, .external_lex_state = 4},
  [1982] = {.lex_state = 87, .external_lex_state = 2},
  [1983] = {.lex_state = 87, .external_lex_state = 2},
  [1984] = {.lex_state = 87, .external_lex_state = 2},
  [1985] = {.lex_state = 87, .external_lex_state = 2},
  [1986] = {.lex_state = 87, .external_lex_state = 2},
  [1987] = {.lex_state = 87, .external_lex_state = 2},
  [1988] = {.lex_state = 87, .external_lex_state = 2},
  [1989] = {.lex_state = 87, .external_lex_state = 2},
  [1990] = {.lex_state = 87, .external_lex_state = 2},
  [1991] = {.lex_state = 87, .external_lex_state = 2},
  [1992] = {.lex_state = 87, .external_lex_state = 2},
  [1993] = {.lex_state = 87, .external_lex_state = 2},
  [1994] = {.lex_state = 87, .external_lex_state = 2},
  [1995] = {.lex_state = 87, .external_lex_state = 2},
  [1996] = {.lex_state = 87, .external_lex_state = 2},
  [1997] = {.lex_state = 87, .external_lex_state = 2},
  [1998] = {.lex_state = 87, .external_lex_state = 2},
  [1999] = {.lex_state = 87, .external_lex_state = 2},
  [2000] = {.lex_state = 87, .external_lex_state = 2},
  [2001] = {.lex_state = 87, .external_lex_state = 2},
  [2002] = {.lex_state = 87, .external_lex_state = 2},
  [2003] = {.lex_state = 95, .external_lex_state = 4},
  [2004] = {.lex_state = 87, .external_lex_state = 2},
  [2005] = {.lex_state = 87, .external_lex_state = 2},
  [2006] = {.lex_state = 87, .external_lex_state = 2},
  [2007] = {.lex_state = 87, .external_lex_state = 2},
  [2008] = {.lex_state = 87, .external_lex_state = 2},
  [2009] = {.lex_state = 87, .external_lex_state = 2},
  [2010] = {.lex_state = 87, .external_lex_state = 2},
  [2011] = {.lex_state = 87, .external_lex_state = 2},
  [2012] = {.lex_state = 87, .external_lex_state = 2},
  [2013] = {.lex_state = 87, .external_lex_state = 2},
  [2014] = {.lex_state = 87, .external_lex_state = 2},
  [2015] = {.lex_state = 87, .external_lex_state = 2},
  [2016] = {.lex_state = 87, .external_lex_state = 2},
  [2017] = {.lex_state = 87, .external_lex_state = 2},
  [2018] = {.lex_state = 87, .external_lex_state = 2},
  [2019] = {.lex_state = 87, .external_lex_state = 2},
  [2020] = {.lex_state = 87, .external_lex_state = 2},
  [2021] = {.lex_state = 87, .external_lex_state = 2},
  [2022] = {.lex_state = 87, .external_lex_state = 2},
  [2023] = {.lex_state = 87, .external_lex_state = 2},
  [2024] = {.lex_state = 87, .external_lex_state = 2},
  [2025] = {.lex_state = 87, .external_lex_state = 2},
  [2026] = {.lex_state = 87, .external_lex_state = 2},
  [2027] = {.lex_state = 87, .external_lex_state = 2},
  [2028] = {.lex_state = 87, .external_lex_state = 2},
  [2029] = {.lex_state = 87, .external_lex_state = 2},
  [2030] = {.lex_state = 87, .external_lex_state = 2},
  [2031] = {.lex_state = 87, .external_lex_state = 2},
  [2032] = {.lex_state = 87, .external_lex_state = 2},
  [2033] = {.lex_state = 87, .external_lex_state = 2},
  [2034] = {.lex_state = 87, .external_lex_state = 2},
  [2035] = {.lex_state = 87, .external_lex_state = 2},
  [2036] = {.lex_state = 87, .external_lex_state = 2},
  [2037] = {.lex_state = 87, .external_lex_state = 2},
  [2038] = {.lex_state = 87, .external_lex_state = 2},
  [2039] = {.lex_state = 87, .external_lex_state = 2},
  [2040] = {.lex_state = 95, .external_lex_state = 5},
  [2041] = {.lex_state = 87, .external_lex_state = 2},
  [2042] = {.lex_state = 87, .external_lex_state = 2},
  [2043] = {.lex_state = 87, .external_lex_state = 2},
  [2044] = {.lex_state = 87, .external_lex_state = 2},
  [2045] = {.lex_state = 87, .external_lex_state = 2},
  [2046] = {.lex_state = 87, .external_lex_state = 2},
  [2047] = {.lex_state = 87, .external_lex_state = 2},
  [2048] = {.lex_state = 87, .external_lex_state = 2},
  [2049] = {.lex_state = 87, .external_lex_state = 2},
  [2050] = {.lex_state = 87, .external_lex_state = 2},
  [2051] = {.lex_state = 87, .external_lex_state = 2},
  [2052] = {.lex_state = 87, .external_lex_state = 2},
  [2053] = {.lex_state = 87, .external_lex_state = 2},
  [2054] = {.lex_state = 87, .external_lex_state = 2},
  [2055] = {.lex_state = 87, .external_lex_state = 2},
  [2056] = {.lex_state = 87, .external_lex_state = 2},
  [2057] = {.lex_state = 87, .external_lex_state = 2},
  [2058] = {.lex_state = 87, .external_lex_state = 2},
  [2059] = {.lex_state = 87, .external_lex_state = 2},
  [2060] = {.lex_state = 87, .external_lex_state = 2},
  [2061] = {.lex_state = 87, .external_lex_state = 2},
  [2062] = {.lex_state = 87, .external_lex_state = 2},
  [2063] = {.lex_state = 87, .external_lex_state = 2},
  [2064] = {.lex_state = 87, .external_lex_state = 2},
  [2065] = {.lex_state = 87, .external_lex_state = 2},
  [2066] = {.lex_state = 87, .external_lex_state = 2},
  [2067] = {.lex_state = 87, .external_lex_state = 2},
  [2068] = {.lex_state = 87, .external_lex_state = 2},
  [2069] = {.lex_state = 87, .external_lex_state = 2},
  [2070] = {.lex_state = 87, .external_lex_state = 2},
  [2071] = {.lex_state = 87, .external_lex_state = 2},
  [2072] = {.lex_state = 87, .external_lex_state = 2},
  [2073] = {.lex_state = 87, .external_lex_state = 2},
  [2074] = {.lex_state = 87, .external_lex_state = 2},
  [2075] = {.lex_state = 87, .external_lex_state = 2},
  [2076] = {.lex_state = 87, .external_lex_state = 2},
  [2077] = {.lex_state = 87, .external_lex_state = 2},
  [2078] = {.lex_state = 87, .external_lex_state = 2},
  [2079] = {.lex_state = 87, .external_lex_state = 2},
  [2080] = {.lex_state = 87, .external_lex_state = 2},
  [2081] = {.lex_state = 87, .external_lex_state = 2},
  [2082] = {.lex_state = 87, .external_lex_state = 2},
  [2083] = {.lex_state = 87, .external_lex_state = 2},
  [2084] = {.lex_state = 87, .external_lex_state = 2},
  [2085] = {.lex_state = 87, .external_lex_state = 2},
  [2086] = {.lex_state = 87, .external_lex_state = 2},
  [2087] = {.lex_state = 87, .external_lex_state = 2},
  [2088] = {.lex_state = 87, .external_lex_state = 2},
  [2089] = {.lex_state = 87, .external_lex_state = 2},
  [2090] = {.lex_state = 87, .external_lex_state = 2},
  [2091] = {.lex_state = 87, .external_lex_state = 2},
  [2092] = {.lex_state = 87, .external_lex_state = 2},
  [2093] = {.lex_state = 87, .external_lex_state = 2},
  [2094] = {.lex_state = 87, .external_lex_state = 2},
  [2095] = {.lex_state = 87, .external_lex_state = 2},
  [2096] = {.lex_state = 87, .external_lex_state = 2},
  [2097] = {.lex_state = 87, .external_lex_state = 2},
  [2098] = {.lex_state = 95, .external_lex_state = 4},
  [2099] = {.lex_state = 87, .external_lex_state = 2},
  [2100] = {.lex_state = 87, .external_lex_state = 2},
  [2101] = {.lex_state = 87, .external_lex_state = 2},
  [2102] = {.lex_state = 93, .external_lex_state = 6},
  [2103] = {.lex_state = 87, .external_lex_state = 2},
  [2104] = {.lex_state = 87, .external_lex_state = 2},
  [2105] = {.lex_state = 95, .external_lex_state = 4},
  [2106] = {.lex_state = 87, .external_lex_state = 2},
  [2107] = {.lex_state = 87, .external_lex_state = 2},
  [2108] = {.lex_state = 87, .external_lex_state = 2},
  [2109] = {.lex_state = 95, .external_lex_state = 4},
  [2110] = {.lex_state = 87, .external_lex_state = 2},
  [2111] = {.lex_state = 87, .external_lex_state = 2},
  [2112] = {.lex_state = 87, .external_lex_state = 2},
  [2113] = {.lex_state = 87, .external_lex_state = 2},
  [2114] = {.lex_state = 87, .external_lex_state = 2},
  [2115] = {.lex_state = 87, .external_lex_state = 2},
  [2116] = {.lex_state = 87, .external_lex_state = 2},
  [2117] = {.lex_state = 87, .external_lex_state = 2},
  [2118] = {.lex_state = 87, .external_lex_state = 2},
  [2119] = {.lex_state = 87, .external_lex_state = 2},
  [2120] = {.lex_state = 87, .external_lex_state = 2},
  [2121] = {.lex_state = 87, .external_lex_state = 2},
  [2122] = {.lex_state = 87, .external_lex_state = 2},
  [2123] = {.lex_state = 87, .external_lex_state = 2},
  [2124] = {.lex_state = 87, .external_lex_state = 2},
  [2125] = {.lex_state = 87, .external_lex_state = 2},
  [2126] = {.lex_state = 87, .external_lex_state = 2},
  [2127] = {.lex_state = 87, .external_lex_state = 2},
  [2128] = {.lex_state = 87, .external_lex_state = 2},
  [2129] = {.lex_state = 87, .external_lex_state = 2},
  [2130] = {.lex_state = 87, .external_lex_state = 2},
  [2131] = {.lex_state = 87, .external_lex_state = 2},
  [2132] = {.lex_state = 87, .external_lex_state = 2},
  [2133] = {.lex_state = 87, .external_lex_state = 2},
  [2134] = {.lex_state = 87, .external_lex_state = 2},
  [2135] = {.lex_state = 87, .external_lex_state = 2},
  [2136] = {.lex_state = 87, .external_lex_state = 2},
  [2137] = {.lex_state = 87, .external_lex_state = 2},
  [2138] = {.lex_state = 95, .external_lex_state = 5},
  [2139] = {.lex_state = 87, .external_lex_state = 2},
  [2140] = {.lex_state = 87, .external_lex_state = 2},
  [2141] = {.lex_state = 87, .external_lex_state = 2},
  [2142] = {.lex_state = 87, .external_lex_state = 2},
  [2143] = {.lex_state = 87, .external_lex_state = 2},
  [2144] = {.lex_state = 87, .external_lex_state = 2},
  [2145] = {.lex_state = 87, .external_lex_state = 2},
  [2146] = {.lex_state = 87, .external_lex_state = 2},
  [2147] = {.lex_state = 87, .external_lex_state = 2},
  [2148] = {.lex_state = 87, .external_lex_state = 2},
  [2149] = {.lex_state = 87, .external_lex_state = 2},
  [2150] = {.lex_state = 87, .external_lex_state = 2},
  [2151] = {.lex_state = 87, .external_lex_state = 2},
  [2152] = {.lex_state = 87, .external_lex_state = 2},
  [2153] = {.lex_state = 87, .external_lex_state = 2},
  [2154] = {.lex_state = 87, .external_lex_state = 2},
  [2155] = {.lex_state = 87, .external_lex_state = 2},
  [2156] = {.lex_state = 87, .external_lex_state = 2},
  [2157] = {.lex_state = 87, .external_lex_state = 2},
  [2158] = {.lex_state = 87, .external_lex_state = 2},
  [2159] = {.lex_state = 87, .external_lex_state = 2},
  [2160] = {.lex_state = 87, .external_lex_state = 2},
  [2161] = {.lex_state = 87, .external_lex_state = 2},
  [2162] = {.lex_state = 87, .external_lex_state = 2},
  [2163] = {.lex_state = 87, .external_lex_state = 2},
  [2164] = {.lex_state = 87, .external_lex_state = 2},
  [2165] = {.lex_state = 87, .external_lex_state = 2},
  [2166] = {.lex_state = 87, .external_lex_state = 2},
  [2167] = {.lex_state = 87, .external_lex_state = 2},
  [2168] = {.lex_state = 87, .external_lex_state = 2},
  [2169] = {.lex_state = 87, .external_lex_state = 2},
  [2170] = {.lex_state = 93, .external_lex_state = 6},
  [2171] = {.lex_state = 87, .external_lex_state = 2},
  [2172] = {.lex_state = 87, .external_lex_state = 2},
  [2173] = {.lex_state = 93, .external_lex_state = 6},
  [2174] = {.lex_state = 87, .external_lex_state = 2},
  [2175] = {.lex_state = 87, .external_lex_state = 2},
  [2176] = {.lex_state = 87, .external_lex_state = 2},
  [2177] = {.lex_state = 87, .external_lex_state = 2},
  [2178] = {.lex_state = 87, .external_lex_state = 2},
  [2179] = {.lex_state = 87, .external_lex_state = 2},
  [2180] = {.lex_state = 87, .external_lex_state = 2},
  [2181] = {.lex_state = 87, .external_lex_state = 2},
  [2182] = {.lex_state = 95, .external_lex_state = 4},
  [2183] = {.lex_state = 87, .external_lex_state = 2},
  [2184] = {.lex_state = 87, .external_lex_state = 2},
  [2185] = {.lex_state = 87, .external_lex_state = 2},
  [2186] = {.lex_state = 87, .external_lex_state = 2},
  [2187] = {.lex_state = 87, .external_lex_state = 2},
  [2188] = {.lex_state = 87, .external_lex_state = 2},
  [2189] = {.lex_state = 87, .external_lex_state = 2},
  [2190] = {.lex_state = 87, .external_lex_state = 2},
  [2191] = {.lex_state = 87, .external_lex_state = 2},
  [2192] = {.lex_state = 87, .external_lex_state = 2},
  [2193] = {.lex_state = 87, .external_lex_state = 2},
  [2194] = {.lex_state = 87, .external_lex_state = 2},
  [2195] = {.lex_state = 87, .external_lex_state = 2},
  [2196] = {.lex_state = 87, .external_lex_state = 2},
  [2197] = {.lex_state = 87, .external_lex_state = 2},
  [2198] = {.lex_state = 87, .external_lex_state = 2},
  [2199] = {.lex_state = 87, .external_lex_state = 2},
  [2200] = {.lex_state = 87, .external_lex_state = 2},
  [2201] = {.lex_state = 87, .external_lex_state = 2},
  [2202] = {.lex_state = 87, .external_lex_state = 2},
  [2203] = {.lex_state = 87, .external_lex_state = 2},
  [2204] = {.lex_state = 87, .external_lex_state = 2},
  [2205] = {.lex_state = 87, .external_lex_state = 2},
  [2206] = {.lex_state = 87, .external_lex_state = 2},
  [2207] = {.lex_state = 87, .external_lex_state = 2},
  [2208] = {.lex_state = 87, .external_lex_state = 2},
  [2209] = {.lex_state = 87, .external_lex_state = 2},
  [2210] = {.lex_state = 87, .external_lex_state = 2},
  [2211] = {.lex_state = 87, .external_lex_state = 2},
  [2212] = {.lex_state = 95, .external_lex_state = 5},
  [2213] = {.lex_state = 95, .external_lex_state = 5},
  [2214] = {.lex_state = 93, .external_lex_state = 6},
  [2215] = {.lex_state = 93, .external_lex_state = 6},
  [2216] = {.lex_state = 95, .external_lex_state = 5},
  [2217] = {.lex_state = 95, .external_lex_state = 5},
  [2218] = {.lex_state = 93, .external_lex_state = 6},
  [2219] = {.lex_state = 95, .external_lex_state = 5},
  [2220] = {.lex_state = 95, .external_lex_state = 5},
  [2221] = {.lex_state = 95, .external_lex_state = 5},
  [2222] = {.lex_state = 95, .external_lex_state = 5},
  [2223] = {.lex_state = 95, .external_lex_state = 5},
  [2224] = {.lex_state = 93, .external_lex_state = 6},
  [2225] = {.lex_state = 93, .external_lex_state = 6},
  [2226] = {.lex_state = 93, .external_lex_state = 6},
  [2227] = {.lex_state = 93, .external_lex_state = 6},
  [2228] = {.lex_state = 93, .external_lex_state = 6},
  [2229] = {.lex_state = 95, .external_lex_state = 5},
  [2230] = {.lex_state = 93, .external_lex_state = 6},
  [2231] = {.lex_state = 95, .external_lex_state = 5},
  [2232] = {.lex_state = 95, .external_lex_state = 5},
  [2233] = {.lex_state = 95, .external_lex_state = 5},
  [2234] = {.lex_state = 95, .external_lex_state = 5},
  [2235] = {.lex_state = 95, .external_lex_state = 5},
  [2236] = {.lex_state = 93, .external_lex_state = 6},
  [2237] = {.lex_state = 95, .external_lex_state = 5},
  [2238] = {.lex_state = 95, .external_lex_state = 5},
  [2239] = {.lex_state = 95, .external_lex_state = 5},
  [2240] = {.lex_state = 95, .external_lex_state = 5},
  [2241] = {.lex_state = 95, .external_lex_state = 5},
  [2242] = {.lex_state = 93, .external_lex_state = 6},
  [2243] = {.lex_state = 93, .external_lex_state = 6},
  [2244] = {.lex_state = 93, .external_lex_state = 6},
  [2245] = {.lex_state = 95, .external_lex_state = 5},
  [2246] = {.lex_state = 93, .external_lex_state = 6},
  [2247] = {.lex_state = 95, .external_lex_state = 5},
  [2248] = {.lex_state = 95, .external_lex_state = 5},
  [2249] = {.lex_state = 95, .external_lex_state = 5},
  [2250] = {.lex_state = 93, .external_lex_state = 6},
  [2251] = {.lex_state = 95, .external_lex_state = 5},
  [2252] = {.lex_state = 95, .external_lex_state = 5},
  [2253] = {.lex_state = 93, .external_lex_state = 6},
  [2254] = {.lex_state = 93, .external_lex_state = 6},
  [2255] = {.lex_state = 93, .external_lex_state = 6},
  [2256] = {.lex_state = 93, .external_lex_state = 6},
  [2257] = {.lex_state = 93, .external_lex_state = 6},
  [2258] = {.lex_state = 93, .external_lex_state = 6},
  [2259] = {.lex_state = 93, .external_lex_state = 6},
  [2260] = {.lex_state = 93, .external_lex_state = 6},
  [2261] = {.lex_state = 95, .external_lex_state = 5},
  [2262] = {.lex_state = 95, .external_lex_state = 5},
  [2263] = {.lex_state = 93, .external_lex_state = 6},
  [2264] = {.lex_state = 93, .external_lex_state = 6},
  [2265] = {.lex_state = 95, .external_lex_state = 5},
  [2266] = {.lex_state = 95, .external_lex_state = 5},
  [2267] = {.lex_state = 93, .external_lex_state = 6},
  [2268] = {.lex_state = 95, .external_lex_state = 5},
  [2269] = {.lex_state = 93, .external_lex_state = 6},
  [2270] = {.lex_state = 93, .external_lex_state = 6},
  [2271] = {.lex_state = 93, .external_lex_state = 6},
  [2272] = {.lex_state = 93, .external_lex_state = 6},
  [2273] = {.lex_state = 93, .external_lex_state = 6},
  [2274] = {.lex_state = 95, .external_lex_state = 5},
  [2275] = {.lex_state = 95, .external_lex_state = 5},
  [2276] = {.lex_state = 95, .external_lex_state = 5},
  [2277] = {.lex_state = 93, .external_lex_state = 6},
  [2278] = {.lex_state = 95, .external_lex_state = 5},
  [2279] = {.lex_state = 95, .external_lex_state = 5},
  [2280] = {.lex_state = 93, .external_lex_state = 6},
  [2281] = {.lex_state = 93, .external_lex_state = 6},
  [2282] = {.lex_state = 93, .external_lex_state = 6},
  [2283] = {.lex_state = 93, .external_lex_state = 6},
  [2284] = {.lex_state = 93, .external_lex_state = 6},
  [2285] = {.lex_state = 95, .external_lex_state = 5},
  [2286] = {.lex_state = 93, .external_lex_state = 6},
  [2287] = {.lex_state = 93, .external_lex_state = 6},
  [2288] = {.lex_state = 93, .external_lex_state = 6},
  [2289] = {.lex_state = 93, .external_lex_state = 6},
  [2290] = {.lex_state = 93, .external_lex_state = 6},
  [2291] = {.lex_state = 93, .external_lex_state = 6},
  [2292] = {.lex_state = 93, .external_lex_state = 6},
  [2293] = {.lex_state = 93, .external_lex_state = 6},
  [2294] = {.lex_state = 95, .external_lex_state = 5},
  [2295] = {.lex_state = 95, .external_lex_state = 5},
  [2296] = {.lex_state = 95, .external_lex_state = 5},
  [2297] = {.lex_state = 93, .external_lex_state = 6},
  [2298] = {.lex_state = 93, .external_lex_state = 6},
  [2299] = {.lex_state = 95, .external_lex_state = 5},
  [2300] = {.lex_state = 93, .external_lex_state = 6},
  [2301] = {.lex_state = 95, .external_lex_state = 5},
  [2302] = {.lex_state = 93, .external_lex_state = 6},
  [2303] = {.lex_state = 93, .external_lex_state = 6},
  [2304] = {.lex_state = 93, .external_lex_state = 6},
  [2305] = {.lex_state = 95, .external_lex_state = 5},
  [2306] = {.lex_state = 95, .external_lex_state = 5},
  [2307] = {.lex_state = 95, .external_lex_state = 5},
  [2308] = {.lex_state = 93, .external_lex_state = 6},
  [2309] = {.lex_state = 93, .external_lex_state = 6},
  [2310] = {.lex_state = 93, .external_lex_state = 6},
  [2311] = {.lex_state = 93, .external_lex_state = 6},
  [2312] = {.lex_state = 93, .external_lex_state = 6},
  [2313] = {.lex_state = 93, .external_lex_state = 6},
  [2314] = {.lex_state = 93, .external_lex_state = 6},
  [2315] = {.lex_state = 95, .external_lex_state = 5},
  [2316] = {.lex_state = 93, .external_lex_state = 6},
  [2317] = {.lex_state = 93, .external_lex_state = 6},
  [2318] = {.lex_state = 95, .external_lex_state = 5},
  [2319] = {.lex_state = 93, .external_lex_state = 6},
  [2320] = {.lex_state = 93, .external_lex_state = 6},
  [2321] = {.lex_state = 93, .external_lex_state = 6},
  [2322] = {.lex_state = 93, .external_lex_state = 6},
  [2323] = {.lex_state = 93, .external_lex_state = 6},
  [2324] = {.lex_state = 95, .external_lex_state = 5},
  [2325] = {.lex_state = 93, .external_lex_state = 6},
  [2326] = {.lex_state = 95, .external_lex_state = 5},
  [2327] = {.lex_state = 93, .external_lex_state = 6},
  [2328] = {.lex_state = 95, .external_lex_state = 5},
  [2329] = {.lex_state = 95, .external_lex_state = 5},
  [2330] = {.lex_state = 95, .external_lex_state = 5},
  [2331] = {.lex_state = 93, .external_lex_state = 6},
  [2332] = {.lex_state = 95, .external_lex_state = 5},
  [2333] = {.lex_state = 93, .external_lex_state = 6},
  [2334] = {.lex_state = 95, .external_lex_state = 5},
  [2335] = {.lex_state = 95, .external_lex_state = 5},
  [2336] = {.lex_state = 95, .external_lex_state = 5},
  [2337] = {.lex_state = 93, .external_lex_state = 6},
  [2338] = {.lex_state = 93, .external_lex_state = 6},
  [2339] = {.lex_state = 93, .external_lex_state = 6},
  [2340] = {.lex_state = 95, .external_lex_state = 5},
  [2341] = {.lex_state = 95, .external_lex_state = 5},
  [2342] = {.lex_state = 95, .external_lex_state = 5},
  [2343] = {.lex_state = 93, .external_lex_state = 6},
  [2344] = {.lex_state = 95, .external_lex_state = 5},
  [2345] = {.lex_state = 93, .external_lex_state = 6},
  [2346] = {.lex_state = 95, .external_lex_state = 5},
  [2347] = {.lex_state = 93, .external_lex_state = 6},
  [2348] = {.lex_state = 95, .external_lex_state = 5},
  [2349] = {.lex_state = 93, .external_lex_state = 6},
  [2350] = {.lex_state = 93, .external_lex_state = 6},
  [2351] = {.lex_state = 93, .external_lex_state = 6},
  [2352] = {.lex_state = 95, .external_lex_state = 5},
  [2353] = {.lex_state = 95, .external_lex_state = 5},
  [2354] = {.lex_state = 95, .external_lex_state = 5},
  [2355] = {.lex_state = 93, .external_lex_state = 6},
  [2356] = {.lex_state = 95, .external_lex_state = 5},
  [2357] = {.lex_state = 95, .external_lex_state = 5},
  [2358] = {.lex_state = 93, .external_lex_state = 6},
  [2359] = {.lex_state = 95, .external_lex_state = 5},
  [2360] = {.lex_state = 93, .external_lex_state = 6},
  [2361] = {.lex_state = 95, .external_lex_state = 5},
  [2362] = {.lex_state = 93, .external_lex_state = 6},
  [2363] = {.lex_state = 93, .external_lex_state = 6},
  [2364] = {.lex_state = 93, .external_lex_state = 6},
  [2365] = {.lex_state = 93, .external_lex_state = 6},
  [2366] = {.lex_state = 93, .external_lex_state = 6},
  [2367] = {.lex_state = 93, .external_lex_state = 6},
  [2368] = {.lex_state = 95, .external_lex_state = 5},
  [2369] = {.lex_state = 95, .external_lex_state = 5},
  [2370] = {.lex_state = 93, .external_lex_state = 6},
  [2371] = {.lex_state = 95, .external_lex_state = 5},
  [2372] = {.lex_state = 93, .external_lex_state = 6},
  [2373] = {.lex_state = 95, .external_lex_state = 5},
  [2374] = {.lex_state = 93, .external_lex_state = 6},
  [2375] = {.lex_state = 93, .external_lex_state = 6},
  [2376] = {.lex_state = 93, .external_lex_state = 6},
  [2377] = {.lex_state = 93, .external_lex_state = 6},
  [2378] = {.lex_state = 93, .external_lex_state = 6},
  [2379] = {.lex_state = 93, .external_lex_state = 6},
  [2380] = {.lex_state = 95, .external_lex_state = 5},
  [2381] = {.lex_state = 95, .external_lex_state = 5},
  [2382] = {.lex_state = 93, .external_lex_state = 6},
  [2383] = {.lex_state = 95, .external_lex_state = 5},
  [2384] = {.lex_state = 93, .external_lex_state = 6},
  [2385] = {.lex_state = 95, .external_lex_state = 5},
  [2386] = {.lex_state = 93, .external_lex_state = 6},
  [2387] = {.lex_state = 93, .external_lex_state = 6},
  [2388] = {.lex_state = 95, .external_lex_state = 5},
  [2389] = {.lex_state = 93, .external_lex_state = 6},
  [2390] = {.lex_state = 95, .external_lex_state = 5},
  [2391] = {.lex_state = 93, .external_lex_state = 6},
  [2392] = {.lex_state = 95, .external_lex_state = 5},
  [2393] = {.lex_state = 95, .external_lex_state = 5},
  [2394] = {.lex_state = 95, .external_lex_state = 5},
  [2395] = {.lex_state = 93, .external_lex_state = 6},
  [2396] = {.lex_state = 93, .external_lex_state = 6},
  [2397] = {.lex_state = 93, .external_lex_state = 6},
  [2398] = {.lex_state = 93, .external_lex_state = 6},
  [2399] = {.lex_state = 93, .external_lex_state = 6},
  [2400] = {.lex_state = 95, .external_lex_state = 5},
  [2401] = {.lex_state = 93, .external_lex_state = 6},
  [2402] = {.lex_state = 93, .external_lex_state = 6},
  [2403] = {.lex_state = 93, .external_lex_state = 6},
  [2404] = {.lex_state = 93, .external_lex_state = 6},
  [2405] = {.lex_state = 93, .external_lex_state = 6},
  [2406] = {.lex_state = 93, .external_lex_state = 6},
  [2407] = {.lex_state = 93, .external_lex_state = 6},
  [2408] = {.lex_state = 93, .external_lex_state = 6},
  [2409] = {.lex_state = 93, .external_lex_state = 6},
  [2410] = {.lex_state = 93, .external_lex_state = 6},
  [2411] = {.lex_state = 93, .external_lex_state = 6},
  [2412] = {.lex_state = 93, .external_lex_state = 6},
  [2413] = {.lex_state = 93, .external_lex_state = 6},
  [2414] = {.lex_state = 95, .external_lex_state = 5},
  [2415] = {.lex_state = 93, .external_lex_state = 6},
  [2416] = {.lex_state = 93, .external_lex_state = 6},
  [2417] = {.lex_state = 93, .external_lex_state = 6},
  [2418] = {.lex_state = 93, .external_lex_state = 6},
  [2419] = {.lex_state = 95, .external_lex_state = 5},
  [2420] = {.lex_state = 95, .external_lex_state = 5},
  [2421] = {.lex_state = 95, .external_lex_state = 5},
  [2422] = {.lex_state = 95, .external_lex_state = 5},
  [2423] = {.lex_state = 93, .external_lex_state = 6},
  [2424] = {.lex_state = 93, .external_lex_state = 6},
  [2425] = {.lex_state = 93, .external_lex_state = 6},
  [2426] = {.lex_state = 93, .external_lex_state = 6},
  [2427] = {.lex_state = 93, .external_lex_state = 6},
  [2428] = {.lex_state = 93, .external_lex_state = 6},
  [2429] = {.lex_state = 93, .external_lex_state = 6},
  [2430] = {.lex_state = 93, .external_lex_state = 6},
  [2431] = {.lex_state = 93, .external_lex_state = 6},
  [2432] = {.lex_state = 93, .external_lex_state = 6},
  [2433] = {.lex_state = 93, .external_lex_state = 6},
  [2434] = {.lex_state = 93, .external_lex_state = 6},
  [2435] = {.lex_state = 95, .external_lex_state = 5},
  [2436] = {.lex_state = 95, .external_lex_state = 5},
  [2437] = {.lex_state = 95, .external_lex_state = 5},
  [2438] = {.lex_state = 95, .external_lex_state = 5},
  [2439] = {.lex_state = 95, .external_lex_state = 5},
  [2440] = {.lex_state = 95, .external_lex_state = 5},
  [2441] = {.lex_state = 95, .external_lex_state = 5},
  [2442] = {.lex_state = 95, .external_lex_state = 5},
  [2443] = {.lex_state = 95, .external_lex_state = 5},
  [2444] = {.lex_state = 95, .external_lex_state = 5},
  [2445] = {.lex_state = 95, .external_lex_state = 5},
  [2446] = {.lex_state = 95, .external_lex_state = 5},
  [2447] = {.lex_state = 95, .external_lex_state = 5},
  [2448] = {.lex_state = 95, .external_lex_state = 5},
  [2449] = {.lex_state = 95, .external_lex_state = 5},
  [2450] = {.lex_state = 95, .external_lex_state = 5},
  [2451] = {.lex_state = 95, .external_lex_state = 5},
  [2452] = {.lex_state = 95, .external_lex_state = 5},
  [2453] = {.lex_state = 93, .external_lex_state = 6},
  [2454] = {.lex_state = 95, .external_lex_state = 5},
  [2455] = {.lex_state = 95, .external_lex_state = 5},
  [2456] = {.lex_state = 95, .external_lex_state = 5},
  [2457] = {.lex_state = 95, .external_lex_state = 5},
  [2458] = {.lex_state = 93, .external_lex_state = 6},
  [2459] = {.lex_state = 93, .external_lex_state = 6},
  [2460] = {.lex_state = 95, .external_lex_state = 5},
  [2461] = {.lex_state = 95, .external_lex_state = 5},
  [2462] = {.lex_state = 95, .external_lex_state = 5},
  [2463] = {.lex_state = 95, .external_lex_state = 5},
  [2464] = {.lex_state = 95, .external_lex_state = 5},
  [2465] = {.lex_state = 93, .external_lex_state = 6},
  [2466] = {.lex_state = 93, .external_lex_state = 6},
  [2467] = {.lex_state = 93, .external_lex_state = 6},
  [2468] = {.lex_state = 95, .external_lex_state = 5},
  [2469] = {.lex_state = 95, .external_lex_state = 5},
  [2470] = {.lex_state = 95, .external_lex_state = 5},
  [2471] = {.lex_state = 93, .external_lex_state = 6},
  [2472] = {.lex_state = 95, .external_lex_state = 5},
  [2473] = {.lex_state = 95, .external_lex_state = 5},
  [2474] = {.lex_state = 93, .external_lex_state = 6},
  [2475] = {.lex_state = 95, .external_lex_state = 5},
  [2476] = {.lex_state = 93, .external_lex_state = 6},
  [2477] = {.lex_state = 93, .external_lex_state = 6},
  [2478] = {.lex_state = 93, .external_lex_state = 6},
  [2479] = {.lex_state = 95, .external_lex_state = 5},
  [2480] = {.lex_state = 93, .external_lex_state = 6},
  [2481] = {.lex_state = 93, .external_lex_state = 6},
  [2482] = {.lex_state = 93, .external_lex_state = 6},
  [2483] = {.lex_state = 95, .external_lex_state = 5},
  [2484] = {.lex_state = 93, .external_lex_state = 6},
  [2485] = {.lex_state = 93, .external_lex_state = 6},
  [2486] = {.lex_state = 93, .external_lex_state = 6},
  [2487] = {.lex_state = 95, .external_lex_state = 5},
  [2488] = {.lex_state = 93, .external_lex_state = 6},
  [2489] = {.lex_state = 95, .external_lex_state = 5},
  [2490] = {.lex_state = 95, .external_lex_state = 5},
  [2491] = {.lex_state = 95, .external_lex_state = 5},
  [2492] = {.lex_state = 93, .external_lex_state = 6},
  [2493] = {.lex_state = 93, .external_lex_state = 6},
  [2494] = {.lex_state = 95, .external_lex_state = 5},
  [2495] = {.lex_state = 95, .external_lex_state = 5},
  [2496] = {.lex_state = 93, .external_lex_state = 6},
  [2497] = {.lex_state = 93, .external_lex_state = 6},
  [2498] = {.lex_state = 95, .external_lex_state = 5},
  [2499] = {.lex_state = 93, .external_lex_state = 6},
  [2500] = {.lex_state = 93, .external_lex_state = 6},
  [2501] = {.lex_state = 93, .external_lex_state = 6},
  [2502] = {.lex_state = 93, .external_lex_state = 6},
  [2503] = {.lex_state = 93, .external_lex_state = 6},
  [2504] = {.lex_state = 95, .external_lex_state = 5},
  [2505] = {.lex_state = 95, .external_lex_state = 4},
  [2506] = {.lex_state = 93, .external_lex_state = 6},
  [2507] = {.lex_state = 93, .external_lex_state = 6},
  [2508] = {.lex_state = 95, .external_lex_state = 5},
  [2509] = {.lex_state = 95, .external_lex_state = 5},
  [2510] = {.lex_state = 95, .external_lex_state = 5},
  [2511] = {.lex_state = 95, .external_lex_state = 5},
  [2512] = {.lex_state = 95, .external_lex_state = 5},
  [2513] = {.lex_state = 95, .external_lex_state = 5},
  [2514] = {.lex_state = 95, .external_lex_state = 5},
  [2515] = {.lex_state = 95, .external_lex_state = 5},
  [2516] = {.lex_state = 95, .external_lex_state = 5},
  [2517] = {.lex_state = 95, .external_lex_state = 5},
  [2518] = {.lex_state = 93, .external_lex_state = 6},
  [2519] = {.lex_state = 93, .external_lex_state = 6},
  [2520] = {.lex_state = 95, .external_lex_state = 5},
  [2521] = {.lex_state = 93, .external_lex_state = 6},
  [2522] = {.lex_state = 95, .external_lex_state = 5},
  [2523] = {.lex_state = 95, .external_lex_state = 5},
  [2524] = {.lex_state = 93, .external_lex_state = 6},
  [2525] = {.lex_state = 95, .external_lex_state = 5},
  [2526] = {.lex_state = 93, .external_lex_state = 6},
  [2527] = {.lex_state = 95, .external_lex_state = 5},
  [2528] = {.lex_state = 93, .external_lex_state = 6},
  [2529] = {.lex_state = 93, .external_lex_state = 6},
  [2530] = {.lex_state = 93, .external_lex_state = 6},
  [2531] = {.lex_state = 94, .external_lex_state = 6},
  [2532] = {.lex_state = 88, .external_lex_state = 2},
  [2533] = {.lex_state = 88, .external_lex_state = 2},
  [2534] = {.lex_state = 88, .external_lex_state = 2},
  [2535] = {.lex_state = 88, .external_lex_state = 2},
  [2536] = {.lex_state = 88, .external_lex_state = 2},
  [2537] = {.lex_state = 88, .external_lex_state = 2},
  [2538] = {.lex_state = 88, .external_lex_state = 2},
  [2539] = {.lex_state = 88, .external_lex_state = 2},
  [2540] = {.lex_state = 88, .external_lex_state = 2},
  [2541] = {.lex_state = 95, .external_lex_state = 5},
  [2542] = {.lex_state = 88, .external_lex_state = 2},
  [2543] = {.lex_state = 94, .external_lex_state = 6},
  [2544] = {.lex_state = 88, .external_lex_state = 2},
  [2545] = {.lex_state = 88, .external_lex_state = 2},
  [2546] = {.lex_state = 95, .external_lex_state = 4},
  [2547] = {.lex_state = 88, .external_lex_state = 2},
  [2548] = {.lex_state = 88, .external_lex_state = 2},
  [2549] = {.lex_state = 93, .external_lex_state = 6},
  [2550] = {.lex_state = 88, .external_lex_state = 2},
  [2551] = {.lex_state = 88, .external_lex_state = 2},
  [2552] = {.lex_state = 88, .external_lex_state = 2},
  [2553] = {.lex_state = 93, .external_lex_state = 6},
  [2554] = {.lex_state = 88, .external_lex_state = 2},
  [2555] = {.lex_state = 93, .external_lex_state = 6},
  [2556] = {.lex_state = 94, .external_lex_state = 6},
  [2557] = {.lex_state = 93, .external_lex_state = 6},
  [2558] = {.lex_state = 93, .external_lex_state = 6},
  [2559] = {.lex_state = 93, .external_lex_state = 6},
  [2560] = {.lex_state = 93, .external_lex_state = 6},
  [2561] = {.lex_state = 95, .external_lex_state = 5},
  [2562] = {.lex_state = 95, .external_lex_state = 5},
  [2563] = {.lex_state = 95, .external_lex_state = 5},
  [2564] = {.lex_state = 95, .external_lex_state = 5},
  [2565] = {.lex_state = 95, .external_lex_state = 5},
  [2566] = {.lex_state = 95, .external_lex_state = 5},
  [2567] = {.lex_state = 95, .external_lex_state = 5},
  [2568] = {.lex_state = 95, .external_lex_state = 6},
  [2569] = {.lex_state = 95, .external_lex_state = 5},
  [2570] = {.lex_state = 95, .external_lex_state = 5},
  [2571] = {.lex_state = 93, .external_lex_state = 6},
  [2572] = {.lex_state = 95, .external_lex_state = 5},
  [2573] = {.lex_state = 95, .external_lex_state = 5},
  [2574] = {.lex_state = 95, .external_lex_state = 5},
  [2575] = {.lex_state = 93, .external_lex_state = 6},
  [2576] = {.lex_state = 93, .external_lex_state = 6},
  [2577] = {.lex_state = 93, .external_lex_state = 6},
  [2578] = {.lex_state = 95, .external_lex_state = 5},
  [2579] = {.lex_state = 95, .external_lex_state = 5},
  [2580] = {.lex_state = 93, .external_lex_state = 6},
  [2581] = {.lex_state = 95, .external_lex_state = 6},
  [2582] = {.lex_state = 95, .external_lex_state = 5},
  [2583] = {.lex_state = 95, .external_lex_state = 5},
  [2584] = {.lex_state = 95, .external_lex_state = 6},
  [2585] = {.lex_state = 95, .external_lex_state = 5},
  [2586] = {.lex_state = 95, .external_lex_state = 5},
  [2587] = {.lex_state = 95, .external_lex_state = 5},
  [2588] = {.lex_state = 95, .external_lex_state = 5},
  [2589] = {.lex_state = 95, .external_lex_state = 5},
  [2590] = {.lex_state = 95, .external_lex_state = 6},
  [2591] = {.lex_state = 95, .external_lex_state = 5},
  [2592] = {.lex_state = 95, .external_lex_state = 5},
  [2593] = {.lex_state = 95, .external_lex_state = 5},
  [2594] = {.lex_state = 95, .external_lex_state = 5},
  [2595] = {.lex_state = 94, .external_lex_state = 6},
  [2596] = {.lex_state = 95, .external_lex_state = 5},
  [2597] = {.lex_state = 95, .external_lex_state = 5},
  [2598] = {.lex_state = 95, .external_lex_state = 5},
  [2599] = {.lex_state = 95, .external_lex_state = 5},
  [2600] = {.lex_state = 93, .external_lex_state = 6},
  [2601] = {.lex_state = 95, .external_lex_state = 6},
  [2602] = {.lex_state = 93, .external_lex_state = 6},
  [2603] = {.lex_state = 95, .external_lex_state = 6},
  [2604] = {.lex_state = 95, .external_lex_state = 6},
  [2605] = {.lex_state = 95, .external_lex_state = 6},
  [2606] = {.lex_state = 93, .external_lex_state = 6},
  [2607] = {.lex_state = 95, .external_lex_state = 6},
  [2608] = {.lex_state = 95, .external_lex_state = 6},
  [2609] = {.lex_state = 95, .external_lex_state = 6},
  [2610] = {.lex_state = 95, .external_lex_state = 6},
  [2611] = {.lex_state = 93, .external_lex_state = 6},
  [2612] = {.lex_state = 95, .external_lex_state = 6},
  [2613] = {.lex_state = 95, .external_lex_state = 6},
  [2614] = {.lex_state = 95, .external_lex_state = 6},
  [2615] = {.lex_state = 93, .external_lex_state = 6},
  [2616] = {.lex_state = 95, .external_lex_state = 6},
  [2617] = {.lex_state = 93, .external_lex_state = 6},
  [2618] = {.lex_state = 95, .external_lex_state = 6},
  [2619] = {.lex_state = 95, .external_lex_state = 6},
  [2620] = {.lex_state = 95, .external_lex_state = 6},
  [2621] = {.lex_state = 95, .external_lex_state = 6},
  [2622] = {.lex_state = 95, .external_lex_state = 6},
  [2623] = {.lex_state = 95, .external_lex_state = 6},
  [2624] = {.lex_state = 95, .external_lex_state = 6},
  [2625] = {.lex_state = 95, .external_lex_state = 6},
  [2626] = {.lex_state = 93, .external_lex_state = 6},
  [2627] = {.lex_state = 95, .external_lex_state = 6},
  [2628] = {.lex_state = 95, .external_lex_state = 6},
  [2629] = {.lex_state = 95, .external_lex_state = 6},
  [2630] = {.lex_state = 95, .external_lex_state = 6},
  [2631] = {.lex_state = 95, .external_lex_state = 6},
  [2632] = {.lex_state = 95, .external_lex_state = 6},
  [2633] = {.lex_state = 95, .external_lex_state = 6},
  [2634] = {.lex_state = 95, .external_lex_state = 6},
  [2635] = {.lex_state = 95, .external_lex_state = 6},
  [2636] = {.lex_state = 95, .external_lex_state = 6},
  [2637] = {.lex_state = 95, .external_lex_state = 6},
  [2638] = {.lex_state = 95, .external_lex_state = 6},
  [2639] = {.lex_state = 95, .external_lex_state = 6},
  [2640] = {.lex_state = 95, .external_lex_state = 6},
  [2641] = {.lex_state = 95, .external_lex_state = 6},
  [2642] = {.lex_state = 95, .external_lex_state = 6},
  [2643] = {.lex_state = 95, .external_lex_state = 6},
  [2644] = {.lex_state = 95, .external_lex_state = 6},
  [2645] = {.lex_state = 95, .external_lex_state = 6},
  [2646] = {.lex_state = 95, .external_lex_state = 6},
  [2647] = {.lex_state = 95, .external_lex_state = 6},
  [2648] = {.lex_state = 95, .external_lex_state = 6},
  [2649] = {.lex_state = 95, .external_lex_state = 6},
  [2650] = {.lex_state = 95, .external_lex_state = 6},
  [2651] = {.lex_state = 95, .external_lex_state = 6},
  [2652] = {.lex_state = 95, .external_lex_state = 6},
  [2653] = {.lex_state = 95, .external_lex_state = 6},
  [2654] = {.lex_state = 95, .external_lex_state = 6},
  [2655] = {.lex_state = 95, .external_lex_state = 6},
  [2656] = {.lex_state = 95, .external_lex_state = 6},
  [2657] = {.lex_state = 95, .external_lex_state = 6},
  [2658] = {.lex_state = 95, .external_lex_state = 6},
  [2659] = {.lex_state = 95, .external_lex_state = 6},
  [2660] = {.lex_state = 95, .external_lex_state = 6},
  [2661] = {.lex_state = 95, .external_lex_state = 6},
  [2662] = {.lex_state = 95, .external_lex_state = 6},
  [2663] = {.lex_state = 93, .external_lex_state = 6},
  [2664] = {.lex_state = 95, .external_lex_state = 6},
  [2665] = {.lex_state = 95, .external_lex_state = 6},
  [2666] = {.lex_state = 95, .external_lex_state = 6},
  [2667] = {.lex_state = 95, .external_lex_state = 6},
  [2668] = {.lex_state = 95, .external_lex_state = 6},
  [2669] = {.lex_state = 95, .external_lex_state = 6},
  [2670] = {.lex_state = 95, .external_lex_state = 6},
  [2671] = {.lex_state = 95, .external_lex_state = 6},
  [2672] = {.lex_state = 95, .external_lex_state = 6},
  [2673] = {.lex_state = 95, .external_lex_state = 6},
  [2674] = {.lex_state = 95, .external_lex_state = 6},
  [2675] = {.lex_state = 95, .external_lex_state = 6},
  [2676] = {.lex_state = 95, .external_lex_state = 6},
  [2677] = {.lex_state = 95, .external_lex_state = 6},
  [2678] = {.lex_state = 95, .external_lex_state = 6},
  [2679] = {.lex_state = 94, .external_lex_state = 7},
  [2680] = {.lex_state = 95, .external_lex_state = 6},
  [2681] = {.lex_state = 95, .external_lex_state = 6},
  [2682] = {.lex_state = 95, .external_lex_state = 6},
  [2683] = {.lex_state = 95, .external_lex_state = 6},
  [2684] = {.lex_state = 94, .external_lex_state = 7},
  [2685] = {.lex_state = 95, .external_lex_state = 6},
  [2686] = {.lex_state = 95, .external_lex_state = 6},
  [2687] = {.lex_state = 95, .external_lex_state = 6},
  [2688] = {.lex_state = 95, .external_lex_state = 6},
  [2689] = {.lex_state = 95, .external_lex_state = 6},
  [2690] = {.lex_state = 95, .external_lex_state = 6},
  [2691] = {.lex_state = 95, .external_lex_state = 6},
  [2692] = {.lex_state = 95, .external_lex_state = 6},
  [2693] = {.lex_state = 95, .external_lex_state = 6},
  [2694] = {.lex_state = 95, .external_lex_state = 6},
  [2695] = {.lex_state = 95, .external_lex_state = 6},
  [2696] = {.lex_state = 95, .external_lex_state = 6},
  [2697] = {.lex_state = 95, .external_lex_state = 6},
  [2698] = {.lex_state = 95, .external_lex_state = 6},
  [2699] = {.lex_state = 95, .external_lex_state = 6},
  [2700] = {.lex_state = 95, .external_lex_state = 6},
  [2701] = {.lex_state = 95, .external_lex_state = 6},
  [2702] = {.lex_state = 94, .external_lex_state = 7},
  [2703] = {.lex_state = 95, .external_lex_state = 6},
  [2704] = {.lex_state = 95, .external_lex_state = 6},
  [2705] = {.lex_state = 95, .external_lex_state = 6},
  [2706] = {.lex_state = 95, .external_lex_state = 6},
  [2707] = {.lex_state = 95, .external_lex_state = 6},
  [2708] = {.lex_state = 95, .external_lex_state = 6},
  [2709] = {.lex_state = 95, .external_lex_state = 6},
  [2710] = {.lex_state = 95, .external_lex_state = 6},
  [2711] = {.lex_state = 95, .external_lex_state = 6},
  [2712] = {.lex_state = 95, .external_lex_state = 6},
  [2713] = {.lex_state = 95, .external_lex_state = 6},
  [2714] = {.lex_state = 95, .external_lex_state = 6},
  [2715] = {.lex_state = 95, .external_lex_state = 6},
  [2716] = {.lex_state = 95, .external_lex_state = 6},
  [2717] = {.lex_state = 95, .external_lex_state = 6},
  [2718] = {.lex_state = 95, .external_lex_state = 6},
  [2719] = {.lex_state = 95, .external_lex_state = 6},
  [2720] = {.lex_state = 95, .external_lex_state = 6},
  [2721] = {.lex_state = 95, .external_lex_state = 6},
  [2722] = {.lex_state = 95, .external_lex_state = 6},
  [2723] = {.lex_state = 95, .external_lex_state = 6},
  [2724] = {.lex_state = 95, .external_lex_state = 6},
  [2725] = {.lex_state = 95, .external_lex_state = 6},
  [2726] = {.lex_state = 95, .external_lex_state = 6},
  [2727] = {.lex_state = 95, .external_lex_state = 6},
  [2728] = {.lex_state = 95, .external_lex_state = 6},
  [2729] = {.lex_state = 95, .external_lex_state = 6},
  [2730] = {.lex_state = 95, .external_lex_state = 6},
  [2731] = {.lex_state = 95, .external_lex_state = 6},
  [2732] = {.lex_state = 95, .external_lex_state = 6},
  [2733] = {.lex_state = 95, .external_lex_state = 6},
  [2734] = {.lex_state = 95, .external_lex_state = 6},
  [2735] = {.lex_state = 95, .external_lex_state = 6},
  [2736] = {.lex_state = 95, .external_lex_state = 6},
  [2737] = {.lex_state = 95, .external_lex_state = 6},
  [2738] = {.lex_state = 95, .external_lex_state = 6},
  [2739] = {.lex_state = 95, .external_lex_state = 6},
  [2740] = {.lex_state = 95, .external_lex_state = 6},
  [2741] = {.lex_state = 95, .external_lex_state = 6},
  [2742] = {.lex_state = 95, .external_lex_state = 6},
  [2743] = {.lex_state = 95, .external_lex_state = 6},
  [2744] = {.lex_state = 95, .external_lex_state = 6},
  [2745] = {.lex_state = 95, .external_lex_state = 6},
  [2746] = {.lex_state = 95, .external_lex_state = 6},
  [2747] = {.lex_state = 95, .external_lex_state = 6},
  [2748] = {.lex_state = 95, .external_lex_state = 6},
  [2749] = {.lex_state = 95, .external_lex_state = 6},
  [2750] = {.lex_state = 95, .external_lex_state = 6},
  [2751] = {.lex_state = 95, .external_lex_state = 6},
  [2752] = {.lex_state = 95, .external_lex_state = 6},
  [2753] = {.lex_state = 95, .external_lex_state = 6},
  [2754] = {.lex_state = 95, .external_lex_state = 6},
  [2755] = {.lex_state = 95, .external_lex_state = 6},
  [2756] = {.lex_state = 95, .external_lex_state = 6},
  [2757] = {.lex_state = 95, .external_lex_state = 6},
  [2758] = {.lex_state = 95, .external_lex_state = 6},
  [2759] = {.lex_state = 95, .external_lex_state = 6},
  [2760] = {.lex_state = 95, .external_lex_state = 6},
  [2761] = {.lex_state = 95, .external_lex_state = 6},
  [2762] = {.lex_state = 95, .external_lex_state = 6},
  [2763] = {.lex_state = 95, .external_lex_state = 6},
  [2764] = {.lex_state = 95, .external_lex_state = 6},
  [2765] = {.lex_state = 95, .external_lex_state = 6},
  [2766] = {.lex_state = 95, .external_lex_state = 6},
  [2767] = {.lex_state = 95, .external_lex_state = 6},
  [2768] = {.lex_state = 95, .external_lex_state = 6},
  [2769] = {.lex_state = 95, .external_lex_state = 6},
  [2770] = {.lex_state = 95, .external_lex_state = 7},
  [2771] = {.lex_state = 95, .external_lex_state = 6},
  [2772] = {.lex_state = 95, .external_lex_state = 6},
  [2773] = {.lex_state = 95, .external_lex_state = 6},
  [2774] = {.lex_state = 95, .external_lex_state = 6},
  [2775] = {.lex_state = 95, .external_lex_state = 6},
  [2776] = {.lex_state = 95, .external_lex_state = 6},
  [2777] = {.lex_state = 95, .external_lex_state = 6},
  [2778] = {.lex_state = 95, .external_lex_state = 6},
  [2779] = {.lex_state = 95, .external_lex_state = 6},
  [2780] = {.lex_state = 95, .external_lex_state = 6},
  [2781] = {.lex_state = 95, .external_lex_state = 6},
  [2782] = {.lex_state = 95, .external_lex_state = 6},
  [2783] = {.lex_state = 95, .external_lex_state = 6},
  [2784] = {.lex_state = 94, .external_lex_state = 7},
  [2785] = {.lex_state = 95, .external_lex_state = 6},
  [2786] = {.lex_state = 95, .external_lex_state = 7},
  [2787] = {.lex_state = 95, .external_lex_state = 6},
  [2788] = {.lex_state = 95, .external_lex_state = 6},
  [2789] = {.lex_state = 95, .external_lex_state = 6},
  [2790] = {.lex_state = 95, .external_lex_state = 6},
  [2791] = {.lex_state = 95, .external_lex_state = 6},
  [2792] = {.lex_state = 95, .external_lex_state = 6},
  [2793] = {.lex_state = 95, .external_lex_state = 6},
  [2794] = {.lex_state = 95, .external_lex_state = 6},
  [2795] = {.lex_state = 95, .external_lex_state = 6},
  [2796] = {.lex_state = 95, .external_lex_state = 6},
  [2797] = {.lex_state = 95, .external_lex_state = 6},
  [2798] = {.lex_state = 95, .external_lex_state = 6},
  [2799] = {.lex_state = 95, .external_lex_state = 6},
  [2800] = {.lex_state = 95, .external_lex_state = 6},
  [2801] = {.lex_state = 95, .external_lex_state = 6},
  [2802] = {.lex_state = 95, .external_lex_state = 6},
  [2803] = {.lex_state = 95, .external_lex_state = 6},
  [2804] = {.lex_state = 95, .external_lex_state = 7},
  [2805] = {.lex_state = 95, .external_lex_state = 7},
  [2806] = {.lex_state = 95, .external_lex_state = 7},
  [2807] = {.lex_state = 95, .external_lex_state = 7},
  [2808] = {.lex_state = 95, .external_lex_state = 7},
  [2809] = {.lex_state = 95, .external_lex_state = 7},
  [2810] = {.lex_state = 95, .external_lex_state = 7},
  [2811] = {.lex_state = 95, .external_lex_state = 7},
  [2812] = {.lex_state = 95, .external_lex_state = 7},
  [2813] = {.lex_state = 95, .external_lex_state = 7},
  [2814] = {.lex_state = 95, .external_lex_state = 7},
  [2815] = {.lex_state = 95, .external_lex_state = 7},
  [2816] = {.lex_state = 91, .external_lex_state = 6},
  [2817] = {.lex_state = 95, .external_lex_state = 7},
  [2818] = {.lex_state = 95, .external_lex_state = 7},
  [2819] = {.lex_state = 95, .external_lex_state = 7},
  [2820] = {.lex_state = 95, .external_lex_state = 6},
  [2821] = {.lex_state = 95, .external_lex_state = 7},
  [2822] = {.lex_state = 95, .external_lex_state = 7},
  [2823] = {.lex_state = 95, .external_lex_state = 7},
  [2824] = {.lex_state = 95, .external_lex_state = 7},
  [2825] = {.lex_state = 95, .external_lex_state = 7},
  [2826] = {.lex_state = 95, .external_lex_state = 7},
  [2827] = {.lex_state = 95, .external_lex_state = 7},
  [2828] = {.lex_state = 95, .external_lex_state = 7},
  [2829] = {.lex_state = 95, .external_lex_state = 7},
  [2830] = {.lex_state = 95, .external_lex_state = 7},
  [2831] = {.lex_state = 95, .external_lex_state = 7},
  [2832] = {.lex_state = 95, .external_lex_state = 7},
  [2833] = {.lex_state = 95, .external_lex_state = 7},
  [2834] = {.lex_state = 95, .external_lex_state = 7},
  [2835] = {.lex_state = 95, .external_lex_state = 7},
  [2836] = {.lex_state = 95, .external_lex_state = 7},
  [2837] = {.lex_state = 95, .external_lex_state = 7},
  [2838] = {.lex_state = 95, .external_lex_state = 7},
  [2839] = {.lex_state = 95, .external_lex_state = 7},
  [2840] = {.lex_state = 95, .external_lex_state = 7},
  [2841] = {.lex_state = 95, .external_lex_state = 7},
  [2842] = {.lex_state = 95, .external_lex_state = 7},
  [2843] = {.lex_state = 95, .external_lex_state = 7},
  [2844] = {.lex_state = 95, .external_lex_state = 7},
  [2845] = {.lex_state = 95, .external_lex_state = 7},
  [2846] = {.lex_state = 95, .external_lex_state = 7},
  [2847] = {.lex_state = 95, .external_lex_state = 7},
  [2848] = {.lex_state = 95, .external_lex_state = 7},
  [2849] = {.lex_state = 95, .external_lex_state = 7},
  [2850] = {.lex_state = 95, .external_lex_state = 7},
  [2851] = {.lex_state = 95, .external_lex_state = 7},
  [2852] = {.lex_state = 95, .external_lex_state = 7},
  [2853] = {.lex_state = 95, .external_lex_state = 7},
  [2854] = {.lex_state = 95, .external_lex_state = 7},
  [2855] = {.lex_state = 95, .external_lex_state = 6},
  [2856] = {.lex_state = 95, .external_lex_state = 7},
  [2857] = {.lex_state = 95, .external_lex_state = 7},
  [2858] = {.lex_state = 95, .external_lex_state = 7},
  [2859] = {.lex_state = 95, .external_lex_state = 7},
  [2860] = {.lex_state = 95, .external_lex_state = 7},
  [2861] = {.lex_state = 95, .external_lex_state = 7},
  [2862] = {.lex_state = 95, .external_lex_state = 7},
  [2863] = {.lex_state = 95, .external_lex_state = 7},
  [2864] = {.lex_state = 95, .external_lex_state = 7},
  [2865] = {.lex_state = 95, .external_lex_state = 7},
  [2866] = {.lex_state = 95, .external_lex_state = 7},
  [2867] = {.lex_state = 95, .external_lex_state = 7},
  [2868] = {.lex_state = 95, .external_lex_state = 7},
  [2869] = {.lex_state = 95, .external_lex_state = 7},
  [2870] = {.lex_state = 95, .external_lex_state = 7},
  [2871] = {.lex_state = 95, .external_lex_state = 7},
  [2872] = {.lex_state = 91, .external_lex_state = 6},
  [2873] = {.lex_state = 95, .external_lex_state = 7},
  [2874] = {.lex_state = 95, .external_lex_state = 7},
  [2875] = {.lex_state = 95, .external_lex_state = 7},
  [2876] = {.lex_state = 95, .external_lex_state = 7},
  [2877] = {.lex_state = 95, .external_lex_state = 7},
  [2878] = {.lex_state = 95, .external_lex_state = 7},
  [2879] = {.lex_state = 95, .external_lex_state = 7},
  [2880] = {.lex_state = 95, .external_lex_state = 7},
  [2881] = {.lex_state = 95, .external_lex_state = 7},
  [2882] = {.lex_state = 95, .external_lex_state = 7},
  [2883] = {.lex_state = 95, .external_lex_state = 7},
  [2884] = {.lex_state = 95, .external_lex_state = 7},
  [2885] = {.lex_state = 95, .external_lex_state = 7},
  [2886] = {.lex_state = 95, .external_lex_state = 7},
  [2887] = {.lex_state = 95, .external_lex_state = 7},
  [2888] = {.lex_state = 95, .external_lex_state = 7},
  [2889] = {.lex_state = 95, .external_lex_state = 7},
  [2890] = {.lex_state = 95, .external_lex_state = 7},
  [2891] = {.lex_state = 95, .external_lex_state = 7},
  [2892] = {.lex_state = 95, .external_lex_state = 7},
  [2893] = {.lex_state = 95, .external_lex_state = 7},
  [2894] = {.lex_state = 95, .external_lex_state = 7},
  [2895] = {.lex_state = 95, .external_lex_state = 7},
  [2896] = {.lex_state = 95, .external_lex_state = 7},
  [2897] = {.lex_state = 95, .external_lex_state = 7},
  [2898] = {.lex_state = 95, .external_lex_state = 7},
  [2899] = {.lex_state = 95, .external_lex_state = 7},
  [2900] = {.lex_state = 95, .external_lex_state = 7},
  [2901] = {.lex_state = 95, .external_lex_state = 7},
  [2902] = {.lex_state = 95, .external_lex_state = 7},
  [2903] = {.lex_state = 95, .external_lex_state = 7},
  [2904] = {.lex_state = 91, .external_lex_state = 6},
  [2905] = {.lex_state = 95, .external_lex_state = 7},
  [2906] = {.lex_state = 95, .external_lex_state = 7},
  [2907] = {.lex_state = 95, .external_lex_state = 7},
  [2908] = {.lex_state = 95, .external_lex_state = 7},
  [2909] = {.lex_state = 95, .external_lex_state = 7},
  [2910] = {.lex_state = 95, .external_lex_state = 7},
  [2911] = {.lex_state = 95, .external_lex_state = 7},
  [2912] = {.lex_state = 95, .external_lex_state = 7},
  [2913] = {.lex_state = 95, .external_lex_state = 7},
  [2914] = {.lex_state = 95, .external_lex_state = 7},
  [2915] = {.lex_state = 95, .external_lex_state = 7},
  [2916] = {.lex_state = 95, .external_lex_state = 7},
  [2917] = {.lex_state = 95, .external_lex_state = 7},
  [2918] = {.lex_state = 95, .external_lex_state = 7},
  [2919] = {.lex_state = 95, .external_lex_state = 6},
  [2920] = {.lex_state = 95, .external_lex_state = 7},
  [2921] = {.lex_state = 95, .external_lex_state = 7},
  [2922] = {.lex_state = 95, .external_lex_state = 7},
  [2923] = {.lex_state = 95, .external_lex_state = 7},
  [2924] = {.lex_state = 95, .external_lex_state = 7},
  [2925] = {.lex_state = 95, .external_lex_state = 7},
  [2926] = {.lex_state = 95, .external_lex_state = 7},
  [2927] = {.lex_state = 95, .external_lex_state = 7},
  [2928] = {.lex_state = 95, .external_lex_state = 7},
  [2929] = {.lex_state = 95, .external_lex_state = 7},
  [2930] = {.lex_state = 95, .external_lex_state = 6},
  [2931] = {.lex_state = 95, .external_lex_state = 7},
  [2932] = {.lex_state = 95, .external_lex_state = 7},
  [2933] = {.lex_state = 95, .external_lex_state = 7},
  [2934] = {.lex_state = 95, .external_lex_state = 7},
  [2935] = {.lex_state = 95, .external_lex_state = 7},
  [2936] = {.lex_state = 95, .external_lex_state = 7},
  [2937] = {.lex_state = 95, .external_lex_state = 7},
  [2938] = {.lex_state = 95, .external_lex_state = 7},
  [2939] = {.lex_state = 95, .external_lex_state = 7},
  [2940] = {.lex_state = 95, .external_lex_state = 7},
  [2941] = {.lex_state = 95, .external_lex_state = 7},
  [2942] = {.lex_state = 95, .external_lex_state = 7},
  [2943] = {.lex_state = 95, .external_lex_state = 7},
  [2944] = {.lex_state = 95, .external_lex_state = 7},
  [2945] = {.lex_state = 95, .external_lex_state = 7},
  [2946] = {.lex_state = 95, .external_lex_state = 7},
  [2947] = {.lex_state = 95, .external_lex_state = 7},
  [2948] = {.lex_state = 95, .external_lex_state = 7},
  [2949] = {.lex_state = 95, .external_lex_state = 7},
  [2950] = {.lex_state = 95, .external_lex_state = 7},
  [2951] = {.lex_state = 95, .external_lex_state = 7},
  [2952] = {.lex_state = 95, .external_lex_state = 7},
  [2953] = {.lex_state = 95, .external_lex_state = 7},
  [2954] = {.lex_state = 95, .external_lex_state = 7},
  [2955] = {.lex_state = 95, .external_lex_state = 7},
  [2956] = {.lex_state = 95, .external_lex_state = 6},
  [2957] = {.lex_state = 92, .external_lex_state = 6},
  [2958] = {.lex_state = 92, .external_lex_state = 6},
  [2959] = {.lex_state = 92, .external_lex_state = 6},
  [2960] = {.lex_state = 92, .external_lex_state = 6},
  [2961] = {.lex_state = 92, .external_lex_state = 6},
  [2962] = {.lex_state = 91, .external_lex_state = 4},
  [2963] = {.lex_state = 92, .external_lex_state = 6},
  [2964] = {.lex_state = 92, .external_lex_state = 6},
  [2965] = {.lex_state = 95, .external_lex_state = 6},
  [2966] = {.lex_state = 92, .external_lex_state = 4},
  [2967] = {.lex_state = 95, .external_lex_state = 6},
  [2968] = {.lex_state = 92, .external_lex_state = 6},
  [2969] = {.lex_state = 92, .external_lex_state = 6},
  [2970] = {.lex_state = 92, .external_lex_state = 4},
  [2971] = {.lex_state = 92, .external_lex_state = 6},
  [2972] = {.lex_state = 92, .external_lex_state = 6},
  [2973] = {.lex_state = 92, .external_lex_state = 6},
  [2974] = {.lex_state = 92, .external_lex_state = 6},
  [2975] = {.lex_state = 92, .external_lex_state = 6},
  [2976] = {.lex_state = 92, .external_lex_state = 6},
  [2977] = {.lex_state = 92, .external_lex_state = 6},
  [2978] = {.lex_state = 92, .external_lex_state = 6},
  [2979] = {.lex_state = 92, .external_lex_state = 6},
  [2980] = {.lex_state = 92, .external_lex_state = 6},
  [2981] = {.lex_state = 92, .external_lex_state = 6},
  [2982] = {.lex_state = 92, .external_lex_state = 6},
  [2983] = {.lex_state = 92, .external_lex_state = 4},
  [2984] = {.lex_state = 92, .external_lex_state = 6},
  [2985] = {.lex_state = 92, .external_lex_state = 6},
  [2986] = {.lex_state = 92, .external_lex_state = 6},
  [2987] = {.lex_state = 92, .external_lex_state = 6},
  [2988] = {.lex_state = 92, .external_lex_state = 6},
  [2989] = {.lex_state = 92, .external_lex_state = 4},
  [2990] = {.lex_state = 92, .external_lex_state = 4},
  [2991] = {.lex_state = 91, .external_lex_state = 6},
  [2992] = {.lex_state = 92, .external_lex_state = 4},
  [2993] = {.lex_state = 92, .external_lex_state = 4},
  [2994] = {.lex_state = 91, .external_lex_state = 4},
  [2995] = {.lex_state = 92, .external_lex_state = 6},
  [2996] = {.lex_state = 92, .external_lex_state = 4},
  [2997] = {.lex_state = 92, .external_lex_state = 4},
  [2998] = {.lex_state = 92, .external_lex_state = 6},
  [2999] = {.lex_state = 92, .external_lex_state = 6},
  [3000] = {.lex_state = 92, .external_lex_state = 6},
  [3001] = {.lex_state = 92, .external_lex_state = 6},
  [3002] = {.lex_state = 91, .external_lex_state = 6},
  [3003] = {.lex_state = 92, .external_lex_state = 6},
  [3004] = {.lex_state = 92, .external_lex_state = 6},
  [3005] = {.lex_state = 95, .external_lex_state = 6},
  [3006] = {.lex_state = 92, .external_lex_state = 4},
  [3007] = {.lex_state = 91, .external_lex_state = 4},
  [3008] = {.lex_state = 92, .external_lex_state = 6},
  [3009] = {.lex_state = 92, .external_lex_state = 6},
  [3010] = {.lex_state = 91, .external_lex_state = 4},
  [3011] = {.lex_state = 92, .external_lex_state = 4},
  [3012] = {.lex_state = 92, .external_lex_state = 6},
  [3013] = {.lex_state = 92, .external_lex_state = 6},
  [3014] = {.lex_state = 92, .external_lex_state = 6},
  [3015] = {.lex_state = 92, .external_lex_state = 6},
  [3016] = {.lex_state = 92, .external_lex_state = 6},
  [3017] = {.lex_state = 92, .external_lex_state = 6},
  [3018] = {.lex_state = 92, .external_lex_state = 6},
  [3019] = {.lex_state = 92, .external_lex_state = 6},
  [3020] = {.lex_state = 92, .external_lex_state = 6},
  [3021] = {.lex_state = 92, .external_lex_state = 6},
  [3022] = {.lex_state = 92, .external_lex_state = 6},
  [3023] = {.lex_state = 92, .external_lex_state = 6},
  [3024] = {.lex_state = 92, .external_lex_state = 6},
  [3025] = {.lex_state = 92, .external_lex_state = 4},
  [3026] = {.lex_state = 92, .external_lex_state = 4},
  [3027] = {.lex_state = 92, .external_lex_state = 6},
  [3028] = {.lex_state = 92, .external_lex_state = 6},
  [3029] = {.lex_state = 92, .external_lex_state = 4},
  [3030] = {.lex_state = 92, .external_lex_state = 4},
  [3031] = {.lex_state = 92, .external_lex_state = 4},
  [3032] = {.lex_state = 92, .external_lex_state = 6},
  [3033] = {.lex_state = 92, .external_lex_state = 4},
  [3034] = {.lex_state = 92, .external_lex_state = 6},
  [3035] = {.lex_state = 92, .external_lex_state = 4},
  [3036] = {.lex_state = 92, .external_lex_state = 4},
  [3037] = {.lex_state = 92, .external_lex_state = 4},
  [3038] = {.lex_state = 92, .external_lex_state = 4},
  [3039] = {.lex_state = 92, .external_lex_state = 6},
  [3040] = {.lex_state = 92, .external_lex_state = 4},
  [3041] = {.lex_state = 92, .external_lex_state = 4},
  [3042] = {.lex_state = 91, .external_lex_state = 4},
  [3043] = {.lex_state = 92, .external_lex_state = 6},
  [3044] = {.lex_state = 92, .external_lex_state = 4},
  [3045] = {.lex_state = 92, .external_lex_state = 4},
  [3046] = {.lex_state = 92, .external_lex_state = 6},
  [3047] = {.lex_state = 92, .external_lex_state = 4},
  [3048] = {.lex_state = 92, .external_lex_state = 4},
  [3049] = {.lex_state = 92, .external_lex_state = 4},
  [3050] = {.lex_state = 92, .external_lex_state = 6},
  [3051] = {.lex_state = 92, .external_lex_state = 6},
  [3052] = {.lex_state = 92, .external_lex_state = 4},
  [3053] = {.lex_state = 95, .external_lex_state = 7},
  [3054] = {.lex_state = 92, .external_lex_state = 6},
  [3055] = {.lex_state = 92, .external_lex_state = 6},
  [3056] = {.lex_state = 92, .external_lex_state = 6},
  [3057] = {.lex_state = 92, .external_lex_state = 6},
  [3058] = {.lex_state = 92, .external_lex_state = 6},
  [3059] = {.lex_state = 92, .external_lex_state = 6},
  [3060] = {.lex_state = 92, .external_lex_state = 6},
  [3061] = {.lex_state = 92, .external_lex_state = 6},
  [3062] = {.lex_state = 92, .external_lex_state = 6},
  [3063] = {.lex_state = 92, .external_lex_state = 6},
  [3064] = {.lex_state = 92, .external_lex_state = 6},
  [3065] = {.lex_state = 92, .external_lex_state = 6},
  [3066] = {.lex_state = 92, .external_lex_state = 6},
  [3067] = {.lex_state = 92, .external_lex_state = 6},
  [3068] = {.lex_state = 92, .external_lex_state = 6},
  [3069] = {.lex_state = 92, .external_lex_state = 6},
  [3070] = {.lex_state = 92, .external_lex_state = 6},
  [3071] = {.lex_state = 92, .external_lex_state = 6},
  [3072] = {.lex_state = 92, .external_lex_state = 6},
  [3073] = {.lex_state = 92, .external_lex_state = 6},
  [3074] = {.lex_state = 92, .external_lex_state = 6},
  [3075] = {.lex_state = 92, .external_lex_state = 6},
  [3076] = {.lex_state = 92, .external_lex_state = 6},
  [3077] = {.lex_state = 92, .external_lex_state = 6},
  [3078] = {.lex_state = 92, .external_lex_state = 6},
  [3079] = {.lex_state = 92, .external_lex_state = 6},
  [3080] = {.lex_state = 92, .external_lex_state = 6},
  [3081] = {.lex_state = 92, .external_lex_state = 6},
  [3082] = {.lex_state = 92, .external_lex_state = 6},
  [3083] = {.lex_state = 92, .external_lex_state = 6},
  [3084] = {.lex_state = 92, .external_lex_state = 6},
  [3085] = {.lex_state = 92, .external_lex_state = 6},
  [3086] = {.lex_state = 92, .external_lex_state = 4},
  [3087] = {.lex_state = 92, .external_lex_state = 4},
  [3088] = {.lex_state = 92, .external_lex_state = 4},
  [3089] = {.lex_state = 92, .external_lex_state = 4},
  [3090] = {.lex_state = 92, .external_lex_state = 4},
  [3091] = {.lex_state = 92, .external_lex_state = 4},
  [3092] = {.lex_state = 92, .external_lex_state = 4},
  [3093] = {.lex_state = 92, .external_lex_state = 4},
  [3094] = {.lex_state = 92, .external_lex_state = 4},
  [3095] = {.lex_state = 92, .external_lex_state = 4},
  [3096] = {.lex_state = 92, .external_lex_state = 6},
  [3097] = {.lex_state = 92, .external_lex_state = 4},
  [3098] = {.lex_state = 92, .external_lex_state = 6},
  [3099] = {.lex_state = 92, .external_lex_state = 6},
  [3100] = {.lex_state = 92, .external_lex_state = 6},
  [3101] = {.lex_state = 92, .external_lex_state = 6},
  [3102] = {.lex_state = 92, .external_lex_state = 6},
  [3103] = {.lex_state = 92, .external_lex_state = 6},
  [3104] = {.lex_state = 92, .external_lex_state = 6},
  [3105] = {.lex_state = 92, .external_lex_state = 6},
  [3106] = {.lex_state = 92, .external_lex_state = 6},
  [3107] = {.lex_state = 92, .external_lex_state = 4},
  [3108] = {.lex_state = 92, .external_lex_state = 6},
  [3109] = {.lex_state = 92, .external_lex_state = 6},
  [3110] = {.lex_state = 92, .external_lex_state = 6},
  [3111] = {.lex_state = 92, .external_lex_state = 6},
  [3112] = {.lex_state = 92, .external_lex_state = 6},
  [3113] = {.lex_state = 92, .external_lex_state = 6},
  [3114] = {.lex_state = 92, .external_lex_state = 6},
  [3115] = {.lex_state = 92, .external_lex_state = 6},
  [3116] = {.lex_state = 92, .external_lex_state = 6},
  [3117] = {.lex_state = 92, .external_lex_state = 6},
  [3118] = {.lex_state = 92, .external_lex_state = 6},
  [3119] = {.lex_state = 92, .external_lex_state = 6},
  [3120] = {.lex_state = 92, .external_lex_state = 6},
  [3121] = {.lex_state = 92, .external_lex_state = 6},
  [3122] = {.lex_state = 92, .external_lex_state = 6},
  [3123] = {.lex_state = 92, .external_lex_state = 6},
  [3124] = {.lex_state = 92, .external_lex_state = 6},
  [3125] = {.lex_state = 92, .external_lex_state = 6},
  [3126] = {.lex_state = 92, .external_lex_state = 6},
  [3127] = {.lex_state = 92, .external_lex_state = 6},
  [3128] = {.lex_state = 92, .external_lex_state = 6},
  [3129] = {.lex_state = 92, .external_lex_state = 6},
  [3130] = {.lex_state = 92, .external_lex_state = 6},
  [3131] = {.lex_state = 92, .external_lex_state = 6},
  [3132] = {.lex_state = 91, .external_lex_state = 8},
  [3133] = {.lex_state = 92, .external_lex_state = 6},
  [3134] = {.lex_state = 92, .external_lex_state = 6},
  [3135] = {.lex_state = 92, .external_lex_state = 6},
  [3136] = {.lex_state = 92, .external_lex_state = 6},
  [3137] = {.lex_state = 92, .external_lex_state = 6},
  [3138] = {.lex_state = 92, .external_lex_state = 6},
  [3139] = {.lex_state = 92, .external_lex_state = 6},
  [3140] = {.lex_state = 92, .external_lex_state = 6},
  [3141] = {.lex_state = 92, .external_lex_state = 6},
  [3142] = {.lex_state = 92, .external_lex_state = 6},
  [3143] = {.lex_state = 92, .external_lex_state = 6},
  [3144] = {.lex_state = 92, .external_lex_state = 6},
  [3145] = {.lex_state = 92, .external_lex_state = 6},
  [3146] = {.lex_state = 92, .external_lex_state = 6},
  [3147] = {.lex_state = 92, .external_lex_state = 6},
  [3148] = {.lex_state = 92, .external_lex_state = 6},
  [3149] = {.lex_state = 92, .external_lex_state = 6},
  [3150] = {.lex_state = 92, .external_lex_state = 6},
  [3151] = {.lex_state = 92, .external_lex_state = 6},
  [3152] = {.lex_state = 92, .external_lex_state = 6},
  [3153] = {.lex_state = 92, .external_lex_state = 6},
  [3154] = {.lex_state = 92, .external_lex_state = 6},
  [3155] = {.lex_state = 92, .external_lex_state = 6},
  [3156] = {.lex_state = 92, .external_lex_state = 4},
  [3157] = {.lex_state = 92, .external_lex_state = 4},
  [3158] = {.lex_state = 92, .external_lex_state = 4},
  [3159] = {.lex_state = 92, .external_lex_state = 6},
  [3160] = {.lex_state = 92, .external_lex_state = 4},
  [3161] = {.lex_state = 92, .external_lex_state = 4},
  [3162] = {.lex_state = 92, .external_lex_state = 4},
  [3163] = {.lex_state = 92, .external_lex_state = 6},
  [3164] = {.lex_state = 92, .external_lex_state = 4},
  [3165] = {.lex_state = 92, .external_lex_state = 6},
  [3166] = {.lex_state = 92, .external_lex_state = 6},
  [3167] = {.lex_state = 92, .external_lex_state = 6},
  [3168] = {.lex_state = 92, .external_lex_state = 4},
  [3169] = {.lex_state = 92, .external_lex_state = 6},
  [3170] = {.lex_state = 92, .external_lex_state = 6},
  [3171] = {.lex_state = 92, .external_lex_state = 6},
  [3172] = {.lex_state = 92, .external_lex_state = 4},
  [3173] = {.lex_state = 92, .external_lex_state = 6},
  [3174] = {.lex_state = 92, .external_lex_state = 4},
  [3175] = {.lex_state = 92, .external_lex_state = 4},
  [3176] = {.lex_state = 92, .external_lex_state = 4},
  [3177] = {.lex_state = 92, .external_lex_state = 4},
  [3178] = {.lex_state = 92, .external_lex_state = 4},
  [3179] = {.lex_state = 92, .external_lex_state = 6},
  [3180] = {.lex_state = 92, .external_lex_state = 6},
  [3181] = {.lex_state = 92, .external_lex_state = 6},
  [3182] = {.lex_state = 92, .external_lex_state = 6},
  [3183] = {.lex_state = 92, .external_lex_state = 6},
  [3184] = {.lex_state = 92, .external_lex_state = 6},
  [3185] = {.lex_state = 92, .external_lex_state = 6},
  [3186] = {.lex_state = 92, .external_lex_state = 6},
  [3187] = {.lex_state = 92, .external_lex_state = 6},
  [3188] = {.lex_state = 92, .external_lex_state = 6},
  [3189] = {.lex_state = 92, .external_lex_state = 6},
  [3190] = {.lex_state = 92, .external_lex_state = 6},
  [3191] = {.lex_state = 92, .external_lex_state = 6},
  [3192] = {.lex_state = 92, .external_lex_state = 6},
  [3193] = {.lex_state = 92, .external_lex_state = 4},
  [3194] = {.lex_state = 92, .external_lex_state = 6},
  [3195] = {.lex_state = 92, .external_lex_state = 6},
  [3196] = {.lex_state = 92, .external_lex_state = 6},
  [3197] = {.lex_state = 92, .external_lex_state = 6},
  [3198] = {.lex_state = 92, .external_lex_state = 6},
  [3199] = {.lex_state = 92, .external_lex_state = 6},
  [3200] = {.lex_state = 92, .external_lex_state = 6},
  [3201] = {.lex_state = 92, .external_lex_state = 6},
  [3202] = {.lex_state = 92, .external_lex_state = 6},
  [3203] = {.lex_state = 92, .external_lex_state = 6},
  [3204] = {.lex_state = 92, .external_lex_state = 6},
  [3205] = {.lex_state = 92, .external_lex_state = 6},
  [3206] = {.lex_state = 92, .external_lex_state = 6},
  [3207] = {.lex_state = 92, .external_lex_state = 6},
  [3208] = {.lex_state = 92, .external_lex_state = 6},
  [3209] = {.lex_state = 92, .external_lex_state = 4},
  [3210] = {.lex_state = 92, .external_lex_state = 4},
  [3211] = {.lex_state = 92, .external_lex_state = 4},
  [3212] = {.lex_state = 92, .external_lex_state = 4},
  [3213] = {.lex_state = 92, .external_lex_state = 4},
  [3214] = {.lex_state = 92, .external_lex_state = 4},
  [3215] = {.lex_state = 92, .external_lex_state = 4},
  [3216] = {.lex_state = 92, .external_lex_state = 4},
  [3217] = {.lex_state = 92, .external_lex_state = 6},
  [3218] = {.lex_state = 88, .external_lex_state = 4},
  [3219] = {.lex_state = 92, .external_lex_state = 6},
  [3220] = {.lex_state = 92, .external_lex_state = 6},
  [3221] = {.lex_state = 92, .external_lex_state = 4},
  [3222] = {.lex_state = 92, .external_lex_state = 6},
  [3223] = {.lex_state = 92, .external_lex_state = 6},
  [3224] = {.lex_state = 92, .external_lex_state = 6},
  [3225] = {.lex_state = 88, .external_lex_state = 8},
  [3226] = {.lex_state = 88, .external_lex_state = 4},
  [3227] = {.lex_state = 88, .external_lex_state = 8},
  [3228] = {.lex_state = 92, .external_lex_state = 4},
  [3229] = {.lex_state = 92, .external_lex_state = 4},
  [3230] = {.lex_state = 92, .external_lex_state = 6},
  [3231] = {.lex_state = 92, .external_lex_state = 4},
  [3232] = {.lex_state = 92, .external_lex_state = 4},
  [3233] = {.lex_state = 92, .external_lex_state = 4},
  [3234] = {.lex_state = 92, .external_lex_state = 6},
  [3235] = {.lex_state = 92, .external_lex_state = 4},
  [3236] = {.lex_state = 92, .external_lex_state = 6},
  [3237] = {.lex_state = 92, .external_lex_state = 4},
  [3238] = {.lex_state = 88, .external_lex_state = 8},
  [3239] = {.lex_state = 92, .external_lex_state = 4},
  [3240] = {.lex_state = 92, .external_lex_state = 6},
  [3241] = {.lex_state = 92, .external_lex_state = 4},
  [3242] = {.lex_state = 92, .external_lex_state = 6},
  [3243] = {.lex_state = 92, .external_lex_state = 6},
  [3244] = {.lex_state = 92, .external_lex_state = 6},
  [3245] = {.lex_state = 92, .external_lex_state = 6},
  [3246] = {.lex_state = 92, .external_lex_state = 4},
  [3247] = {.lex_state = 92, .external_lex_state = 4},
  [3248] = {.lex_state = 92, .external_lex_state = 8},
  [3249] = {.lex_state = 92, .external_lex_state = 8},
  [3250] = {.lex_state = 92, .external_lex_state = 8},
  [3251] = {.lex_state = 92, .external_lex_state = 8},
  [3252] = {.lex_state = 92, .external_lex_state = 8},
  [3253] = {.lex_state = 92, .external_lex_state = 8},
  [3254] = {.lex_state = 92, .external_lex_state = 8},
  [3255] = {.lex_state = 92, .external_lex_state = 8},
  [3256] = {.lex_state = 92, .external_lex_state = 8},
  [3257] = {.lex_state = 92, .external_lex_state = 8},
  [3258] = {.lex_state = 92, .external_lex_state = 8},
  [3259] = {.lex_state = 88, .external_lex_state = 4},
  [3260] = {.lex_state = 92, .external_lex_state = 6},
  [3261] = {.lex_state = 92, .external_lex_state = 4},
  [3262] = {.lex_state = 88, .external_lex_state = 8},
  [3263] = {.lex_state = 92, .external_lex_state = 4},
  [3264] = {.lex_state = 92, .external_lex_state = 4},
  [3265] = {.lex_state = 92, .external_lex_state = 4},
  [3266] = {.lex_state = 92, .external_lex_state = 4},
  [3267] = {.lex_state = 92, .external_lex_state = 4},
  [3268] = {.lex_state = 92, .external_lex_state = 4},
  [3269] = {.lex_state = 92, .external_lex_state = 4},
  [3270] = {.lex_state = 92, .external_lex_state = 4},
  [3271] = {.lex_state = 92, .external_lex_state = 4},
  [3272] = {.lex_state = 92, .external_lex_state = 4},
  [3273] = {.lex_state = 92, .external_lex_state = 6},
  [3274] = {.lex_state = 92, .external_lex_state = 4},
  [3275] = {.lex_state = 92, .external_lex_state = 6},
  [3276] = {.lex_state = 92, .external_lex_state = 6},
  [3277] = {.lex_state = 92, .external_lex_state = 6},
  [3278] = {.lex_state = 92, .external_lex_state = 4},
  [3279] = {.lex_state = 92, .external_lex_state = 4},
  [3280] = {.lex_state = 92, .external_lex_state = 4},
  [3281] = {.lex_state = 92, .external_lex_state = 6},
  [3282] = {.lex_state = 92, .external_lex_state = 4},
  [3283] = {.lex_state = 92, .external_lex_state = 4},
  [3284] = {.lex_state = 92, .external_lex_state = 4},
  [3285] = {.lex_state = 92, .external_lex_state = 6},
  [3286] = {.lex_state = 92, .external_lex_state = 4},
  [3287] = {.lex_state = 92, .external_lex_state = 4},
  [3288] = {.lex_state = 92, .external_lex_state = 4},
  [3289] = {.lex_state = 92, .external_lex_state = 4},
  [3290] = {.lex_state = 92, .external_lex_state = 6},
  [3291] = {.lex_state = 92, .external_lex_state = 4},
  [3292] = {.lex_state = 92, .external_lex_state = 4},
  [3293] = {.lex_state = 92, .external_lex_state = 4},
  [3294] = {.lex_state = 92, .external_lex_state = 6},
  [3295] = {.lex_state = 92, .external_lex_state = 6},
  [3296] = {.lex_state = 92, .external_lex_state = 4},
  [3297] = {.lex_state = 92, .external_lex_state = 4},
  [3298] = {.lex_state = 92, .external_lex_state = 4},
  [3299] = {.lex_state = 92, .external_lex_state = 4},
  [3300] = {.lex_state = 92, .external_lex_state = 4},
  [3301] = {.lex_state = 92, .external_lex_state = 4},
  [3302] = {.lex_state = 95, .external_lex_state = 7},
  [3303] = {.lex_state = 92, .external_lex_state = 4},
  [3304] = {.lex_state = 92, .external_lex_state = 4},
  [3305] = {.lex_state = 92, .external_lex_state = 4},
  [3306] = {.lex_state = 92, .external_lex_state = 4},
  [3307] = {.lex_state = 92, .external_lex_state = 4},
  [3308] = {.lex_state = 92, .external_lex_state = 4},
  [3309] = {.lex_state = 92, .external_lex_state = 4},
  [3310] = {.lex_state = 92, .external_lex_state = 4},
  [3311] = {.lex_state = 92, .external_lex_state = 4},
  [3312] = {.lex_state = 92, .external_lex_state = 4},
  [3313] = {.lex_state = 92, .external_lex_state = 6},
  [3314] = {.lex_state = 92, .external_lex_state = 6},
  [3315] = {.lex_state = 92, .external_lex_state = 4},
  [3316] = {.lex_state = 92, .external_lex_state = 4},
  [3317] = {.lex_state = 92, .external_lex_state = 6},
  [3318] = {.lex_state = 92, .external_lex_state = 6},
  [3319] = {.lex_state = 88, .external_lex_state = 8},
  [3320] = {.lex_state = 92, .external_lex_state = 6},
  [3321] = {.lex_state = 92, .external_lex_state = 4},
  [3322] = {.lex_state = 91, .external_lex_state = 8},
  [3323] = {.lex_state = 92, .external_lex_state = 4},
  [3324] = {.lex_state = 92, .external_lex_state = 4},
  [3325] = {.lex_state = 92, .external_lex_state = 6},
  [3326] = {.lex_state = 92, .external_lex_state = 4},
  [3327] = {.lex_state = 92, .external_lex_state = 4},
  [3328] = {.lex_state = 92, .external_lex_state = 4},
  [3329] = {.lex_state = 92, .external_lex_state = 4},
  [3330] = {.lex_state = 92, .external_lex_state = 4},
  [3331] = {.lex_state = 92, .external_lex_state = 6},
  [3332] = {.lex_state = 92, .external_lex_state = 4},
  [3333] = {.lex_state = 92, .external_lex_state = 6},
  [3334] = {.lex_state = 92, .external_lex_state = 4},
  [3335] = {.lex_state = 91, .external_lex_state = 8},
  [3336] = {.lex_state = 92, .external_lex_state = 6},
  [3337] = {.lex_state = 92, .external_lex_state = 4},
  [3338] = {.lex_state = 92, .external_lex_state = 4},
  [3339] = {.lex_state = 92, .external_lex_state = 4},
  [3340] = {.lex_state = 92, .external_lex_state = 4},
  [3341] = {.lex_state = 92, .external_lex_state = 4},
  [3342] = {.lex_state = 92, .external_lex_state = 4},
  [3343] = {.lex_state = 92, .external_lex_state = 4},
  [3344] = {.lex_state = 92, .external_lex_state = 4},
  [3345] = {.lex_state = 92, .external_lex_state = 4},
  [3346] = {.lex_state = 92, .external_lex_state = 4},
  [3347] = {.lex_state = 92, .external_lex_state = 6},
  [3348] = {.lex_state = 92, .external_lex_state = 4},
  [3349] = {.lex_state = 92, .external_lex_state = 4},
  [3350] = {.lex_state = 92, .external_lex_state = 4},
  [3351] = {.lex_state = 92, .external_lex_state = 4},
  [3352] = {.lex_state = 92, .external_lex_state = 4},
  [3353] = {.lex_state = 92, .external_lex_state = 4},
  [3354] = {.lex_state = 92, .external_lex_state = 4},
  [3355] = {.lex_state = 92, .external_lex_state = 4},
  [3356] = {.lex_state = 92, .external_lex_state = 4},
  [3357] = {.lex_state = 92, .external_lex_state = 4},
  [3358] = {.lex_state = 92, .external_lex_state = 6},
  [3359] = {.lex_state = 92, .external_lex_state = 4},
  [3360] = {.lex_state = 92, .external_lex_state = 4},
  [3361] = {.lex_state = 92, .external_lex_state = 4},
  [3362] = {.lex_state = 92, .external_lex_state = 6},
  [3363] = {.lex_state = 88, .external_lex_state = 8},
  [3364] = {.lex_state = 92, .external_lex_state = 4},
  [3365] = {.lex_state = 92, .external_lex_state = 4},
  [3366] = {.lex_state = 92, .external_lex_state = 4},
  [3367] = {.lex_state = 92, .external_lex_state = 4},
  [3368] = {.lex_state = 92, .external_lex_state = 4},
  [3369] = {.lex_state = 92, .external_lex_state = 4},
  [3370] = {.lex_state = 92, .external_lex_state = 4},
  [3371] = {.lex_state = 92, .external_lex_state = 4},
  [3372] = {.lex_state = 92, .external_lex_state = 4},
  [3373] = {.lex_state = 92, .external_lex_state = 4},
  [3374] = {.lex_state = 92, .external_lex_state = 4},
  [3375] = {.lex_state = 92, .external_lex_state = 4},
  [3376] = {.lex_state = 92, .external_lex_state = 4},
  [3377] = {.lex_state = 92, .external_lex_state = 4},
  [3378] = {.lex_state = 92, .external_lex_state = 4},
  [3379] = {.lex_state = 91, .external_lex_state = 8},
  [3380] = {.lex_state = 92, .external_lex_state = 4},
  [3381] = {.lex_state = 92, .external_lex_state = 4},
  [3382] = {.lex_state = 88, .external_lex_state = 4},
  [3383] = {.lex_state = 88, .external_lex_state = 4},
  [3384] = {.lex_state = 92, .external_lex_state = 4},
  [3385] = {.lex_state = 92, .external_lex_state = 6},
  [3386] = {.lex_state = 92, .external_lex_state = 4},
  [3387] = {.lex_state = 92, .external_lex_state = 4},
  [3388] = {.lex_state = 92, .external_lex_state = 4},
  [3389] = {.lex_state = 92, .external_lex_state = 4},
  [3390] = {.lex_state = 92, .external_lex_state = 4},
  [3391] = {.lex_state = 92, .external_lex_state = 4},
  [3392] = {.lex_state = 92, .external_lex_state = 4},
  [3393] = {.lex_state = 92, .external_lex_state = 4},
  [3394] = {.lex_state = 92, .external_lex_state = 4},
  [3395] = {.lex_state = 92, .external_lex_state = 4},
  [3396] = {.lex_state = 92, .external_lex_state = 4},
  [3397] = {.lex_state = 92, .external_lex_state = 4},
  [3398] = {.lex_state = 92, .external_lex_state = 4},
  [3399] = {.lex_state = 92, .external_lex_state = 4},
  [3400] = {.lex_state = 92, .external_lex_state = 4},
  [3401] = {.lex_state = 88, .external_lex_state = 4},
  [3402] = {.lex_state = 92, .external_lex_state = 4},
  [3403] = {.lex_state = 92, .external_lex_state = 4},
  [3404] = {.lex_state = 95, .external_lex_state = 7},
  [3405] = {.lex_state = 92, .external_lex_state = 4},
  [3406] = {.lex_state = 92, .external_lex_state = 4},
  [3407] = {.lex_state = 92, .external_lex_state = 4},
  [3408] = {.lex_state = 92, .external_lex_state = 4},
  [3409] = {.lex_state = 92, .external_lex_state = 4},
  [3410] = {.lex_state = 92, .external_lex_state = 4},
  [3411] = {.lex_state = 92, .external_lex_state = 4},
  [3412] = {.lex_state = 92, .external_lex_state = 4},
  [3413] = {.lex_state = 92, .external_lex_state = 4},
  [3414] = {.lex_state = 92, .external_lex_state = 4},
  [3415] = {.lex_state = 92, .external_lex_state = 6},
  [3416] = {.lex_state = 92, .external_lex_state = 4},
  [3417] = {.lex_state = 92, .external_lex_state = 4},
  [3418] = {.lex_state = 88, .external_lex_state = 8},
  [3419] = {.lex_state = 88, .external_lex_state = 4},
  [3420] = {.lex_state = 92, .external_lex_state = 4},
  [3421] = {.lex_state = 92, .external_lex_state = 4},
  [3422] = {.lex_state = 92, .external_lex_state = 4},
  [3423] = {.lex_state = 92, .external_lex_state = 4},
  [3424] = {.lex_state = 92, .external_lex_state = 4},
  [3425] = {.lex_state = 92, .external_lex_state = 4},
  [3426] = {.lex_state = 92, .external_lex_state = 6},
  [3427] = {.lex_state = 92, .external_lex_state = 4},
  [3428] = {.lex_state = 92, .external_lex_state = 4},
  [3429] = {.lex_state = 92, .external_lex_state = 4},
  [3430] = {.lex_state = 92, .external_lex_state = 4},
  [3431] = {.lex_state = 92, .external_lex_state = 4},
  [3432] = {.lex_state = 92, .external_lex_state = 4},
  [3433] = {.lex_state = 92, .external_lex_state = 4},
  [3434] = {.lex_state = 92, .external_lex_state = 4},
  [3435] = {.lex_state = 92, .external_lex_state = 4},
  [3436] = {.lex_state = 92, .external_lex_state = 4},
  [3437] = {.lex_state = 92, .external_lex_state = 4},
  [3438] = {.lex_state = 92, .external_lex_state = 4},
  [3439] = {.lex_state = 92, .external_lex_state = 8},
  [3440] = {.lex_state = 92, .external_lex_state = 4},
  [3441] = {.lex_state = 92, .external_lex_state = 8},
  [3442] = {.lex_state = 92, .external_lex_state = 6},
  [3443] = {.lex_state = 92, .external_lex_state = 8},
  [3444] = {.lex_state = 92, .external_lex_state = 8},
  [3445] = {.lex_state = 92, .external_lex_state = 6},
  [3446] = {.lex_state = 92, .external_lex_state = 6},
  [3447] = {.lex_state = 92, .external_lex_state = 8},
  [3448] = {.lex_state = 92, .external_lex_state = 6},
  [3449] = {.lex_state = 96, .external_lex_state = 6},
  [3450] = {.lex_state = 92, .external_lex_state = 8},
  [3451] = {.lex_state = 92, .external_lex_state = 8},
  [3452] = {.lex_state = 92, .external_lex_state = 4},
  [3453] = {.lex_state = 92, .external_lex_state = 4},
  [3454] = {.lex_state = 92, .external_lex_state = 6},
  [3455] = {.lex_state = 92, .external_lex_state = 8},
  [3456] = {.lex_state = 92, .external_lex_state = 8},
  [3457] = {.lex_state = 88, .external_lex_state = 6},
  [3458] = {.lex_state = 92, .external_lex_state = 4},
  [3459] = {.lex_state = 92, .external_lex_state = 8},
  [3460] = {.lex_state = 92, .external_lex_state = 8},
  [3461] = {.lex_state = 91, .external_lex_state = 8},
  [3462] = {.lex_state = 88, .external_lex_state = 6},
  [3463] = {.lex_state = 92, .external_lex_state = 8},
  [3464] = {.lex_state = 92, .external_lex_state = 8},
  [3465] = {.lex_state = 92, .external_lex_state = 4},
  [3466] = {.lex_state = 92, .external_lex_state = 4},
  [3467] = {.lex_state = 88, .external_lex_state = 6},
  [3468] = {.lex_state = 92, .external_lex_state = 8},
  [3469] = {.lex_state = 92, .external_lex_state = 8},
  [3470] = {.lex_state = 92, .external_lex_state = 8},
  [3471] = {.lex_state = 92, .external_lex_state = 8},
  [3472] = {.lex_state = 92, .external_lex_state = 8},
  [3473] = {.lex_state = 92, .external_lex_state = 8},
  [3474] = {.lex_state = 95, .external_lex_state = 7},
  [3475] = {.lex_state = 92, .external_lex_state = 8},
  [3476] = {.lex_state = 92, .external_lex_state = 8},
  [3477] = {.lex_state = 92, .external_lex_state = 6},
  [3478] = {.lex_state = 92, .external_lex_state = 6},
  [3479] = {.lex_state = 92, .external_lex_state = 4},
  [3480] = {.lex_state = 88, .external_lex_state = 6},
  [3481] = {.lex_state = 92, .external_lex_state = 8},
  [3482] = {.lex_state = 92, .external_lex_state = 6},
  [3483] = {.lex_state = 92, .external_lex_state = 4},
  [3484] = {.lex_state = 92, .external_lex_state = 8},
  [3485] = {.lex_state = 92, .external_lex_state = 8},
  [3486] = {.lex_state = 92, .external_lex_state = 8},
  [3487] = {.lex_state = 92, .external_lex_state = 8},
  [3488] = {.lex_state = 88, .external_lex_state = 6},
  [3489] = {.lex_state = 92, .external_lex_state = 8},
  [3490] = {.lex_state = 92, .external_lex_state = 6},
  [3491] = {.lex_state = 92, .external_lex_state = 4},
  [3492] = {.lex_state = 92, .external_lex_state = 8},
  [3493] = {.lex_state = 92, .external_lex_state = 8},
  [3494] = {.lex_state = 92, .external_lex_state = 6},
  [3495] = {.lex_state = 92, .external_lex_state = 6},
  [3496] = {.lex_state = 92, .external_lex_state = 6},
  [3497] = {.lex_state = 92, .external_lex_state = 8},
  [3498] = {.lex_state = 92, .external_lex_state = 4},
  [3499] = {.lex_state = 92, .external_lex_state = 8},
  [3500] = {.lex_state = 92, .external_lex_state = 8},
  [3501] = {.lex_state = 88, .external_lex_state = 6},
  [3502] = {.lex_state = 92, .external_lex_state = 8},
  [3503] = {.lex_state = 92, .external_lex_state = 8},
  [3504] = {.lex_state = 92, .external_lex_state = 4},
  [3505] = {.lex_state = 92, .external_lex_state = 8},
  [3506] = {.lex_state = 92, .external_lex_state = 6},
  [3507] = {.lex_state = 96, .external_lex_state = 6},
  [3508] = {.lex_state = 92, .external_lex_state = 4},
  [3509] = {.lex_state = 92, .external_lex_state = 8},
  [3510] = {.lex_state = 92, .external_lex_state = 6},
  [3511] = {.lex_state = 92, .external_lex_state = 8},
  [3512] = {.lex_state = 97, .external_lex_state = 6},
  [3513] = {.lex_state = 92, .external_lex_state = 8},
  [3514] = {.lex_state = 92, .external_lex_state = 8},
  [3515] = {.lex_state = 96, .external_lex_state = 6},
  [3516] = {.lex_state = 92, .external_lex_state = 8},
  [3517] = {.lex_state = 92, .external_lex_state = 8},
  [3518] = {.lex_state = 92, .external_lex_state = 8},
  [3519] = {.lex_state = 92, .external_lex_state = 8},
  [3520] = {.lex_state = 92, .external_lex_state = 4},
  [3521] = {.lex_state = 92, .external_lex_state = 8},
  [3522] = {.lex_state = 88, .external_lex_state = 6},
  [3523] = {.lex_state = 92, .external_lex_state = 8},
  [3524] = {.lex_state = 92, .external_lex_state = 8},
  [3525] = {.lex_state = 92, .external_lex_state = 8},
  [3526] = {.lex_state = 92, .external_lex_state = 8},
  [3527] = {.lex_state = 92, .external_lex_state = 8},
  [3528] = {.lex_state = 92, .external_lex_state = 8},
  [3529] = {.lex_state = 92, .external_lex_state = 8},
  [3530] = {.lex_state = 92, .external_lex_state = 8},
  [3531] = {.lex_state = 92, .external_lex_state = 8},
  [3532] = {.lex_state = 92, .external_lex_state = 8},
  [3533] = {.lex_state = 92, .external_lex_state = 8},
  [3534] = {.lex_state = 92, .external_lex_state = 8},
  [3535] = {.lex_state = 96, .external_lex_state = 4},
  [3536] = {.lex_state = 92, .external_lex_state = 8},
  [3537] = {.lex_state = 92, .external_lex_state = 8},
  [3538] = {.lex_state = 92, .external_lex_state = 8},
  [3539] = {.lex_state = 92, .external_lex_state = 8},
  [3540] = {.lex_state = 92, .external_lex_state = 8},
  [3541] = {.lex_state = 92, .external_lex_state = 8},
  [3542] = {.lex_state = 96, .external_lex_state = 4},
  [3543] = {.lex_state = 92, .external_lex_state = 8},
  [3544] = {.lex_state = 92, .external_lex_state = 8},
  [3545] = {.lex_state = 92, .external_lex_state = 8},
  [3546] = {.lex_state = 92, .external_lex_state = 8},
  [3547] = {.lex_state = 92, .external_lex_state = 8},
  [3548] = {.lex_state = 92, .external_lex_state = 8},
  [3549] = {.lex_state = 92, .external_lex_state = 8},
  [3550] = {.lex_state = 92, .external_lex_state = 8},
  [3551] = {.lex_state = 92, .external_lex_state = 8},
  [3552] = {.lex_state = 92, .external_lex_state = 8},
  [3553] = {.lex_state = 92, .external_lex_state = 8},
  [3554] = {.lex_state = 92, .external_lex_state = 8},
  [3555] = {.lex_state = 92, .external_lex_state = 8},
  [3556] = {.lex_state = 92, .external_lex_state = 8},
  [3557] = {.lex_state = 92, .external_lex_state = 8},
  [3558] = {.lex_state = 92, .external_lex_state = 8},
  [3559] = {.lex_state = 92, .external_lex_state = 8},
  [3560] = {.lex_state = 92, .external_lex_state = 8},
  [3561] = {.lex_state = 92, .external_lex_state = 8},
  [3562] = {.lex_state = 92, .external_lex_state = 8},
  [3563] = {.lex_state = 92, .external_lex_state = 8},
  [3564] = {.lex_state = 92, .external_lex_state = 8},
  [3565] = {.lex_state = 92, .external_lex_state = 8},
  [3566] = {.lex_state = 92, .external_lex_state = 8},
  [3567] = {.lex_state = 92, .external_lex_state = 8},
  [3568] = {.lex_state = 92, .external_lex_state = 8},
  [3569] = {.lex_state = 97, .external_lex_state = 4},
  [3570] = {.lex_state = 92, .external_lex_state = 8},
  [3571] = {.lex_state = 97, .external_lex_state = 4},
  [3572] = {.lex_state = 92, .external_lex_state = 8},
  [3573] = {.lex_state = 97, .external_lex_state = 6},
  [3574] = {.lex_state = 97, .external_lex_state = 6},
  [3575] = {.lex_state = 95, .external_lex_state = 7},
  [3576] = {.lex_state = 92, .external_lex_state = 8},
  [3577] = {.lex_state = 92, .external_lex_state = 8},
  [3578] = {.lex_state = 92, .external_lex_state = 4},
  [3579] = {.lex_state = 92, .external_lex_state = 4},
  [3580] = {.lex_state = 92, .external_lex_state = 4},
  [3581] = {.lex_state = 92, .external_lex_state = 8},
  [3582] = {.lex_state = 92, .external_lex_state = 8},
  [3583] = {.lex_state = 92, .external_lex_state = 8},
  [3584] = {.lex_state = 92, .external_lex_state = 8},
  [3585] = {.lex_state = 92, .external_lex_state = 8},
  [3586] = {.lex_state = 92, .external_lex_state = 4},
  [3587] = {.lex_state = 92, .external_lex_state = 8},
  [3588] = {.lex_state = 92, .external_lex_state = 8},
  [3589] = {.lex_state = 92, .external_lex_state = 4},
  [3590] = {.lex_state = 92, .external_lex_state = 4},
  [3591] = {.lex_state = 92, .external_lex_state = 8},
  [3592] = {.lex_state = 92, .external_lex_state = 8},
  [3593] = {.lex_state = 92, .external_lex_state = 8},
  [3594] = {.lex_state = 92, .external_lex_state = 8},
  [3595] = {.lex_state = 92, .external_lex_state = 4},
  [3596] = {.lex_state = 97, .external_lex_state = 4},
  [3597] = {.lex_state = 92, .external_lex_state = 8},
  [3598] = {.lex_state = 92, .external_lex_state = 8},
  [3599] = {.lex_state = 92, .external_lex_state = 8},
  [3600] = {.lex_state = 92, .external_lex_state = 8},
  [3601] = {.lex_state = 92, .external_lex_state = 8},
  [3602] = {.lex_state = 92, .external_lex_state = 8},
  [3603] = {.lex_state = 92, .external_lex_state = 8},
  [3604] = {.lex_state = 92, .external_lex_state = 8},
  [3605] = {.lex_state = 97, .external_lex_state = 6},
  [3606] = {.lex_state = 96, .external_lex_state = 7},
  [3607] = {.lex_state = 92, .external_lex_state = 8},
  [3608] = {.lex_state = 92, .external_lex_state = 8},
  [3609] = {.lex_state = 92, .external_lex_state = 8},
  [3610] = {.lex_state = 92, .external_lex_state = 8},
  [3611] = {.lex_state = 92, .external_lex_state = 8},
  [3612] = {.lex_state = 92, .external_lex_state = 8},
  [3613] = {.lex_state = 92, .external_lex_state = 8},
  [3614] = {.lex_state = 92, .external_lex_state = 8},
  [3615] = {.lex_state = 96, .external_lex_state = 5},
  [3616] = {.lex_state = 96, .external_lex_state = 4},
  [3617] = {.lex_state = 92, .external_lex_state = 8},
  [3618] = {.lex_state = 92, .external_lex_state = 8},
  [3619] = {.lex_state = 92, .external_lex_state = 8},
  [3620] = {.lex_state = 92, .external_lex_state = 8},
  [3621] = {.lex_state = 92, .external_lex_state = 8},
  [3622] = {.lex_state = 92, .external_lex_state = 8},
  [3623] = {.lex_state = 92, .external_lex_state = 8},
  [3624] = {.lex_state = 92, .external_lex_state = 8},
  [3625] = {.lex_state = 92, .external_lex_state = 8},
  [3626] = {.lex_state = 92, .external_lex_state = 8},
  [3627] = {.lex_state = 92, .external_lex_state = 8},
  [3628] = {.lex_state = 92, .external_lex_state = 8},
  [3629] = {.lex_state = 92, .external_lex_state = 8},
  [3630] = {.lex_state = 92, .external_lex_state = 8},
  [3631] = {.lex_state = 92, .external_lex_state = 8},
  [3632] = {.lex_state = 92, .external_lex_state = 8},
  [3633] = {.lex_state = 92, .external_lex_state = 8},
  [3634] = {.lex_state = 92, .external_lex_state = 8},
  [3635] = {.lex_state = 92, .external_lex_state = 8},
  [3636] = {.lex_state = 96, .external_lex_state = 5},
  [3637] = {.lex_state = 92, .external_lex_state = 8},
  [3638] = {.lex_state = 92, .external_lex_state = 8},
  [3639] = {.lex_state = 92, .external_lex_state = 8},
  [3640] = {.lex_state = 92, .external_lex_state = 8},
  [3641] = {.lex_state = 92, .external_lex_state = 8},
  [3642] = {.lex_state = 92, .external_lex_state = 8},
  [3643] = {.lex_state = 92, .external_lex_state = 8},
  [3644] = {.lex_state = 92, .external_lex_state = 8},
  [3645] = {.lex_state = 92, .external_lex_state = 8},
  [3646] = {.lex_state = 92, .external_lex_state = 8},
  [3647] = {.lex_state = 96, .external_lex_state = 5},
  [3648] = {.lex_state = 92, .external_lex_state = 8},
  [3649] = {.lex_state = 92, .external_lex_state = 8},
  [3650] = {.lex_state = 92, .external_lex_state = 8},
  [3651] = {.lex_state = 92, .external_lex_state = 8},
  [3652] = {.lex_state = 92, .external_lex_state = 8},
  [3653] = {.lex_state = 92, .external_lex_state = 8},
  [3654] = {.lex_state = 92, .external_lex_state = 8},
  [3655] = {.lex_state = 92, .external_lex_state = 8},
  [3656] = {.lex_state = 92, .external_lex_state = 8},
  [3657] = {.lex_state = 92, .external_lex_state = 8},
  [3658] = {.lex_state = 92, .external_lex_state = 8},
  [3659] = {.lex_state = 92, .external_lex_state = 8},
  [3660] = {.lex_state = 92, .external_lex_state = 8},
  [3661] = {.lex_state = 92, .external_lex_state = 8},
  [3662] = {.lex_state = 92, .external_lex_state = 8},
  [3663] = {.lex_state = 92, .external_lex_state = 8},
  [3664] = {.lex_state = 92, .external_lex_state = 8},
  [3665] = {.lex_state = 92, .external_lex_state = 8},
  [3666] = {.lex_state = 92, .external_lex_state = 8},
  [3667] = {.lex_state = 92, .external_lex_state = 8},
  [3668] = {.lex_state = 92, .external_lex_state = 4},
  [3669] = {.lex_state = 92, .external_lex_state = 8},
  [3670] = {.lex_state = 92, .external_lex_state = 8},
  [3671] = {.lex_state = 92, .external_lex_state = 8},
  [3672] = {.lex_state = 92, .external_lex_state = 8},
  [3673] = {.lex_state = 92, .external_lex_state = 8},
  [3674] = {.lex_state = 92, .external_lex_state = 8},
  [3675] = {.lex_state = 92, .external_lex_state = 8},
  [3676] = {.lex_state = 92, .external_lex_state = 8},
  [3677] = {.lex_state = 92, .external_lex_state = 8},
  [3678] = {.lex_state = 92, .external_lex_state = 8},
  [3679] = {.lex_state = 92, .external_lex_state = 8},
  [3680] = {.lex_state = 92, .external_lex_state = 8},
  [3681] = {.lex_state = 97, .external_lex_state = 6},
  [3682] = {.lex_state = 92, .external_lex_state = 8},
  [3683] = {.lex_state = 92, .external_lex_state = 8},
  [3684] = {.lex_state = 96, .external_lex_state = 7},
  [3685] = {.lex_state = 95, .external_lex_state = 7},
  [3686] = {.lex_state = 97, .external_lex_state = 4},
  [3687] = {.lex_state = 92, .external_lex_state = 8},
  [3688] = {.lex_state = 92, .external_lex_state = 8},
  [3689] = {.lex_state = 92, .external_lex_state = 8},
  [3690] = {.lex_state = 97, .external_lex_state = 6},
  [3691] = {.lex_state = 92, .external_lex_state = 8},
  [3692] = {.lex_state = 92, .external_lex_state = 8},
  [3693] = {.lex_state = 96, .external_lex_state = 6},
  [3694] = {.lex_state = 92, .external_lex_state = 8},
  [3695] = {.lex_state = 92, .external_lex_state = 8},
  [3696] = {.lex_state = 92, .external_lex_state = 8},
  [3697] = {.lex_state = 92, .external_lex_state = 8},
  [3698] = {.lex_state = 92, .external_lex_state = 8},
  [3699] = {.lex_state = 92, .external_lex_state = 8},
  [3700] = {.lex_state = 92, .external_lex_state = 8},
  [3701] = {.lex_state = 92, .external_lex_state = 8},
  [3702] = {.lex_state = 92, .external_lex_state = 8},
  [3703] = {.lex_state = 92, .external_lex_state = 8},
  [3704] = {.lex_state = 97, .external_lex_state = 6},
  [3705] = {.lex_state = 92, .external_lex_state = 8},
  [3706] = {.lex_state = 97, .external_lex_state = 6},
  [3707] = {.lex_state = 97, .external_lex_state = 6},
  [3708] = {.lex_state = 92, .external_lex_state = 8},
  [3709] = {.lex_state = 92, .external_lex_state = 8},
  [3710] = {.lex_state = 96, .external_lex_state = 7},
  [3711] = {.lex_state = 92, .external_lex_state = 8},
  [3712] = {.lex_state = 97, .external_lex_state = 6},
  [3713] = {.lex_state = 97, .external_lex_state = 6},
  [3714] = {.lex_state = 97, .external_lex_state = 6},
  [3715] = {.lex_state = 97, .external_lex_state = 6},
  [3716] = {.lex_state = 97, .external_lex_state = 6},
  [3717] = {.lex_state = 88, .external_lex_state = 5},
  [3718] = {.lex_state = 97, .external_lex_state = 4},
  [3719] = {.lex_state = 96, .external_lex_state = 4},
  [3720] = {.lex_state = 97, .external_lex_state = 6},
  [3721] = {.lex_state = 88, .external_lex_state = 5},
  [3722] = {.lex_state = 97, .external_lex_state = 4},
  [3723] = {.lex_state = 88, .external_lex_state = 5},
  [3724] = {.lex_state = 97, .external_lex_state = 4},
  [3725] = {.lex_state = 92, .external_lex_state = 8},
  [3726] = {.lex_state = 97, .external_lex_state = 6},
  [3727] = {.lex_state = 96, .external_lex_state = 5},
  [3728] = {.lex_state = 97, .external_lex_state = 4},
  [3729] = {.lex_state = 97, .external_lex_state = 6},
  [3730] = {.lex_state = 97, .external_lex_state = 6},
  [3731] = {.lex_state = 97, .external_lex_state = 6},
  [3732] = {.lex_state = 97, .external_lex_state = 6},
  [3733] = {.lex_state = 88, .external_lex_state = 5},
  [3734] = {.lex_state = 97, .external_lex_state = 6},
  [3735] = {.lex_state = 97, .external_lex_state = 6},
  [3736] = {.lex_state = 97, .external_lex_state = 6},
  [3737] = {.lex_state = 97, .external_lex_state = 6},
  [3738] = {.lex_state = 88, .external_lex_state = 5},
  [3739] = {.lex_state = 97, .external_lex_state = 6},
  [3740] = {.lex_state = 97, .external_lex_state = 6},
  [3741] = {.lex_state = 92, .external_lex_state = 8},
  [3742] = {.lex_state = 97, .external_lex_state = 6},
  [3743] = {.lex_state = 97, .external_lex_state = 4},
  [3744] = {.lex_state = 97, .external_lex_state = 6},
  [3745] = {.lex_state = 92, .external_lex_state = 8},
  [3746] = {.lex_state = 92, .external_lex_state = 8},
  [3747] = {.lex_state = 92, .external_lex_state = 8},
  [3748] = {.lex_state = 88, .external_lex_state = 5},
  [3749] = {.lex_state = 97, .external_lex_state = 6},
  [3750] = {.lex_state = 92, .external_lex_state = 8},
  [3751] = {.lex_state = 97, .external_lex_state = 6},
  [3752] = {.lex_state = 97, .external_lex_state = 6},
  [3753] = {.lex_state = 97, .external_lex_state = 6},
  [3754] = {.lex_state = 97, .external_lex_state = 6},
  [3755] = {.lex_state = 97, .external_lex_state = 6},
  [3756] = {.lex_state = 97, .external_lex_state = 6},
  [3757] = {.lex_state = 97, .external_lex_state = 6},
  [3758] = {.lex_state = 97, .external_lex_state = 6},
  [3759] = {.lex_state = 92, .external_lex_state = 8},
  [3760] = {.lex_state = 97, .external_lex_state = 6},
  [3761] = {.lex_state = 97, .external_lex_state = 6},
  [3762] = {.lex_state = 92, .external_lex_state = 8},
  [3763] = {.lex_state = 97, .external_lex_state = 6},
  [3764] = {.lex_state = 97, .external_lex_state = 6},
  [3765] = {.lex_state = 97, .external_lex_state = 4},
  [3766] = {.lex_state = 92, .external_lex_state = 8},
  [3767] = {.lex_state = 97, .external_lex_state = 6},
  [3768] = {.lex_state = 97, .external_lex_state = 6},
  [3769] = {.lex_state = 97, .external_lex_state = 6},
  [3770] = {.lex_state = 92, .external_lex_state = 8},
  [3771] = {.lex_state = 91, .external_lex_state = 9},
  [3772] = {.lex_state = 97, .external_lex_state = 6},
  [3773] = {.lex_state = 97, .external_lex_state = 6},
  [3774] = {.lex_state = 97, .external_lex_state = 6},
  [3775] = {.lex_state = 97, .external_lex_state = 6},
  [3776] = {.lex_state = 97, .external_lex_state = 6},
  [3777] = {.lex_state = 97, .external_lex_state = 6},
  [3778] = {.lex_state = 97, .external_lex_state = 6},
  [3779] = {.lex_state = 97, .external_lex_state = 6},
  [3780] = {.lex_state = 97, .external_lex_state = 6},
  [3781] = {.lex_state = 97, .external_lex_state = 6},
  [3782] = {.lex_state = 97, .external_lex_state = 6},
  [3783] = {.lex_state = 97, .external_lex_state = 6},
  [3784] = {.lex_state = 97, .external_lex_state = 6},
  [3785] = {.lex_state = 88, .external_lex_state = 5},
  [3786] = {.lex_state = 97, .external_lex_state = 6},
  [3787] = {.lex_state = 97, .external_lex_state = 6},
  [3788] = {.lex_state = 97, .external_lex_state = 6},
  [3789] = {.lex_state = 97, .external_lex_state = 6},
  [3790] = {.lex_state = 97, .external_lex_state = 6},
  [3791] = {.lex_state = 96, .external_lex_state = 7},
  [3792] = {.lex_state = 97, .external_lex_state = 6},
  [3793] = {.lex_state = 92, .external_lex_state = 8},
  [3794] = {.lex_state = 97, .external_lex_state = 6},
  [3795] = {.lex_state = 97, .external_lex_state = 6},
  [3796] = {.lex_state = 92, .external_lex_state = 8},
  [3797] = {.lex_state = 97, .external_lex_state = 4},
  [3798] = {.lex_state = 97, .external_lex_state = 5},
  [3799] = {.lex_state = 97, .external_lex_state = 5},
  [3800] = {.lex_state = 97, .external_lex_state = 5},
  [3801] = {.lex_state = 97, .external_lex_state = 7},
  [3802] = {.lex_state = 97, .external_lex_state = 7},
  [3803] = {.lex_state = 97, .external_lex_state = 5},
  [3804] = {.lex_state = 92, .external_lex_state = 8},
  [3805] = {.lex_state = 97, .external_lex_state = 5},
  [3806] = {.lex_state = 97, .external_lex_state = 7},
  [3807] = {.lex_state = 97, .external_lex_state = 7},
  [3808] = {.lex_state = 97, .external_lex_state = 7},
  [3809] = {.lex_state = 88, .external_lex_state = 4},
  [3810] = {.lex_state = 97, .external_lex_state = 5},
  [3811] = {.lex_state = 88, .external_lex_state = 7},
  [3812] = {.lex_state = 97, .external_lex_state = 5},
  [3813] = {.lex_state = 97, .external_lex_state = 4},
  [3814] = {.lex_state = 97, .external_lex_state = 6},
  [3815] = {.lex_state = 97, .external_lex_state = 4},
  [3816] = {.lex_state = 97, .external_lex_state = 7},
  [3817] = {.lex_state = 97, .external_lex_state = 7},
  [3818] = {.lex_state = 92, .external_lex_state = 8},
  [3819] = {.lex_state = 97, .external_lex_state = 4},
  [3820] = {.lex_state = 97, .external_lex_state = 7},
  [3821] = {.lex_state = 97, .external_lex_state = 5},
  [3822] = {.lex_state = 97, .external_lex_state = 7},
  [3823] = {.lex_state = 97, .external_lex_state = 5},
  [3824] = {.lex_state = 97, .external_lex_state = 4},
  [3825] = {.lex_state = 92, .external_lex_state = 8},
  [3826] = {.lex_state = 97, .external_lex_state = 7},
  [3827] = {.lex_state = 97, .external_lex_state = 4},
  [3828] = {.lex_state = 97, .external_lex_state = 7},
  [3829] = {.lex_state = 97, .external_lex_state = 4},
  [3830] = {.lex_state = 88, .external_lex_state = 4},
  [3831] = {.lex_state = 97, .external_lex_state = 4},
  [3832] = {.lex_state = 97, .external_lex_state = 4},
  [3833] = {.lex_state = 88, .external_lex_state = 7},
  [3834] = {.lex_state = 88, .external_lex_state = 9},
  [3835] = {.lex_state = 97, .external_lex_state = 7},
  [3836] = {.lex_state = 97, .external_lex_state = 4},
  [3837] = {.lex_state = 88, .external_lex_state = 9},
  [3838] = {.lex_state = 88, .external_lex_state = 9},
  [3839] = {.lex_state = 97, .external_lex_state = 4},
  [3840] = {.lex_state = 88, .external_lex_state = 9},
  [3841] = {.lex_state = 97, .external_lex_state = 7},
  [3842] = {.lex_state = 88, .external_lex_state = 9},
  [3843] = {.lex_state = 97, .external_lex_state = 4},
  [3844] = {.lex_state = 97, .external_lex_state = 6},
  [3845] = {.lex_state = 97, .external_lex_state = 5},
  [3846] = {.lex_state = 97, .external_lex_state = 4},
  [3847] = {.lex_state = 97, .external_lex_state = 5},
  [3848] = {.lex_state = 97, .external_lex_state = 4},
  [3849] = {.lex_state = 88, .external_lex_state = 9},
  [3850] = {.lex_state = 88, .external_lex_state = 9},
  [3851] = {.lex_state = 97, .external_lex_state = 7},
  [3852] = {.lex_state = 97, .external_lex_state = 4},
  [3853] = {.lex_state = 88, .external_lex_state = 4},
  [3854] = {.lex_state = 97, .external_lex_state = 4},
  [3855] = {.lex_state = 97, .external_lex_state = 4},
  [3856] = {.lex_state = 92, .external_lex_state = 8},
  [3857] = {.lex_state = 97, .external_lex_state = 7},
  [3858] = {.lex_state = 91, .external_lex_state = 9},
  [3859] = {.lex_state = 97, .external_lex_state = 5},
  [3860] = {.lex_state = 88, .external_lex_state = 7},
  [3861] = {.lex_state = 97, .external_lex_state = 5},
  [3862] = {.lex_state = 92, .external_lex_state = 9},
  [3863] = {.lex_state = 97, .external_lex_state = 4},
  [3864] = {.lex_state = 97, .external_lex_state = 4},
  [3865] = {.lex_state = 97, .external_lex_state = 4},
  [3866] = {.lex_state = 92, .external_lex_state = 9},
  [3867] = {.lex_state = 97, .external_lex_state = 4},
  [3868] = {.lex_state = 92, .external_lex_state = 9},
  [3869] = {.lex_state = 92, .external_lex_state = 9},
  [3870] = {.lex_state = 97, .external_lex_state = 5},
  [3871] = {.lex_state = 97, .external_lex_state = 5},
  [3872] = {.lex_state = 97, .external_lex_state = 4},
  [3873] = {.lex_state = 92, .external_lex_state = 9},
  [3874] = {.lex_state = 92, .external_lex_state = 9},
  [3875] = {.lex_state = 97, .external_lex_state = 4},
  [3876] = {.lex_state = 97, .external_lex_state = 7},
  [3877] = {.lex_state = 92, .external_lex_state = 9},
  [3878] = {.lex_state = 97, .external_lex_state = 4},
  [3879] = {.lex_state = 97, .external_lex_state = 7},
  [3880] = {.lex_state = 97, .external_lex_state = 4},
  [3881] = {.lex_state = 97, .external_lex_state = 4},
  [3882] = {.lex_state = 97, .external_lex_state = 4},
  [3883] = {.lex_state = 97, .external_lex_state = 5},
  [3884] = {.lex_state = 97, .external_lex_state = 4},
  [3885] = {.lex_state = 97, .external_lex_state = 7},
  [3886] = {.lex_state = 97, .external_lex_state = 5},
  [3887] = {.lex_state = 92, .external_lex_state = 9},
  [3888] = {.lex_state = 97, .external_lex_state = 4},
  [3889] = {.lex_state = 88, .external_lex_state = 7},
  [3890] = {.lex_state = 97, .external_lex_state = 5},
  [3891] = {.lex_state = 97, .external_lex_state = 5},
  [3892] = {.lex_state = 92, .external_lex_state = 9},
  [3893] = {.lex_state = 97, .external_lex_state = 5},
  [3894] = {.lex_state = 97, .external_lex_state = 4},
  [3895] = {.lex_state = 92, .external_lex_state = 4},
  [3896] = {.lex_state = 97, .external_lex_state = 5},
  [3897] = {.lex_state = 97, .external_lex_state = 4},
  [3898] = {.lex_state = 92, .external_lex_state = 9},
  [3899] = {.lex_state = 92, .external_lex_state = 9},
  [3900] = {.lex_state = 97, .external_lex_state = 7},
  [3901] = {.lex_state = 97, .external_lex_state = 4},
  [3902] = {.lex_state = 97, .external_lex_state = 5},
  [3903] = {.lex_state = 97, .external_lex_state = 4},
  [3904] = {.lex_state = 97, .external_lex_state = 4},
  [3905] = {.lex_state = 97, .external_lex_state = 5},
  [3906] = {.lex_state = 97, .external_lex_state = 5},
  [3907] = {.lex_state = 97, .external_lex_state = 7},
  [3908] = {.lex_state = 97, .external_lex_state = 4},
  [3909] = {.lex_state = 97, .external_lex_state = 5},
  [3910] = {.lex_state = 97, .external_lex_state = 5},
  [3911] = {.lex_state = 97, .external_lex_state = 4},
  [3912] = {.lex_state = 97, .external_lex_state = 7},
  [3913] = {.lex_state = 92, .external_lex_state = 6},
  [3914] = {.lex_state = 97, .external_lex_state = 5},
  [3915] = {.lex_state = 88, .external_lex_state = 7},
  [3916] = {.lex_state = 97, .external_lex_state = 7},
  [3917] = {.lex_state = 97, .external_lex_state = 5},
  [3918] = {.lex_state = 97, .external_lex_state = 4},
  [3919] = {.lex_state = 97, .external_lex_state = 7},
  [3920] = {.lex_state = 97, .external_lex_state = 4},
  [3921] = {.lex_state = 97, .external_lex_state = 4},
  [3922] = {.lex_state = 91, .external_lex_state = 6},
  [3923] = {.lex_state = 97, .external_lex_state = 4},
  [3924] = {.lex_state = 97, .external_lex_state = 5},
  [3925] = {.lex_state = 97, .external_lex_state = 7},
  [3926] = {.lex_state = 97, .external_lex_state = 7},
  [3927] = {.lex_state = 97, .external_lex_state = 7},
  [3928] = {.lex_state = 97, .external_lex_state = 7},
  [3929] = {.lex_state = 97, .external_lex_state = 7},
  [3930] = {.lex_state = 97, .external_lex_state = 7},
  [3931] = {.lex_state = 97, .external_lex_state = 5},
  [3932] = {.lex_state = 88, .external_lex_state = 7},
  [3933] = {.lex_state = 97, .external_lex_state = 4},
  [3934] = {.lex_state = 91, .external_lex_state = 9},
  [3935] = {.lex_state = 97, .external_lex_state = 4},
  [3936] = {.lex_state = 88, .external_lex_state = 7},
  [3937] = {.lex_state = 97, .external_lex_state = 7},
  [3938] = {.lex_state = 97, .external_lex_state = 7},
  [3939] = {.lex_state = 97, .external_lex_state = 4},
  [3940] = {.lex_state = 97, .external_lex_state = 7},
  [3941] = {.lex_state = 97, .external_lex_state = 7},
  [3942] = {.lex_state = 97, .external_lex_state = 4},
  [3943] = {.lex_state = 97, .external_lex_state = 5},
  [3944] = {.lex_state = 92, .external_lex_state = 8},
  [3945] = {.lex_state = 97, .external_lex_state = 7},
  [3946] = {.lex_state = 92, .external_lex_state = 8},
  [3947] = {.lex_state = 97, .external_lex_state = 7},
  [3948] = {.lex_state = 92, .external_lex_state = 8},
  [3949] = {.lex_state = 97, .external_lex_state = 5},
  [3950] = {.lex_state = 97, .external_lex_state = 7},
  [3951] = {.lex_state = 97, .external_lex_state = 5},
  [3952] = {.lex_state = 97, .external_lex_state = 5},
  [3953] = {.lex_state = 92, .external_lex_state = 8},
  [3954] = {.lex_state = 97, .external_lex_state = 4},
  [3955] = {.lex_state = 97, .external_lex_state = 7},
  [3956] = {.lex_state = 92, .external_lex_state = 8},
  [3957] = {.lex_state = 97, .external_lex_state = 4},
  [3958] = {.lex_state = 97, .external_lex_state = 5},
  [3959] = {.lex_state = 97, .external_lex_state = 5},
  [3960] = {.lex_state = 92, .external_lex_state = 8},
  [3961] = {.lex_state = 92, .external_lex_state = 8},
  [3962] = {.lex_state = 97, .external_lex_state = 5},
  [3963] = {.lex_state = 97, .external_lex_state = 7},
  [3964] = {.lex_state = 96, .external_lex_state = 8},
  [3965] = {.lex_state = 97, .external_lex_state = 7},
  [3966] = {.lex_state = 88, .external_lex_state = 4},
  [3967] = {.lex_state = 92, .external_lex_state = 8},
  [3968] = {.lex_state = 88, .external_lex_state = 4},
  [3969] = {.lex_state = 92, .external_lex_state = 8},
  [3970] = {.lex_state = 97, .external_lex_state = 4},
  [3971] = {.lex_state = 97, .external_lex_state = 5},
  [3972] = {.lex_state = 97, .external_lex_state = 5},
  [3973] = {.lex_state = 92, .external_lex_state = 8},
  [3974] = {.lex_state = 97, .external_lex_state = 5},
  [3975] = {.lex_state = 97, .external_lex_state = 5},
  [3976] = {.lex_state = 97, .external_lex_state = 7},
  [3977] = {.lex_state = 97, .external_lex_state = 7},
  [3978] = {.lex_state = 97, .external_lex_state = 4},
  [3979] = {.lex_state = 97, .external_lex_state = 5},
  [3980] = {.lex_state = 97, .external_lex_state = 5},
  [3981] = {.lex_state = 97, .external_lex_state = 4},
  [3982] = {.lex_state = 97, .external_lex_state = 4},
  [3983] = {.lex_state = 97, .external_lex_state = 7},
  [3984] = {.lex_state = 97, .external_lex_state = 7},
  [3985] = {.lex_state = 97, .external_lex_state = 7},
  [3986] = {.lex_state = 97, .external_lex_state = 5},
  [3987] = {.lex_state = 97, .external_lex_state = 5},
  [3988] = {.lex_state = 97, .external_lex_state = 4},
  [3989] = {.lex_state = 97, .external_lex_state = 7},
  [3990] = {.lex_state = 97, .external_lex_state = 4},
  [3991] = {.lex_state = 97, .external_lex_state = 7},
  [3992] = {.lex_state = 97, .external_lex_state = 7},
  [3993] = {.lex_state = 97, .external_lex_state = 4},
  [3994] = {.lex_state = 97, .external_lex_state = 5},
  [3995] = {.lex_state = 97, .external_lex_state = 5},
  [3996] = {.lex_state = 97, .external_lex_state = 7},
  [3997] = {.lex_state = 96, .external_lex_state = 8},
  [3998] = {.lex_state = 97, .external_lex_state = 7},
  [3999] = {.lex_state = 88, .external_lex_state = 4},
  [4000] = {.lex_state = 97, .external_lex_state = 5},
  [4001] = {.lex_state = 96, .external_lex_state = 8},
  [4002] = {.lex_state = 92, .external_lex_state = 8},
  [4003] = {.lex_state = 88, .external_lex_state = 4},
  [4004] = {.lex_state = 97, .external_lex_state = 7},
  [4005] = {.lex_state = 97, .external_lex_state = 4},
  [4006] = {.lex_state = 97, .external_lex_state = 5},
  [4007] = {.lex_state = 97, .external_lex_state = 7},
  [4008] = {.lex_state = 97, .external_lex_state = 5},
  [4009] = {.lex_state = 97, .external_lex_state = 5},
  [4010] = {.lex_state = 97, .external_lex_state = 4},
  [4011] = {.lex_state = 97, .external_lex_state = 4},
  [4012] = {.lex_state = 97, .external_lex_state = 7},
  [4013] = {.lex_state = 97, .external_lex_state = 4},
  [4014] = {.lex_state = 91, .external_lex_state = 9},
  [4015] = {.lex_state = 97, .external_lex_state = 5},
  [4016] = {.lex_state = 97, .external_lex_state = 7},
  [4017] = {.lex_state = 97, .external_lex_state = 5},
  [4018] = {.lex_state = 97, .external_lex_state = 7},
  [4019] = {.lex_state = 97, .external_lex_state = 5},
  [4020] = {.lex_state = 97, .external_lex_state = 7},
  [4021] = {.lex_state = 97, .external_lex_state = 5},
  [4022] = {.lex_state = 96, .external_lex_state = 10},
  [4023] = {.lex_state = 97, .external_lex_state = 7},
  [4024] = {.lex_state = 97, .external_lex_state = 5},
  [4025] = {.lex_state = 97, .external_lex_state = 5},
  [4026] = {.lex_state = 97, .external_lex_state = 7},
  [4027] = {.lex_state = 97, .external_lex_state = 7},
  [4028] = {.lex_state = 97, .external_lex_state = 7},
  [4029] = {.lex_state = 97, .external_lex_state = 7},
  [4030] = {.lex_state = 97, .external_lex_state = 5},
  [4031] = {.lex_state = 97, .external_lex_state = 8},
  [4032] = {.lex_state = 92, .external_lex_state = 9},
  [4033] = {.lex_state = 97, .external_lex_state = 7},
  [4034] = {.lex_state = 97, .external_lex_state = 7},
  [4035] = {.lex_state = 97, .external_lex_state = 7},
  [4036] = {.lex_state = 97, .external_lex_state = 7},
  [4037] = {.lex_state = 97, .external_lex_state = 7},
  [4038] = {.lex_state = 97, .external_lex_state = 7},
  [4039] = {.lex_state = 92, .external_lex_state = 9},
  [4040] = {.lex_state = 97, .external_lex_state = 7},
  [4041] = {.lex_state = 97, .external_lex_state = 7},
  [4042] = {.lex_state = 88, .external_lex_state = 6},
  [4043] = {.lex_state = 88, .external_lex_state = 6},
  [4044] = {.lex_state = 88, .external_lex_state = 6},
  [4045] = {.lex_state = 97, .external_lex_state = 5},
  [4046] = {.lex_state = 97, .external_lex_state = 5},
  [4047] = {.lex_state = 97, .external_lex_state = 5},
  [4048] = {.lex_state = 88, .external_lex_state = 6},
  [4049] = {.lex_state = 88, .external_lex_state = 6},
  [4050] = {.lex_state = 88, .external_lex_state = 6},
  [4051] = {.lex_state = 88, .external_lex_state = 6},
  [4052] = {.lex_state = 97, .external_lex_state = 5},
  [4053] = {.lex_state = 97, .external_lex_state = 5},
  [4054] = {.lex_state = 97, .external_lex_state = 8},
  [4055] = {.lex_state = 97, .external_lex_state = 7},
  [4056] = {.lex_state = 97, .external_lex_state = 5},
  [4057] = {.lex_state = 97, .external_lex_state = 7},
  [4058] = {.lex_state = 97, .external_lex_state = 7},
  [4059] = {.lex_state = 92, .external_lex_state = 6},
  [4060] = {.lex_state = 92, .external_lex_state = 6},
  [4061] = {.lex_state = 92, .external_lex_state = 6},
  [4062] = {.lex_state = 92, .external_lex_state = 6},
  [4063] = {.lex_state = 92, .external_lex_state = 6},
  [4064] = {.lex_state = 92, .external_lex_state = 6},
  [4065] = {.lex_state = 92, .external_lex_state = 6},
  [4066] = {.lex_state = 92, .external_lex_state = 6},
  [4067] = {.lex_state = 92, .external_lex_state = 6},
  [4068] = {.lex_state = 92, .external_lex_state = 6},
  [4069] = {.lex_state = 92, .external_lex_state = 6},
  [4070] = {.lex_state = 97, .external_lex_state = 7},
  [4071] = {.lex_state = 92, .external_lex_state = 9},
  [4072] = {.lex_state = 92, .external_lex_state = 9},
  [4073] = {.lex_state = 92, .external_lex_state = 9},
  [4074] = {.lex_state = 97, .external_lex_state = 7},
  [4075] = {.lex_state = 97, .external_lex_state = 5},
  [4076] = {.lex_state = 97, .external_lex_state = 5},
  [4077] = {.lex_state = 97, .external_lex_state = 5},
  [4078] = {.lex_state = 97, .external_lex_state = 5},
  [4079] = {.lex_state = 97, .external_lex_state = 7},
  [4080] = {.lex_state = 97, .external_lex_state = 7},
  [4081] = {.lex_state = 97, .external_lex_state = 7},
  [4082] = {.lex_state = 96, .external_lex_state = 10},
  [4083] = {.lex_state = 92, .external_lex_state = 4},
  [4084] = {.lex_state = 97, .external_lex_state = 7},
  [4085] = {.lex_state = 97, .external_lex_state = 7},
  [4086] = {.lex_state = 97, .external_lex_state = 8},
  [4087] = {.lex_state = 97, .external_lex_state = 5},
  [4088] = {.lex_state = 97, .external_lex_state = 5},
  [4089] = {.lex_state = 97, .external_lex_state = 5},
  [4090] = {.lex_state = 97, .external_lex_state = 7},
  [4091] = {.lex_state = 97, .external_lex_state = 5},
  [4092] = {.lex_state = 97, .external_lex_state = 7},
  [4093] = {.lex_state = 97, .external_lex_state = 7},
  [4094] = {.lex_state = 97, .external_lex_state = 7},
  [4095] = {.lex_state = 92, .external_lex_state = 9},
  [4096] = {.lex_state = 97, .external_lex_state = 5},
  [4097] = {.lex_state = 97, .external_lex_state = 5},
  [4098] = {.lex_state = 97, .external_lex_state = 7},
  [4099] = {.lex_state = 97, .external_lex_state = 7},
  [4100] = {.lex_state = 97, .external_lex_state = 5},
  [4101] = {.lex_state = 97, .external_lex_state = 7},
  [4102] = {.lex_state = 97, .external_lex_state = 7},
  [4103] = {.lex_state = 97, .external_lex_state = 7},
  [4104] = {.lex_state = 97, .external_lex_state = 7},
  [4105] = {.lex_state = 97, .external_lex_state = 5},
  [4106] = {.lex_state = 97, .external_lex_state = 7},
  [4107] = {.lex_state = 97, .external_lex_state = 7},
  [4108] = {.lex_state = 97, .external_lex_state = 7},
  [4109] = {.lex_state = 97, .external_lex_state = 5},
  [4110] = {.lex_state = 97, .external_lex_state = 7},
  [4111] = {.lex_state = 97, .external_lex_state = 5},
  [4112] = {.lex_state = 97, .external_lex_state = 5},
  [4113] = {.lex_state = 97, .external_lex_state = 5},
  [4114] = {.lex_state = 97, .external_lex_state = 7},
  [4115] = {.lex_state = 91, .external_lex_state = 9},
  [4116] = {.lex_state = 97, .external_lex_state = 5},
  [4117] = {.lex_state = 97, .external_lex_state = 5},
  [4118] = {.lex_state = 97, .external_lex_state = 7},
  [4119] = {.lex_state = 97, .external_lex_state = 7},
  [4120] = {.lex_state = 97, .external_lex_state = 7},
  [4121] = {.lex_state = 97, .external_lex_state = 7},
  [4122] = {.lex_state = 97, .external_lex_state = 5},
  [4123] = {.lex_state = 97, .external_lex_state = 5},
  [4124] = {.lex_state = 92, .external_lex_state = 8},
  [4125] = {.lex_state = 97, .external_lex_state = 5},
  [4126] = {.lex_state = 88, .external_lex_state = 6},
  [4127] = {.lex_state = 97, .external_lex_state = 5},
  [4128] = {.lex_state = 97, .external_lex_state = 7},
  [4129] = {.lex_state = 97, .external_lex_state = 7},
  [4130] = {.lex_state = 97, .external_lex_state = 7},
  [4131] = {.lex_state = 97, .external_lex_state = 5},
  [4132] = {.lex_state = 97, .external_lex_state = 5},
  [4133] = {.lex_state = 92, .external_lex_state = 9},
  [4134] = {.lex_state = 97, .external_lex_state = 7},
  [4135] = {.lex_state = 97, .external_lex_state = 7},
  [4136] = {.lex_state = 97, .external_lex_state = 7},
  [4137] = {.lex_state = 97, .external_lex_state = 7},
  [4138] = {.lex_state = 97, .external_lex_state = 5},
  [4139] = {.lex_state = 97, .external_lex_state = 7},
  [4140] = {.lex_state = 97, .external_lex_state = 7},
  [4141] = {.lex_state = 97, .external_lex_state = 5},
  [4142] = {.lex_state = 97, .external_lex_state = 5},
  [4143] = {.lex_state = 92, .external_lex_state = 9},
  [4144] = {.lex_state = 97, .external_lex_state = 7},
  [4145] = {.lex_state = 97, .external_lex_state = 7},
  [4146] = {.lex_state = 97, .external_lex_state = 5},
  [4147] = {.lex_state = 97, .external_lex_state = 5},
  [4148] = {.lex_state = 97, .external_lex_state = 5},
  [4149] = {.lex_state = 97, .external_lex_state = 5},
  [4150] = {.lex_state = 97, .external_lex_state = 7},
  [4151] = {.lex_state = 97, .external_lex_state = 5},
  [4152] = {.lex_state = 97, .external_lex_state = 7},
  [4153] = {.lex_state = 92, .external_lex_state = 9},
  [4154] = {.lex_state = 97, .external_lex_state = 5},
  [4155] = {.lex_state = 97, .external_lex_state = 5},
  [4156] = {.lex_state = 97, .external_lex_state = 7},
  [4157] = {.lex_state = 97, .external_lex_state = 7},
  [4158] = {.lex_state = 92, .external_lex_state = 9},
  [4159] = {.lex_state = 97, .external_lex_state = 8},
  [4160] = {.lex_state = 97, .external_lex_state = 7},
  [4161] = {.lex_state = 97, .external_lex_state = 7},
  [4162] = {.lex_state = 92, .external_lex_state = 9},
  [4163] = {.lex_state = 92, .external_lex_state = 9},
  [4164] = {.lex_state = 92, .external_lex_state = 9},
  [4165] = {.lex_state = 92, .external_lex_state = 9},
  [4166] = {.lex_state = 97, .external_lex_state = 5},
  [4167] = {.lex_state = 97, .external_lex_state = 5},
  [4168] = {.lex_state = 97, .external_lex_state = 5},
  [4169] = {.lex_state = 97, .external_lex_state = 7},
  [4170] = {.lex_state = 97, .external_lex_state = 5},
  [4171] = {.lex_state = 92, .external_lex_state = 9},
  [4172] = {.lex_state = 97, .external_lex_state = 4},
  [4173] = {.lex_state = 97, .external_lex_state = 5},
  [4174] = {.lex_state = 97, .external_lex_state = 5},
  [4175] = {.lex_state = 97, .external_lex_state = 5},
  [4176] = {.lex_state = 97, .external_lex_state = 7},
  [4177] = {.lex_state = 92, .external_lex_state = 9},
  [4178] = {.lex_state = 92, .external_lex_state = 9},
  [4179] = {.lex_state = 92, .external_lex_state = 9},
  [4180] = {.lex_state = 97, .external_lex_state = 5},
  [4181] = {.lex_state = 97, .external_lex_state = 5},
  [4182] = {.lex_state = 92, .external_lex_state = 9},
  [4183] = {.lex_state = 97, .external_lex_state = 5},
  [4184] = {.lex_state = 97, .external_lex_state = 5},
  [4185] = {.lex_state = 97, .external_lex_state = 5},
  [4186] = {.lex_state = 97, .external_lex_state = 5},
  [4187] = {.lex_state = 97, .external_lex_state = 5},
  [4188] = {.lex_state = 97, .external_lex_state = 5},
  [4189] = {.lex_state = 97, .external_lex_state = 5},
  [4190] = {.lex_state = 97, .external_lex_state = 5},
  [4191] = {.lex_state = 97, .external_lex_state = 5},
  [4192] = {.lex_state = 97, .external_lex_state = 5},
  [4193] = {.lex_state = 97, .external_lex_state = 5},
  [4194] = {.lex_state = 97, .external_lex_state = 5},
  [4195] = {.lex_state = 96, .external_lex_state = 10},
  [4196] = {.lex_state = 92, .external_lex_state = 9},
  [4197] = {.lex_state = 97, .external_lex_state = 7},
  [4198] = {.lex_state = 97, .external_lex_state = 5},
  [4199] = {.lex_state = 97, .external_lex_state = 5},
  [4200] = {.lex_state = 97, .external_lex_state = 5},
  [4201] = {.lex_state = 97, .external_lex_state = 5},
  [4202] = {.lex_state = 97, .external_lex_state = 7},
  [4203] = {.lex_state = 97, .external_lex_state = 5},
  [4204] = {.lex_state = 97, .external_lex_state = 7},
  [4205] = {.lex_state = 97, .external_lex_state = 5},
  [4206] = {.lex_state = 97, .external_lex_state = 5},
  [4207] = {.lex_state = 97, .external_lex_state = 5},
  [4208] = {.lex_state = 97, .external_lex_state = 5},
  [4209] = {.lex_state = 97, .external_lex_state = 5},
  [4210] = {.lex_state = 97, .external_lex_state = 7},
  [4211] = {.lex_state = 97, .external_lex_state = 7},
  [4212] = {.lex_state = 97, .external_lex_state = 5},
  [4213] = {.lex_state = 97, .external_lex_state = 5},
  [4214] = {.lex_state = 97, .external_lex_state = 5},
  [4215] = {.lex_state = 97, .external_lex_state = 7},
  [4216] = {.lex_state = 97, .external_lex_state = 5},
  [4217] = {.lex_state = 88, .external_lex_state = 6},
  [4218] = {.lex_state = 97, .external_lex_state = 7},
  [4219] = {.lex_state = 97, .external_lex_state = 7},
  [4220] = {.lex_state = 97, .external_lex_state = 7},
  [4221] = {.lex_state = 97, .external_lex_state = 7},
  [4222] = {.lex_state = 97, .external_lex_state = 5},
  [4223] = {.lex_state = 97, .external_lex_state = 7},
  [4224] = {.lex_state = 97, .external_lex_state = 5},
  [4225] = {.lex_state = 97, .external_lex_state = 5},
  [4226] = {.lex_state = 97, .external_lex_state = 5},
  [4227] = {.lex_state = 97, .external_lex_state = 5},
  [4228] = {.lex_state = 97, .external_lex_state = 8},
  [4229] = {.lex_state = 97, .external_lex_state = 7},
  [4230] = {.lex_state = 97, .external_lex_state = 8},
  [4231] = {.lex_state = 97, .external_lex_state = 5},
  [4232] = {.lex_state = 97, .external_lex_state = 8},
  [4233] = {.lex_state = 97, .external_lex_state = 7},
  [4234] = {.lex_state = 97, .external_lex_state = 7},
  [4235] = {.lex_state = 97, .external_lex_state = 7},
  [4236] = {.lex_state = 97, .external_lex_state = 7},
  [4237] = {.lex_state = 97, .external_lex_state = 8},
  [4238] = {.lex_state = 97, .external_lex_state = 7},
  [4239] = {.lex_state = 96, .external_lex_state = 8},
  [4240] = {.lex_state = 97, .external_lex_state = 7},
  [4241] = {.lex_state = 97, .external_lex_state = 5},
  [4242] = {.lex_state = 97, .external_lex_state = 7},
  [4243] = {.lex_state = 97, .external_lex_state = 7},
  [4244] = {.lex_state = 97, .external_lex_state = 7},
  [4245] = {.lex_state = 97, .external_lex_state = 7},
  [4246] = {.lex_state = 97, .external_lex_state = 8},
  [4247] = {.lex_state = 97, .external_lex_state = 7},
  [4248] = {.lex_state = 97, .external_lex_state = 7},
  [4249] = {.lex_state = 97, .external_lex_state = 7},
  [4250] = {.lex_state = 97, .external_lex_state = 7},
  [4251] = {.lex_state = 92, .external_lex_state = 9},
  [4252] = {.lex_state = 97, .external_lex_state = 7},
  [4253] = {.lex_state = 97, .external_lex_state = 5},
  [4254] = {.lex_state = 97, .external_lex_state = 5},
  [4255] = {.lex_state = 97, .external_lex_state = 7},
  [4256] = {.lex_state = 97, .external_lex_state = 7},
  [4257] = {.lex_state = 97, .external_lex_state = 5},
  [4258] = {.lex_state = 97, .external_lex_state = 5},
  [4259] = {.lex_state = 97, .external_lex_state = 7},
  [4260] = {.lex_state = 97, .external_lex_state = 5},
  [4261] = {.lex_state = 97, .external_lex_state = 7},
  [4262] = {.lex_state = 92, .external_lex_state = 9},
  [4263] = {.lex_state = 97, .external_lex_state = 5},
  [4264] = {.lex_state = 92, .external_lex_state = 9},
  [4265] = {.lex_state = 92, .external_lex_state = 9},
  [4266] = {.lex_state = 92, .external_lex_state = 9},
  [4267] = {.lex_state = 92, .external_lex_state = 9},
  [4268] = {.lex_state = 92, .external_lex_state = 9},
  [4269] = {.lex_state = 92, .external_lex_state = 9},
  [4270] = {.lex_state = 92, .external_lex_state = 9},
  [4271] = {.lex_state = 92, .external_lex_state = 9},
  [4272] = {.lex_state = 92, .external_lex_state = 9},
  [4273] = {.lex_state = 92, .external_lex_state = 9},
  [4274] = {.lex_state = 92, .external_lex_state = 9},
  [4275] = {.lex_state = 92, .external_lex_state = 9},
  [4276] = {.lex_state = 92, .external_lex_state = 9},
  [4277] = {.lex_state = 92, .external_lex_state = 9},
  [4278] = {.lex_state = 92, .external_lex_state = 9},
  [4279] = {.lex_state = 92, .external_lex_state = 9},
  [4280] = {.lex_state = 92, .external_lex_state = 9},
  [4281] = {.lex_state = 92, .external_lex_state = 9},
  [4282] = {.lex_state = 97, .external_lex_state = 8},
  [4283] = {.lex_state = 92, .external_lex_state = 9},
  [4284] = {.lex_state = 92, .external_lex_state = 9},
  [4285] = {.lex_state = 97, .external_lex_state = 8},
  [4286] = {.lex_state = 92, .external_lex_state = 9},
  [4287] = {.lex_state = 97, .external_lex_state = 8},
  [4288] = {.lex_state = 97, .external_lex_state = 8},
  [4289] = {.lex_state = 92, .external_lex_state = 9},
  [4290] = {.lex_state = 97, .external_lex_state = 8},
  [4291] = {.lex_state = 92, .external_lex_state = 9},
  [4292] = {.lex_state = 97, .external_lex_state = 8},
  [4293] = {.lex_state = 97, .external_lex_state = 8},
  [4294] = {.lex_state = 97, .external_lex_state = 8},
  [4295] = {.lex_state = 97, .external_lex_state = 8},
  [4296] = {.lex_state = 97, .external_lex_state = 8},
  [4297] = {.lex_state = 92, .external_lex_state = 9},
  [4298] = {.lex_state = 97, .external_lex_state = 8},
  [4299] = {.lex_state = 97, .external_lex_state = 8},
  [4300] = {.lex_state = 97, .external_lex_state = 8},
  [4301] = {.lex_state = 97, .external_lex_state = 8},
  [4302] = {.lex_state = 92, .external_lex_state = 9},
  [4303] = {.lex_state = 97, .external_lex_state = 8},
  [4304] = {.lex_state = 92, .external_lex_state = 9},
  [4305] = {.lex_state = 97, .external_lex_state = 8},
  [4306] = {.lex_state = 97, .external_lex_state = 8},
  [4307] = {.lex_state = 97, .external_lex_state = 8},
  [4308] = {.lex_state = 97, .external_lex_state = 8},
  [4309] = {.lex_state = 97, .external_lex_state = 8},
  [4310] = {.lex_state = 92, .external_lex_state = 9},
  [4311] = {.lex_state = 97, .external_lex_state = 8},
  [4312] = {.lex_state = 97, .external_lex_state = 8},
  [4313] = {.lex_state = 97, .external_lex_state = 8},
  [4314] = {.lex_state = 97, .external_lex_state = 8},
  [4315] = {.lex_state = 97, .external_lex_state = 8},
  [4316] = {.lex_state = 92, .external_lex_state = 9},
  [4317] = {.lex_state = 92, .external_lex_state = 9},
  [4318] = {.lex_state = 97, .external_lex_state = 8},
  [4319] = {.lex_state = 97, .external_lex_state = 8},
  [4320] = {.lex_state = 97, .external_lex_state = 8},
  [4321] = {.lex_state = 97, .external_lex_state = 8},
  [4322] = {.lex_state = 97, .external_lex_state = 8},
  [4323] = {.lex_state = 92, .external_lex_state = 9},
  [4324] = {.lex_state = 97, .external_lex_state = 8},
  [4325] = {.lex_state = 97, .external_lex_state = 8},
  [4326] = {.lex_state = 97, .external_lex_state = 8},
  [4327] = {.lex_state = 92, .external_lex_state = 9},
  [4328] = {.lex_state = 97, .external_lex_state = 8},
  [4329] = {.lex_state = 97, .external_lex_state = 8},
  [4330] = {.lex_state = 92, .external_lex_state = 9},
  [4331] = {.lex_state = 97, .external_lex_state = 8},
  [4332] = {.lex_state = 97, .external_lex_state = 8},
  [4333] = {.lex_state = 92, .external_lex_state = 9},
  [4334] = {.lex_state = 97, .external_lex_state = 8},
  [4335] = {.lex_state = 97, .external_lex_state = 8},
  [4336] = {.lex_state = 92, .external_lex_state = 9},
  [4337] = {.lex_state = 92, .external_lex_state = 9},
  [4338] = {.lex_state = 97, .external_lex_state = 8},
  [4339] = {.lex_state = 92, .external_lex_state = 9},
  [4340] = {.lex_state = 97, .external_lex_state = 8},
  [4341] = {.lex_state = 97, .external_lex_state = 8},
  [4342] = {.lex_state = 92, .external_lex_state = 9},
  [4343] = {.lex_state = 97, .external_lex_state = 8},
  [4344] = {.lex_state = 97, .external_lex_state = 8},
  [4345] = {.lex_state = 92, .external_lex_state = 9},
  [4346] = {.lex_state = 92, .external_lex_state = 9},
  [4347] = {.lex_state = 92, .external_lex_state = 9},
  [4348] = {.lex_state = 92, .external_lex_state = 9},
  [4349] = {.lex_state = 97, .external_lex_state = 8},
  [4350] = {.lex_state = 92, .external_lex_state = 9},
  [4351] = {.lex_state = 92, .external_lex_state = 9},
  [4352] = {.lex_state = 92, .external_lex_state = 9},
  [4353] = {.lex_state = 92, .external_lex_state = 9},
  [4354] = {.lex_state = 92, .external_lex_state = 9},
  [4355] = {.lex_state = 97, .external_lex_state = 8},
  [4356] = {.lex_state = 97, .external_lex_state = 8},
  [4357] = {.lex_state = 92, .external_lex_state = 9},
  [4358] = {.lex_state = 92, .external_lex_state = 9},
  [4359] = {.lex_state = 92, .external_lex_state = 9},
  [4360] = {.lex_state = 92, .external_lex_state = 9},
  [4361] = {.lex_state = 92, .external_lex_state = 9},
  [4362] = {.lex_state = 92, .external_lex_state = 9},
  [4363] = {.lex_state = 92, .external_lex_state = 9},
  [4364] = {.lex_state = 92, .external_lex_state = 9},
  [4365] = {.lex_state = 92, .external_lex_state = 9},
  [4366] = {.lex_state = 92, .external_lex_state = 9},
  [4367] = {.lex_state = 92, .external_lex_state = 9},
  [4368] = {.lex_state = 92, .external_lex_state = 9},
  [4369] = {.lex_state = 92, .external_lex_state = 9},
  [4370] = {.lex_state = 92, .external_lex_state = 9},
  [4371] = {.lex_state = 97, .external_lex_state = 8},
  [4372] = {.lex_state = 92, .external_lex_state = 9},
  [4373] = {.lex_state = 92, .external_lex_state = 9},
  [4374] = {.lex_state = 97, .external_lex_state = 8},
  [4375] = {.lex_state = 97, .external_lex_state = 8},
  [4376] = {.lex_state = 92, .external_lex_state = 9},
  [4377] = {.lex_state = 97, .external_lex_state = 8},
  [4378] = {.lex_state = 92, .external_lex_state = 9},
  [4379] = {.lex_state = 88, .external_lex_state = 5},
  [4380] = {.lex_state = 97, .external_lex_state = 8},
  [4381] = {.lex_state = 92, .external_lex_state = 9},
  [4382] = {.lex_state = 92, .external_lex_state = 9},
  [4383] = {.lex_state = 92, .external_lex_state = 9},
  [4384] = {.lex_state = 92, .external_lex_state = 9},
  [4385] = {.lex_state = 88, .external_lex_state = 5},
  [4386] = {.lex_state = 92, .external_lex_state = 9},
  [4387] = {.lex_state = 92, .external_lex_state = 9},
  [4388] = {.lex_state = 88, .external_lex_state = 6},
  [4389] = {.lex_state = 88, .external_lex_state = 6},
  [4390] = {.lex_state = 88, .external_lex_state = 6},
  [4391] = {.lex_state = 88, .external_lex_state = 6},
  [4392] = {.lex_state = 88, .external_lex_state = 6},
  [4393] = {.lex_state = 88, .external_lex_state = 6},
  [4394] = {.lex_state = 88, .external_lex_state = 6},
  [4395] = {.lex_state = 92, .external_lex_state = 9},
  [4396] = {.lex_state = 88, .external_lex_state = 5},
  [4397] = {.lex_state = 88, .external_lex_state = 5},
  [4398] = {.lex_state = 92, .external_lex_state = 9},
  [4399] = {.lex_state = 92, .external_lex_state = 9},
  [4400] = {.lex_state = 97, .external_lex_state = 8},
  [4401] = {.lex_state = 92, .external_lex_state = 6},
  [4402] = {.lex_state = 92, .external_lex_state = 9},
  [4403] = {.lex_state = 97, .external_lex_state = 8},
  [4404] = {.lex_state = 97, .external_lex_state = 8},
  [4405] = {.lex_state = 92, .external_lex_state = 9},
  [4406] = {.lex_state = 92, .external_lex_state = 9},
  [4407] = {.lex_state = 92, .external_lex_state = 9},
  [4408] = {.lex_state = 97, .external_lex_state = 4},
  [4409] = {.lex_state = 88, .external_lex_state = 5},
  [4410] = {.lex_state = 92, .external_lex_state = 9},
  [4411] = {.lex_state = 88, .external_lex_state = 5},
  [4412] = {.lex_state = 92, .external_lex_state = 6},
  [4413] = {.lex_state = 97, .external_lex_state = 10},
  [4414] = {.lex_state = 97, .external_lex_state = 10},
  [4415] = {.lex_state = 92, .external_lex_state = 9},
  [4416] = {.lex_state = 92, .external_lex_state = 9},
  [4417] = {.lex_state = 92, .external_lex_state = 9},
  [4418] = {.lex_state = 92, .external_lex_state = 9},
  [4419] = {.lex_state = 92, .external_lex_state = 9},
  [4420] = {.lex_state = 88, .external_lex_state = 5},
  [4421] = {.lex_state = 92, .external_lex_state = 9},
  [4422] = {.lex_state = 92, .external_lex_state = 9},
  [4423] = {.lex_state = 92, .external_lex_state = 9},
  [4424] = {.lex_state = 92, .external_lex_state = 9},
  [4425] = {.lex_state = 92, .external_lex_state = 9},
  [4426] = {.lex_state = 92, .external_lex_state = 9},
  [4427] = {.lex_state = 96, .external_lex_state = 10},
  [4428] = {.lex_state = 92, .external_lex_state = 9},
  [4429] = {.lex_state = 92, .external_lex_state = 9},
  [4430] = {.lex_state = 92, .external_lex_state = 9},
  [4431] = {.lex_state = 92, .external_lex_state = 9},
  [4432] = {.lex_state = 97, .external_lex_state = 8},
  [4433] = {.lex_state = 92, .external_lex_state = 9},
  [4434] = {.lex_state = 92, .external_lex_state = 9},
  [4435] = {.lex_state = 92, .external_lex_state = 9},
  [4436] = {.lex_state = 92, .external_lex_state = 9},
  [4437] = {.lex_state = 92, .external_lex_state = 9},
  [4438] = {.lex_state = 92, .external_lex_state = 9},
  [4439] = {.lex_state = 92, .external_lex_state = 9},
  [4440] = {.lex_state = 92, .external_lex_state = 9},
  [4441] = {.lex_state = 92, .external_lex_state = 9},
  [4442] = {.lex_state = 92, .external_lex_state = 9},
  [4443] = {.lex_state = 92, .external_lex_state = 9},
  [4444] = {.lex_state = 92, .external_lex_state = 9},
  [4445] = {.lex_state = 92, .external_lex_state = 9},
  [4446] = {.lex_state = 92, .external_lex_state = 9},
  [4447] = {.lex_state = 92, .external_lex_state = 9},
  [4448] = {.lex_state = 92, .external_lex_state = 9},
  [4449] = {.lex_state = 92, .external_lex_state = 9},
  [4450] = {.lex_state = 92, .external_lex_state = 9},
  [4451] = {.lex_state = 92, .external_lex_state = 9},
  [4452] = {.lex_state = 92, .external_lex_state = 9},
  [4453] = {.lex_state = 92, .external_lex_state = 6},
  [4454] = {.lex_state = 92, .external_lex_state = 6},
  [4455] = {.lex_state = 92, .external_lex_state = 9},
  [4456] = {.lex_state = 92, .external_lex_state = 9},
  [4457] = {.lex_state = 92, .external_lex_state = 9},
  [4458] = {.lex_state = 92, .external_lex_state = 9},
  [4459] = {.lex_state = 92, .external_lex_state = 9},
  [4460] = {.lex_state = 92, .external_lex_state = 9},
  [4461] = {.lex_state = 92, .external_lex_state = 9},
  [4462] = {.lex_state = 92, .external_lex_state = 9},
  [4463] = {.lex_state = 97, .external_lex_state = 8},
  [4464] = {.lex_state = 92, .external_lex_state = 9},
  [4465] = {.lex_state = 88, .external_lex_state = 5},
  [4466] = {.lex_state = 92, .external_lex_state = 9},
  [4467] = {.lex_state = 92, .external_lex_state = 9},
  [4468] = {.lex_state = 92, .external_lex_state = 9},
  [4469] = {.lex_state = 92, .external_lex_state = 9},
  [4470] = {.lex_state = 92, .external_lex_state = 9},
  [4471] = {.lex_state = 97, .external_lex_state = 8},
  [4472] = {.lex_state = 92, .external_lex_state = 9},
  [4473] = {.lex_state = 92, .external_lex_state = 9},
  [4474] = {.lex_state = 92, .external_lex_state = 9},
  [4475] = {.lex_state = 92, .external_lex_state = 9},
  [4476] = {.lex_state = 92, .external_lex_state = 9},
  [4477] = {.lex_state = 92, .external_lex_state = 9},
  [4478] = {.lex_state = 92, .external_lex_state = 9},
  [4479] = {.lex_state = 92, .external_lex_state = 9},
  [4480] = {.lex_state = 92, .external_lex_state = 9},
  [4481] = {.lex_state = 92, .external_lex_state = 6},
  [4482] = {.lex_state = 97, .external_lex_state = 8},
  [4483] = {.lex_state = 92, .external_lex_state = 9},
  [4484] = {.lex_state = 92, .external_lex_state = 9},
  [4485] = {.lex_state = 92, .external_lex_state = 9},
  [4486] = {.lex_state = 92, .external_lex_state = 9},
  [4487] = {.lex_state = 92, .external_lex_state = 9},
  [4488] = {.lex_state = 92, .external_lex_state = 9},
  [4489] = {.lex_state = 92, .external_lex_state = 9},
  [4490] = {.lex_state = 92, .external_lex_state = 9},
  [4491] = {.lex_state = 92, .external_lex_state = 9},
  [4492] = {.lex_state = 92, .external_lex_state = 9},
  [4493] = {.lex_state = 97, .external_lex_state = 8},
  [4494] = {.lex_state = 92, .external_lex_state = 9},
  [4495] = {.lex_state = 92, .external_lex_state = 9},
  [4496] = {.lex_state = 92, .external_lex_state = 9},
  [4497] = {.lex_state = 92, .external_lex_state = 9},
  [4498] = {.lex_state = 92, .external_lex_state = 9},
  [4499] = {.lex_state = 92, .external_lex_state = 9},
  [4500] = {.lex_state = 92, .external_lex_state = 9},
  [4501] = {.lex_state = 92, .external_lex_state = 9},
  [4502] = {.lex_state = 92, .external_lex_state = 9},
  [4503] = {.lex_state = 92, .external_lex_state = 9},
  [4504] = {.lex_state = 92, .external_lex_state = 9},
  [4505] = {.lex_state = 97, .external_lex_state = 10},
  [4506] = {.lex_state = 97, .external_lex_state = 10},
  [4507] = {.lex_state = 97, .external_lex_state = 10},
  [4508] = {.lex_state = 97, .external_lex_state = 10},
  [4509] = {.lex_state = 97, .external_lex_state = 10},
  [4510] = {.lex_state = 97, .external_lex_state = 10},
  [4511] = {.lex_state = 97, .external_lex_state = 10},
  [4512] = {.lex_state = 97, .external_lex_state = 10},
  [4513] = {.lex_state = 97, .external_lex_state = 10},
  [4514] = {.lex_state = 97, .external_lex_state = 10},
  [4515] = {.lex_state = 97, .external_lex_state = 10},
  [4516] = {.lex_state = 97, .external_lex_state = 10},
  [4517] = {.lex_state = 97, .external_lex_state = 10},
  [4518] = {.lex_state = 97, .external_lex_state = 10},
  [4519] = {.lex_state = 97, .external_lex_state = 10},
  [4520] = {.lex_state = 97, .external_lex_state = 10},
  [4521] = {.lex_state = 97, .external_lex_state = 10},
  [4522] = {.lex_state = 97, .external_lex_state = 10},
  [4523] = {.lex_state = 97, .external_lex_state = 10},
  [4524] = {.lex_state = 97, .external_lex_state = 10},
  [4525] = {.lex_state = 97, .external_lex_state = 10},
  [4526] = {.lex_state = 97, .external_lex_state = 10},
  [4527] = {.lex_state = 97, .external_lex_state = 10},
  [4528] = {.lex_state = 97, .external_lex_state = 10},
  [4529] = {.lex_state = 97, .external_lex_state = 10},
  [4530] = {.lex_state = 97, .external_lex_state = 10},
  [4531] = {.lex_state = 97, .external_lex_state = 10},
  [4532] = {.lex_state = 97, .external_lex_state = 10},
  [4533] = {.lex_state = 97, .external_lex_state = 10},
  [4534] = {.lex_state = 97, .external_lex_state = 10},
  [4535] = {.lex_state = 97, .external_lex_state = 10},
  [4536] = {.lex_state = 97, .external_lex_state = 10},
  [4537] = {.lex_state = 97, .external_lex_state = 10},
  [4538] = {.lex_state = 97, .external_lex_state = 10},
  [4539] = {.lex_state = 97, .external_lex_state = 5},
  [4540] = {.lex_state = 97, .external_lex_state = 10},
  [4541] = {.lex_state = 97, .external_lex_state = 10},
  [4542] = {.lex_state = 97, .external_lex_state = 4},
  [4543] = {.lex_state = 97, .external_lex_state = 10},
  [4544] = {.lex_state = 92, .external_lex_state = 6},
  [4545] = {.lex_state = 92, .external_lex_state = 6},
  [4546] = {.lex_state = 92, .external_lex_state = 6},
  [4547] = {.lex_state = 92, .external_lex_state = 6},
  [4548] = {.lex_state = 88, .external_lex_state = 6},
  [4549] = {.lex_state = 97, .external_lex_state = 10},
  [4550] = {.lex_state = 97, .external_lex_state = 10},
  [4551] = {.lex_state = 88, .external_lex_state = 6},
  [4552] = {.lex_state = 88, .external_lex_state = 6},
  [4553] = {.lex_state = 97, .external_lex_state = 10},
  [4554] = {.lex_state = 88, .external_lex_state = 6},
  [4555] = {.lex_state = 97, .external_lex_state = 10},
  [4556] = {.lex_state = 97, .external_lex_state = 10},
  [4557] = {.lex_state = 97, .external_lex_state = 10},
  [4558] = {.lex_state = 97, .external_lex_state = 10},
  [4559] = {.lex_state = 97, .external_lex_state = 10},
  [4560] = {.lex_state = 97, .external_lex_state = 10},
  [4561] = {.lex_state = 97, .external_lex_state = 10},
  [4562] = {.lex_state = 97, .external_lex_state = 10},
  [4563] = {.lex_state = 97, .external_lex_state = 10},
  [4564] = {.lex_state = 97, .external_lex_state = 10},
  [4565] = {.lex_state = 97, .external_lex_state = 10},
  [4566] = {.lex_state = 97, .external_lex_state = 10},
  [4567] = {.lex_state = 97, .external_lex_state = 10},
  [4568] = {.lex_state = 97, .external_lex_state = 10},
  [4569] = {.lex_state = 97, .external_lex_state = 10},
  [4570] = {.lex_state = 97, .external_lex_state = 10},
  [4571] = {.lex_state = 97, .external_lex_state = 10},
  [4572] = {.lex_state = 97, .external_lex_state = 10},
  [4573] = {.lex_state = 97, .external_lex_state = 10},
  [4574] = {.lex_state = 97, .external_lex_state = 10},
  [4575] = {.lex_state = 97, .external_lex_state = 10},
  [4576] = {.lex_state = 97, .external_lex_state = 10},
  [4577] = {.lex_state = 97, .external_lex_state = 10},
  [4578] = {.lex_state = 97, .external_lex_state = 10},
  [4579] = {.lex_state = 97, .external_lex_state = 10},
  [4580] = {.lex_state = 97, .external_lex_state = 10},
  [4581] = {.lex_state = 97, .external_lex_state = 10},
  [4582] = {.lex_state = 97, .external_lex_state = 10},
  [4583] = {.lex_state = 97, .external_lex_state = 10},
  [4584] = {.lex_state = 97, .external_lex_state = 10},
  [4585] = {.lex_state = 97, .external_lex_state = 10},
  [4586] = {.lex_state = 97, .external_lex_state = 10},
  [4587] = {.lex_state = 97, .external_lex_state = 10},
  [4588] = {.lex_state = 97, .external_lex_state = 10},
  [4589] = {.lex_state = 97, .external_lex_state = 10},
  [4590] = {.lex_state = 97, .external_lex_state = 10},
  [4591] = {.lex_state = 97, .external_lex_state = 10},
  [4592] = {.lex_state = 97, .external_lex_state = 10},
  [4593] = {.lex_state = 97, .external_lex_state = 10},
  [4594] = {.lex_state = 97, .external_lex_state = 10},
  [4595] = {.lex_state = 97, .external_lex_state = 10},
  [4596] = {.lex_state = 97, .external_lex_state = 10},
  [4597] = {.lex_state = 97, .external_lex_state = 10},
  [4598] = {.lex_state = 97, .external_lex_state = 10},
  [4599] = {.lex_state = 97, .external_lex_state = 10},
  [4600] = {.lex_state = 97, .external_lex_state = 10},
  [4601] = {.lex_state = 97, .external_lex_state = 10},
  [4602] = {.lex_state = 97, .external_lex_state = 10},
  [4603] = {.lex_state = 97, .external_lex_state = 10},
  [4604] = {.lex_state = 97, .external_lex_state = 10},
  [4605] = {.lex_state = 97, .external_lex_state = 10},
  [4606] = {.lex_state = 97, .external_lex_state = 10},
  [4607] = {.lex_state = 97, .external_lex_state = 10},
  [4608] = {.lex_state = 97, .external_lex_state = 10},
  [4609] = {.lex_state = 97, .external_lex_state = 10},
  [4610] = {.lex_state = 88, .external_lex_state = 6},
  [4611] = {.lex_state = 97, .external_lex_state = 10},
  [4612] = {.lex_state = 97, .external_lex_state = 10},
  [4613] = {.lex_state = 97, .external_lex_state = 10},
  [4614] = {.lex_state = 97, .external_lex_state = 10},
  [4615] = {.lex_state = 97, .external_lex_state = 10},
  [4616] = {.lex_state = 92, .external_lex_state = 6},
  [4617] = {.lex_state = 97, .external_lex_state = 10},
  [4618] = {.lex_state = 97, .external_lex_state = 10},
  [4619] = {.lex_state = 97, .external_lex_state = 10},
  [4620] = {.lex_state = 97, .external_lex_state = 10},
  [4621] = {.lex_state = 97, .external_lex_state = 10},
  [4622] = {.lex_state = 97, .external_lex_state = 10},
  [4623] = {.lex_state = 97, .external_lex_state = 10},
  [4624] = {.lex_state = 97, .external_lex_state = 10},
  [4625] = {.lex_state = 92, .external_lex_state = 6},
  [4626] = {.lex_state = 92, .external_lex_state = 6},
  [4627] = {.lex_state = 92, .external_lex_state = 6},
  [4628] = {.lex_state = 92, .external_lex_state = 6},
  [4629] = {.lex_state = 92, .external_lex_state = 6},
  [4630] = {.lex_state = 92, .external_lex_state = 6},
  [4631] = {.lex_state = 92, .external_lex_state = 6},
  [4632] = {.lex_state = 92, .external_lex_state = 6},
  [4633] = {.lex_state = 92, .external_lex_state = 6},
  [4634] = {.lex_state = 92, .external_lex_state = 6},
  [4635] = {.lex_state = 92, .external_lex_state = 6},
  [4636] = {.lex_state = 92, .external_lex_state = 6},
  [4637] = {.lex_state = 92, .external_lex_state = 6},
  [4638] = {.lex_state = 92, .external_lex_state = 6},
  [4639] = {.lex_state = 92, .external_lex_state = 6},
  [4640] = {.lex_state = 92, .external_lex_state = 6},
  [4641] = {.lex_state = 92, .external_lex_state = 6},
  [4642] = {.lex_state = 97, .external_lex_state = 10},
  [4643] = {.lex_state = 97, .external_lex_state = 10},
  [4644] = {.lex_state = 97, .external_lex_state = 10},
  [4645] = {.lex_state = 97, .external_lex_state = 10},
  [4646] = {.lex_state = 97, .external_lex_state = 10},
  [4647] = {.lex_state = 97, .external_lex_state = 10},
  [4648] = {.lex_state = 97, .external_lex_state = 10},
  [4649] = {.lex_state = 97, .external_lex_state = 10},
  [4650] = {.lex_state = 97, .external_lex_state = 10},
  [4651] = {.lex_state = 97, .external_lex_state = 10},
  [4652] = {.lex_state = 97, .external_lex_state = 10},
  [4653] = {.lex_state = 97, .external_lex_state = 10},
  [4654] = {.lex_state = 92, .external_lex_state = 6},
  [4655] = {.lex_state = 92, .external_lex_state = 6},
  [4656] = {.lex_state = 97, .external_lex_state = 10},
  [4657] = {.lex_state = 97, .external_lex_state = 4},
  [4658] = {.lex_state = 97, .external_lex_state = 10},
  [4659] = {.lex_state = 88, .external_lex_state = 6},
  [4660] = {.lex_state = 97, .external_lex_state = 10},
  [4661] = {.lex_state = 97, .external_lex_state = 10},
  [4662] = {.lex_state = 97, .external_lex_state = 10},
  [4663] = {.lex_state = 97, .external_lex_state = 10},
  [4664] = {.lex_state = 97, .external_lex_state = 10},
  [4665] = {.lex_state = 97, .external_lex_state = 10},
  [4666] = {.lex_state = 97, .external_lex_state = 10},
  [4667] = {.lex_state = 97, .external_lex_state = 10},
  [4668] = {.lex_state = 97, .external_lex_state = 10},
  [4669] = {.lex_state = 97, .external_lex_state = 10},
  [4670] = {.lex_state = 97, .external_lex_state = 10},
  [4671] = {.lex_state = 97, .external_lex_state = 10},
  [4672] = {.lex_state = 97, .external_lex_state = 10},
  [4673] = {.lex_state = 97, .external_lex_state = 10},
  [4674] = {.lex_state = 92, .external_lex_state = 6},
  [4675] = {.lex_state = 97, .external_lex_state = 10},
  [4676] = {.lex_state = 97, .external_lex_state = 10},
  [4677] = {.lex_state = 97, .external_lex_state = 10},
  [4678] = {.lex_state = 92, .external_lex_state = 6},
  [4679] = {.lex_state = 92, .external_lex_state = 6},
  [4680] = {.lex_state = 92, .external_lex_state = 6},
  [4681] = {.lex_state = 92, .external_lex_state = 6},
  [4682] = {.lex_state = 97, .external_lex_state = 10},
  [4683] = {.lex_state = 97, .external_lex_state = 10},
  [4684] = {.lex_state = 88, .external_lex_state = 6},
  [4685] = {.lex_state = 97, .external_lex_state = 10},
  [4686] = {.lex_state = 97, .external_lex_state = 10},
  [4687] = {.lex_state = 97, .external_lex_state = 10},
  [4688] = {.lex_state = 97, .external_lex_state = 10},
  [4689] = {.lex_state = 97, .external_lex_state = 10},
  [4690] = {.lex_state = 97, .external_lex_state = 10},
  [4691] = {.lex_state = 97, .external_lex_state = 10},
  [4692] = {.lex_state = 97, .external_lex_state = 10},
  [4693] = {.lex_state = 97, .external_lex_state = 10},
  [4694] = {.lex_state = 97, .external_lex_state = 10},
  [4695] = {.lex_state = 97, .external_lex_state = 10},
  [4696] = {.lex_state = 97, .external_lex_state = 5},
  [4697] = {.lex_state = 97, .external_lex_state = 5},
  [4698] = {.lex_state = 97, .external_lex_state = 5},
  [4699] = {.lex_state = 97, .external_lex_state = 5},
  [4700] = {.lex_state = 97, .external_lex_state = 5},
  [4701] = {.lex_state = 88, .external_lex_state = 11},
  [4702] = {.lex_state = 97, .external_lex_state = 5},
  [4703] = {.lex_state = 97, .external_lex_state = 5},
  [4704] = {.lex_state = 97, .external_lex_state = 4},
  [4705] = {.lex_state = 97, .external_lex_state = 4},
  [4706] = {.lex_state = 97, .external_lex_state = 5},
  [4707] = {.lex_state = 97, .external_lex_state = 5},
  [4708] = {.lex_state = 97, .external_lex_state = 5},
  [4709] = {.lex_state = 97, .external_lex_state = 5},
  [4710] = {.lex_state = 97, .external_lex_state = 5},
  [4711] = {.lex_state = 97, .external_lex_state = 5},
  [4712] = {.lex_state = 97, .external_lex_state = 5},
  [4713] = {.lex_state = 97, .external_lex_state = 5},
  [4714] = {.lex_state = 92, .external_lex_state = 9},
  [4715] = {.lex_state = 97, .external_lex_state = 6},
  [4716] = {.lex_state = 97, .external_lex_state = 6},
  [4717] = {.lex_state = 97, .external_lex_state = 5},
  [4718] = {.lex_state = 97, .external_lex_state = 5},
  [4719] = {.lex_state = 97, .external_lex_state = 5},
  [4720] = {.lex_state = 97, .external_lex_state = 5},
  [4721] = {.lex_state = 88, .external_lex_state = 11},
  [4722] = {.lex_state = 97, .external_lex_state = 5},
  [4723] = {.lex_state = 97, .external_lex_state = 5},
  [4724] = {.lex_state = 97, .external_lex_state = 6},
  [4725] = {.lex_state = 88, .external_lex_state = 11},
  [4726] = {.lex_state = 97, .external_lex_state = 5},
  [4727] = {.lex_state = 97, .external_lex_state = 5},
  [4728] = {.lex_state = 97, .external_lex_state = 5},
  [4729] = {.lex_state = 97, .external_lex_state = 7},
  [4730] = {.lex_state = 97, .external_lex_state = 5},
  [4731] = {.lex_state = 88, .external_lex_state = 11},
  [4732] = {.lex_state = 97, .external_lex_state = 6},
  [4733] = {.lex_state = 97, .external_lex_state = 5},
  [4734] = {.lex_state = 97, .external_lex_state = 5},
  [4735] = {.lex_state = 88, .external_lex_state = 11},
  [4736] = {.lex_state = 88, .external_lex_state = 11},
  [4737] = {.lex_state = 92, .external_lex_state = 6},
  [4738] = {.lex_state = 97, .external_lex_state = 5},
  [4739] = {.lex_state = 97, .external_lex_state = 5},
  [4740] = {.lex_state = 88, .external_lex_state = 11},
  [4741] = {.lex_state = 97, .external_lex_state = 5},
  [4742] = {.lex_state = 97, .external_lex_state = 5},
  [4743] = {.lex_state = 97, .external_lex_state = 6},
  [4744] = {.lex_state = 97, .external_lex_state = 6},
  [4745] = {.lex_state = 88, .external_lex_state = 7},
  [4746] = {.lex_state = 97, .external_lex_state = 6},
  [4747] = {.lex_state = 97, .external_lex_state = 6},
  [4748] = {.lex_state = 88, .external_lex_state = 7},
  [4749] = {.lex_state = 88, .external_lex_state = 7},
  [4750] = {.lex_state = 88, .external_lex_state = 7},
  [4751] = {.lex_state = 97, .external_lex_state = 6},
  [4752] = {.lex_state = 97, .external_lex_state = 6},
  [4753] = {.lex_state = 97, .external_lex_state = 6},
  [4754] = {.lex_state = 97, .external_lex_state = 6},
  [4755] = {.lex_state = 97, .external_lex_state = 6},
  [4756] = {.lex_state = 97, .external_lex_state = 6},
  [4757] = {.lex_state = 97, .external_lex_state = 6},
  [4758] = {.lex_state = 97, .external_lex_state = 6},
  [4759] = {.lex_state = 97, .external_lex_state = 6},
  [4760] = {.lex_state = 97, .external_lex_state = 6},
  [4761] = {.lex_state = 88, .external_lex_state = 7},
  [4762] = {.lex_state = 97, .external_lex_state = 7},
  [4763] = {.lex_state = 97, .external_lex_state = 6},
  [4764] = {.lex_state = 97, .external_lex_state = 6},
  [4765] = {.lex_state = 97, .external_lex_state = 6},
  [4766] = {.lex_state = 97, .external_lex_state = 6},
  [4767] = {.lex_state = 97, .external_lex_state = 6},
  [4768] = {.lex_state = 97, .external_lex_state = 6},
  [4769] = {.lex_state = 97, .external_lex_state = 6},
  [4770] = {.lex_state = 97, .external_lex_state = 6},
  [4771] = {.lex_state = 97, .external_lex_state = 6},
  [4772] = {.lex_state = 97, .external_lex_state = 6},
  [4773] = {.lex_state = 97, .external_lex_state = 6},
  [4774] = {.lex_state = 97, .external_lex_state = 6},
  [4775] = {.lex_state = 97, .external_lex_state = 7},
  [4776] = {.lex_state = 97, .external_lex_state = 7},
  [4777] = {.lex_state = 97, .external_lex_state = 7},
  [4778] = {.lex_state = 97, .external_lex_state = 6},
  [4779] = {.lex_state = 97, .external_lex_state = 6},
  [4780] = {.lex_state = 97, .external_lex_state = 6},
  [4781] = {.lex_state = 97, .external_lex_state = 6},
  [4782] = {.lex_state = 97, .external_lex_state = 6},
  [4783] = {.lex_state = 97, .external_lex_state = 7},
  [4784] = {.lex_state = 97, .external_lex_state = 7},
  [4785] = {.lex_state = 97, .external_lex_state = 7},
  [4786] = {.lex_state = 97, .external_lex_state = 6},
  [4787] = {.lex_state = 97, .external_lex_state = 6},
  [4788] = {.lex_state = 97, .external_lex_state = 6},
  [4789] = {.lex_state = 97, .external_lex_state = 6},
  [4790] = {.lex_state = 97, .external_lex_state = 6},
  [4791] = {.lex_state = 97, .external_lex_state = 6},
  [4792] = {.lex_state = 97, .external_lex_state = 6},
  [4793] = {.lex_state = 97, .external_lex_state = 6},
  [4794] = {.lex_state = 97, .external_lex_state = 6},
  [4795] = {.lex_state = 97, .external_lex_state = 6},
  [4796] = {.lex_state = 97, .external_lex_state = 6},
  [4797] = {.lex_state = 97, .external_lex_state = 6},
  [4798] = {.lex_state = 97, .external_lex_state = 6},
  [4799] = {.lex_state = 97, .external_lex_state = 6},
  [4800] = {.lex_state = 97, .external_lex_state = 6},
  [4801] = {.lex_state = 97, .external_lex_state = 6},
  [4802] = {.lex_state = 97, .external_lex_state = 6},
  [4803] = {.lex_state = 97, .external_lex_state = 6},
  [4804] = {.lex_state = 97, .external_lex_state = 7},
  [4805] = {.lex_state = 97, .external_lex_state = 6},
  [4806] = {.lex_state = 88, .external_lex_state = 7},
  [4807] = {.lex_state = 97, .external_lex_state = 6},
  [4808] = {.lex_state = 97, .external_lex_state = 6},
  [4809] = {.lex_state = 97, .external_lex_state = 6},
  [4810] = {.lex_state = 97, .external_lex_state = 6},
  [4811] = {.lex_state = 97, .external_lex_state = 6},
  [4812] = {.lex_state = 97, .external_lex_state = 6},
  [4813] = {.lex_state = 97, .external_lex_state = 6},
  [4814] = {.lex_state = 97, .external_lex_state = 6},
  [4815] = {.lex_state = 88, .external_lex_state = 7},
  [4816] = {.lex_state = 97, .external_lex_state = 6},
  [4817] = {.lex_state = 88, .external_lex_state = 7},
  [4818] = {.lex_state = 97, .external_lex_state = 6},
  [4819] = {.lex_state = 92, .external_lex_state = 9},
  [4820] = {.lex_state = 97, .external_lex_state = 6},
  [4821] = {.lex_state = 88, .external_lex_state = 7},
  [4822] = {.lex_state = 97, .external_lex_state = 6},
  [4823] = {.lex_state = 97, .external_lex_state = 7},
  [4824] = {.lex_state = 97, .external_lex_state = 7},
  [4825] = {.lex_state = 97, .external_lex_state = 7},
  [4826] = {.lex_state = 97, .external_lex_state = 7},
  [4827] = {.lex_state = 97, .external_lex_state = 7},
  [4828] = {.lex_state = 97, .external_lex_state = 7},
  [4829] = {.lex_state = 97, .external_lex_state = 7},
  [4830] = {.lex_state = 97, .external_lex_state = 7},
  [4831] = {.lex_state = 97, .external_lex_state = 7},
  [4832] = {.lex_state = 97, .external_lex_state = 7},
  [4833] = {.lex_state = 97, .external_lex_state = 7},
  [4834] = {.lex_state = 97, .external_lex_state = 7},
  [4835] = {.lex_state = 97, .external_lex_state = 7},
  [4836] = {.lex_state = 97, .external_lex_state = 7},
  [4837] = {.lex_state = 97, .external_lex_state = 6},
  [4838] = {.lex_state = 88, .external_lex_state = 7},
  [4839] = {.lex_state = 97, .external_lex_state = 7},
  [4840] = {.lex_state = 97, .external_lex_state = 7},
  [4841] = {.lex_state = 97, .external_lex_state = 7},
  [4842] = {.lex_state = 88, .external_lex_state = 7},
  [4843] = {.lex_state = 88, .external_lex_state = 7},
  [4844] = {.lex_state = 97, .external_lex_state = 7},
  [4845] = {.lex_state = 88, .external_lex_state = 7},
  [4846] = {.lex_state = 88, .external_lex_state = 7},
  [4847] = {.lex_state = 92, .external_lex_state = 6},
  [4848] = {.lex_state = 97, .external_lex_state = 6},
  [4849] = {.lex_state = 97, .external_lex_state = 6},
  [4850] = {.lex_state = 97, .external_lex_state = 6},
  [4851] = {.lex_state = 97, .external_lex_state = 6},
  [4852] = {.lex_state = 97, .external_lex_state = 6},
  [4853] = {.lex_state = 97, .external_lex_state = 6},
  [4854] = {.lex_state = 97, .external_lex_state = 6},
  [4855] = {.lex_state = 97, .external_lex_state = 6},
  [4856] = {.lex_state = 97, .external_lex_state = 6},
  [4857] = {.lex_state = 97, .external_lex_state = 6},
  [4858] = {.lex_state = 97, .external_lex_state = 6},
  [4859] = {.lex_state = 97, .external_lex_state = 6},
  [4860] = {.lex_state = 88, .external_lex_state = 7},
  [4861] = {.lex_state = 88, .external_lex_state = 7},
  [4862] = {.lex_state = 97, .external_lex_state = 6},
  [4863] = {.lex_state = 97, .external_lex_state = 6},
  [4864] = {.lex_state = 97, .external_lex_state = 6},
  [4865] = {.lex_state = 97, .external_lex_state = 6},
  [4866] = {.lex_state = 97, .external_lex_state = 6},
  [4867] = {.lex_state = 97, .external_lex_state = 6},
  [4868] = {.lex_state = 97, .external_lex_state = 6},
  [4869] = {.lex_state = 97, .external_lex_state = 6},
  [4870] = {.lex_state = 97, .external_lex_state = 6},
  [4871] = {.lex_state = 97, .external_lex_state = 6},
  [4872] = {.lex_state = 88, .external_lex_state = 7},
  [4873] = {.lex_state = 97, .external_lex_state = 6},
  [4874] = {.lex_state = 97, .external_lex_state = 6},
  [4875] = {.lex_state = 97, .external_lex_state = 6},
  [4876] = {.lex_state = 97, .external_lex_state = 6},
  [4877] = {.lex_state = 97, .external_lex_state = 6},
  [4878] = {.lex_state = 97, .external_lex_state = 6},
  [4879] = {.lex_state = 97, .external_lex_state = 6},
  [4880] = {.lex_state = 88, .external_lex_state = 7},
  [4881] = {.lex_state = 92, .external_lex_state = 6},
  [4882] = {.lex_state = 97, .external_lex_state = 7},
  [4883] = {.lex_state = 97, .external_lex_state = 7},
  [4884] = {.lex_state = 97, .external_lex_state = 7},
  [4885] = {.lex_state = 97, .external_lex_state = 6},
  [4886] = {.lex_state = 97, .external_lex_state = 6},
  [4887] = {.lex_state = 97, .external_lex_state = 6},
  [4888] = {.lex_state = 97, .external_lex_state = 6},
  [4889] = {.lex_state = 88, .external_lex_state = 7},
  [4890] = {.lex_state = 97, .external_lex_state = 6},
  [4891] = {.lex_state = 97, .external_lex_state = 6},
  [4892] = {.lex_state = 88, .external_lex_state = 7},
  [4893] = {.lex_state = 88, .external_lex_state = 7},
  [4894] = {.lex_state = 88, .external_lex_state = 7},
  [4895] = {.lex_state = 88, .external_lex_state = 7},
  [4896] = {.lex_state = 88, .external_lex_state = 7},
  [4897] = {.lex_state = 88, .external_lex_state = 7},
  [4898] = {.lex_state = 97, .external_lex_state = 5},
  [4899] = {.lex_state = 97, .external_lex_state = 10},
  [4900] = {.lex_state = 88, .external_lex_state = 7},
  [4901] = {.lex_state = 88, .external_lex_state = 7},
  [4902] = {.lex_state = 88, .external_lex_state = 7},
  [4903] = {.lex_state = 88, .external_lex_state = 7},
  [4904] = {.lex_state = 88, .external_lex_state = 7},
  [4905] = {.lex_state = 88, .external_lex_state = 7},
  [4906] = {.lex_state = 88, .external_lex_state = 7},
  [4907] = {.lex_state = 88, .external_lex_state = 7},
  [4908] = {.lex_state = 88, .external_lex_state = 7},
  [4909] = {.lex_state = 88, .external_lex_state = 7},
  [4910] = {.lex_state = 88, .external_lex_state = 7},
  [4911] = {.lex_state = 88, .external_lex_state = 7},
  [4912] = {.lex_state = 88, .external_lex_state = 7},
  [4913] = {.lex_state = 88, .external_lex_state = 7},
  [4914] = {.lex_state = 97, .external_lex_state = 10},
  [4915] = {.lex_state = 88, .external_lex_state = 7},
  [4916] = {.lex_state = 88, .external_lex_state = 7},
  [4917] = {.lex_state = 88, .external_lex_state = 7},
  [4918] = {.lex_state = 88, .external_lex_state = 7},
  [4919] = {.lex_state = 88, .external_lex_state = 7},
  [4920] = {.lex_state = 88, .external_lex_state = 7},
  [4921] = {.lex_state = 88, .external_lex_state = 7},
  [4922] = {.lex_state = 88, .external_lex_state = 7},
  [4923] = {.lex_state = 88, .external_lex_state = 7},
  [4924] = {.lex_state = 88, .external_lex_state = 7},
  [4925] = {.lex_state = 88, .external_lex_state = 7},
  [4926] = {.lex_state = 88, .external_lex_state = 7},
  [4927] = {.lex_state = 88, .external_lex_state = 7},
  [4928] = {.lex_state = 88, .external_lex_state = 7},
  [4929] = {.lex_state = 88, .external_lex_state = 7},
  [4930] = {.lex_state = 88, .external_lex_state = 7},
  [4931] = {.lex_state = 88, .external_lex_state = 7},
  [4932] = {.lex_state = 88, .external_lex_state = 7},
  [4933] = {.lex_state = 88, .external_lex_state = 7},
  [4934] = {.lex_state = 88, .external_lex_state = 7},
  [4935] = {.lex_state = 88, .external_lex_state = 7},
  [4936] = {.lex_state = 88, .external_lex_state = 7},
  [4937] = {.lex_state = 92, .external_lex_state = 6},
  [4938] = {.lex_state = 88, .external_lex_state = 7},
  [4939] = {.lex_state = 88, .external_lex_state = 7},
  [4940] = {.lex_state = 88, .external_lex_state = 7},
  [4941] = {.lex_state = 88, .external_lex_state = 7},
  [4942] = {.lex_state = 88, .external_lex_state = 7},
  [4943] = {.lex_state = 88, .external_lex_state = 7},
  [4944] = {.lex_state = 88, .external_lex_state = 7},
  [4945] = {.lex_state = 88, .external_lex_state = 7},
  [4946] = {.lex_state = 88, .external_lex_state = 7},
  [4947] = {.lex_state = 88, .external_lex_state = 7},
  [4948] = {.lex_state = 88, .external_lex_state = 7},
  [4949] = {.lex_state = 88, .external_lex_state = 7},
  [4950] = {.lex_state = 88, .external_lex_state = 7},
  [4951] = {.lex_state = 88, .external_lex_state = 7},
  [4952] = {.lex_state = 88, .external_lex_state = 7},
  [4953] = {.lex_state = 97, .external_lex_state = 5},
  [4954] = {.lex_state = 97, .external_lex_state = 5},
  [4955] = {.lex_state = 97, .external_lex_state = 5},
  [4956] = {.lex_state = 97, .external_lex_state = 5},
  [4957] = {.lex_state = 97, .external_lex_state = 5},
  [4958] = {.lex_state = 97, .external_lex_state = 5},
  [4959] = {.lex_state = 97, .external_lex_state = 5},
  [4960] = {.lex_state = 97, .external_lex_state = 5},
  [4961] = {.lex_state = 97, .external_lex_state = 5},
  [4962] = {.lex_state = 97, .external_lex_state = 5},
  [4963] = {.lex_state = 97, .external_lex_state = 5},
  [4964] = {.lex_state = 88, .external_lex_state = 7},
  [4965] = {.lex_state = 97, .external_lex_state = 10},
  [4966] = {.lex_state = 97, .external_lex_state = 5},
  [4967] = {.lex_state = 97, .external_lex_state = 5},
  [4968] = {.lex_state = 97, .external_lex_state = 5},
  [4969] = {.lex_state = 97, .external_lex_state = 5},
  [4970] = {.lex_state = 88, .external_lex_state = 6},
  [4971] = {.lex_state = 88, .external_lex_state = 7},
  [4972] = {.lex_state = 88, .external_lex_state = 7},
  [4973] = {.lex_state = 88, .external_lex_state = 7},
  [4974] = {.lex_state = 88, .external_lex_state = 7},
  [4975] = {.lex_state = 88, .external_lex_state = 7},
  [4976] = {.lex_state = 88, .external_lex_state = 7},
  [4977] = {.lex_state = 88, .external_lex_state = 7},
  [4978] = {.lex_state = 88, .external_lex_state = 7},
  [4979] = {.lex_state = 88, .external_lex_state = 7},
  [4980] = {.lex_state = 88, .external_lex_state = 7},
  [4981] = {.lex_state = 88, .external_lex_state = 7},
  [4982] = {.lex_state = 88, .external_lex_state = 7},
  [4983] = {.lex_state = 97, .external_lex_state = 5},
  [4984] = {.lex_state = 88, .external_lex_state = 7},
  [4985] = {.lex_state = 88, .external_lex_state = 7},
  [4986] = {.lex_state = 88, .external_lex_state = 7},
  [4987] = {.lex_state = 88, .external_lex_state = 7},
  [4988] = {.lex_state = 88, .external_lex_state = 7},
  [4989] = {.lex_state = 88, .external_lex_state = 7},
  [4990] = {.lex_state = 88, .external_lex_state = 7},
  [4991] = {.lex_state = 97, .external_lex_state = 6},
  [4992] = {.lex_state = 88, .external_lex_state = 7},
  [4993] = {.lex_state = 88, .external_lex_state = 7},
  [4994] = {.lex_state = 88, .external_lex_state = 7},
  [4995] = {.lex_state = 88, .external_lex_state = 7},
  [4996] = {.lex_state = 88, .external_lex_state = 7},
  [4997] = {.lex_state = 88, .external_lex_state = 7},
  [4998] = {.lex_state = 88, .external_lex_state = 7},
  [4999] = {.lex_state = 88, .external_lex_state = 7},
  [5000] = {.lex_state = 88, .external_lex_state = 7},
  [5001] = {.lex_state = 88, .external_lex_state = 7},
  [5002] = {.lex_state = 88, .external_lex_state = 7},
  [5003] = {.lex_state = 88, .external_lex_state = 7},
  [5004] = {.lex_state = 88, .external_lex_state = 7},
  [5005] = {.lex_state = 88, .external_lex_state = 7},
  [5006] = {.lex_state = 88, .external_lex_state = 7},
  [5007] = {.lex_state = 88, .external_lex_state = 7},
  [5008] = {.lex_state = 88, .external_lex_state = 7},
  [5009] = {.lex_state = 88, .external_lex_state = 7},
  [5010] = {.lex_state = 88, .external_lex_state = 7},
  [5011] = {.lex_state = 88, .external_lex_state = 7},
  [5012] = {.lex_state = 88, .external_lex_state = 7},
  [5013] = {.lex_state = 88, .external_lex_state = 7},
  [5014] = {.lex_state = 88, .external_lex_state = 7},
  [5015] = {.lex_state = 97, .external_lex_state = 5},
  [5016] = {.lex_state = 88, .external_lex_state = 7},
  [5017] = {.lex_state = 88, .external_lex_state = 7},
  [5018] = {.lex_state = 88, .external_lex_state = 7},
  [5019] = {.lex_state = 88, .external_lex_state = 6},
  [5020] = {.lex_state = 88, .external_lex_state = 7},
  [5021] = {.lex_state = 88, .external_lex_state = 7},
  [5022] = {.lex_state = 88, .external_lex_state = 7},
  [5023] = {.lex_state = 88, .external_lex_state = 7},
  [5024] = {.lex_state = 88, .external_lex_state = 7},
  [5025] = {.lex_state = 88, .external_lex_state = 7},
  [5026] = {.lex_state = 88, .external_lex_state = 7},
  [5027] = {.lex_state = 88, .external_lex_state = 7},
  [5028] = {.lex_state = 88, .external_lex_state = 7},
  [5029] = {.lex_state = 88, .external_lex_state = 7},
  [5030] = {.lex_state = 88, .external_lex_state = 7},
  [5031] = {.lex_state = 88, .external_lex_state = 7},
  [5032] = {.lex_state = 88, .external_lex_state = 7},
  [5033] = {.lex_state = 88, .external_lex_state = 7},
  [5034] = {.lex_state = 88, .external_lex_state = 7},
  [5035] = {.lex_state = 88, .external_lex_state = 7},
  [5036] = {.lex_state = 88, .external_lex_state = 7},
  [5037] = {.lex_state = 88, .external_lex_state = 7},
  [5038] = {.lex_state = 88, .external_lex_state = 7},
  [5039] = {.lex_state = 88, .external_lex_state = 7},
  [5040] = {.lex_state = 97, .external_lex_state = 6},
  [5041] = {.lex_state = 88, .external_lex_state = 7},
  [5042] = {.lex_state = 88, .external_lex_state = 7},
  [5043] = {.lex_state = 88, .external_lex_state = 7},
  [5044] = {.lex_state = 88, .external_lex_state = 7},
  [5045] = {.lex_state = 88, .external_lex_state = 7},
  [5046] = {.lex_state = 88, .external_lex_state = 7},
  [5047] = {.lex_state = 88, .external_lex_state = 7},
  [5048] = {.lex_state = 88, .external_lex_state = 7},
  [5049] = {.lex_state = 88, .external_lex_state = 7},
  [5050] = {.lex_state = 88, .external_lex_state = 7},
  [5051] = {.lex_state = 88, .external_lex_state = 6},
  [5052] = {.lex_state = 88, .external_lex_state = 7},
  [5053] = {.lex_state = 88, .external_lex_state = 7},
  [5054] = {.lex_state = 88, .external_lex_state = 6},
  [5055] = {.lex_state = 88, .external_lex_state = 7},
  [5056] = {.lex_state = 88, .external_lex_state = 7},
  [5057] = {.lex_state = 88, .external_lex_state = 7},
  [5058] = {.lex_state = 88, .external_lex_state = 6},
  [5059] = {.lex_state = 88, .external_lex_state = 6},
  [5060] = {.lex_state = 88, .external_lex_state = 7},
  [5061] = {.lex_state = 88, .external_lex_state = 6},
  [5062] = {.lex_state = 88, .external_lex_state = 6},
  [5063] = {.lex_state = 88, .external_lex_state = 7},
  [5064] = {.lex_state = 88, .external_lex_state = 6},
  [5065] = {.lex_state = 88, .external_lex_state = 6},
  [5066] = {.lex_state = 88, .external_lex_state = 7},
  [5067] = {.lex_state = 88, .external_lex_state = 6},
  [5068] = {.lex_state = 88, .external_lex_state = 6},
  [5069] = {.lex_state = 88, .external_lex_state = 7},
  [5070] = {.lex_state = 88, .external_lex_state = 7},
  [5071] = {.lex_state = 88, .external_lex_state = 6},
  [5072] = {.lex_state = 88, .external_lex_state = 7},
  [5073] = {.lex_state = 88, .external_lex_state = 6},
  [5074] = {.lex_state = 88, .external_lex_state = 7},
  [5075] = {.lex_state = 88, .external_lex_state = 6},
  [5076] = {.lex_state = 88, .external_lex_state = 7},
  [5077] = {.lex_state = 88, .external_lex_state = 6},
  [5078] = {.lex_state = 88, .external_lex_state = 6},
  [5079] = {.lex_state = 88, .external_lex_state = 7},
  [5080] = {.lex_state = 88, .external_lex_state = 7},
  [5081] = {.lex_state = 88, .external_lex_state = 7},
  [5082] = {.lex_state = 88, .external_lex_state = 7},
  [5083] = {.lex_state = 88, .external_lex_state = 7},
  [5084] = {.lex_state = 88, .external_lex_state = 7},
  [5085] = {.lex_state = 88, .external_lex_state = 7},
  [5086] = {.lex_state = 88, .external_lex_state = 7},
  [5087] = {.lex_state = 88, .external_lex_state = 7},
  [5088] = {.lex_state = 88, .external_lex_state = 7},
  [5089] = {.lex_state = 88, .external_lex_state = 7},
  [5090] = {.lex_state = 88, .external_lex_state = 7},
  [5091] = {.lex_state = 88, .external_lex_state = 7},
  [5092] = {.lex_state = 88, .external_lex_state = 7},
  [5093] = {.lex_state = 88, .external_lex_state = 7},
  [5094] = {.lex_state = 88, .external_lex_state = 7},
  [5095] = {.lex_state = 88, .external_lex_state = 7},
  [5096] = {.lex_state = 88, .external_lex_state = 7},
  [5097] = {.lex_state = 88, .external_lex_state = 7},
  [5098] = {.lex_state = 88, .external_lex_state = 7},
  [5099] = {.lex_state = 88, .external_lex_state = 7},
  [5100] = {.lex_state = 88, .external_lex_state = 7},
  [5101] = {.lex_state = 88, .external_lex_state = 7},
  [5102] = {.lex_state = 88, .external_lex_state = 7},
  [5103] = {.lex_state = 88, .external_lex_state = 7},
  [5104] = {.lex_state = 88, .external_lex_state = 7},
  [5105] = {.lex_state = 88, .external_lex_state = 7},
  [5106] = {.lex_state = 88, .external_lex_state = 7},
  [5107] = {.lex_state = 88, .external_lex_state = 7},
  [5108] = {.lex_state = 88, .external_lex_state = 7},
  [5109] = {.lex_state = 88, .external_lex_state = 7},
  [5110] = {.lex_state = 97, .external_lex_state = 5},
  [5111] = {.lex_state = 88, .external_lex_state = 7},
  [5112] = {.lex_state = 88, .external_lex_state = 7},
  [5113] = {.lex_state = 88, .external_lex_state = 7},
  [5114] = {.lex_state = 88, .external_lex_state = 7},
  [5115] = {.lex_state = 88, .external_lex_state = 7},
  [5116] = {.lex_state = 97, .external_lex_state = 6},
  [5117] = {.lex_state = 88, .external_lex_state = 7},
  [5118] = {.lex_state = 88, .external_lex_state = 7},
  [5119] = {.lex_state = 88, .external_lex_state = 6},
  [5120] = {.lex_state = 88, .external_lex_state = 7},
  [5121] = {.lex_state = 88, .external_lex_state = 7},
  [5122] = {.lex_state = 88, .external_lex_state = 7},
  [5123] = {.lex_state = 88, .external_lex_state = 7},
  [5124] = {.lex_state = 88, .external_lex_state = 7},
  [5125] = {.lex_state = 88, .external_lex_state = 7},
  [5126] = {.lex_state = 88, .external_lex_state = 7},
  [5127] = {.lex_state = 88, .external_lex_state = 7},
  [5128] = {.lex_state = 88, .external_lex_state = 7},
  [5129] = {.lex_state = 88, .external_lex_state = 7},
  [5130] = {.lex_state = 88, .external_lex_state = 7},
  [5131] = {.lex_state = 88, .external_lex_state = 7},
  [5132] = {.lex_state = 88, .external_lex_state = 7},
  [5133] = {.lex_state = 88, .external_lex_state = 7},
  [5134] = {.lex_state = 88, .external_lex_state = 7},
  [5135] = {.lex_state = 88, .external_lex_state = 7},
  [5136] = {.lex_state = 88, .external_lex_state = 6},
  [5137] = {.lex_state = 88, .external_lex_state = 7},
  [5138] = {.lex_state = 88, .external_lex_state = 7},
  [5139] = {.lex_state = 88, .external_lex_state = 7},
  [5140] = {.lex_state = 88, .external_lex_state = 7},
  [5141] = {.lex_state = 88, .external_lex_state = 7},
  [5142] = {.lex_state = 88, .external_lex_state = 7},
  [5143] = {.lex_state = 88, .external_lex_state = 7},
  [5144] = {.lex_state = 88, .external_lex_state = 7},
  [5145] = {.lex_state = 88, .external_lex_state = 7},
  [5146] = {.lex_state = 88, .external_lex_state = 7},
  [5147] = {.lex_state = 88, .external_lex_state = 7},
  [5148] = {.lex_state = 88, .external_lex_state = 7},
  [5149] = {.lex_state = 88, .external_lex_state = 7},
  [5150] = {.lex_state = 97, .external_lex_state = 5},
  [5151] = {.lex_state = 88, .external_lex_state = 7},
  [5152] = {.lex_state = 88, .external_lex_state = 7},
  [5153] = {.lex_state = 88, .external_lex_state = 7},
  [5154] = {.lex_state = 88, .external_lex_state = 7},
  [5155] = {.lex_state = 88, .external_lex_state = 7},
  [5156] = {.lex_state = 88, .external_lex_state = 7},
  [5157] = {.lex_state = 88, .external_lex_state = 7},
  [5158] = {.lex_state = 88, .external_lex_state = 7},
  [5159] = {.lex_state = 88, .external_lex_state = 7},
  [5160] = {.lex_state = 88, .external_lex_state = 6},
  [5161] = {.lex_state = 88, .external_lex_state = 7},
  [5162] = {.lex_state = 88, .external_lex_state = 7},
  [5163] = {.lex_state = 88, .external_lex_state = 7},
  [5164] = {.lex_state = 88, .external_lex_state = 7},
  [5165] = {.lex_state = 88, .external_lex_state = 7},
  [5166] = {.lex_state = 88, .external_lex_state = 7},
  [5167] = {.lex_state = 88, .external_lex_state = 7},
  [5168] = {.lex_state = 88, .external_lex_state = 7},
  [5169] = {.lex_state = 88, .external_lex_state = 7},
  [5170] = {.lex_state = 88, .external_lex_state = 7},
  [5171] = {.lex_state = 88, .external_lex_state = 7},
  [5172] = {.lex_state = 88, .external_lex_state = 7},
  [5173] = {.lex_state = 88, .external_lex_state = 7},
  [5174] = {.lex_state = 88, .external_lex_state = 7},
  [5175] = {.lex_state = 88, .external_lex_state = 7},
  [5176] = {.lex_state = 88, .external_lex_state = 7},
  [5177] = {.lex_state = 88, .external_lex_state = 7},
  [5178] = {.lex_state = 88, .external_lex_state = 7},
  [5179] = {.lex_state = 88, .external_lex_state = 7},
  [5180] = {.lex_state = 88, .external_lex_state = 7},
  [5181] = {.lex_state = 88, .external_lex_state = 7},
  [5182] = {.lex_state = 97, .external_lex_state = 6},
  [5183] = {.lex_state = 88, .external_lex_state = 7},
  [5184] = {.lex_state = 88, .external_lex_state = 7},
  [5185] = {.lex_state = 88, .external_lex_state = 7},
  [5186] = {.lex_state = 88, .external_lex_state = 7},
  [5187] = {.lex_state = 88, .external_lex_state = 7},
  [5188] = {.lex_state = 88, .external_lex_state = 7},
  [5189] = {.lex_state = 88, .external_lex_state = 7},
  [5190] = {.lex_state = 88, .external_lex_state = 7},
  [5191] = {.lex_state = 88, .external_lex_state = 7},
  [5192] = {.lex_state = 88, .external_lex_state = 7},
  [5193] = {.lex_state = 88, .external_lex_state = 7},
  [5194] = {.lex_state = 88, .external_lex_state = 7},
  [5195] = {.lex_state = 88, .external_lex_state = 7},
  [5196] = {.lex_state = 88, .external_lex_state = 7},
  [5197] = {.lex_state = 88, .external_lex_state = 7},
  [5198] = {.lex_state = 88, .external_lex_state = 7},
  [5199] = {.lex_state = 88, .external_lex_state = 7},
  [5200] = {.lex_state = 88, .external_lex_state = 7},
  [5201] = {.lex_state = 88, .external_lex_state = 7},
  [5202] = {.lex_state = 88, .external_lex_state = 7},
  [5203] = {.lex_state = 88, .external_lex_state = 7},
  [5204] = {.lex_state = 88, .external_lex_state = 7},
  [5205] = {.lex_state = 88, .external_lex_state = 7},
  [5206] = {.lex_state = 88, .external_lex_state = 7},
  [5207] = {.lex_state = 88, .external_lex_state = 7},
  [5208] = {.lex_state = 88, .external_lex_state = 7},
  [5209] = {.lex_state = 88, .external_lex_state = 7},
  [5210] = {.lex_state = 88, .external_lex_state = 7},
  [5211] = {.lex_state = 88, .external_lex_state = 7},
  [5212] = {.lex_state = 88, .external_lex_state = 7},
  [5213] = {.lex_state = 88, .external_lex_state = 7},
  [5214] = {.lex_state = 88, .external_lex_state = 7},
  [5215] = {.lex_state = 88, .external_lex_state = 7},
  [5216] = {.lex_state = 88, .external_lex_state = 7},
  [5217] = {.lex_state = 88, .external_lex_state = 7},
  [5218] = {.lex_state = 88, .external_lex_state = 7},
  [5219] = {.lex_state = 88, .external_lex_state = 7},
  [5220] = {.lex_state = 88, .external_lex_state = 7},
  [5221] = {.lex_state = 88, .external_lex_state = 7},
  [5222] = {.lex_state = 88, .external_lex_state = 7},
  [5223] = {.lex_state = 88, .external_lex_state = 7},
  [5224] = {.lex_state = 88, .external_lex_state = 7},
  [5225] = {.lex_state = 88, .external_lex_state = 7},
  [5226] = {.lex_state = 88, .external_lex_state = 7},
  [5227] = {.lex_state = 88, .external_lex_state = 7},
  [5228] = {.lex_state = 88, .external_lex_state = 7},
  [5229] = {.lex_state = 88, .external_lex_state = 7},
  [5230] = {.lex_state = 88, .external_lex_state = 7},
  [5231] = {.lex_state = 88, .external_lex_state = 7},
  [5232] = {.lex_state = 88, .external_lex_state = 7},
  [5233] = {.lex_state = 88, .external_lex_state = 7},
  [5234] = {.lex_state = 88, .external_lex_state = 7},
  [5235] = {.lex_state = 88, .external_lex_state = 7},
  [5236] = {.lex_state = 88, .external_lex_state = 7},
  [5237] = {.lex_state = 88, .external_lex_state = 7},
  [5238] = {.lex_state = 88, .external_lex_state = 7},
  [5239] = {.lex_state = 88, .external_lex_state = 7},
  [5240] = {.lex_state = 88, .external_lex_state = 7},
  [5241] = {.lex_state = 88, .external_lex_state = 7},
  [5242] = {.lex_state = 88, .external_lex_state = 7},
  [5243] = {.lex_state = 88, .external_lex_state = 7},
  [5244] = {.lex_state = 88, .external_lex_state = 7},
  [5245] = {.lex_state = 88, .external_lex_state = 7},
  [5246] = {.lex_state = 88, .external_lex_state = 7},
  [5247] = {.lex_state = 88, .external_lex_state = 7},
  [5248] = {.lex_state = 88, .external_lex_state = 7},
  [5249] = {.lex_state = 88, .external_lex_state = 7},
  [5250] = {.lex_state = 88, .external_lex_state = 7},
  [5251] = {.lex_state = 88, .external_lex_state = 7},
  [5252] = {.lex_state = 88, .external_lex_state = 7},
  [5253] = {.lex_state = 88, .external_lex_state = 7},
  [5254] = {.lex_state = 88, .external_lex_state = 7},
  [5255] = {.lex_state = 88, .external_lex_state = 7},
  [5256] = {.lex_state = 88, .external_lex_state = 7},
  [5257] = {.lex_state = 88, .external_lex_state = 7},
  [5258] = {.lex_state = 88, .external_lex_state = 7},
  [5259] = {.lex_state = 88, .external_lex_state = 7},
  [5260] = {.lex_state = 88, .external_lex_state = 7},
  [5261] = {.lex_state = 88, .external_lex_state = 7},
  [5262] = {.lex_state = 88, .external_lex_state = 7},
  [5263] = {.lex_state = 88, .external_lex_state = 7},
  [5264] = {.lex_state = 88, .external_lex_state = 7},
  [5265] = {.lex_state = 88, .external_lex_state = 7},
  [5266] = {.lex_state = 88, .external_lex_state = 7},
  [5267] = {.lex_state = 88, .external_lex_state = 7},
  [5268] = {.lex_state = 88, .external_lex_state = 7},
  [5269] = {.lex_state = 88, .external_lex_state = 7},
  [5270] = {.lex_state = 88, .external_lex_state = 7},
  [5271] = {.lex_state = 88, .external_lex_state = 7},
  [5272] = {.lex_state = 88, .external_lex_state = 7},
  [5273] = {.lex_state = 88, .external_lex_state = 7},
  [5274] = {.lex_state = 88, .external_lex_state = 7},
  [5275] = {.lex_state = 88, .external_lex_state = 7},
  [5276] = {.lex_state = 88, .external_lex_state = 7},
  [5277] = {.lex_state = 88, .external_lex_state = 7},
  [5278] = {.lex_state = 88, .external_lex_state = 7},
  [5279] = {.lex_state = 97, .external_lex_state = 7},
  [5280] = {.lex_state = 88, .external_lex_state = 7},
  [5281] = {.lex_state = 88, .external_lex_state = 7},
  [5282] = {.lex_state = 88, .external_lex_state = 7},
  [5283] = {.lex_state = 88, .external_lex_state = 7},
  [5284] = {.lex_state = 88, .external_lex_state = 7},
  [5285] = {.lex_state = 88, .external_lex_state = 7},
  [5286] = {.lex_state = 88, .external_lex_state = 7},
  [5287] = {.lex_state = 88, .external_lex_state = 7},
  [5288] = {.lex_state = 88, .external_lex_state = 7},
  [5289] = {.lex_state = 88, .external_lex_state = 7},
  [5290] = {.lex_state = 88, .external_lex_state = 7},
  [5291] = {.lex_state = 88, .external_lex_state = 7},
  [5292] = {.lex_state = 88, .external_lex_state = 7},
  [5293] = {.lex_state = 88, .external_lex_state = 7},
  [5294] = {.lex_state = 88, .external_lex_state = 7},
  [5295] = {.lex_state = 88, .external_lex_state = 7},
  [5296] = {.lex_state = 88, .external_lex_state = 7},
  [5297] = {.lex_state = 88, .external_lex_state = 7},
  [5298] = {.lex_state = 88, .external_lex_state = 7},
  [5299] = {.lex_state = 88, .external_lex_state = 7},
  [5300] = {.lex_state = 88, .external_lex_state = 7},
  [5301] = {.lex_state = 88, .external_lex_state = 7},
  [5302] = {.lex_state = 88, .external_lex_state = 7},
  [5303] = {.lex_state = 88, .external_lex_state = 7},
  [5304] = {.lex_state = 88, .external_lex_state = 7},
  [5305] = {.lex_state = 88, .external_lex_state = 7},
  [5306] = {.lex_state = 88, .external_lex_state = 7},
  [5307] = {.lex_state = 88, .external_lex_state = 7},
  [5308] = {.lex_state = 88, .external_lex_state = 7},
  [5309] = {.lex_state = 88, .external_lex_state = 7},
  [5310] = {.lex_state = 88, .external_lex_state = 7},
  [5311] = {.lex_state = 88, .external_lex_state = 7},
  [5312] = {.lex_state = 88, .external_lex_state = 7},
  [5313] = {.lex_state = 88, .external_lex_state = 7},
  [5314] = {.lex_state = 88, .external_lex_state = 7},
  [5315] = {.lex_state = 88, .external_lex_state = 7},
  [5316] = {.lex_state = 88, .external_lex_state = 7},
  [5317] = {.lex_state = 88, .external_lex_state = 7},
  [5318] = {.lex_state = 88, .external_lex_state = 7},
  [5319] = {.lex_state = 88, .external_lex_state = 7},
  [5320] = {.lex_state = 88, .external_lex_state = 7},
  [5321] = {.lex_state = 88, .external_lex_state = 7},
  [5322] = {.lex_state = 88, .external_lex_state = 7},
  [5323] = {.lex_state = 88, .external_lex_state = 7},
  [5324] = {.lex_state = 88, .external_lex_state = 7},
  [5325] = {.lex_state = 88, .external_lex_state = 7},
  [5326] = {.lex_state = 88, .external_lex_state = 7},
  [5327] = {.lex_state = 88, .external_lex_state = 7},
  [5328] = {.lex_state = 88, .external_lex_state = 7},
  [5329] = {.lex_state = 88, .external_lex_state = 7},
  [5330] = {.lex_state = 88, .external_lex_state = 7},
  [5331] = {.lex_state = 88, .external_lex_state = 7},
  [5332] = {.lex_state = 88, .external_lex_state = 7},
  [5333] = {.lex_state = 88, .external_lex_state = 7},
  [5334] = {.lex_state = 88, .external_lex_state = 7},
  [5335] = {.lex_state = 88, .external_lex_state = 7},
  [5336] = {.lex_state = 88, .external_lex_state = 7},
  [5337] = {.lex_state = 88, .external_lex_state = 7},
  [5338] = {.lex_state = 88, .external_lex_state = 7},
  [5339] = {.lex_state = 88, .external_lex_state = 7},
  [5340] = {.lex_state = 88, .external_lex_state = 7},
  [5341] = {.lex_state = 88, .external_lex_state = 7},
  [5342] = {.lex_state = 88, .external_lex_state = 7},
  [5343] = {.lex_state = 88, .external_lex_state = 7},
  [5344] = {.lex_state = 88, .external_lex_state = 7},
  [5345] = {.lex_state = 88, .external_lex_state = 7},
  [5346] = {.lex_state = 88, .external_lex_state = 7},
  [5347] = {.lex_state = 88, .external_lex_state = 7},
  [5348] = {.lex_state = 88, .external_lex_state = 7},
  [5349] = {.lex_state = 88, .external_lex_state = 7},
  [5350] = {.lex_state = 88, .external_lex_state = 7},
  [5351] = {.lex_state = 88, .external_lex_state = 7},
  [5352] = {.lex_state = 88, .external_lex_state = 7},
  [5353] = {.lex_state = 88, .external_lex_state = 7},
  [5354] = {.lex_state = 88, .external_lex_state = 7},
  [5355] = {.lex_state = 88, .external_lex_state = 7},
  [5356] = {.lex_state = 88, .external_lex_state = 7},
  [5357] = {.lex_state = 88, .external_lex_state = 7},
  [5358] = {.lex_state = 88, .external_lex_state = 7},
  [5359] = {.lex_state = 88, .external_lex_state = 7},
  [5360] = {.lex_state = 88, .external_lex_state = 7},
  [5361] = {.lex_state = 88, .external_lex_state = 7},
  [5362] = {.lex_state = 88, .external_lex_state = 7},
  [5363] = {.lex_state = 88, .external_lex_state = 7},
  [5364] = {.lex_state = 88, .external_lex_state = 7},
  [5365] = {.lex_state = 88, .external_lex_state = 7},
  [5366] = {.lex_state = 88, .external_lex_state = 7},
  [5367] = {.lex_state = 88, .external_lex_state = 7},
  [5368] = {.lex_state = 88, .external_lex_state = 7},
  [5369] = {.lex_state = 88, .external_lex_state = 7},
  [5370] = {.lex_state = 97, .external_lex_state = 7},
  [5371] = {.lex_state = 88, .external_lex_state = 7},
  [5372] = {.lex_state = 88, .external_lex_state = 7},
  [5373] = {.lex_state = 88, .external_lex_state = 7},
  [5374] = {.lex_state = 88, .external_lex_state = 7},
  [5375] = {.lex_state = 88, .external_lex_state = 7},
  [5376] = {.lex_state = 88, .external_lex_state = 7},
  [5377] = {.lex_state = 88, .external_lex_state = 7},
  [5378] = {.lex_state = 88, .external_lex_state = 7},
  [5379] = {.lex_state = 88, .external_lex_state = 7},
  [5380] = {.lex_state = 88, .external_lex_state = 7},
  [5381] = {.lex_state = 88, .external_lex_state = 7},
  [5382] = {.lex_state = 88, .external_lex_state = 7},
  [5383] = {.lex_state = 88, .external_lex_state = 7},
  [5384] = {.lex_state = 88, .external_lex_state = 7},
  [5385] = {.lex_state = 88, .external_lex_state = 7},
  [5386] = {.lex_state = 88, .external_lex_state = 7},
  [5387] = {.lex_state = 88, .external_lex_state = 7},
  [5388] = {.lex_state = 88, .external_lex_state = 7},
  [5389] = {.lex_state = 88, .external_lex_state = 7},
  [5390] = {.lex_state = 88, .external_lex_state = 7},
  [5391] = {.lex_state = 88, .external_lex_state = 7},
  [5392] = {.lex_state = 88, .external_lex_state = 7},
  [5393] = {.lex_state = 88, .external_lex_state = 7},
  [5394] = {.lex_state = 88, .external_lex_state = 7},
  [5395] = {.lex_state = 88, .external_lex_state = 7},
  [5396] = {.lex_state = 88, .external_lex_state = 7},
  [5397] = {.lex_state = 88, .external_lex_state = 7},
  [5398] = {.lex_state = 88, .external_lex_state = 7},
  [5399] = {.lex_state = 88, .external_lex_state = 7},
  [5400] = {.lex_state = 88, .external_lex_state = 7},
  [5401] = {.lex_state = 88, .external_lex_state = 7},
  [5402] = {.lex_state = 88, .external_lex_state = 7},
  [5403] = {.lex_state = 88, .external_lex_state = 7},
  [5404] = {.lex_state = 88, .external_lex_state = 7},
  [5405] = {.lex_state = 88, .external_lex_state = 7},
  [5406] = {.lex_state = 88, .external_lex_state = 7},
  [5407] = {.lex_state = 88, .external_lex_state = 7},
  [5408] = {.lex_state = 88, .external_lex_state = 7},
  [5409] = {.lex_state = 88, .external_lex_state = 7},
  [5410] = {.lex_state = 88, .external_lex_state = 7},
  [5411] = {.lex_state = 88, .external_lex_state = 7},
  [5412] = {.lex_state = 88, .external_lex_state = 7},
  [5413] = {.lex_state = 88, .external_lex_state = 7},
  [5414] = {.lex_state = 88, .external_lex_state = 7},
  [5415] = {.lex_state = 88, .external_lex_state = 7},
  [5416] = {.lex_state = 88, .external_lex_state = 7},
  [5417] = {.lex_state = 88, .external_lex_state = 7},
  [5418] = {.lex_state = 88, .external_lex_state = 7},
  [5419] = {.lex_state = 88, .external_lex_state = 7},
  [5420] = {.lex_state = 88, .external_lex_state = 7},
  [5421] = {.lex_state = 88, .external_lex_state = 7},
  [5422] = {.lex_state = 88, .external_lex_state = 7},
  [5423] = {.lex_state = 88, .external_lex_state = 7},
  [5424] = {.lex_state = 88, .external_lex_state = 7},
  [5425] = {.lex_state = 88, .external_lex_state = 7},
  [5426] = {.lex_state = 88, .external_lex_state = 7},
  [5427] = {.lex_state = 88, .external_lex_state = 7},
  [5428] = {.lex_state = 88, .external_lex_state = 7},
  [5429] = {.lex_state = 88, .external_lex_state = 7},
  [5430] = {.lex_state = 88, .external_lex_state = 7},
  [5431] = {.lex_state = 88, .external_lex_state = 7},
  [5432] = {.lex_state = 88, .external_lex_state = 7},
  [5433] = {.lex_state = 88, .external_lex_state = 7},
  [5434] = {.lex_state = 88, .external_lex_state = 7},
  [5435] = {.lex_state = 88, .external_lex_state = 7},
  [5436] = {.lex_state = 88, .external_lex_state = 7},
  [5437] = {.lex_state = 88, .external_lex_state = 7},
  [5438] = {.lex_state = 88, .external_lex_state = 7},
  [5439] = {.lex_state = 88, .external_lex_state = 7},
  [5440] = {.lex_state = 88, .external_lex_state = 7},
  [5441] = {.lex_state = 88, .external_lex_state = 7},
  [5442] = {.lex_state = 88, .external_lex_state = 7},
  [5443] = {.lex_state = 88, .external_lex_state = 7},
  [5444] = {.lex_state = 88, .external_lex_state = 7},
  [5445] = {.lex_state = 88, .external_lex_state = 7},
  [5446] = {.lex_state = 88, .external_lex_state = 7},
  [5447] = {.lex_state = 88, .external_lex_state = 7},
  [5448] = {.lex_state = 88, .external_lex_state = 7},
  [5449] = {.lex_state = 88, .external_lex_state = 7},
  [5450] = {.lex_state = 88, .external_lex_state = 7},
  [5451] = {.lex_state = 88, .external_lex_state = 7},
  [5452] = {.lex_state = 88, .external_lex_state = 7},
  [5453] = {.lex_state = 88, .external_lex_state = 7},
  [5454] = {.lex_state = 88, .external_lex_state = 7},
  [5455] = {.lex_state = 88, .external_lex_state = 7},
  [5456] = {.lex_state = 88, .external_lex_state = 7},
  [5457] = {.lex_state = 88, .external_lex_state = 7},
  [5458] = {.lex_state = 88, .external_lex_state = 7},
  [5459] = {.lex_state = 88, .external_lex_state = 7},
  [5460] = {.lex_state = 88, .external_lex_state = 7},
  [5461] = {.lex_state = 88, .external_lex_state = 7},
  [5462] = {.lex_state = 88, .external_lex_state = 7},
  [5463] = {.lex_state = 88, .external_lex_state = 7},
  [5464] = {.lex_state = 88, .external_lex_state = 7},
  [5465] = {.lex_state = 88, .external_lex_state = 7},
  [5466] = {.lex_state = 88, .external_lex_state = 7},
  [5467] = {.lex_state = 88, .external_lex_state = 7},
  [5468] = {.lex_state = 88, .external_lex_state = 7},
  [5469] = {.lex_state = 88, .external_lex_state = 7},
  [5470] = {.lex_state = 88, .external_lex_state = 7},
  [5471] = {.lex_state = 88, .external_lex_state = 7},
  [5472] = {.lex_state = 88, .external_lex_state = 7},
  [5473] = {.lex_state = 88, .external_lex_state = 7},
  [5474] = {.lex_state = 88, .external_lex_state = 7},
  [5475] = {.lex_state = 88, .external_lex_state = 7},
  [5476] = {.lex_state = 88, .external_lex_state = 7},
  [5477] = {.lex_state = 88, .external_lex_state = 7},
  [5478] = {.lex_state = 88, .external_lex_state = 7},
  [5479] = {.lex_state = 88, .external_lex_state = 7},
  [5480] = {.lex_state = 88, .external_lex_state = 7},
  [5481] = {.lex_state = 88, .external_lex_state = 7},
  [5482] = {.lex_state = 88, .external_lex_state = 7},
  [5483] = {.lex_state = 88, .external_lex_state = 7},
  [5484] = {.lex_state = 88, .external_lex_state = 7},
  [5485] = {.lex_state = 88, .external_lex_state = 7},
  [5486] = {.lex_state = 88, .external_lex_state = 7},
  [5487] = {.lex_state = 88, .external_lex_state = 7},
  [5488] = {.lex_state = 88, .external_lex_state = 7},
  [5489] = {.lex_state = 88, .external_lex_state = 7},
  [5490] = {.lex_state = 88, .external_lex_state = 7},
  [5491] = {.lex_state = 88, .external_lex_state = 7},
  [5492] = {.lex_state = 88, .external_lex_state = 7},
  [5493] = {.lex_state = 88, .external_lex_state = 7},
  [5494] = {.lex_state = 88, .external_lex_state = 7},
  [5495] = {.lex_state = 88, .external_lex_state = 7},
  [5496] = {.lex_state = 88, .external_lex_state = 7},
  [5497] = {.lex_state = 88, .external_lex_state = 7},
  [5498] = {.lex_state = 88, .external_lex_state = 7},
  [5499] = {.lex_state = 88, .external_lex_state = 7},
  [5500] = {.lex_state = 88, .external_lex_state = 7},
  [5501] = {.lex_state = 88, .external_lex_state = 7},
  [5502] = {.lex_state = 88, .external_lex_state = 7},
  [5503] = {.lex_state = 88, .external_lex_state = 7},
  [5504] = {.lex_state = 88, .external_lex_state = 7},
  [5505] = {.lex_state = 88, .external_lex_state = 7},
  [5506] = {.lex_state = 88, .external_lex_state = 7},
  [5507] = {.lex_state = 97, .external_lex_state = 7},
  [5508] = {.lex_state = 88, .external_lex_state = 7},
  [5509] = {.lex_state = 88, .external_lex_state = 7},
  [5510] = {.lex_state = 88, .external_lex_state = 7},
  [5511] = {.lex_state = 88, .external_lex_state = 7},
  [5512] = {.lex_state = 88, .external_lex_state = 7},
  [5513] = {.lex_state = 88, .external_lex_state = 7},
  [5514] = {.lex_state = 88, .external_lex_state = 7},
  [5515] = {.lex_state = 88, .external_lex_state = 7},
  [5516] = {.lex_state = 88, .external_lex_state = 7},
  [5517] = {.lex_state = 88, .external_lex_state = 7},
  [5518] = {.lex_state = 88, .external_lex_state = 7},
  [5519] = {.lex_state = 88, .external_lex_state = 7},
  [5520] = {.lex_state = 88, .external_lex_state = 7},
  [5521] = {.lex_state = 88, .external_lex_state = 7},
  [5522] = {.lex_state = 88, .external_lex_state = 7},
  [5523] = {.lex_state = 88, .external_lex_state = 7},
  [5524] = {.lex_state = 88, .external_lex_state = 7},
  [5525] = {.lex_state = 88, .external_lex_state = 7},
  [5526] = {.lex_state = 88, .external_lex_state = 7},
  [5527] = {.lex_state = 88, .external_lex_state = 7},
  [5528] = {.lex_state = 88, .external_lex_state = 7},
  [5529] = {.lex_state = 88, .external_lex_state = 7},
  [5530] = {.lex_state = 88, .external_lex_state = 7},
  [5531] = {.lex_state = 88, .external_lex_state = 7},
  [5532] = {.lex_state = 88, .external_lex_state = 7},
  [5533] = {.lex_state = 88, .external_lex_state = 7},
  [5534] = {.lex_state = 88, .external_lex_state = 7},
  [5535] = {.lex_state = 88, .external_lex_state = 7},
  [5536] = {.lex_state = 88, .external_lex_state = 7},
  [5537] = {.lex_state = 88, .external_lex_state = 7},
  [5538] = {.lex_state = 97, .external_lex_state = 6},
  [5539] = {.lex_state = 88, .external_lex_state = 7},
  [5540] = {.lex_state = 88, .external_lex_state = 7},
  [5541] = {.lex_state = 88, .external_lex_state = 7},
  [5542] = {.lex_state = 88, .external_lex_state = 7},
  [5543] = {.lex_state = 88, .external_lex_state = 7},
  [5544] = {.lex_state = 88, .external_lex_state = 7},
  [5545] = {.lex_state = 88, .external_lex_state = 7},
  [5546] = {.lex_state = 88, .external_lex_state = 7},
  [5547] = {.lex_state = 88, .external_lex_state = 7},
  [5548] = {.lex_state = 88, .external_lex_state = 7},
  [5549] = {.lex_state = 88, .external_lex_state = 7},
  [5550] = {.lex_state = 88, .external_lex_state = 7},
  [5551] = {.lex_state = 88, .external_lex_state = 7},
  [5552] = {.lex_state = 88, .external_lex_state = 7},
  [5553] = {.lex_state = 88, .external_lex_state = 7},
  [5554] = {.lex_state = 88, .external_lex_state = 7},
  [5555] = {.lex_state = 88, .external_lex_state = 7},
  [5556] = {.lex_state = 88, .external_lex_state = 7},
  [5557] = {.lex_state = 88, .external_lex_state = 7},
  [5558] = {.lex_state = 88, .external_lex_state = 7},
  [5559] = {.lex_state = 88, .external_lex_state = 7},
  [5560] = {.lex_state = 88, .external_lex_state = 7},
  [5561] = {.lex_state = 88, .external_lex_state = 7},
  [5562] = {.lex_state = 88, .external_lex_state = 7},
  [5563] = {.lex_state = 88, .external_lex_state = 7},
  [5564] = {.lex_state = 88, .external_lex_state = 7},
  [5565] = {.lex_state = 88, .external_lex_state = 7},
  [5566] = {.lex_state = 88, .external_lex_state = 7},
  [5567] = {.lex_state = 88, .external_lex_state = 7},
  [5568] = {.lex_state = 88, .external_lex_state = 7},
  [5569] = {.lex_state = 88, .external_lex_state = 7},
  [5570] = {.lex_state = 88, .external_lex_state = 7},
  [5571] = {.lex_state = 88, .external_lex_state = 7},
  [5572] = {.lex_state = 88, .external_lex_state = 7},
  [5573] = {.lex_state = 88, .external_lex_state = 7},
  [5574] = {.lex_state = 88, .external_lex_state = 7},
  [5575] = {.lex_state = 88, .external_lex_state = 7},
  [5576] = {.lex_state = 88, .external_lex_state = 7},
  [5577] = {.lex_state = 88, .external_lex_state = 7},
  [5578] = {.lex_state = 88, .external_lex_state = 7},
  [5579] = {.lex_state = 88, .external_lex_state = 7},
  [5580] = {.lex_state = 88, .external_lex_state = 7},
  [5581] = {.lex_state = 88, .external_lex_state = 7},
  [5582] = {.lex_state = 88, .external_lex_state = 7},
  [5583] = {.lex_state = 88, .external_lex_state = 7},
  [5584] = {.lex_state = 88, .external_lex_state = 7},
  [5585] = {.lex_state = 88, .external_lex_state = 7},
  [5586] = {.lex_state = 88, .external_lex_state = 7},
  [5587] = {.lex_state = 88, .external_lex_state = 7},
  [5588] = {.lex_state = 88, .external_lex_state = 7},
  [5589] = {.lex_state = 88, .external_lex_state = 7},
  [5590] = {.lex_state = 88, .external_lex_state = 7},
  [5591] = {.lex_state = 88, .external_lex_state = 7},
  [5592] = {.lex_state = 88, .external_lex_state = 7},
  [5593] = {.lex_state = 88, .external_lex_state = 7},
  [5594] = {.lex_state = 88, .external_lex_state = 7},
  [5595] = {.lex_state = 88, .external_lex_state = 7},
  [5596] = {.lex_state = 88, .external_lex_state = 7},
  [5597] = {.lex_state = 88, .external_lex_state = 7},
  [5598] = {.lex_state = 88, .external_lex_state = 7},
  [5599] = {.lex_state = 88, .external_lex_state = 7},
  [5600] = {.lex_state = 88, .external_lex_state = 7},
  [5601] = {.lex_state = 88, .external_lex_state = 7},
  [5602] = {.lex_state = 88, .external_lex_state = 7},
  [5603] = {.lex_state = 88, .external_lex_state = 7},
  [5604] = {.lex_state = 88, .external_lex_state = 7},
  [5605] = {.lex_state = 88, .external_lex_state = 7},
  [5606] = {.lex_state = 88, .external_lex_state = 7},
  [5607] = {.lex_state = 88, .external_lex_state = 7},
  [5608] = {.lex_state = 88, .external_lex_state = 7},
  [5609] = {.lex_state = 88, .external_lex_state = 7},
  [5610] = {.lex_state = 88, .external_lex_state = 7},
  [5611] = {.lex_state = 88, .external_lex_state = 7},
  [5612] = {.lex_state = 88, .external_lex_state = 7},
  [5613] = {.lex_state = 88, .external_lex_state = 7},
  [5614] = {.lex_state = 88, .external_lex_state = 7},
  [5615] = {.lex_state = 88, .external_lex_state = 7},
  [5616] = {.lex_state = 88, .external_lex_state = 7},
  [5617] = {.lex_state = 88, .external_lex_state = 7},
  [5618] = {.lex_state = 88, .external_lex_state = 7},
  [5619] = {.lex_state = 88, .external_lex_state = 7},
  [5620] = {.lex_state = 88, .external_lex_state = 7},
  [5621] = {.lex_state = 88, .external_lex_state = 7},
  [5622] = {.lex_state = 88, .external_lex_state = 7},
  [5623] = {.lex_state = 88, .external_lex_state = 7},
  [5624] = {.lex_state = 88, .external_lex_state = 7},
  [5625] = {.lex_state = 88, .external_lex_state = 7},
  [5626] = {.lex_state = 88, .external_lex_state = 7},
  [5627] = {.lex_state = 88, .external_lex_state = 7},
  [5628] = {.lex_state = 88, .external_lex_state = 7},
  [5629] = {.lex_state = 97, .external_lex_state = 7},
  [5630] = {.lex_state = 88, .external_lex_state = 7},
  [5631] = {.lex_state = 88, .external_lex_state = 7},
  [5632] = {.lex_state = 88, .external_lex_state = 7},
  [5633] = {.lex_state = 88, .external_lex_state = 7},
  [5634] = {.lex_state = 88, .external_lex_state = 7},
  [5635] = {.lex_state = 88, .external_lex_state = 7},
  [5636] = {.lex_state = 88, .external_lex_state = 7},
  [5637] = {.lex_state = 88, .external_lex_state = 7},
  [5638] = {.lex_state = 88, .external_lex_state = 7},
  [5639] = {.lex_state = 88, .external_lex_state = 7},
  [5640] = {.lex_state = 88, .external_lex_state = 7},
  [5641] = {.lex_state = 88, .external_lex_state = 7},
  [5642] = {.lex_state = 88, .external_lex_state = 7},
  [5643] = {.lex_state = 88, .external_lex_state = 7},
  [5644] = {.lex_state = 88, .external_lex_state = 7},
  [5645] = {.lex_state = 88, .external_lex_state = 7},
  [5646] = {.lex_state = 88, .external_lex_state = 7},
  [5647] = {.lex_state = 88, .external_lex_state = 7},
  [5648] = {.lex_state = 88, .external_lex_state = 7},
  [5649] = {.lex_state = 88, .external_lex_state = 7},
  [5650] = {.lex_state = 88, .external_lex_state = 7},
  [5651] = {.lex_state = 88, .external_lex_state = 7},
  [5652] = {.lex_state = 88, .external_lex_state = 7},
  [5653] = {.lex_state = 88, .external_lex_state = 7},
  [5654] = {.lex_state = 88, .external_lex_state = 7},
  [5655] = {.lex_state = 88, .external_lex_state = 7},
  [5656] = {.lex_state = 97, .external_lex_state = 6},
  [5657] = {.lex_state = 88, .external_lex_state = 7},
  [5658] = {.lex_state = 88, .external_lex_state = 7},
  [5659] = {.lex_state = 88, .external_lex_state = 7},
  [5660] = {.lex_state = 88, .external_lex_state = 7},
  [5661] = {.lex_state = 88, .external_lex_state = 7},
  [5662] = {.lex_state = 88, .external_lex_state = 7},
  [5663] = {.lex_state = 88, .external_lex_state = 7},
  [5664] = {.lex_state = 88, .external_lex_state = 7},
  [5665] = {.lex_state = 88, .external_lex_state = 7},
  [5666] = {.lex_state = 88, .external_lex_state = 7},
  [5667] = {.lex_state = 88, .external_lex_state = 7},
  [5668] = {.lex_state = 88, .external_lex_state = 7},
  [5669] = {.lex_state = 88, .external_lex_state = 7},
  [5670] = {.lex_state = 88, .external_lex_state = 7},
  [5671] = {.lex_state = 88, .external_lex_state = 7},
  [5672] = {.lex_state = 88, .external_lex_state = 7},
  [5673] = {.lex_state = 88, .external_lex_state = 7},
  [5674] = {.lex_state = 88, .external_lex_state = 7},
  [5675] = {.lex_state = 97, .external_lex_state = 6},
  [5676] = {.lex_state = 88, .external_lex_state = 7},
  [5677] = {.lex_state = 88, .external_lex_state = 7},
  [5678] = {.lex_state = 88, .external_lex_state = 7},
  [5679] = {.lex_state = 88, .external_lex_state = 7},
  [5680] = {.lex_state = 88, .external_lex_state = 7},
  [5681] = {.lex_state = 88, .external_lex_state = 7},
  [5682] = {.lex_state = 88, .external_lex_state = 7},
  [5683] = {.lex_state = 88, .external_lex_state = 7},
  [5684] = {.lex_state = 88, .external_lex_state = 7},
  [5685] = {.lex_state = 88, .external_lex_state = 7},
  [5686] = {.lex_state = 88, .external_lex_state = 7},
  [5687] = {.lex_state = 88, .external_lex_state = 7},
  [5688] = {.lex_state = 88, .external_lex_state = 7},
  [5689] = {.lex_state = 88, .external_lex_state = 7},
  [5690] = {.lex_state = 88, .external_lex_state = 7},
  [5691] = {.lex_state = 88, .external_lex_state = 7},
  [5692] = {.lex_state = 88, .external_lex_state = 7},
  [5693] = {.lex_state = 88, .external_lex_state = 7},
  [5694] = {.lex_state = 88, .external_lex_state = 7},
  [5695] = {.lex_state = 88, .external_lex_state = 7},
  [5696] = {.lex_state = 88, .external_lex_state = 7},
  [5697] = {.lex_state = 88, .external_lex_state = 7},
  [5698] = {.lex_state = 88, .external_lex_state = 7},
  [5699] = {.lex_state = 88, .external_lex_state = 7},
  [5700] = {.lex_state = 88, .external_lex_state = 7},
  [5701] = {.lex_state = 88, .external_lex_state = 7},
  [5702] = {.lex_state = 88, .external_lex_state = 7},
  [5703] = {.lex_state = 88, .external_lex_state = 7},
  [5704] = {.lex_state = 88, .external_lex_state = 7},
  [5705] = {.lex_state = 88, .external_lex_state = 7},
  [5706] = {.lex_state = 88, .external_lex_state = 7},
  [5707] = {.lex_state = 88, .external_lex_state = 7},
  [5708] = {.lex_state = 88, .external_lex_state = 7},
  [5709] = {.lex_state = 88, .external_lex_state = 7},
  [5710] = {.lex_state = 88, .external_lex_state = 7},
  [5711] = {.lex_state = 88, .external_lex_state = 7},
  [5712] = {.lex_state = 88, .external_lex_state = 7},
  [5713] = {.lex_state = 88, .external_lex_state = 7},
  [5714] = {.lex_state = 88, .external_lex_state = 7},
  [5715] = {.lex_state = 97, .external_lex_state = 7},
  [5716] = {.lex_state = 97, .external_lex_state = 7},
  [5717] = {.lex_state = 97, .external_lex_state = 7},
  [5718] = {.lex_state = 97, .external_lex_state = 7},
  [5719] = {.lex_state = 97, .external_lex_state = 7},
  [5720] = {.lex_state = 97, .external_lex_state = 7},
  [5721] = {.lex_state = 97, .external_lex_state = 5},
  [5722] = {.lex_state = 97, .external_lex_state = 7},
  [5723] = {.lex_state = 97, .external_lex_state = 7},
  [5724] = {.lex_state = 97, .external_lex_state = 7},
  [5725] = {.lex_state = 97, .external_lex_state = 7},
  [5726] = {.lex_state = 97, .external_lex_state = 7},
  [5727] = {.lex_state = 97, .external_lex_state = 7},
  [5728] = {.lex_state = 97, .external_lex_state = 7},
  [5729] = {.lex_state = 97, .external_lex_state = 7},
  [5730] = {.lex_state = 97, .external_lex_state = 7},
  [5731] = {.lex_state = 97, .external_lex_state = 7},
  [5732] = {.lex_state = 97, .external_lex_state = 7},
  [5733] = {.lex_state = 97, .external_lex_state = 7},
  [5734] = {.lex_state = 97, .external_lex_state = 7},
  [5735] = {.lex_state = 97, .external_lex_state = 7},
  [5736] = {.lex_state = 97, .external_lex_state = 7},
  [5737] = {.lex_state = 97, .external_lex_state = 7},
  [5738] = {.lex_state = 97, .external_lex_state = 7},
  [5739] = {.lex_state = 97, .external_lex_state = 7},
  [5740] = {.lex_state = 97, .external_lex_state = 7},
  [5741] = {.lex_state = 97, .external_lex_state = 7},
  [5742] = {.lex_state = 97, .external_lex_state = 7},
  [5743] = {.lex_state = 97, .external_lex_state = 7},
  [5744] = {.lex_state = 97, .external_lex_state = 7},
  [5745] = {.lex_state = 97, .external_lex_state = 5},
  [5746] = {.lex_state = 97, .external_lex_state = 7},
  [5747] = {.lex_state = 97, .external_lex_state = 7},
  [5748] = {.lex_state = 97, .external_lex_state = 7},
  [5749] = {.lex_state = 97, .external_lex_state = 7},
  [5750] = {.lex_state = 97, .external_lex_state = 7},
  [5751] = {.lex_state = 97, .external_lex_state = 7},
  [5752] = {.lex_state = 97, .external_lex_state = 7},
  [5753] = {.lex_state = 97, .external_lex_state = 6},
  [5754] = {.lex_state = 97, .external_lex_state = 7},
  [5755] = {.lex_state = 97, .external_lex_state = 7},
  [5756] = {.lex_state = 97, .external_lex_state = 7},
  [5757] = {.lex_state = 97, .external_lex_state = 7},
  [5758] = {.lex_state = 97, .external_lex_state = 7},
  [5759] = {.lex_state = 97, .external_lex_state = 7},
  [5760] = {.lex_state = 97, .external_lex_state = 7},
  [5761] = {.lex_state = 97, .external_lex_state = 7},
  [5762] = {.lex_state = 97, .external_lex_state = 7},
  [5763] = {.lex_state = 97, .external_lex_state = 7},
  [5764] = {.lex_state = 97, .external_lex_state = 7},
  [5765] = {.lex_state = 97, .external_lex_state = 7},
  [5766] = {.lex_state = 97, .external_lex_state = 7},
  [5767] = {.lex_state = 97, .external_lex_state = 7},
  [5768] = {.lex_state = 97, .external_lex_state = 7},
  [5769] = {.lex_state = 97, .external_lex_state = 7},
  [5770] = {.lex_state = 97, .external_lex_state = 7},
  [5771] = {.lex_state = 97, .external_lex_state = 7},
  [5772] = {.lex_state = 97, .external_lex_state = 7},
  [5773] = {.lex_state = 97, .external_lex_state = 7},
  [5774] = {.lex_state = 97, .external_lex_state = 7},
  [5775] = {.lex_state = 97, .external_lex_state = 7},
  [5776] = {.lex_state = 97, .external_lex_state = 7},
  [5777] = {.lex_state = 97, .external_lex_state = 7},
  [5778] = {.lex_state = 97, .external_lex_state = 7},
  [5779] = {.lex_state = 97, .external_lex_state = 7},
  [5780] = {.lex_state = 97, .external_lex_state = 7},
  [5781] = {.lex_state = 97, .external_lex_state = 7},
  [5782] = {.lex_state = 97, .external_lex_state = 7},
  [5783] = {.lex_state = 97, .external_lex_state = 7},
  [5784] = {.lex_state = 97, .external_lex_state = 7},
  [5785] = {.lex_state = 97, .external_lex_state = 7},
  [5786] = {.lex_state = 97, .external_lex_state = 7},
  [5787] = {.lex_state = 97, .external_lex_state = 6},
  [5788] = {.lex_state = 97, .external_lex_state = 7},
  [5789] = {.lex_state = 97, .external_lex_state = 7},
  [5790] = {.lex_state = 97, .external_lex_state = 7},
  [5791] = {.lex_state = 97, .external_lex_state = 7},
  [5792] = {.lex_state = 97, .external_lex_state = 7},
  [5793] = {.lex_state = 97, .external_lex_state = 7},
  [5794] = {.lex_state = 97, .external_lex_state = 7},
  [5795] = {.lex_state = 97, .external_lex_state = 7},
  [5796] = {.lex_state = 97, .external_lex_state = 7},
  [5797] = {.lex_state = 97, .external_lex_state = 7},
  [5798] = {.lex_state = 97, .external_lex_state = 7},
  [5799] = {.lex_state = 97, .external_lex_state = 7},
  [5800] = {.lex_state = 97, .external_lex_state = 7},
  [5801] = {.lex_state = 97, .external_lex_state = 7},
  [5802] = {.lex_state = 97, .external_lex_state = 7},
  [5803] = {.lex_state = 97, .external_lex_state = 5},
  [5804] = {.lex_state = 97, .external_lex_state = 7},
  [5805] = {.lex_state = 97, .external_lex_state = 7},
  [5806] = {.lex_state = 97, .external_lex_state = 7},
  [5807] = {.lex_state = 97, .external_lex_state = 5},
  [5808] = {.lex_state = 97, .external_lex_state = 5},
  [5809] = {.lex_state = 97, .external_lex_state = 7},
  [5810] = {.lex_state = 97, .external_lex_state = 7},
  [5811] = {.lex_state = 97, .external_lex_state = 7},
  [5812] = {.lex_state = 97, .external_lex_state = 7},
  [5813] = {.lex_state = 97, .external_lex_state = 7},
  [5814] = {.lex_state = 97, .external_lex_state = 7},
  [5815] = {.lex_state = 97, .external_lex_state = 7},
  [5816] = {.lex_state = 97, .external_lex_state = 7},
  [5817] = {.lex_state = 97, .external_lex_state = 7},
  [5818] = {.lex_state = 97, .external_lex_state = 7},
  [5819] = {.lex_state = 97, .external_lex_state = 7},
  [5820] = {.lex_state = 97, .external_lex_state = 7},
  [5821] = {.lex_state = 97, .external_lex_state = 7},
  [5822] = {.lex_state = 97, .external_lex_state = 7},
  [5823] = {.lex_state = 97, .external_lex_state = 7},
  [5824] = {.lex_state = 97, .external_lex_state = 7},
  [5825] = {.lex_state = 97, .external_lex_state = 7},
  [5826] = {.lex_state = 97, .external_lex_state = 7},
  [5827] = {.lex_state = 97, .external_lex_state = 7},
  [5828] = {.lex_state = 97, .external_lex_state = 7},
  [5829] = {.lex_state = 97, .external_lex_state = 7},
  [5830] = {.lex_state = 97, .external_lex_state = 7},
  [5831] = {.lex_state = 97, .external_lex_state = 7},
  [5832] = {.lex_state = 97, .external_lex_state = 7},
  [5833] = {.lex_state = 97, .external_lex_state = 7},
  [5834] = {.lex_state = 97, .external_lex_state = 7},
  [5835] = {.lex_state = 97, .external_lex_state = 7},
  [5836] = {.lex_state = 97, .external_lex_state = 7},
  [5837] = {.lex_state = 97, .external_lex_state = 7},
  [5838] = {.lex_state = 97, .external_lex_state = 7},
  [5839] = {.lex_state = 97, .external_lex_state = 7},
  [5840] = {.lex_state = 97, .external_lex_state = 7},
  [5841] = {.lex_state = 97, .external_lex_state = 7},
  [5842] = {.lex_state = 97, .external_lex_state = 7},
  [5843] = {.lex_state = 97, .external_lex_state = 7},
  [5844] = {.lex_state = 97, .external_lex_state = 7},
  [5845] = {.lex_state = 97, .external_lex_state = 7},
  [5846] = {.lex_state = 97, .external_lex_state = 7},
  [5847] = {.lex_state = 97, .external_lex_state = 7},
  [5848] = {.lex_state = 97, .external_lex_state = 7},
  [5849] = {.lex_state = 97, .external_lex_state = 7},
  [5850] = {.lex_state = 97, .external_lex_state = 7},
  [5851] = {.lex_state = 97, .external_lex_state = 7},
  [5852] = {.lex_state = 97, .external_lex_state = 7},
  [5853] = {.lex_state = 97, .external_lex_state = 7},
  [5854] = {.lex_state = 97, .external_lex_state = 7},
  [5855] = {.lex_state = 97, .external_lex_state = 7},
  [5856] = {.lex_state = 97, .external_lex_state = 7},
  [5857] = {.lex_state = 97, .external_lex_state = 7},
  [5858] = {.lex_state = 97, .external_lex_state = 7},
  [5859] = {.lex_state = 97, .external_lex_state = 7},
  [5860] = {.lex_state = 97, .external_lex_state = 7},
  [5861] = {.lex_state = 97, .external_lex_state = 7},
  [5862] = {.lex_state = 97, .external_lex_state = 7},
  [5863] = {.lex_state = 97, .external_lex_state = 7},
  [5864] = {.lex_state = 97, .external_lex_state = 7},
  [5865] = {.lex_state = 97, .external_lex_state = 7},
  [5866] = {.lex_state = 97, .external_lex_state = 7},
  [5867] = {.lex_state = 97, .external_lex_state = 7},
  [5868] = {.lex_state = 97, .external_lex_state = 7},
  [5869] = {.lex_state = 97, .external_lex_state = 7},
  [5870] = {.lex_state = 97, .external_lex_state = 7},
  [5871] = {.lex_state = 97, .external_lex_state = 7},
  [5872] = {.lex_state = 97, .external_lex_state = 7},
  [5873] = {.lex_state = 97, .external_lex_state = 7},
  [5874] = {.lex_state = 97, .external_lex_state = 7},
  [5875] = {.lex_state = 97, .external_lex_state = 7},
  [5876] = {.lex_state = 97, .external_lex_state = 7},
  [5877] = {.lex_state = 97, .external_lex_state = 7},
  [5878] = {.lex_state = 97, .external_lex_state = 7},
  [5879] = {.lex_state = 97, .external_lex_state = 7},
  [5880] = {.lex_state = 97, .external_lex_state = 7},
  [5881] = {.lex_state = 97, .external_lex_state = 7},
  [5882] = {.lex_state = 97, .external_lex_state = 7},
  [5883] = {.lex_state = 97, .external_lex_state = 7},
  [5884] = {.lex_state = 97, .external_lex_state = 7},
  [5885] = {.lex_state = 97, .external_lex_state = 7},
  [5886] = {.lex_state = 97, .external_lex_state = 7},
  [5887] = {.lex_state = 97, .external_lex_state = 7},
  [5888] = {.lex_state = 97, .external_lex_state = 7},
  [5889] = {.lex_state = 97, .external_lex_state = 7},
  [5890] = {.lex_state = 97, .external_lex_state = 7},
  [5891] = {.lex_state = 97, .external_lex_state = 7},
  [5892] = {.lex_state = 97, .external_lex_state = 7},
  [5893] = {.lex_state = 97, .external_lex_state = 7},
  [5894] = {.lex_state = 97, .external_lex_state = 7},
  [5895] = {.lex_state = 97, .external_lex_state = 7},
  [5896] = {.lex_state = 97, .external_lex_state = 7},
  [5897] = {.lex_state = 97, .external_lex_state = 5},
  [5898] = {.lex_state = 97, .external_lex_state = 7},
  [5899] = {.lex_state = 97, .external_lex_state = 7},
  [5900] = {.lex_state = 97, .external_lex_state = 7},
  [5901] = {.lex_state = 97, .external_lex_state = 7},
  [5902] = {.lex_state = 97, .external_lex_state = 6},
  [5903] = {.lex_state = 97, .external_lex_state = 7},
  [5904] = {.lex_state = 97, .external_lex_state = 7},
  [5905] = {.lex_state = 97, .external_lex_state = 7},
  [5906] = {.lex_state = 97, .external_lex_state = 7},
  [5907] = {.lex_state = 97, .external_lex_state = 7},
  [5908] = {.lex_state = 97, .external_lex_state = 7},
  [5909] = {.lex_state = 97, .external_lex_state = 7},
  [5910] = {.lex_state = 97, .external_lex_state = 7},
  [5911] = {.lex_state = 97, .external_lex_state = 7},
  [5912] = {.lex_state = 97, .external_lex_state = 7},
  [5913] = {.lex_state = 97, .external_lex_state = 7},
  [5914] = {.lex_state = 97, .external_lex_state = 7},
  [5915] = {.lex_state = 97, .external_lex_state = 7},
  [5916] = {.lex_state = 97, .external_lex_state = 7},
  [5917] = {.lex_state = 97, .external_lex_state = 7},
  [5918] = {.lex_state = 97, .external_lex_state = 7},
  [5919] = {.lex_state = 97, .external_lex_state = 7},
  [5920] = {.lex_state = 97, .external_lex_state = 7},
  [5921] = {.lex_state = 97, .external_lex_state = 7},
  [5922] = {.lex_state = 97, .external_lex_state = 6},
  [5923] = {.lex_state = 97, .external_lex_state = 7},
  [5924] = {.lex_state = 97, .external_lex_state = 7},
  [5925] = {.lex_state = 97, .external_lex_state = 7},
  [5926] = {.lex_state = 97, .external_lex_state = 7},
  [5927] = {.lex_state = 97, .external_lex_state = 7},
  [5928] = {.lex_state = 97, .external_lex_state = 6},
  [5929] = {.lex_state = 97, .external_lex_state = 7},
  [5930] = {.lex_state = 97, .external_lex_state = 7},
  [5931] = {.lex_state = 97, .external_lex_state = 7},
  [5932] = {.lex_state = 97, .external_lex_state = 7},
  [5933] = {.lex_state = 97, .external_lex_state = 7},
  [5934] = {.lex_state = 97, .external_lex_state = 7},
  [5935] = {.lex_state = 97, .external_lex_state = 7},
  [5936] = {.lex_state = 97, .external_lex_state = 7},
  [5937] = {.lex_state = 97, .external_lex_state = 7},
  [5938] = {.lex_state = 97, .external_lex_state = 7},
  [5939] = {.lex_state = 97, .external_lex_state = 7},
  [5940] = {.lex_state = 97, .external_lex_state = 7},
  [5941] = {.lex_state = 97, .external_lex_state = 7},
  [5942] = {.lex_state = 87, .external_lex_state = 2},
  [5943] = {.lex_state = 97, .external_lex_state = 7},
  [5944] = {.lex_state = 97, .external_lex_state = 6},
  [5945] = {.lex_state = 97, .external_lex_state = 7},
  [5946] = {.lex_state = 97, .external_lex_state = 7},
  [5947] = {.lex_state = 97, .external_lex_state = 7},
  [5948] = {.lex_state = 97, .external_lex_state = 6},
  [5949] = {.lex_state = 97, .external_lex_state = 7},
  [5950] = {.lex_state = 97, .external_lex_state = 7},
  [5951] = {.lex_state = 97, .external_lex_state = 6},
  [5952] = {.lex_state = 97, .external_lex_state = 7},
  [5953] = {.lex_state = 97, .external_lex_state = 7},
  [5954] = {.lex_state = 97, .external_lex_state = 7},
  [5955] = {.lex_state = 97, .external_lex_state = 7},
  [5956] = {.lex_state = 97, .external_lex_state = 7},
  [5957] = {.lex_state = 97, .external_lex_state = 7},
  [5958] = {.lex_state = 97, .external_lex_state = 7},
  [5959] = {.lex_state = 97, .external_lex_state = 7},
  [5960] = {.lex_state = 97, .external_lex_state = 7},
  [5961] = {.lex_state = 97, .external_lex_state = 7},
  [5962] = {.lex_state = 97, .external_lex_state = 6},
  [5963] = {.lex_state = 97, .external_lex_state = 7},
  [5964] = {.lex_state = 97, .external_lex_state = 7},
  [5965] = {.lex_state = 97, .external_lex_state = 7},
  [5966] = {.lex_state = 97, .external_lex_state = 7},
  [5967] = {.lex_state = 97, .external_lex_state = 7},
  [5968] = {.lex_state = 97, .external_lex_state = 7},
  [5969] = {.lex_state = 97, .external_lex_state = 7},
  [5970] = {.lex_state = 97, .external_lex_state = 7},
  [5971] = {.lex_state = 97, .external_lex_state = 7},
  [5972] = {.lex_state = 97, .external_lex_state = 7},
  [5973] = {.lex_state = 97, .external_lex_state = 7},
  [5974] = {.lex_state = 97, .external_lex_state = 7},
  [5975] = {.lex_state = 97, .external_lex_state = 7},
  [5976] = {.lex_state = 97, .external_lex_state = 7},
  [5977] = {.lex_state = 97, .external_lex_state = 7},
  [5978] = {.lex_state = 97, .external_lex_state = 7},
  [5979] = {.lex_state = 97, .external_lex_state = 7},
  [5980] = {.lex_state = 97, .external_lex_state = 7},
  [5981] = {.lex_state = 97, .external_lex_state = 7},
  [5982] = {.lex_state = 97, .external_lex_state = 7},
  [5983] = {.lex_state = 97, .external_lex_state = 7},
  [5984] = {.lex_state = 97, .external_lex_state = 7},
  [5985] = {.lex_state = 97, .external_lex_state = 7},
  [5986] = {.lex_state = 97, .external_lex_state = 7},
  [5987] = {.lex_state = 97, .external_lex_state = 7},
  [5988] = {.lex_state = 97, .external_lex_state = 7},
  [5989] = {.lex_state = 97, .external_lex_state = 7},
  [5990] = {.lex_state = 97, .external_lex_state = 7},
  [5991] = {.lex_state = 97, .external_lex_state = 7},
  [5992] = {.lex_state = 97, .external_lex_state = 7},
  [5993] = {.lex_state = 97, .external_lex_state = 7},
  [5994] = {.lex_state = 97, .external_lex_state = 6},
  [5995] = {.lex_state = 97, .external_lex_state = 7},
  [5996] = {.lex_state = 97, .external_lex_state = 6},
  [5997] = {.lex_state = 97, .external_lex_state = 7},
  [5998] = {.lex_state = 97, .external_lex_state = 7},
  [5999] = {.lex_state = 97, .external_lex_state = 7},
  [6000] = {.lex_state = 97, .external_lex_state = 6},
  [6001] = {.lex_state = 97, .external_lex_state = 6},
  [6002] = {.lex_state = 97, .external_lex_state = 7},
  [6003] = {.lex_state = 97, .external_lex_state = 7},
  [6004] = {.lex_state = 97, .external_lex_state = 7},
  [6005] = {.lex_state = 97, .external_lex_state = 7},
  [6006] = {.lex_state = 97, .external_lex_state = 7},
  [6007] = {.lex_state = 97, .external_lex_state = 7},
  [6008] = {.lex_state = 97, .external_lex_state = 7},
  [6009] = {.lex_state = 97, .external_lex_state = 6},
  [6010] = {.lex_state = 97, .external_lex_state = 7},
  [6011] = {.lex_state = 97, .external_lex_state = 7},
  [6012] = {.lex_state = 97, .external_lex_state = 7},
  [6013] = {.lex_state = 97, .external_lex_state = 7},
  [6014] = {.lex_state = 97, .external_lex_state = 7},
  [6015] = {.lex_state = 97, .external_lex_state = 7},
  [6016] = {.lex_state = 97, .external_lex_state = 7},
  [6017] = {.lex_state = 97, .external_lex_state = 7},
  [6018] = {.lex_state = 97, .external_lex_state = 7},
  [6019] = {.lex_state = 97, .external_lex_state = 7},
  [6020] = {.lex_state = 97, .external_lex_state = 7},
  [6021] = {.lex_state = 97, .external_lex_state = 6},
  [6022] = {.lex_state = 97, .external_lex_state = 7},
  [6023] = {.lex_state = 97, .external_lex_state = 7},
  [6024] = {.lex_state = 97, .external_lex_state = 7},
  [6025] = {.lex_state = 97, .external_lex_state = 7},
  [6026] = {.lex_state = 97, .external_lex_state = 7},
  [6027] = {.lex_state = 97, .external_lex_state = 7},
  [6028] = {.lex_state = 97, .external_lex_state = 7},
  [6029] = {.lex_state = 97, .external_lex_state = 7},
  [6030] = {.lex_state = 97, .external_lex_state = 7},
  [6031] = {.lex_state = 97, .external_lex_state = 7},
  [6032] = {.lex_state = 97, .external_lex_state = 7},
  [6033] = {.lex_state = 97, .external_lex_state = 7},
  [6034] = {.lex_state = 97, .external_lex_state = 7},
  [6035] = {.lex_state = 97, .external_lex_state = 7},
  [6036] = {.lex_state = 97, .external_lex_state = 7},
  [6037] = {.lex_state = 97, .external_lex_state = 7},
  [6038] = {.lex_state = 97, .external_lex_state = 7},
  [6039] = {.lex_state = 97, .external_lex_state = 7},
  [6040] = {.lex_state = 97, .external_lex_state = 7},
  [6041] = {.lex_state = 97, .external_lex_state = 6},
  [6042] = {.lex_state = 97, .external_lex_state = 7},
  [6043] = {.lex_state = 97, .external_lex_state = 7},
  [6044] = {.lex_state = 97, .external_lex_state = 7},
  [6045] = {.lex_state = 97, .external_lex_state = 7},
  [6046] = {.lex_state = 97, .external_lex_state = 7},
  [6047] = {.lex_state = 97, .external_lex_state = 7},
  [6048] = {.lex_state = 97, .external_lex_state = 7},
  [6049] = {.lex_state = 97, .external_lex_state = 7},
  [6050] = {.lex_state = 97, .external_lex_state = 7},
  [6051] = {.lex_state = 97, .external_lex_state = 7},
  [6052] = {.lex_state = 97, .external_lex_state = 7},
  [6053] = {.lex_state = 97, .external_lex_state = 7},
  [6054] = {.lex_state = 97, .external_lex_state = 7},
  [6055] = {.lex_state = 97, .external_lex_state = 6},
  [6056] = {.lex_state = 97, .external_lex_state = 7},
  [6057] = {.lex_state = 97, .external_lex_state = 7},
  [6058] = {.lex_state = 97, .external_lex_state = 7},
  [6059] = {.lex_state = 97, .external_lex_state = 7},
  [6060] = {.lex_state = 97, .external_lex_state = 7},
  [6061] = {.lex_state = 97, .external_lex_state = 7},
  [6062] = {.lex_state = 97, .external_lex_state = 7},
  [6063] = {.lex_state = 97, .external_lex_state = 7},
  [6064] = {.lex_state = 97, .external_lex_state = 7},
  [6065] = {.lex_state = 97, .external_lex_state = 7},
  [6066] = {.lex_state = 97, .external_lex_state = 7},
  [6067] = {.lex_state = 97, .external_lex_state = 7},
  [6068] = {.lex_state = 97, .external_lex_state = 7},
  [6069] = {.lex_state = 97, .external_lex_state = 6},
  [6070] = {.lex_state = 97, .external_lex_state = 7},
  [6071] = {.lex_state = 97, .external_lex_state = 7},
  [6072] = {.lex_state = 97, .external_lex_state = 7},
  [6073] = {.lex_state = 97, .external_lex_state = 7},
  [6074] = {.lex_state = 97, .external_lex_state = 7},
  [6075] = {.lex_state = 97, .external_lex_state = 7},
  [6076] = {.lex_state = 97, .external_lex_state = 7},
  [6077] = {.lex_state = 97, .external_lex_state = 7},
  [6078] = {.lex_state = 97, .external_lex_state = 7},
  [6079] = {.lex_state = 97, .external_lex_state = 7},
  [6080] = {.lex_state = 97, .external_lex_state = 7},
  [6081] = {.lex_state = 97, .external_lex_state = 6},
  [6082] = {.lex_state = 97, .external_lex_state = 7},
  [6083] = {.lex_state = 97, .external_lex_state = 7},
  [6084] = {.lex_state = 97, .external_lex_state = 7},
  [6085] = {.lex_state = 97, .external_lex_state = 7},
  [6086] = {.lex_state = 97, .external_lex_state = 7},
  [6087] = {.lex_state = 97, .external_lex_state = 7},
  [6088] = {.lex_state = 97, .external_lex_state = 7},
  [6089] = {.lex_state = 97, .external_lex_state = 7},
  [6090] = {.lex_state = 97, .external_lex_state = 7},
  [6091] = {.lex_state = 97, .external_lex_state = 7},
  [6092] = {.lex_state = 97, .external_lex_state = 7},
  [6093] = {.lex_state = 97, .external_lex_state = 7},
  [6094] = {.lex_state = 97, .external_lex_state = 7},
  [6095] = {.lex_state = 97, .external_lex_state = 7},
  [6096] = {.lex_state = 97, .external_lex_state = 7},
  [6097] = {.lex_state = 97, .external_lex_state = 7},
  [6098] = {.lex_state = 97, .external_lex_state = 7},
  [6099] = {.lex_state = 97, .external_lex_state = 7},
  [6100] = {.lex_state = 97, .external_lex_state = 7},
  [6101] = {.lex_state = 97, .external_lex_state = 6},
  [6102] = {.lex_state = 97, .external_lex_state = 7},
  [6103] = {.lex_state = 97, .external_lex_state = 7},
  [6104] = {.lex_state = 97, .external_lex_state = 7},
  [6105] = {.lex_state = 97, .external_lex_state = 7},
  [6106] = {.lex_state = 97, .external_lex_state = 7},
  [6107] = {.lex_state = 97, .external_lex_state = 7},
  [6108] = {.lex_state = 97, .external_lex_state = 7},
  [6109] = {.lex_state = 97, .external_lex_state = 7},
  [6110] = {.lex_state = 97, .external_lex_state = 6},
  [6111] = {.lex_state = 97, .external_lex_state = 7},
  [6112] = {.lex_state = 97, .external_lex_state = 7},
  [6113] = {.lex_state = 97, .external_lex_state = 7},
  [6114] = {.lex_state = 97, .external_lex_state = 7},
  [6115] = {.lex_state = 97, .external_lex_state = 7},
  [6116] = {.lex_state = 97, .external_lex_state = 7},
  [6117] = {.lex_state = 97, .external_lex_state = 7},
  [6118] = {.lex_state = 97, .external_lex_state = 7},
  [6119] = {.lex_state = 97, .external_lex_state = 7},
  [6120] = {.lex_state = 97, .external_lex_state = 7},
  [6121] = {.lex_state = 97, .external_lex_state = 7},
  [6122] = {.lex_state = 97, .external_lex_state = 7},
  [6123] = {.lex_state = 97, .external_lex_state = 6},
  [6124] = {.lex_state = 97, .external_lex_state = 7},
  [6125] = {.lex_state = 97, .external_lex_state = 7},
  [6126] = {.lex_state = 97, .external_lex_state = 7},
  [6127] = {.lex_state = 97, .external_lex_state = 6},
  [6128] = {.lex_state = 97, .external_lex_state = 7},
  [6129] = {.lex_state = 97, .external_lex_state = 7},
  [6130] = {.lex_state = 97, .external_lex_state = 7},
  [6131] = {.lex_state = 97, .external_lex_state = 7},
  [6132] = {.lex_state = 97, .external_lex_state = 7},
  [6133] = {.lex_state = 97, .external_lex_state = 7},
  [6134] = {.lex_state = 97, .external_lex_state = 6},
  [6135] = {.lex_state = 97, .external_lex_state = 7},
  [6136] = {.lex_state = 97, .external_lex_state = 7},
  [6137] = {.lex_state = 97, .external_lex_state = 7},
  [6138] = {.lex_state = 97, .external_lex_state = 7},
  [6139] = {.lex_state = 97, .external_lex_state = 7},
  [6140] = {.lex_state = 97, .external_lex_state = 7},
  [6141] = {.lex_state = 97, .external_lex_state = 7},
  [6142] = {.lex_state = 97, .external_lex_state = 7},
  [6143] = {.lex_state = 97, .external_lex_state = 7},
  [6144] = {.lex_state = 97, .external_lex_state = 7},
  [6145] = {.lex_state = 97, .external_lex_state = 7},
  [6146] = {.lex_state = 97, .external_lex_state = 7},
  [6147] = {.lex_state = 97, .external_lex_state = 7},
  [6148] = {.lex_state = 97, .external_lex_state = 7},
  [6149] = {.lex_state = 97, .external_lex_state = 7},
  [6150] = {.lex_state = 97, .external_lex_state = 6},
  [6151] = {.lex_state = 97, .external_lex_state = 7},
  [6152] = {.lex_state = 97, .external_lex_state = 7},
  [6153] = {.lex_state = 97, .external_lex_state = 7},
  [6154] = {.lex_state = 97, .external_lex_state = 7},
  [6155] = {.lex_state = 97, .external_lex_state = 7},
  [6156] = {.lex_state = 97, .external_lex_state = 7},
  [6157] = {.lex_state = 97, .external_lex_state = 7},
  [6158] = {.lex_state = 97, .external_lex_state = 7},
  [6159] = {.lex_state = 97, .external_lex_state = 7},
  [6160] = {.lex_state = 97, .external_lex_state = 7},
  [6161] = {.lex_state = 97, .external_lex_state = 7},
  [6162] = {.lex_state = 97, .external_lex_state = 7},
  [6163] = {.lex_state = 97, .external_lex_state = 7},
  [6164] = {.lex_state = 97, .external_lex_state = 7},
  [6165] = {.lex_state = 97, .external_lex_state = 7},
  [6166] = {.lex_state = 97, .external_lex_state = 7},
  [6167] = {.lex_state = 97, .external_lex_state = 7},
  [6168] = {.lex_state = 97, .external_lex_state = 7},
  [6169] = {.lex_state = 97, .external_lex_state = 7},
  [6170] = {.lex_state = 97, .external_lex_state = 7},
  [6171] = {.lex_state = 97, .external_lex_state = 7},
  [6172] = {.lex_state = 97, .external_lex_state = 7},
  [6173] = {.lex_state = 97, .external_lex_state = 7},
  [6174] = {.lex_state = 97, .external_lex_state = 7},
  [6175] = {.lex_state = 97, .external_lex_state = 7},
  [6176] = {.lex_state = 97, .external_lex_state = 7},
  [6177] = {.lex_state = 97, .external_lex_state = 7},
  [6178] = {.lex_state = 97, .external_lex_state = 7},
  [6179] = {.lex_state = 97, .external_lex_state = 7},
  [6180] = {.lex_state = 87, .external_lex_state = 2},
  [6181] = {.lex_state = 97, .external_lex_state = 7},
  [6182] = {.lex_state = 97, .external_lex_state = 7},
  [6183] = {.lex_state = 97, .external_lex_state = 6},
  [6184] = {.lex_state = 97, .external_lex_state = 7},
  [6185] = {.lex_state = 97, .external_lex_state = 7},
  [6186] = {.lex_state = 97, .external_lex_state = 7},
  [6187] = {.lex_state = 97, .external_lex_state = 7},
  [6188] = {.lex_state = 97, .external_lex_state = 7},
  [6189] = {.lex_state = 97, .external_lex_state = 7},
  [6190] = {.lex_state = 97, .external_lex_state = 7},
  [6191] = {.lex_state = 97, .external_lex_state = 7},
  [6192] = {.lex_state = 97, .external_lex_state = 7},
  [6193] = {.lex_state = 97, .external_lex_state = 7},
  [6194] = {.lex_state = 97, .external_lex_state = 7},
  [6195] = {.lex_state = 97, .external_lex_state = 7},
  [6196] = {.lex_state = 97, .external_lex_state = 7},
  [6197] = {.lex_state = 97, .external_lex_state = 7},
  [6198] = {.lex_state = 97, .external_lex_state = 7},
  [6199] = {.lex_state = 97, .external_lex_state = 7},
  [6200] = {.lex_state = 97, .external_lex_state = 6},
  [6201] = {.lex_state = 97, .external_lex_state = 7},
  [6202] = {.lex_state = 87, .external_lex_state = 2},
  [6203] = {.lex_state = 97, .external_lex_state = 7},
  [6204] = {.lex_state = 97, .external_lex_state = 7},
  [6205] = {.lex_state = 97, .external_lex_state = 7},
  [6206] = {.lex_state = 97, .external_lex_state = 7},
  [6207] = {.lex_state = 97, .external_lex_state = 7},
  [6208] = {.lex_state = 97, .external_lex_state = 7},
  [6209] = {.lex_state = 97, .external_lex_state = 7},
  [6210] = {.lex_state = 97, .external_lex_state = 7},
  [6211] = {.lex_state = 97, .external_lex_state = 7},
  [6212] = {.lex_state = 97, .external_lex_state = 6},
  [6213] = {.lex_state = 97, .external_lex_state = 7},
  [6214] = {.lex_state = 97, .external_lex_state = 6},
  [6215] = {.lex_state = 97, .external_lex_state = 7},
  [6216] = {.lex_state = 97, .external_lex_state = 7},
  [6217] = {.lex_state = 97, .external_lex_state = 7},
  [6218] = {.lex_state = 97, .external_lex_state = 7},
  [6219] = {.lex_state = 97, .external_lex_state = 7},
  [6220] = {.lex_state = 97, .external_lex_state = 7},
  [6221] = {.lex_state = 97, .external_lex_state = 7},
  [6222] = {.lex_state = 97, .external_lex_state = 7},
  [6223] = {.lex_state = 97, .external_lex_state = 7},
  [6224] = {.lex_state = 97, .external_lex_state = 7},
  [6225] = {.lex_state = 97, .external_lex_state = 7},
  [6226] = {.lex_state = 97, .external_lex_state = 7},
  [6227] = {.lex_state = 97, .external_lex_state = 7},
  [6228] = {.lex_state = 97, .external_lex_state = 7},
  [6229] = {.lex_state = 97, .external_lex_state = 7},
  [6230] = {.lex_state = 97, .external_lex_state = 7},
  [6231] = {.lex_state = 97, .external_lex_state = 7},
  [6232] = {.lex_state = 97, .external_lex_state = 7},
  [6233] = {.lex_state = 97, .external_lex_state = 7},
  [6234] = {.lex_state = 97, .external_lex_state = 7},
  [6235] = {.lex_state = 97, .external_lex_state = 7},
  [6236] = {.lex_state = 97, .external_lex_state = 7},
  [6237] = {.lex_state = 97, .external_lex_state = 7},
  [6238] = {.lex_state = 97, .external_lex_state = 7},
  [6239] = {.lex_state = 97, .external_lex_state = 7},
  [6240] = {.lex_state = 97, .external_lex_state = 7},
  [6241] = {.lex_state = 97, .external_lex_state = 7},
  [6242] = {.lex_state = 97, .external_lex_state = 7},
  [6243] = {.lex_state = 97, .external_lex_state = 7},
  [6244] = {.lex_state = 97, .external_lex_state = 7},
  [6245] = {.lex_state = 97, .external_lex_state = 7},
  [6246] = {.lex_state = 97, .external_lex_state = 7},
  [6247] = {.lex_state = 97, .external_lex_state = 7},
  [6248] = {.lex_state = 97, .external_lex_state = 7},
  [6249] = {.lex_state = 97, .external_lex_state = 7},
  [6250] = {.lex_state = 97, .external_lex_state = 7},
  [6251] = {.lex_state = 97, .external_lex_state = 7},
  [6252] = {.lex_state = 97, .external_lex_state = 7},
  [6253] = {.lex_state = 97, .external_lex_state = 7},
  [6254] = {.lex_state = 97, .external_lex_state = 7},
  [6255] = {.lex_state = 97, .external_lex_state = 7},
  [6256] = {.lex_state = 97, .external_lex_state = 7},
  [6257] = {.lex_state = 97, .external_lex_state = 7},
  [6258] = {.lex_state = 97, .external_lex_state = 7},
  [6259] = {.lex_state = 97, .external_lex_state = 7},
  [6260] = {.lex_state = 97, .external_lex_state = 7},
  [6261] = {.lex_state = 97, .external_lex_state = 7},
  [6262] = {.lex_state = 97, .external_lex_state = 7},
  [6263] = {.lex_state = 97, .external_lex_state = 7},
  [6264] = {.lex_state = 97, .external_lex_state = 7},
  [6265] = {.lex_state = 97, .external_lex_state = 7},
  [6266] = {.lex_state = 97, .external_lex_state = 7},
  [6267] = {.lex_state = 97, .external_lex_state = 7},
  [6268] = {.lex_state = 97, .external_lex_state = 7},
  [6269] = {.lex_state = 97, .external_lex_state = 7},
  [6270] = {.lex_state = 97, .external_lex_state = 7},
  [6271] = {.lex_state = 97, .external_lex_state = 7},
  [6272] = {.lex_state = 97, .external_lex_state = 7},
  [6273] = {.lex_state = 97, .external_lex_state = 7},
  [6274] = {.lex_state = 97, .external_lex_state = 7},
  [6275] = {.lex_state = 97, .external_lex_state = 7},
  [6276] = {.lex_state = 97, .external_lex_state = 7},
  [6277] = {.lex_state = 97, .external_lex_state = 7},
  [6278] = {.lex_state = 97, .external_lex_state = 7},
  [6279] = {.lex_state = 97, .external_lex_state = 7},
  [6280] = {.lex_state = 97, .external_lex_state = 7},
  [6281] = {.lex_state = 97, .external_lex_state = 7},
  [6282] = {.lex_state = 97, .external_lex_state = 7},
  [6283] = {.lex_state = 97, .external_lex_state = 7},
  [6284] = {.lex_state = 97, .external_lex_state = 7},
  [6285] = {.lex_state = 97, .external_lex_state = 7},
  [6286] = {.lex_state = 97, .external_lex_state = 7},
  [6287] = {.lex_state = 97, .external_lex_state = 7},
  [6288] = {.lex_state = 97, .external_lex_state = 7},
  [6289] = {.lex_state = 97, .external_lex_state = 7},
  [6290] = {.lex_state = 97, .external_lex_state = 7},
  [6291] = {.lex_state = 97, .external_lex_state = 7},
  [6292] = {.lex_state = 97, .external_lex_state = 7},
  [6293] = {.lex_state = 97, .external_lex_state = 7},
  [6294] = {.lex_state = 97, .external_lex_state = 7},
  [6295] = {.lex_state = 97, .external_lex_state = 7},
  [6296] = {.lex_state = 97, .external_lex_state = 7},
  [6297] = {.lex_state = 97, .external_lex_state = 7},
  [6298] = {.lex_state = 97, .external_lex_state = 7},
  [6299] = {.lex_state = 97, .external_lex_state = 7},
  [6300] = {.lex_state = 97, .external_lex_state = 7},
  [6301] = {.lex_state = 97, .external_lex_state = 7},
  [6302] = {.lex_state = 97, .external_lex_state = 7},
  [6303] = {.lex_state = 97, .external_lex_state = 7},
  [6304] = {.lex_state = 97, .external_lex_state = 7},
  [6305] = {.lex_state = 97, .external_lex_state = 7},
  [6306] = {.lex_state = 97, .external_lex_state = 7},
  [6307] = {.lex_state = 97, .external_lex_state = 7},
  [6308] = {.lex_state = 97, .external_lex_state = 7},
  [6309] = {.lex_state = 97, .external_lex_state = 7},
  [6310] = {.lex_state = 97, .external_lex_state = 7},
  [6311] = {.lex_state = 97, .external_lex_state = 7},
  [6312] = {.lex_state = 97, .external_lex_state = 7},
  [6313] = {.lex_state = 97, .external_lex_state = 7},
  [6314] = {.lex_state = 97, .external_lex_state = 7},
  [6315] = {.lex_state = 97, .external_lex_state = 7},
  [6316] = {.lex_state = 97, .external_lex_state = 7},
  [6317] = {.lex_state = 97, .external_lex_state = 7},
  [6318] = {.lex_state = 97, .external_lex_state = 7},
  [6319] = {.lex_state = 97, .external_lex_state = 7},
  [6320] = {.lex_state = 97, .external_lex_state = 7},
  [6321] = {.lex_state = 97, .external_lex_state = 7},
  [6322] = {.lex_state = 97, .external_lex_state = 7},
  [6323] = {.lex_state = 97, .external_lex_state = 7},
  [6324] = {.lex_state = 97, .external_lex_state = 7},
  [6325] = {.lex_state = 97, .external_lex_state = 7},
  [6326] = {.lex_state = 97, .external_lex_state = 7},
  [6327] = {.lex_state = 97, .external_lex_state = 7},
  [6328] = {.lex_state = 97, .external_lex_state = 7},
  [6329] = {.lex_state = 97, .external_lex_state = 7},
  [6330] = {.lex_state = 97, .external_lex_state = 7},
  [6331] = {.lex_state = 97, .external_lex_state = 7},
  [6332] = {.lex_state = 97, .external_lex_state = 7},
  [6333] = {.lex_state = 97, .external_lex_state = 7},
  [6334] = {.lex_state = 97, .external_lex_state = 7},
  [6335] = {.lex_state = 97, .external_lex_state = 7},
  [6336] = {.lex_state = 97, .external_lex_state = 7},
  [6337] = {.lex_state = 97, .external_lex_state = 7},
  [6338] = {.lex_state = 97, .external_lex_state = 7},
  [6339] = {.lex_state = 97, .external_lex_state = 7},
  [6340] = {.lex_state = 97, .external_lex_state = 7},
  [6341] = {.lex_state = 97, .external_lex_state = 7},
  [6342] = {.lex_state = 97, .external_lex_state = 7},
  [6343] = {.lex_state = 97, .external_lex_state = 7},
  [6344] = {.lex_state = 97, .external_lex_state = 7},
  [6345] = {.lex_state = 97, .external_lex_state = 7},
  [6346] = {.lex_state = 97, .external_lex_state = 7},
  [6347] = {.lex_state = 97, .external_lex_state = 7},
  [6348] = {.lex_state = 97, .external_lex_state = 7},
  [6349] = {.lex_state = 97, .external_lex_state = 7},
  [6350] = {.lex_state = 97, .external_lex_state = 7},
  [6351] = {.lex_state = 97, .external_lex_state = 7},
  [6352] = {.lex_state = 97, .external_lex_state = 7},
  [6353] = {.lex_state = 97, .external_lex_state = 7},
  [6354] = {.lex_state = 97, .external_lex_state = 7},
  [6355] = {.lex_state = 97, .external_lex_state = 7},
  [6356] = {.lex_state = 97, .external_lex_state = 7},
  [6357] = {.lex_state = 97, .external_lex_state = 7},
  [6358] = {.lex_state = 97, .external_lex_state = 7},
  [6359] = {.lex_state = 97, .external_lex_state = 7},
  [6360] = {.lex_state = 97, .external_lex_state = 7},
  [6361] = {.lex_state = 97, .external_lex_state = 7},
  [6362] = {.lex_state = 97, .external_lex_state = 7},
  [6363] = {.lex_state = 97, .external_lex_state = 7},
  [6364] = {.lex_state = 97, .external_lex_state = 7},
  [6365] = {.lex_state = 97, .external_lex_state = 7},
  [6366] = {.lex_state = 97, .external_lex_state = 7},
  [6367] = {.lex_state = 97, .external_lex_state = 7},
  [6368] = {.lex_state = 97, .external_lex_state = 7},
  [6369] = {.lex_state = 97, .external_lex_state = 7},
  [6370] = {.lex_state = 97, .external_lex_state = 7},
  [6371] = {.lex_state = 97, .external_lex_state = 7},
  [6372] = {.lex_state = 97, .external_lex_state = 7},
  [6373] = {.lex_state = 97, .external_lex_state = 7},
  [6374] = {.lex_state = 97, .external_lex_state = 7},
  [6375] = {.lex_state = 97, .external_lex_state = 7},
  [6376] = {.lex_state = 97, .external_lex_state = 7},
  [6377] = {.lex_state = 97, .external_lex_state = 7},
  [6378] = {.lex_state = 97, .external_lex_state = 7},
  [6379] = {.lex_state = 97, .external_lex_state = 7},
  [6380] = {.lex_state = 97, .external_lex_state = 7},
  [6381] = {.lex_state = 97, .external_lex_state = 7},
  [6382] = {.lex_state = 97, .external_lex_state = 7},
  [6383] = {.lex_state = 97, .external_lex_state = 7},
  [6384] = {.lex_state = 97, .external_lex_state = 7},
  [6385] = {.lex_state = 97, .external_lex_state = 7},
  [6386] = {.lex_state = 97, .external_lex_state = 7},
  [6387] = {.lex_state = 97, .external_lex_state = 7},
  [6388] = {.lex_state = 97, .external_lex_state = 7},
  [6389] = {.lex_state = 97, .external_lex_state = 7},
  [6390] = {.lex_state = 97, .external_lex_state = 7},
  [6391] = {.lex_state = 97, .external_lex_state = 7},
  [6392] = {.lex_state = 97, .external_lex_state = 7},
  [6393] = {.lex_state = 97, .external_lex_state = 7},
  [6394] = {.lex_state = 97, .external_lex_state = 7},
  [6395] = {.lex_state = 97, .external_lex_state = 7},
  [6396] = {.lex_state = 97, .external_lex_state = 7},
  [6397] = {.lex_state = 97, .external_lex_state = 7},
  [6398] = {.lex_state = 97, .external_lex_state = 7},
  [6399] = {.lex_state = 97, .external_lex_state = 7},
  [6400] = {.lex_state = 97, .external_lex_state = 7},
  [6401] = {.lex_state = 97, .external_lex_state = 7},
  [6402] = {.lex_state = 97, .external_lex_state = 7},
  [6403] = {.lex_state = 97, .external_lex_state = 7},
  [6404] = {.lex_state = 97, .external_lex_state = 7},
  [6405] = {.lex_state = 97, .external_lex_state = 7},
  [6406] = {.lex_state = 97, .external_lex_state = 7},
  [6407] = {.lex_state = 97, .external_lex_state = 7},
  [6408] = {.lex_state = 97, .external_lex_state = 7},
  [6409] = {.lex_state = 97, .external_lex_state = 7},
  [6410] = {.lex_state = 97, .external_lex_state = 7},
  [6411] = {.lex_state = 97, .external_lex_state = 7},
  [6412] = {.lex_state = 97, .external_lex_state = 7},
  [6413] = {.lex_state = 97, .external_lex_state = 7},
  [6414] = {.lex_state = 97, .external_lex_state = 7},
  [6415] = {.lex_state = 97, .external_lex_state = 7},
  [6416] = {.lex_state = 97, .external_lex_state = 7},
  [6417] = {.lex_state = 97, .external_lex_state = 7},
  [6418] = {.lex_state = 97, .external_lex_state = 7},
  [6419] = {.lex_state = 97, .external_lex_state = 7},
  [6420] = {.lex_state = 97, .external_lex_state = 7},
  [6421] = {.lex_state = 97, .external_lex_state = 7},
  [6422] = {.lex_state = 97, .external_lex_state = 7},
  [6423] = {.lex_state = 97, .external_lex_state = 7},
  [6424] = {.lex_state = 97, .external_lex_state = 7},
  [6425] = {.lex_state = 97, .external_lex_state = 7},
  [6426] = {.lex_state = 97, .external_lex_state = 7},
  [6427] = {.lex_state = 97, .external_lex_state = 7},
  [6428] = {.lex_state = 97, .external_lex_state = 7},
  [6429] = {.lex_state = 97, .external_lex_state = 7},
  [6430] = {.lex_state = 97, .external_lex_state = 7},
  [6431] = {.lex_state = 97, .external_lex_state = 7},
  [6432] = {.lex_state = 97, .external_lex_state = 7},
  [6433] = {.lex_state = 97, .external_lex_state = 7},
  [6434] = {.lex_state = 97, .external_lex_state = 7},
  [6435] = {.lex_state = 97, .external_lex_state = 7},
  [6436] = {.lex_state = 97, .external_lex_state = 7},
  [6437] = {.lex_state = 97, .external_lex_state = 7},
  [6438] = {.lex_state = 97, .external_lex_state = 7},
  [6439] = {.lex_state = 97, .external_lex_state = 7},
  [6440] = {.lex_state = 97, .external_lex_state = 7},
  [6441] = {.lex_state = 97, .external_lex_state = 7},
  [6442] = {.lex_state = 97, .external_lex_state = 7},
  [6443] = {.lex_state = 97, .external_lex_state = 7},
  [6444] = {.lex_state = 97, .external_lex_state = 7},
  [6445] = {.lex_state = 97, .external_lex_state = 7},
  [6446] = {.lex_state = 97, .external_lex_state = 7},
  [6447] = {.lex_state = 97, .external_lex_state = 7},
  [6448] = {.lex_state = 97, .external_lex_state = 7},
  [6449] = {.lex_state = 97, .external_lex_state = 7},
  [6450] = {.lex_state = 97, .external_lex_state = 7},
  [6451] = {.lex_state = 97, .external_lex_state = 7},
  [6452] = {.lex_state = 97, .external_lex_state = 7},
  [6453] = {.lex_state = 97, .external_lex_state = 7},
  [6454] = {.lex_state = 97, .external_lex_state = 7},
  [6455] = {.lex_state = 97, .external_lex_state = 7},
  [6456] = {.lex_state = 97, .external_lex_state = 7},
  [6457] = {.lex_state = 97, .external_lex_state = 7},
  [6458] = {.lex_state = 97, .external_lex_state = 7},
  [6459] = {.lex_state = 97, .external_lex_state = 7},
  [6460] = {.lex_state = 97, .external_lex_state = 7},
  [6461] = {.lex_state = 97, .external_lex_state = 7},
  [6462] = {.lex_state = 97, .external_lex_state = 7},
  [6463] = {.lex_state = 97, .external_lex_state = 7},
  [6464] = {.lex_state = 97, .external_lex_state = 7},
  [6465] = {.lex_state = 97, .external_lex_state = 7},
  [6466] = {.lex_state = 97, .external_lex_state = 7},
  [6467] = {.lex_state = 97, .external_lex_state = 7},
  [6468] = {.lex_state = 97, .external_lex_state = 7},
  [6469] = {.lex_state = 97, .external_lex_state = 7},
  [6470] = {.lex_state = 97, .external_lex_state = 7},
  [6471] = {.lex_state = 97, .external_lex_state = 7},
  [6472] = {.lex_state = 97, .external_lex_state = 7},
  [6473] = {.lex_state = 97, .external_lex_state = 7},
  [6474] = {.lex_state = 97, .external_lex_state = 7},
  [6475] = {.lex_state = 97, .external_lex_state = 7},
  [6476] = {.lex_state = 97, .external_lex_state = 7},
  [6477] = {.lex_state = 97, .external_lex_state = 7},
  [6478] = {.lex_state = 97, .external_lex_state = 7},
  [6479] = {.lex_state = 97, .external_lex_state = 7},
  [6480] = {.lex_state = 97, .external_lex_state = 7},
  [6481] = {.lex_state = 97, .external_lex_state = 7},
  [6482] = {.lex_state = 97, .external_lex_state = 7},
  [6483] = {.lex_state = 97, .external_lex_state = 7},
  [6484] = {.lex_state = 97, .external_lex_state = 7},
  [6485] = {.lex_state = 97, .external_lex_state = 7},
  [6486] = {.lex_state = 97, .external_lex_state = 7},
  [6487] = {.lex_state = 97, .external_lex_state = 7},
  [6488] = {.lex_state = 97, .external_lex_state = 7},
  [6489] = {.lex_state = 97, .external_lex_state = 7},
  [6490] = {.lex_state = 97, .external_lex_state = 7},
  [6491] = {.lex_state = 97, .external_lex_state = 7},
  [6492] = {.lex_state = 97, .external_lex_state = 7},
  [6493] = {.lex_state = 97, .external_lex_state = 7},
  [6494] = {.lex_state = 97, .external_lex_state = 7},
  [6495] = {.lex_state = 97, .external_lex_state = 7},
  [6496] = {.lex_state = 97, .external_lex_state = 7},
  [6497] = {.lex_state = 97, .external_lex_state = 7},
  [6498] = {.lex_state = 97, .external_lex_state = 7},
  [6499] = {.lex_state = 97, .external_lex_state = 7},
  [6500] = {.lex_state = 97, .external_lex_state = 7},
  [6501] = {.lex_state = 97, .external_lex_state = 7},
  [6502] = {.lex_state = 97, .external_lex_state = 7},
  [6503] = {.lex_state = 97, .external_lex_state = 7},
  [6504] = {.lex_state = 97, .external_lex_state = 7},
  [6505] = {.lex_state = 97, .external_lex_state = 7},
  [6506] = {.lex_state = 97, .external_lex_state = 7},
  [6507] = {.lex_state = 97, .external_lex_state = 7},
  [6508] = {.lex_state = 97, .external_lex_state = 6},
  [6509] = {.lex_state = 97, .external_lex_state = 7},
  [6510] = {.lex_state = 97, .external_lex_state = 7},
  [6511] = {.lex_state = 97, .external_lex_state = 7},
  [6512] = {.lex_state = 97, .external_lex_state = 7},
  [6513] = {.lex_state = 97, .external_lex_state = 7},
  [6514] = {.lex_state = 97, .external_lex_state = 7},
  [6515] = {.lex_state = 97, .external_lex_state = 7},
  [6516] = {.lex_state = 97, .external_lex_state = 7},
  [6517] = {.lex_state = 97, .external_lex_state = 7},
  [6518] = {.lex_state = 97, .external_lex_state = 7},
  [6519] = {.lex_state = 97, .external_lex_state = 7},
  [6520] = {.lex_state = 97, .external_lex_state = 7},
  [6521] = {.lex_state = 97, .external_lex_state = 7},
  [6522] = {.lex_state = 97, .external_lex_state = 7},
  [6523] = {.lex_state = 97, .external_lex_state = 7},
  [6524] = {.lex_state = 97, .external_lex_state = 7},
  [6525] = {.lex_state = 97, .external_lex_state = 7},
  [6526] = {.lex_state = 97, .external_lex_state = 7},
  [6527] = {.lex_state = 97, .external_lex_state = 7},
  [6528] = {.lex_state = 97, .external_lex_state = 7},
  [6529] = {.lex_state = 97, .external_lex_state = 7},
  [6530] = {.lex_state = 97, .external_lex_state = 7},
  [6531] = {.lex_state = 97, .external_lex_state = 7},
  [6532] = {.lex_state = 97, .external_lex_state = 7},
  [6533] = {.lex_state = 97, .external_lex_state = 7},
  [6534] = {.lex_state = 97, .external_lex_state = 7},
  [6535] = {.lex_state = 97, .external_lex_state = 7},
  [6536] = {.lex_state = 97, .external_lex_state = 7},
  [6537] = {.lex_state = 97, .external_lex_state = 7},
  [6538] = {.lex_state = 97, .external_lex_state = 7},
  [6539] = {.lex_state = 97, .external_lex_state = 7},
  [6540] = {.lex_state = 97, .external_lex_state = 7},
  [6541] = {.lex_state = 97, .external_lex_state = 7},
  [6542] = {.lex_state = 97, .external_lex_state = 7},
  [6543] = {.lex_state = 97, .external_lex_state = 7},
  [6544] = {.lex_state = 97, .external_lex_state = 7},
  [6545] = {.lex_state = 97, .external_lex_state = 7},
  [6546] = {.lex_state = 97, .external_lex_state = 7},
  [6547] = {.lex_state = 97, .external_lex_state = 7},
  [6548] = {.lex_state = 97, .external_lex_state = 7},
  [6549] = {.lex_state = 97, .external_lex_state = 7},
  [6550] = {.lex_state = 97, .external_lex_state = 7},
  [6551] = {.lex_state = 97, .external_lex_state = 7},
  [6552] = {.lex_state = 97, .external_lex_state = 7},
  [6553] = {.lex_state = 97, .external_lex_state = 7},
  [6554] = {.lex_state = 97, .external_lex_state = 7},
  [6555] = {.lex_state = 97, .external_lex_state = 7},
  [6556] = {.lex_state = 97, .external_lex_state = 7},
  [6557] = {.lex_state = 97, .external_lex_state = 7},
  [6558] = {.lex_state = 97, .external_lex_state = 7},
  [6559] = {.lex_state = 97, .external_lex_state = 7},
  [6560] = {.lex_state = 97, .external_lex_state = 7},
  [6561] = {.lex_state = 97, .external_lex_state = 7},
  [6562] = {.lex_state = 97, .external_lex_state = 7},
  [6563] = {.lex_state = 97, .external_lex_state = 7},
  [6564] = {.lex_state = 97, .external_lex_state = 7},
  [6565] = {.lex_state = 97, .external_lex_state = 7},
  [6566] = {.lex_state = 97, .external_lex_state = 7},
  [6567] = {.lex_state = 97, .external_lex_state = 7},
  [6568] = {.lex_state = 97, .external_lex_state = 7},
  [6569] = {.lex_state = 97, .external_lex_state = 7},
  [6570] = {.lex_state = 97, .external_lex_state = 7},
  [6571] = {.lex_state = 97, .external_lex_state = 7},
  [6572] = {.lex_state = 97, .external_lex_state = 7},
  [6573] = {.lex_state = 97, .external_lex_state = 7},
  [6574] = {.lex_state = 97, .external_lex_state = 7},
  [6575] = {.lex_state = 97, .external_lex_state = 7},
  [6576] = {.lex_state = 97, .external_lex_state = 7},
  [6577] = {.lex_state = 97, .external_lex_state = 7},
  [6578] = {.lex_state = 97, .external_lex_state = 7},
  [6579] = {.lex_state = 97, .external_lex_state = 7},
  [6580] = {.lex_state = 97, .external_lex_state = 7},
  [6581] = {.lex_state = 97, .external_lex_state = 7},
  [6582] = {.lex_state = 97, .external_lex_state = 7},
  [6583] = {.lex_state = 97, .external_lex_state = 7},
  [6584] = {.lex_state = 97, .external_lex_state = 7},
  [6585] = {.lex_state = 97, .external_lex_state = 7},
  [6586] = {.lex_state = 97, .external_lex_state = 7},
  [6587] = {.lex_state = 97, .external_lex_state = 7},
  [6588] = {.lex_state = 97, .external_lex_state = 7},
  [6589] = {.lex_state = 97, .external_lex_state = 7},
  [6590] = {.lex_state = 97, .external_lex_state = 7},
  [6591] = {.lex_state = 97, .external_lex_state = 7},
  [6592] = {.lex_state = 97, .external_lex_state = 7},
  [6593] = {.lex_state = 97, .external_lex_state = 7},
  [6594] = {.lex_state = 97, .external_lex_state = 7},
  [6595] = {.lex_state = 97, .external_lex_state = 7},
  [6596] = {.lex_state = 97, .external_lex_state = 7},
  [6597] = {.lex_state = 97, .external_lex_state = 7},
  [6598] = {.lex_state = 97, .external_lex_state = 7},
  [6599] = {.lex_state = 97, .external_lex_state = 7},
  [6600] = {.lex_state = 97, .external_lex_state = 7},
  [6601] = {.lex_state = 97, .external_lex_state = 7},
  [6602] = {.lex_state = 97, .external_lex_state = 7},
  [6603] = {.lex_state = 97, .external_lex_state = 7},
  [6604] = {.lex_state = 97, .external_lex_state = 7},
  [6605] = {.lex_state = 97, .external_lex_state = 7},
  [6606] = {.lex_state = 97, .external_lex_state = 7},
  [6607] = {.lex_state = 97, .external_lex_state = 7},
  [6608] = {.lex_state = 97, .external_lex_state = 7},
  [6609] = {.lex_state = 97, .external_lex_state = 7},
  [6610] = {.lex_state = 97, .external_lex_state = 7},
  [6611] = {.lex_state = 97, .external_lex_state = 7},
  [6612] = {.lex_state = 97, .external_lex_state = 7},
  [6613] = {.lex_state = 97, .external_lex_state = 7},
  [6614] = {.lex_state = 97, .external_lex_state = 7},
  [6615] = {.lex_state = 87, .external_lex_state = 2},
  [6616] = {.lex_state = 97, .external_lex_state = 7},
  [6617] = {.lex_state = 87, .external_lex_state = 2},
  [6618] = {.lex_state = 87, .external_lex_state = 2},
  [6619] = {.lex_state = 87, .external_lex_state = 2},
  [6620] = {.lex_state = 87, .external_lex_state = 2},
  [6621] = {.lex_state = 0, .external_lex_state = 2},
  [6622] = {.lex_state = 0, .external_lex_state = 2},
  [6623] = {.lex_state = 0, .external_lex_state = 2},
  [6624] = {.lex_state = 0, .external_lex_state = 2},
  [6625] = {.lex_state = 0, .external_lex_state = 2},
  [6626] = {.lex_state = 0, .external_lex_state = 2},
  [6627] = {.lex_state = 0, .external_lex_state = 2},
  [6628] = {.lex_state = 0, .external_lex_state = 7},
  [6629] = {.lex_state = 0, .external_lex_state = 7},
  [6630] = {.lex_state = 0, .external_lex_state = 7},
  [6631] = {.lex_state = 0, .external_lex_state = 7},
  [6632] = {.lex_state = 87, .external_lex_state = 4},
  [6633] = {.lex_state = 87, .external_lex_state = 7},
  [6634] = {.lex_state = 87, .external_lex_state = 7},
  [6635] = {.lex_state = 87, .external_lex_state = 7},
  [6636] = {.lex_state = 87, .external_lex_state = 4},
  [6637] = {.lex_state = 87, .external_lex_state = 7},
  [6638] = {.lex_state = 87, .external_lex_state = 7},
  [6639] = {.lex_state = 87, .external_lex_state = 7},
  [6640] = {.lex_state = 87, .external_lex_state = 7},
  [6641] = {.lex_state = 87, .external_lex_state = 7},
  [6642] = {.lex_state = 87, .external_lex_state = 7},
  [6643] = {.lex_state = 87, .external_lex_state = 8},
  [6644] = {.lex_state = 87, .external_lex_state = 7},
  [6645] = {.lex_state = 87, .external_lex_state = 7},
  [6646] = {.lex_state = 87, .external_lex_state = 7},
  [6647] = {.lex_state = 87, .external_lex_state = 4},
  [6648] = {.lex_state = 87, .external_lex_state = 8},
  [6649] = {.lex_state = 87, .external_lex_state = 4},
  [6650] = {.lex_state = 87, .external_lex_state = 7},
  [6651] = {.lex_state = 0, .external_lex_state = 7},
  [6652] = {.lex_state = 89, .external_lex_state = 8},
  [6653] = {.lex_state = 87, .external_lex_state = 7},
  [6654] = {.lex_state = 87, .external_lex_state = 7},
  [6655] = {.lex_state = 87, .external_lex_state = 7},
  [6656] = {.lex_state = 87, .external_lex_state = 7},
  [6657] = {.lex_state = 87, .external_lex_state = 7},
  [6658] = {.lex_state = 87, .external_lex_state = 4},
  [6659] = {.lex_state = 87, .external_lex_state = 8},
  [6660] = {.lex_state = 0, .external_lex_state = 7},
  [6661] = {.lex_state = 87, .external_lex_state = 6},
  [6662] = {.lex_state = 87, .external_lex_state = 6},
  [6663] = {.lex_state = 87, .external_lex_state = 4},
  [6664] = {.lex_state = 87, .external_lex_state = 4},
  [6665] = {.lex_state = 87, .external_lex_state = 4},
  [6666] = {.lex_state = 87, .external_lex_state = 4},
  [6667] = {.lex_state = 87, .external_lex_state = 4},
  [6668] = {.lex_state = 87, .external_lex_state = 4},
  [6669] = {.lex_state = 87, .external_lex_state = 4},
  [6670] = {.lex_state = 87, .external_lex_state = 4},
  [6671] = {.lex_state = 87, .external_lex_state = 4},
  [6672] = {.lex_state = 87, .external_lex_state = 6},
  [6673] = {.lex_state = 87, .external_lex_state = 4},
  [6674] = {.lex_state = 87, .external_lex_state = 4},
  [6675] = {.lex_state = 87, .external_lex_state = 4},
  [6676] = {.lex_state = 87, .external_lex_state = 4},
  [6677] = {.lex_state = 87, .external_lex_state = 4},
  [6678] = {.lex_state = 87, .external_lex_state = 4},
  [6679] = {.lex_state = 87, .external_lex_state = 4},
  [6680] = {.lex_state = 87, .external_lex_state = 7},
  [6681] = {.lex_state = 89, .external_lex_state = 4},
  [6682] = {.lex_state = 87, .external_lex_state = 6},
  [6683] = {.lex_state = 87, .external_lex_state = 8},
  [6684] = {.lex_state = 87, .external_lex_state = 8},
  [6685] = {.lex_state = 87, .external_lex_state = 8},
  [6686] = {.lex_state = 87, .external_lex_state = 8},
  [6687] = {.lex_state = 87, .external_lex_state = 8},
  [6688] = {.lex_state = 87, .external_lex_state = 8},
  [6689] = {.lex_state = 87, .external_lex_state = 8},
  [6690] = {.lex_state = 87, .external_lex_state = 8},
  [6691] = {.lex_state = 87, .external_lex_state = 4},
  [6692] = {.lex_state = 87, .external_lex_state = 4},
  [6693] = {.lex_state = 87, .external_lex_state = 6},
  [6694] = {.lex_state = 87, .external_lex_state = 6},
  [6695] = {.lex_state = 87, .external_lex_state = 6},
  [6696] = {.lex_state = 87, .external_lex_state = 6},
  [6697] = {.lex_state = 87, .external_lex_state = 6},
  [6698] = {.lex_state = 87, .external_lex_state = 6},
  [6699] = {.lex_state = 87, .external_lex_state = 6},
  [6700] = {.lex_state = 87, .external_lex_state = 6},
  [6701] = {.lex_state = 87, .external_lex_state = 6},
  [6702] = {.lex_state = 87, .external_lex_state = 4},
  [6703] = {.lex_state = 87, .external_lex_state = 4},
  [6704] = {.lex_state = 87, .external_lex_state = 6},
  [6705] = {.lex_state = 87, .external_lex_state = 6},
  [6706] = {.lex_state = 87, .external_lex_state = 6},
  [6707] = {.lex_state = 89, .external_lex_state = 6},
  [6708] = {.lex_state = 87, .external_lex_state = 6},
  [6709] = {.lex_state = 87, .external_lex_state = 6},
  [6710] = {.lex_state = 87, .external_lex_state = 8},
  [6711] = {.lex_state = 87, .external_lex_state = 8},
  [6712] = {.lex_state = 87, .external_lex_state = 8},
  [6713] = {.lex_state = 87, .external_lex_state = 8},
  [6714] = {.lex_state = 87, .external_lex_state = 8},
  [6715] = {.lex_state = 87, .external_lex_state = 6},
  [6716] = {.lex_state = 87, .external_lex_state = 6},
  [6717] = {.lex_state = 87, .external_lex_state = 6},
  [6718] = {.lex_state = 87, .external_lex_state = 6},
  [6719] = {.lex_state = 87, .external_lex_state = 4},
  [6720] = {.lex_state = 87, .external_lex_state = 4},
  [6721] = {.lex_state = 87, .external_lex_state = 4},
  [6722] = {.lex_state = 87, .external_lex_state = 4},
  [6723] = {.lex_state = 87, .external_lex_state = 4},
  [6724] = {.lex_state = 87, .external_lex_state = 8},
  [6725] = {.lex_state = 87, .external_lex_state = 6},
  [6726] = {.lex_state = 87, .external_lex_state = 7},
  [6727] = {.lex_state = 87, .external_lex_state = 8},
  [6728] = {.lex_state = 87, .external_lex_state = 4},
  [6729] = {.lex_state = 87, .external_lex_state = 4},
  [6730] = {.lex_state = 87, .external_lex_state = 4},
  [6731] = {.lex_state = 87, .external_lex_state = 8},
  [6732] = {.lex_state = 87, .external_lex_state = 4},
  [6733] = {.lex_state = 87, .external_lex_state = 8},
  [6734] = {.lex_state = 87, .external_lex_state = 4},
  [6735] = {.lex_state = 87, .external_lex_state = 8},
  [6736] = {.lex_state = 87, .external_lex_state = 8},
  [6737] = {.lex_state = 87, .external_lex_state = 6},
  [6738] = {.lex_state = 87, .external_lex_state = 4},
  [6739] = {.lex_state = 87, .external_lex_state = 4},
  [6740] = {.lex_state = 87, .external_lex_state = 4},
  [6741] = {.lex_state = 87, .external_lex_state = 4},
  [6742] = {.lex_state = 87, .external_lex_state = 4},
  [6743] = {.lex_state = 87, .external_lex_state = 8},
  [6744] = {.lex_state = 87, .external_lex_state = 8},
  [6745] = {.lex_state = 87, .external_lex_state = 4},
  [6746] = {.lex_state = 87, .external_lex_state = 8},
  [6747] = {.lex_state = 87, .external_lex_state = 7},
  [6748] = {.lex_state = 87, .external_lex_state = 6},
  [6749] = {.lex_state = 87, .external_lex_state = 6},
  [6750] = {.lex_state = 84, .external_lex_state = 6},
  [6751] = {.lex_state = 87, .external_lex_state = 8},
  [6752] = {.lex_state = 87, .external_lex_state = 6},
  [6753] = {.lex_state = 84, .external_lex_state = 6},
  [6754] = {.lex_state = 87, .external_lex_state = 8},
  [6755] = {.lex_state = 87, .external_lex_state = 8},
  [6756] = {.lex_state = 89, .external_lex_state = 9},
  [6757] = {.lex_state = 87, .external_lex_state = 6},
  [6758] = {.lex_state = 87, .external_lex_state = 6},
  [6759] = {.lex_state = 87, .external_lex_state = 8},
  [6760] = {.lex_state = 87, .external_lex_state = 7},
  [6761] = {.lex_state = 87, .external_lex_state = 8},
  [6762] = {.lex_state = 87, .external_lex_state = 9},
  [6763] = {.lex_state = 87, .external_lex_state = 6},
  [6764] = {.lex_state = 87, .external_lex_state = 9},
  [6765] = {.lex_state = 84, .external_lex_state = 7},
  [6766] = {.lex_state = 84, .external_lex_state = 7},
  [6767] = {.lex_state = 84, .external_lex_state = 7},
  [6768] = {.lex_state = 84, .external_lex_state = 7},
  [6769] = {.lex_state = 84, .external_lex_state = 7},
  [6770] = {.lex_state = 84, .external_lex_state = 7},
  [6771] = {.lex_state = 84, .external_lex_state = 7},
  [6772] = {.lex_state = 87, .external_lex_state = 9},
  [6773] = {.lex_state = 84, .external_lex_state = 7},
  [6774] = {.lex_state = 87, .external_lex_state = 6},
  [6775] = {.lex_state = 84, .external_lex_state = 7},
  [6776] = {.lex_state = 84, .external_lex_state = 7},
  [6777] = {.lex_state = 84, .external_lex_state = 7},
  [6778] = {.lex_state = 84, .external_lex_state = 7},
  [6779] = {.lex_state = 84, .external_lex_state = 7},
  [6780] = {.lex_state = 84, .external_lex_state = 7},
  [6781] = {.lex_state = 87, .external_lex_state = 6},
  [6782] = {.lex_state = 87, .external_lex_state = 6},
  [6783] = {.lex_state = 84, .external_lex_state = 7},
  [6784] = {.lex_state = 87, .external_lex_state = 7},
  [6785] = {.lex_state = 87, .external_lex_state = 9},
  [6786] = {.lex_state = 87, .external_lex_state = 7},
  [6787] = {.lex_state = 84, .external_lex_state = 7},
  [6788] = {.lex_state = 84, .external_lex_state = 7},
  [6789] = {.lex_state = 87, .external_lex_state = 6},
  [6790] = {.lex_state = 87, .external_lex_state = 6},
  [6791] = {.lex_state = 84, .external_lex_state = 7},
  [6792] = {.lex_state = 84, .external_lex_state = 7},
  [6793] = {.lex_state = 87, .external_lex_state = 7},
  [6794] = {.lex_state = 87, .external_lex_state = 6},
  [6795] = {.lex_state = 87, .external_lex_state = 6},
  [6796] = {.lex_state = 84, .external_lex_state = 7},
  [6797] = {.lex_state = 84, .external_lex_state = 7},
  [6798] = {.lex_state = 84, .external_lex_state = 7},
  [6799] = {.lex_state = 84, .external_lex_state = 7},
  [6800] = {.lex_state = 84, .external_lex_state = 7},
  [6801] = {.lex_state = 89, .external_lex_state = 6},
  [6802] = {.lex_state = 84, .external_lex_state = 7},
  [6803] = {.lex_state = 84, .external_lex_state = 7},
  [6804] = {.lex_state = 87, .external_lex_state = 7},
  [6805] = {.lex_state = 84, .external_lex_state = 7},
  [6806] = {.lex_state = 84, .external_lex_state = 7},
  [6807] = {.lex_state = 89, .external_lex_state = 6},
  [6808] = {.lex_state = 84, .external_lex_state = 7},
  [6809] = {.lex_state = 84, .external_lex_state = 7},
  [6810] = {.lex_state = 87, .external_lex_state = 6},
  [6811] = {.lex_state = 84, .external_lex_state = 7},
  [6812] = {.lex_state = 87, .external_lex_state = 9},
  [6813] = {.lex_state = 87, .external_lex_state = 9},
  [6814] = {.lex_state = 87, .external_lex_state = 9},
  [6815] = {.lex_state = 87, .external_lex_state = 9},
  [6816] = {.lex_state = 87, .external_lex_state = 9},
  [6817] = {.lex_state = 87, .external_lex_state = 9},
  [6818] = {.lex_state = 87, .external_lex_state = 9},
  [6819] = {.lex_state = 87, .external_lex_state = 9},
  [6820] = {.lex_state = 87, .external_lex_state = 9},
  [6821] = {.lex_state = 87, .external_lex_state = 6},
  [6822] = {.lex_state = 87, .external_lex_state = 6},
  [6823] = {.lex_state = 87, .external_lex_state = 6},
  [6824] = {.lex_state = 87, .external_lex_state = 6},
  [6825] = {.lex_state = 87, .external_lex_state = 6},
  [6826] = {.lex_state = 87, .external_lex_state = 6},
  [6827] = {.lex_state = 87, .external_lex_state = 6},
  [6828] = {.lex_state = 87, .external_lex_state = 6},
  [6829] = {.lex_state = 87, .external_lex_state = 6},
  [6830] = {.lex_state = 87, .external_lex_state = 9},
  [6831] = {.lex_state = 87, .external_lex_state = 6},
  [6832] = {.lex_state = 87, .external_lex_state = 9},
  [6833] = {.lex_state = 87, .external_lex_state = 6},
  [6834] = {.lex_state = 87, .external_lex_state = 6},
  [6835] = {.lex_state = 87, .external_lex_state = 6},
  [6836] = {.lex_state = 87, .external_lex_state = 6},
  [6837] = {.lex_state = 87, .external_lex_state = 6},
  [6838] = {.lex_state = 87, .external_lex_state = 6},
  [6839] = {.lex_state = 87, .external_lex_state = 6},
  [6840] = {.lex_state = 87, .external_lex_state = 6},
  [6841] = {.lex_state = 87, .external_lex_state = 6},
  [6842] = {.lex_state = 87, .external_lex_state = 6},
  [6843] = {.lex_state = 87, .external_lex_state = 6},
  [6844] = {.lex_state = 87, .external_lex_state = 6},
  [6845] = {.lex_state = 87, .external_lex_state = 6},
  [6846] = {.lex_state = 87, .external_lex_state = 6},
  [6847] = {.lex_state = 87, .external_lex_state = 9},
  [6848] = {.lex_state = 87, .external_lex_state = 6},
  [6849] = {.lex_state = 87, .external_lex_state = 6},
  [6850] = {.lex_state = 87, .external_lex_state = 6},
  [6851] = {.lex_state = 87, .external_lex_state = 9},
  [6852] = {.lex_state = 87, .external_lex_state = 6},
  [6853] = {.lex_state = 87, .external_lex_state = 7},
  [6854] = {.lex_state = 87, .external_lex_state = 6},
  [6855] = {.lex_state = 87, .external_lex_state = 6},
  [6856] = {.lex_state = 87, .external_lex_state = 6},
  [6857] = {.lex_state = 87, .external_lex_state = 6},
  [6858] = {.lex_state = 87, .external_lex_state = 6},
  [6859] = {.lex_state = 87, .external_lex_state = 6},
  [6860] = {.lex_state = 87, .external_lex_state = 9},
  [6861] = {.lex_state = 87, .external_lex_state = 9},
  [6862] = {.lex_state = 87, .external_lex_state = 6},
  [6863] = {.lex_state = 87, .external_lex_state = 7},
  [6864] = {.lex_state = 87, .external_lex_state = 9},
  [6865] = {.lex_state = 87, .external_lex_state = 9},
  [6866] = {.lex_state = 87, .external_lex_state = 9},
  [6867] = {.lex_state = 87, .external_lex_state = 9},
  [6868] = {.lex_state = 87, .external_lex_state = 7},
  [6869] = {.lex_state = 87, .external_lex_state = 9},
  [6870] = {.lex_state = 87, .external_lex_state = 6},
  [6871] = {.lex_state = 87, .external_lex_state = 6},
  [6872] = {.lex_state = 87, .external_lex_state = 6},
  [6873] = {.lex_state = 87, .external_lex_state = 6},
  [6874] = {.lex_state = 87, .external_lex_state = 9},
  [6875] = {.lex_state = 87, .external_lex_state = 9},
  [6876] = {.lex_state = 87, .external_lex_state = 9},
  [6877] = {.lex_state = 87, .external_lex_state = 9},
  [6878] = {.lex_state = 87, .external_lex_state = 9},
  [6879] = {.lex_state = 0, .external_lex_state = 5},
  [6880] = {.lex_state = 0, .external_lex_state = 5},
  [6881] = {.lex_state = 87, .external_lex_state = 6},
  [6882] = {.lex_state = 87, .external_lex_state = 6},
  [6883] = {.lex_state = 87, .external_lex_state = 6},
  [6884] = {.lex_state = 87, .external_lex_state = 6},
  [6885] = {.lex_state = 87, .external_lex_state = 6},
  [6886] = {.lex_state = 87, .external_lex_state = 6},
  [6887] = {.lex_state = 87, .external_lex_state = 6},
  [6888] = {.lex_state = 87, .external_lex_state = 6},
  [6889] = {.lex_state = 87, .external_lex_state = 6},
  [6890] = {.lex_state = 87, .external_lex_state = 6},
  [6891] = {.lex_state = 87, .external_lex_state = 6},
  [6892] = {.lex_state = 0, .external_lex_state = 5},
  [6893] = {.lex_state = 87, .external_lex_state = 6},
  [6894] = {.lex_state = 0, .external_lex_state = 5},
  [6895] = {.lex_state = 0, .external_lex_state = 5},
  [6896] = {.lex_state = 87, .external_lex_state = 9},
  [6897] = {.lex_state = 0, .external_lex_state = 7},
  [6898] = {.lex_state = 0, .external_lex_state = 4},
  [6899] = {.lex_state = 0, .external_lex_state = 5},
  [6900] = {.lex_state = 0, .external_lex_state = 7},
  [6901] = {.lex_state = 0, .external_lex_state = 4},
  [6902] = {.lex_state = 0, .external_lex_state = 7},
  [6903] = {.lex_state = 0, .external_lex_state = 4},
  [6904] = {.lex_state = 0, .external_lex_state = 7},
  [6905] = {.lex_state = 0, .external_lex_state = 5},
  [6906] = {.lex_state = 0, .external_lex_state = 4},
  [6907] = {.lex_state = 87, .external_lex_state = 6},
  [6908] = {.lex_state = 87, .external_lex_state = 6},
  [6909] = {.lex_state = 87, .external_lex_state = 6},
  [6910] = {.lex_state = 0, .external_lex_state = 4},
  [6911] = {.lex_state = 87, .external_lex_state = 6},
  [6912] = {.lex_state = 0, .external_lex_state = 4},
  [6913] = {.lex_state = 87, .external_lex_state = 9},
  [6914] = {.lex_state = 87, .external_lex_state = 9},
  [6915] = {.lex_state = 87, .external_lex_state = 6},
  [6916] = {.lex_state = 0, .external_lex_state = 5},
  [6917] = {.lex_state = 87, .external_lex_state = 9},
  [6918] = {.lex_state = 87, .external_lex_state = 6},
  [6919] = {.lex_state = 87, .external_lex_state = 9},
  [6920] = {.lex_state = 87, .external_lex_state = 6},
  [6921] = {.lex_state = 87, .external_lex_state = 6},
  [6922] = {.lex_state = 0, .external_lex_state = 7},
  [6923] = {.lex_state = 87, .external_lex_state = 9},
  [6924] = {.lex_state = 87, .external_lex_state = 6},
  [6925] = {.lex_state = 0, .external_lex_state = 5},
  [6926] = {.lex_state = 87, .external_lex_state = 6},
  [6927] = {.lex_state = 87, .external_lex_state = 6},
  [6928] = {.lex_state = 0, .external_lex_state = 5},
  [6929] = {.lex_state = 87, .external_lex_state = 9},
  [6930] = {.lex_state = 87, .external_lex_state = 6},
  [6931] = {.lex_state = 0, .external_lex_state = 4},
  [6932] = {.lex_state = 0, .external_lex_state = 5},
  [6933] = {.lex_state = 0, .external_lex_state = 4},
  [6934] = {.lex_state = 0, .external_lex_state = 4},
  [6935] = {.lex_state = 0, .external_lex_state = 5},
  [6936] = {.lex_state = 0, .external_lex_state = 5},
  [6937] = {.lex_state = 0, .external_lex_state = 9},
  [6938] = {.lex_state = 0, .external_lex_state = 5},
  [6939] = {.lex_state = 0, .external_lex_state = 10},
  [6940] = {.lex_state = 0, .external_lex_state = 5},
  [6941] = {.lex_state = 0, .external_lex_state = 5},
  [6942] = {.lex_state = 0, .external_lex_state = 5},
  [6943] = {.lex_state = 0, .external_lex_state = 5},
  [6944] = {.lex_state = 0, .external_lex_state = 5},
  [6945] = {.lex_state = 0, .external_lex_state = 5},
  [6946] = {.lex_state = 0, .external_lex_state = 5},
  [6947] = {.lex_state = 0, .external_lex_state = 5},
  [6948] = {.lex_state = 0, .external_lex_state = 5},
  [6949] = {.lex_state = 0, .external_lex_state = 5},
  [6950] = {.lex_state = 0, .external_lex_state = 5},
  [6951] = {.lex_state = 0, .external_lex_state = 5},
  [6952] = {.lex_state = 0, .external_lex_state = 9},
  [6953] = {.lex_state = 0, .external_lex_state = 11},
  [6954] = {.lex_state = 0, .external_lex_state = 11},
  [6955] = {.lex_state = 14, .external_lex_state = 6},
  [6956] = {.lex_state = 0, .external_lex_state = 5},
  [6957] = {.lex_state = 0, .external_lex_state = 5},
  [6958] = {.lex_state = 0, .external_lex_state = 10},
  [6959] = {.lex_state = 0, .external_lex_state = 11},
  [6960] = {.lex_state = 0, .external_lex_state = 10},
  [6961] = {.lex_state = 0, .external_lex_state = 5},
  [6962] = {.lex_state = 0, .external_lex_state = 11},
  [6963] = {.lex_state = 0, .external_lex_state = 9},
  [6964] = {.lex_state = 0, .external_lex_state = 5},
  [6965] = {.lex_state = 0, .external_lex_state = 9},
  [6966] = {.lex_state = 0, .external_lex_state = 5},
  [6967] = {.lex_state = 0, .external_lex_state = 10},
  [6968] = {.lex_state = 0, .external_lex_state = 5},
  [6969] = {.lex_state = 0, .external_lex_state = 5},
  [6970] = {.lex_state = 0, .external_lex_state = 5},
  [6971] = {.lex_state = 0, .external_lex_state = 5},
  [6972] = {.lex_state = 0, .external_lex_state = 9},
  [6973] = {.lex_state = 0, .external_lex_state = 11},
  [6974] = {.lex_state = 0, .external_lex_state = 5},
  [6975] = {.lex_state = 0, .external_lex_state = 11},
  [6976] = {.lex_state = 0, .external_lex_state = 9},
  [6977] = {.lex_state = 89, .external_lex_state = 7},
  [6978] = {.lex_state = 0, .external_lex_state = 5},
  [6979] = {.lex_state = 0, .external_lex_state = 5},
  [6980] = {.lex_state = 0, .external_lex_state = 11},
  [6981] = {.lex_state = 0, .external_lex_state = 5},
  [6982] = {.lex_state = 0, .external_lex_state = 5},
  [6983] = {.lex_state = 0, .external_lex_state = 11},
  [6984] = {.lex_state = 0, .external_lex_state = 5},
  [6985] = {.lex_state = 0, .external_lex_state = 11},
  [6986] = {.lex_state = 0, .external_lex_state = 5},
  [6987] = {.lex_state = 0, .external_lex_state = 9},
  [6988] = {.lex_state = 0, .external_lex_state = 5},
  [6989] = {.lex_state = 0, .external_lex_state = 10},
  [6990] = {.lex_state = 0, .external_lex_state = 5},
  [6991] = {.lex_state = 0, .external_lex_state = 5},
  [6992] = {.lex_state = 0, .external_lex_state = 5},
  [6993] = {.lex_state = 0, .external_lex_state = 5},
  [6994] = {.lex_state = 0, .external_lex_state = 10},
  [6995] = {.lex_state = 89, .external_lex_state = 11},
  [6996] = {.lex_state = 0, .external_lex_state = 5},
  [6997] = {.lex_state = 0, .external_lex_state = 5},
  [6998] = {.lex_state = 0, .external_lex_state = 5},
  [6999] = {.lex_state = 0, .external_lex_state = 5},
  [7000] = {.lex_state = 0, .external_lex_state = 5},
  [7001] = {.lex_state = 0, .external_lex_state = 5},
  [7002] = {.lex_state = 0, .external_lex_state = 5},
  [7003] = {.lex_state = 0, .external_lex_state = 5},
  [7004] = {.lex_state = 0, .external_lex_state = 9},
  [7005] = {.lex_state = 0, .external_lex_state = 5},
  [7006] = {.lex_state = 0, .external_lex_state = 5},
  [7007] = {.lex_state = 0, .external_lex_state = 5},
  [7008] = {.lex_state = 0, .external_lex_state = 5},
  [7009] = {.lex_state = 0, .external_lex_state = 5},
  [7010] = {.lex_state = 0, .external_lex_state = 5},
  [7011] = {.lex_state = 89, .external_lex_state = 11},
  [7012] = {.lex_state = 0, .external_lex_state = 5},
  [7013] = {.lex_state = 0, .external_lex_state = 5},
  [7014] = {.lex_state = 0, .external_lex_state = 5},
  [7015] = {.lex_state = 0, .external_lex_state = 5},
  [7016] = {.lex_state = 0, .external_lex_state = 5},
  [7017] = {.lex_state = 0, .external_lex_state = 5},
  [7018] = {.lex_state = 0, .external_lex_state = 5},
  [7019] = {.lex_state = 0, .external_lex_state = 5},
  [7020] = {.lex_state = 0, .external_lex_state = 5},
  [7021] = {.lex_state = 0, .external_lex_state = 5},
  [7022] = {.lex_state = 0, .external_lex_state = 5},
  [7023] = {.lex_state = 0, .external_lex_state = 5},
  [7024] = {.lex_state = 0, .external_lex_state = 5},
  [7025] = {.lex_state = 0, .external_lex_state = 5},
  [7026] = {.lex_state = 0, .external_lex_state = 5},
  [7027] = {.lex_state = 0, .external_lex_state = 5},
  [7028] = {.lex_state = 0, .external_lex_state = 5},
  [7029] = {.lex_state = 0, .external_lex_state = 5},
  [7030] = {.lex_state = 0, .external_lex_state = 5},
  [7031] = {.lex_state = 0, .external_lex_state = 5},
  [7032] = {.lex_state = 0, .external_lex_state = 9},
  [7033] = {.lex_state = 0, .external_lex_state = 5},
  [7034] = {.lex_state = 0, .external_lex_state = 5},
  [7035] = {.lex_state = 0, .external_lex_state = 9},
  [7036] = {.lex_state = 0, .external_lex_state = 5},
  [7037] = {.lex_state = 0, .external_lex_state = 5},
  [7038] = {.lex_state = 0, .external_lex_state = 5},
  [7039] = {.lex_state = 89, .external_lex_state = 11},
  [7040] = {.lex_state = 0, .external_lex_state = 4},
  [7041] = {.lex_state = 0, .external_lex_state = 5},
  [7042] = {.lex_state = 0, .external_lex_state = 5},
  [7043] = {.lex_state = 0, .external_lex_state = 5},
  [7044] = {.lex_state = 0, .external_lex_state = 5},
  [7045] = {.lex_state = 0, .external_lex_state = 4},
  [7046] = {.lex_state = 0, .external_lex_state = 5},
  [7047] = {.lex_state = 0, .external_lex_state = 5},
  [7048] = {.lex_state = 0, .external_lex_state = 5},
  [7049] = {.lex_state = 0, .external_lex_state = 5},
  [7050] = {.lex_state = 0, .external_lex_state = 5},
  [7051] = {.lex_state = 0, .external_lex_state = 5},
  [7052] = {.lex_state = 0, .external_lex_state = 5},
  [7053] = {.lex_state = 0, .external_lex_state = 5},
  [7054] = {.lex_state = 0, .external_lex_state = 11},
  [7055] = {.lex_state = 0, .external_lex_state = 11},
  [7056] = {.lex_state = 87, .external_lex_state = 6},
  [7057] = {.lex_state = 0, .external_lex_state = 9},
  [7058] = {.lex_state = 0, .external_lex_state = 11},
  [7059] = {.lex_state = 0, .external_lex_state = 9},
  [7060] = {.lex_state = 0, .external_lex_state = 6},
  [7061] = {.lex_state = 0, .external_lex_state = 6},
  [7062] = {.lex_state = 0, .external_lex_state = 5},
  [7063] = {.lex_state = 0, .external_lex_state = 11},
  [7064] = {.lex_state = 0, .external_lex_state = 5},
  [7065] = {.lex_state = 89, .external_lex_state = 11},
  [7066] = {.lex_state = 0, .external_lex_state = 9},
  [7067] = {.lex_state = 0, .external_lex_state = 5},
  [7068] = {.lex_state = 87, .external_lex_state = 6},
  [7069] = {.lex_state = 0, .external_lex_state = 11},
  [7070] = {.lex_state = 0, .external_lex_state = 6},
  [7071] = {.lex_state = 0, .external_lex_state = 11},
  [7072] = {.lex_state = 0, .external_lex_state = 11},
  [7073] = {.lex_state = 0, .external_lex_state = 11},
  [7074] = {.lex_state = 0, .external_lex_state = 11},
  [7075] = {.lex_state = 0, .external_lex_state = 5},
  [7076] = {.lex_state = 0, .external_lex_state = 6},
  [7077] = {.lex_state = 0, .external_lex_state = 11},
  [7078] = {.lex_state = 0, .external_lex_state = 6},
  [7079] = {.lex_state = 0, .external_lex_state = 6},
  [7080] = {.lex_state = 0, .external_lex_state = 6},
  [7081] = {.lex_state = 0, .external_lex_state = 5},
  [7082] = {.lex_state = 0, .external_lex_state = 7},
  [7083] = {.lex_state = 0, .external_lex_state = 5},
  [7084] = {.lex_state = 0, .external_lex_state = 5},
  [7085] = {.lex_state = 0, .external_lex_state = 5},
  [7086] = {.lex_state = 0, .external_lex_state = 5},
  [7087] = {.lex_state = 0, .external_lex_state = 5},
  [7088] = {.lex_state = 0, .external_lex_state = 5},
  [7089] = {.lex_state = 87, .external_lex_state = 6},
  [7090] = {.lex_state = 0, .external_lex_state = 7},
  [7091] = {.lex_state = 0, .external_lex_state = 7},
  [7092] = {.lex_state = 0, .external_lex_state = 7},
  [7093] = {.lex_state = 87, .external_lex_state = 6},
  [7094] = {.lex_state = 0, .external_lex_state = 5},
  [7095] = {.lex_state = 0, .external_lex_state = 5},
  [7096] = {.lex_state = 0, .external_lex_state = 5},
  [7097] = {.lex_state = 0, .external_lex_state = 5},
  [7098] = {.lex_state = 0, .external_lex_state = 5},
  [7099] = {.lex_state = 0, .external_lex_state = 5},
  [7100] = {.lex_state = 0, .external_lex_state = 5},
  [7101] = {.lex_state = 0, .external_lex_state = 5},
  [7102] = {.lex_state = 0, .external_lex_state = 11},
  [7103] = {.lex_state = 0, .external_lex_state = 7},
  [7104] = {.lex_state = 0, .external_lex_state = 7},
  [7105] = {.lex_state = 87, .external_lex_state = 6},
  [7106] = {.lex_state = 0, .external_lex_state = 5},
  [7107] = {.lex_state = 0, .external_lex_state = 5},
  [7108] = {.lex_state = 0, .external_lex_state = 5},
  [7109] = {.lex_state = 0, .external_lex_state = 5},
  [7110] = {.lex_state = 0, .external_lex_state = 5},
  [7111] = {.lex_state = 0, .external_lex_state = 5},
  [7112] = {.lex_state = 0, .external_lex_state = 5},
  [7113] = {.lex_state = 0, .external_lex_state = 5},
  [7114] = {.lex_state = 87, .external_lex_state = 6},
  [7115] = {.lex_state = 0, .external_lex_state = 11},
  [7116] = {.lex_state = 0, .external_lex_state = 5},
  [7117] = {.lex_state = 0, .external_lex_state = 5},
  [7118] = {.lex_state = 0, .external_lex_state = 5},
  [7119] = {.lex_state = 0, .external_lex_state = 7},
  [7120] = {.lex_state = 0, .external_lex_state = 5},
  [7121] = {.lex_state = 0, .external_lex_state = 5},
  [7122] = {.lex_state = 0, .external_lex_state = 5},
  [7123] = {.lex_state = 87, .external_lex_state = 6},
  [7124] = {.lex_state = 0, .external_lex_state = 5},
  [7125] = {.lex_state = 0, .external_lex_state = 7},
  [7126] = {.lex_state = 0, .external_lex_state = 5},
  [7127] = {.lex_state = 0, .external_lex_state = 5},
  [7128] = {.lex_state = 0, .external_lex_state = 5},
  [7129] = {.lex_state = 0, .external_lex_state = 11},
  [7130] = {.lex_state = 0, .external_lex_state = 5},
  [7131] = {.lex_state = 0, .external_lex_state = 5},
  [7132] = {.lex_state = 0, .external_lex_state = 5},
  [7133] = {.lex_state = 0, .external_lex_state = 5},
  [7134] = {.lex_state = 0, .external_lex_state = 5},
  [7135] = {.lex_state = 0, .external_lex_state = 11},
  [7136] = {.lex_state = 0, .external_lex_state = 5},
  [7137] = {.lex_state = 0, .external_lex_state = 5},
  [7138] = {.lex_state = 0, .external_lex_state = 5},
  [7139] = {.lex_state = 0, .external_lex_state = 5},
  [7140] = {.lex_state = 0, .external_lex_state = 5},
  [7141] = {.lex_state = 0, .external_lex_state = 5},
  [7142] = {.lex_state = 0, .external_lex_state = 5},
  [7143] = {.lex_state = 0, .external_lex_state = 5},
  [7144] = {.lex_state = 0, .external_lex_state = 11},
  [7145] = {.lex_state = 0, .external_lex_state = 5},
  [7146] = {.lex_state = 0, .external_lex_state = 5},
  [7147] = {.lex_state = 0, .external_lex_state = 5},
  [7148] = {.lex_state = 0, .external_lex_state = 5},
  [7149] = {.lex_state = 0, .external_lex_state = 5},
  [7150] = {.lex_state = 0, .external_lex_state = 5},
  [7151] = {.lex_state = 87, .external_lex_state = 6},
  [7152] = {.lex_state = 0, .external_lex_state = 5},
  [7153] = {.lex_state = 0, .external_lex_state = 5},
  [7154] = {.lex_state = 0, .external_lex_state = 5},
  [7155] = {.lex_state = 0, .external_lex_state = 7},
  [7156] = {.lex_state = 0, .external_lex_state = 5},
  [7157] = {.lex_state = 0, .external_lex_state = 5},
  [7158] = {.lex_state = 0, .external_lex_state = 7},
  [7159] = {.lex_state = 0, .external_lex_state = 11},
  [7160] = {.lex_state = 0, .external_lex_state = 5},
  [7161] = {.lex_state = 0, .external_lex_state = 5},
  [7162] = {.lex_state = 0, .external_lex_state = 11},
  [7163] = {.lex_state = 0, .external_lex_state = 5},
  [7164] = {.lex_state = 0, .external_lex_state = 5},
  [7165] = {.lex_state = 0, .external_lex_state = 5},
  [7166] = {.lex_state = 0, .external_lex_state = 5},
  [7167] = {.lex_state = 0, .external_lex_state = 5},
  [7168] = {.lex_state = 0, .external_lex_state = 5},
  [7169] = {.lex_state = 0, .external_lex_state = 5},
  [7170] = {.lex_state = 0, .external_lex_state = 5},
  [7171] = {.lex_state = 0, .external_lex_state = 5},
  [7172] = {.lex_state = 0, .external_lex_state = 5},
  [7173] = {.lex_state = 0, .external_lex_state = 5},
  [7174] = {.lex_state = 0, .external_lex_state = 5},
  [7175] = {.lex_state = 0, .external_lex_state = 11},
  [7176] = {.lex_state = 0, .external_lex_state = 5},
  [7177] = {.lex_state = 0, .external_lex_state = 5},
  [7178] = {.lex_state = 0, .external_lex_state = 7},
  [7179] = {.lex_state = 87, .external_lex_state = 6},
  [7180] = {.lex_state = 0, .external_lex_state = 5},
  [7181] = {.lex_state = 0, .external_lex_state = 11},
  [7182] = {.lex_state = 0, .external_lex_state = 5},
  [7183] = {.lex_state = 0, .external_lex_state = 7},
  [7184] = {.lex_state = 0, .external_lex_state = 7},
  [7185] = {.lex_state = 0, .external_lex_state = 5},
  [7186] = {.lex_state = 0, .external_lex_state = 11},
  [7187] = {.lex_state = 0, .external_lex_state = 11},
  [7188] = {.lex_state = 89, .external_lex_state = 7},
  [7189] = {.lex_state = 0, .external_lex_state = 7},
  [7190] = {.lex_state = 0, .external_lex_state = 11},
  [7191] = {.lex_state = 0, .external_lex_state = 7},
  [7192] = {.lex_state = 0, .external_lex_state = 11},
  [7193] = {.lex_state = 87, .external_lex_state = 6},
  [7194] = {.lex_state = 0, .external_lex_state = 11},
  [7195] = {.lex_state = 0, .external_lex_state = 11},
  [7196] = {.lex_state = 0, .external_lex_state = 7},
  [7197] = {.lex_state = 0, .external_lex_state = 9},
  [7198] = {.lex_state = 0, .external_lex_state = 11},
  [7199] = {.lex_state = 0, .external_lex_state = 11},
  [7200] = {.lex_state = 0, .external_lex_state = 9},
  [7201] = {.lex_state = 0, .external_lex_state = 11},
  [7202] = {.lex_state = 0, .external_lex_state = 5},
  [7203] = {.lex_state = 0, .external_lex_state = 5},
  [7204] = {.lex_state = 0, .external_lex_state = 5},
  [7205] = {.lex_state = 0, .external_lex_state = 5},
  [7206] = {.lex_state = 0, .external_lex_state = 11},
  [7207] = {.lex_state = 0, .external_lex_state = 11},
  [7208] = {.lex_state = 0, .external_lex_state = 5},
  [7209] = {.lex_state = 0, .external_lex_state = 5},
  [7210] = {.lex_state = 0, .external_lex_state = 5},
  [7211] = {.lex_state = 0, .external_lex_state = 5},
  [7212] = {.lex_state = 0, .external_lex_state = 11},
  [7213] = {.lex_state = 0, .external_lex_state = 5},
  [7214] = {.lex_state = 0, .external_lex_state = 11},
  [7215] = {.lex_state = 0, .external_lex_state = 5},
  [7216] = {.lex_state = 0, .external_lex_state = 5},
  [7217] = {.lex_state = 0, .external_lex_state = 5},
  [7218] = {.lex_state = 0, .external_lex_state = 5},
  [7219] = {.lex_state = 0, .external_lex_state = 5},
  [7220] = {.lex_state = 0, .external_lex_state = 11},
  [7221] = {.lex_state = 0, .external_lex_state = 11},
  [7222] = {.lex_state = 0, .external_lex_state = 5},
  [7223] = {.lex_state = 0, .external_lex_state = 11},
  [7224] = {.lex_state = 0, .external_lex_state = 5},
  [7225] = {.lex_state = 0, .external_lex_state = 11},
  [7226] = {.lex_state = 0, .external_lex_state = 5},
  [7227] = {.lex_state = 0, .external_lex_state = 5},
  [7228] = {.lex_state = 0, .external_lex_state = 5},
  [7229] = {.lex_state = 89, .external_lex_state = 7},
  [7230] = {.lex_state = 0, .external_lex_state = 5},
  [7231] = {.lex_state = 87, .external_lex_state = 6},
  [7232] = {.lex_state = 0, .external_lex_state = 5},
  [7233] = {.lex_state = 0, .external_lex_state = 5},
  [7234] = {.lex_state = 0, .external_lex_state = 5},
  [7235] = {.lex_state = 0, .external_lex_state = 11},
  [7236] = {.lex_state = 87, .external_lex_state = 6},
  [7237] = {.lex_state = 0, .external_lex_state = 5},
  [7238] = {.lex_state = 0, .external_lex_state = 5},
  [7239] = {.lex_state = 0, .external_lex_state = 7},
  [7240] = {.lex_state = 0, .external_lex_state = 7},
  [7241] = {.lex_state = 0, .external_lex_state = 11},
  [7242] = {.lex_state = 87, .external_lex_state = 6},
  [7243] = {.lex_state = 0, .external_lex_state = 11},
  [7244] = {.lex_state = 0, .external_lex_state = 7},
  [7245] = {.lex_state = 0, .external_lex_state = 5},
  [7246] = {.lex_state = 0, .external_lex_state = 11},
  [7247] = {.lex_state = 0, .external_lex_state = 5},
  [7248] = {.lex_state = 0, .external_lex_state = 11},
  [7249] = {.lex_state = 0, .external_lex_state = 5},
  [7250] = {.lex_state = 0, .external_lex_state = 5},
  [7251] = {.lex_state = 0, .external_lex_state = 5},
  [7252] = {.lex_state = 0, .external_lex_state = 5},
  [7253] = {.lex_state = 0, .external_lex_state = 9},
  [7254] = {.lex_state = 0, .external_lex_state = 7},
  [7255] = {.lex_state = 0, .external_lex_state = 11},
  [7256] = {.lex_state = 0, .external_lex_state = 5},
  [7257] = {.lex_state = 0, .external_lex_state = 5},
  [7258] = {.lex_state = 0, .external_lex_state = 5},
  [7259] = {.lex_state = 0, .external_lex_state = 11},
  [7260] = {.lex_state = 0, .external_lex_state = 11},
  [7261] = {.lex_state = 0, .external_lex_state = 11},
  [7262] = {.lex_state = 0, .external_lex_state = 5},
  [7263] = {.lex_state = 0, .external_lex_state = 11},
  [7264] = {.lex_state = 0, .external_lex_state = 5},
  [7265] = {.lex_state = 0, .external_lex_state = 5},
  [7266] = {.lex_state = 0, .external_lex_state = 11},
  [7267] = {.lex_state = 0, .external_lex_state = 5},
  [7268] = {.lex_state = 0, .external_lex_state = 5},
  [7269] = {.lex_state = 0, .external_lex_state = 5},
  [7270] = {.lex_state = 0, .external_lex_state = 5},
  [7271] = {.lex_state = 0, .external_lex_state = 5},
  [7272] = {.lex_state = 0, .external_lex_state = 5},
  [7273] = {.lex_state = 0, .external_lex_state = 5},
  [7274] = {.lex_state = 87, .external_lex_state = 6},
  [7275] = {.lex_state = 0, .external_lex_state = 5},
  [7276] = {.lex_state = 0, .external_lex_state = 5},
  [7277] = {.lex_state = 0, .external_lex_state = 5},
  [7278] = {.lex_state = 0, .external_lex_state = 5},
  [7279] = {.lex_state = 0, .external_lex_state = 7},
  [7280] = {.lex_state = 0, .external_lex_state = 7},
  [7281] = {.lex_state = 0, .external_lex_state = 7},
  [7282] = {.lex_state = 0, .external_lex_state = 7},
  [7283] = {.lex_state = 0, .external_lex_state = 5},
  [7284] = {.lex_state = 0, .external_lex_state = 11},
  [7285] = {.lex_state = 0, .external_lex_state = 11},
  [7286] = {.lex_state = 0, .external_lex_state = 11},
  [7287] = {.lex_state = 0, .external_lex_state = 11},
  [7288] = {.lex_state = 0, .external_lex_state = 11},
  [7289] = {.lex_state = 0, .external_lex_state = 5},
  [7290] = {.lex_state = 0, .external_lex_state = 11},
  [7291] = {.lex_state = 0, .external_lex_state = 5},
  [7292] = {.lex_state = 0, .external_lex_state = 5},
  [7293] = {.lex_state = 0, .external_lex_state = 5},
  [7294] = {.lex_state = 0, .external_lex_state = 5},
  [7295] = {.lex_state = 87, .external_lex_state = 6},
  [7296] = {.lex_state = 0, .external_lex_state = 11},
  [7297] = {.lex_state = 0, .external_lex_state = 5},
  [7298] = {.lex_state = 0, .external_lex_state = 11},
  [7299] = {.lex_state = 0, .external_lex_state = 11},
  [7300] = {.lex_state = 0, .external_lex_state = 11},
  [7301] = {.lex_state = 0, .external_lex_state = 5},
  [7302] = {.lex_state = 0, .external_lex_state = 11},
  [7303] = {.lex_state = 0, .external_lex_state = 11},
  [7304] = {.lex_state = 0, .external_lex_state = 5},
  [7305] = {.lex_state = 0, .external_lex_state = 5},
  [7306] = {.lex_state = 0, .external_lex_state = 5},
  [7307] = {.lex_state = 0, .external_lex_state = 11},
  [7308] = {.lex_state = 0, .external_lex_state = 11},
  [7309] = {.lex_state = 0, .external_lex_state = 11},
  [7310] = {.lex_state = 0, .external_lex_state = 5},
  [7311] = {.lex_state = 0, .external_lex_state = 7},
  [7312] = {.lex_state = 0, .external_lex_state = 7},
  [7313] = {.lex_state = 87, .external_lex_state = 6},
  [7314] = {.lex_state = 0, .external_lex_state = 11},
  [7315] = {.lex_state = 0, .external_lex_state = 11},
  [7316] = {.lex_state = 0, .external_lex_state = 5},
  [7317] = {.lex_state = 0, .external_lex_state = 5},
  [7318] = {.lex_state = 0, .external_lex_state = 7},
  [7319] = {.lex_state = 0, .external_lex_state = 5},
  [7320] = {.lex_state = 0, .external_lex_state = 11},
  [7321] = {.lex_state = 0, .external_lex_state = 11},
  [7322] = {.lex_state = 0, .external_lex_state = 5},
  [7323] = {.lex_state = 0, .external_lex_state = 5},
  [7324] = {.lex_state = 0, .external_lex_state = 11},
  [7325] = {.lex_state = 0, .external_lex_state = 11},
  [7326] = {.lex_state = 89, .external_lex_state = 7},
  [7327] = {.lex_state = 0, .external_lex_state = 5},
  [7328] = {.lex_state = 0, .external_lex_state = 5},
  [7329] = {.lex_state = 0, .external_lex_state = 11},
  [7330] = {.lex_state = 0, .external_lex_state = 5},
  [7331] = {.lex_state = 0, .external_lex_state = 5},
  [7332] = {.lex_state = 0, .external_lex_state = 5},
  [7333] = {.lex_state = 0, .external_lex_state = 5},
  [7334] = {.lex_state = 0, .external_lex_state = 5},
  [7335] = {.lex_state = 87, .external_lex_state = 6},
  [7336] = {.lex_state = 0, .external_lex_state = 11},
  [7337] = {.lex_state = 0, .external_lex_state = 5},
  [7338] = {.lex_state = 0, .external_lex_state = 5},
  [7339] = {.lex_state = 0, .external_lex_state = 5},
  [7340] = {.lex_state = 0, .external_lex_state = 5},
  [7341] = {.lex_state = 0, .external_lex_state = 5},
  [7342] = {.lex_state = 87, .external_lex_state = 6},
  [7343] = {.lex_state = 0, .external_lex_state = 5},
  [7344] = {.lex_state = 0, .external_lex_state = 11},
  [7345] = {.lex_state = 0, .external_lex_state = 7},
  [7346] = {.lex_state = 87, .external_lex_state = 6},
  [7347] = {.lex_state = 0, .external_lex_state = 11},
  [7348] = {.lex_state = 0, .external_lex_state = 7},
  [7349] = {.lex_state = 0, .external_lex_state = 7},
  [7350] = {.lex_state = 0, .external_lex_state = 5},
  [7351] = {.lex_state = 0, .external_lex_state = 5},
  [7352] = {.lex_state = 0, .external_lex_state = 5},
  [7353] = {.lex_state = 0, .external_lex_state = 5},
  [7354] = {.lex_state = 0, .external_lex_state = 5},
  [7355] = {.lex_state = 0, .external_lex_state = 5},
  [7356] = {.lex_state = 0, .external_lex_state = 5},
  [7357] = {.lex_state = 0, .external_lex_state = 7},
  [7358] = {.lex_state = 0, .external_lex_state = 7},
  [7359] = {.lex_state = 0, .external_lex_state = 7},
  [7360] = {.lex_state = 0, .external_lex_state = 7},
  [7361] = {.lex_state = 0, .external_lex_state = 5},
  [7362] = {.lex_state = 0, .external_lex_state = 5},
  [7363] = {.lex_state = 0, .external_lex_state = 7},
  [7364] = {.lex_state = 0, .external_lex_state = 7},
  [7365] = {.lex_state = 0, .external_lex_state = 5},
  [7366] = {.lex_state = 0, .external_lex_state = 7},
  [7367] = {.lex_state = 0, .external_lex_state = 7},
  [7368] = {.lex_state = 0, .external_lex_state = 6},
  [7369] = {.lex_state = 0, .external_lex_state = 5},
  [7370] = {.lex_state = 0, .external_lex_state = 7},
  [7371] = {.lex_state = 0, .external_lex_state = 5},
  [7372] = {.lex_state = 0, .external_lex_state = 5},
  [7373] = {.lex_state = 0, .external_lex_state = 7},
  [7374] = {.lex_state = 0, .external_lex_state = 7},
  [7375] = {.lex_state = 0, .external_lex_state = 7},
  [7376] = {.lex_state = 87, .external_lex_state = 7},
  [7377] = {.lex_state = 0, .external_lex_state = 5},
  [7378] = {.lex_state = 0, .external_lex_state = 7},
  [7379] = {.lex_state = 0, .external_lex_state = 5},
  [7380] = {.lex_state = 0, .external_lex_state = 5},
  [7381] = {.lex_state = 0, .external_lex_state = 5},
  [7382] = {.lex_state = 0, .external_lex_state = 5},
  [7383] = {.lex_state = 0, .external_lex_state = 7},
  [7384] = {.lex_state = 0, .external_lex_state = 7},
  [7385] = {.lex_state = 0, .external_lex_state = 7},
  [7386] = {.lex_state = 0, .external_lex_state = 5},
  [7387] = {.lex_state = 0, .external_lex_state = 5},
  [7388] = {.lex_state = 87, .external_lex_state = 7},
  [7389] = {.lex_state = 87, .external_lex_state = 6},
  [7390] = {.lex_state = 0, .external_lex_state = 7},
  [7391] = {.lex_state = 0, .external_lex_state = 5},
  [7392] = {.lex_state = 87, .external_lex_state = 7},
  [7393] = {.lex_state = 0, .external_lex_state = 7},
  [7394] = {.lex_state = 87, .external_lex_state = 7},
  [7395] = {.lex_state = 0, .external_lex_state = 7},
  [7396] = {.lex_state = 0, .external_lex_state = 5},
  [7397] = {.lex_state = 0, .external_lex_state = 7},
  [7398] = {.lex_state = 87, .external_lex_state = 6},
  [7399] = {.lex_state = 0, .external_lex_state = 5},
  [7400] = {.lex_state = 0, .external_lex_state = 7},
  [7401] = {.lex_state = 0, .external_lex_state = 6},
  [7402] = {.lex_state = 0, .external_lex_state = 5},
  [7403] = {.lex_state = 0, .external_lex_state = 7},
  [7404] = {.lex_state = 89, .external_lex_state = 7},
  [7405] = {.lex_state = 87, .external_lex_state = 7},
  [7406] = {.lex_state = 87, .external_lex_state = 7},
  [7407] = {.lex_state = 0, .external_lex_state = 6},
  [7408] = {.lex_state = 0, .external_lex_state = 7},
  [7409] = {.lex_state = 0, .external_lex_state = 6},
  [7410] = {.lex_state = 0, .external_lex_state = 5},
  [7411] = {.lex_state = 0, .external_lex_state = 5},
  [7412] = {.lex_state = 0, .external_lex_state = 5},
  [7413] = {.lex_state = 0, .external_lex_state = 7},
  [7414] = {.lex_state = 0, .external_lex_state = 5},
  [7415] = {.lex_state = 0, .external_lex_state = 7},
  [7416] = {.lex_state = 0, .external_lex_state = 5},
  [7417] = {.lex_state = 0, .external_lex_state = 5},
  [7418] = {.lex_state = 0, .external_lex_state = 5},
  [7419] = {.lex_state = 0, .external_lex_state = 5},
  [7420] = {.lex_state = 0, .external_lex_state = 5},
  [7421] = {.lex_state = 0, .external_lex_state = 7},
  [7422] = {.lex_state = 0, .external_lex_state = 7},
  [7423] = {.lex_state = 0, .external_lex_state = 7},
  [7424] = {.lex_state = 0, .external_lex_state = 5},
  [7425] = {.lex_state = 0, .external_lex_state = 7},
  [7426] = {.lex_state = 0, .external_lex_state = 5},
  [7427] = {.lex_state = 0, .external_lex_state = 5},
  [7428] = {.lex_state = 0, .external_lex_state = 5},
  [7429] = {.lex_state = 0, .external_lex_state = 5},
  [7430] = {.lex_state = 0, .external_lex_state = 7},
  [7431] = {.lex_state = 0, .external_lex_state = 5},
  [7432] = {.lex_state = 0, .external_lex_state = 7},
  [7433] = {.lex_state = 89, .external_lex_state = 7},
  [7434] = {.lex_state = 0, .external_lex_state = 5},
  [7435] = {.lex_state = 0, .external_lex_state = 7},
  [7436] = {.lex_state = 0, .external_lex_state = 5},
  [7437] = {.lex_state = 0, .external_lex_state = 5},
  [7438] = {.lex_state = 0, .external_lex_state = 7},
  [7439] = {.lex_state = 87, .external_lex_state = 7},
  [7440] = {.lex_state = 0, .external_lex_state = 7},
  [7441] = {.lex_state = 0, .external_lex_state = 5},
  [7442] = {.lex_state = 0, .external_lex_state = 7},
  [7443] = {.lex_state = 0, .external_lex_state = 7},
  [7444] = {.lex_state = 0, .external_lex_state = 7},
  [7445] = {.lex_state = 0, .external_lex_state = 5},
  [7446] = {.lex_state = 0, .external_lex_state = 7},
  [7447] = {.lex_state = 0, .external_lex_state = 7},
  [7448] = {.lex_state = 0, .external_lex_state = 5},
  [7449] = {.lex_state = 0, .external_lex_state = 7},
  [7450] = {.lex_state = 0, .external_lex_state = 5},
  [7451] = {.lex_state = 0, .external_lex_state = 7},
  [7452] = {.lex_state = 0, .external_lex_state = 5},
  [7453] = {.lex_state = 0, .external_lex_state = 7},
  [7454] = {.lex_state = 0, .external_lex_state = 5},
  [7455] = {.lex_state = 0, .external_lex_state = 7},
  [7456] = {.lex_state = 0, .external_lex_state = 7},
  [7457] = {.lex_state = 0, .external_lex_state = 5},
  [7458] = {.lex_state = 0, .external_lex_state = 7},
  [7459] = {.lex_state = 0, .external_lex_state = 5},
  [7460] = {.lex_state = 0, .external_lex_state = 5},
  [7461] = {.lex_state = 0, .external_lex_state = 5},
  [7462] = {.lex_state = 0, .external_lex_state = 5},
  [7463] = {.lex_state = 0, .external_lex_state = 7},
  [7464] = {.lex_state = 0, .external_lex_state = 7},
  [7465] = {.lex_state = 0, .external_lex_state = 7},
  [7466] = {.lex_state = 0, .external_lex_state = 5},
  [7467] = {.lex_state = 87, .external_lex_state = 7},
  [7468] = {.lex_state = 87, .external_lex_state = 7},
  [7469] = {.lex_state = 87, .external_lex_state = 6},
  [7470] = {.lex_state = 0, .external_lex_state = 5},
  [7471] = {.lex_state = 87, .external_lex_state = 6},
  [7472] = {.lex_state = 0, .external_lex_state = 7},
  [7473] = {.lex_state = 0, .external_lex_state = 5},
  [7474] = {.lex_state = 0, .external_lex_state = 5},
  [7475] = {.lex_state = 89, .external_lex_state = 7},
  [7476] = {.lex_state = 0, .external_lex_state = 7},
  [7477] = {.lex_state = 0, .external_lex_state = 7},
  [7478] = {.lex_state = 0, .external_lex_state = 7},
  [7479] = {.lex_state = 0, .external_lex_state = 5},
  [7480] = {.lex_state = 0, .external_lex_state = 6},
  [7481] = {.lex_state = 0, .external_lex_state = 7},
  [7482] = {.lex_state = 0, .external_lex_state = 7},
  [7483] = {.lex_state = 0, .external_lex_state = 5},
  [7484] = {.lex_state = 0, .external_lex_state = 5},
  [7485] = {.lex_state = 0, .external_lex_state = 5},
  [7486] = {.lex_state = 0, .external_lex_state = 5},
  [7487] = {.lex_state = 0, .external_lex_state = 5},
  [7488] = {.lex_state = 0, .external_lex_state = 7},
  [7489] = {.lex_state = 0, .external_lex_state = 7},
  [7490] = {.lex_state = 0, .external_lex_state = 5},
  [7491] = {.lex_state = 0, .external_lex_state = 7},
  [7492] = {.lex_state = 0, .external_lex_state = 7},
  [7493] = {.lex_state = 0, .external_lex_state = 5},
  [7494] = {.lex_state = 0, .external_lex_state = 7},
  [7495] = {.lex_state = 0, .external_lex_state = 7},
  [7496] = {.lex_state = 0, .external_lex_state = 7},
  [7497] = {.lex_state = 0, .external_lex_state = 7},
  [7498] = {.lex_state = 0, .external_lex_state = 7},
  [7499] = {.lex_state = 0, .external_lex_state = 5},
  [7500] = {.lex_state = 0, .external_lex_state = 5},
  [7501] = {.lex_state = 0, .external_lex_state = 7},
  [7502] = {.lex_state = 0, .external_lex_state = 5},
  [7503] = {.lex_state = 89, .external_lex_state = 7},
  [7504] = {.lex_state = 0, .external_lex_state = 7},
  [7505] = {.lex_state = 0, .external_lex_state = 5},
  [7506] = {.lex_state = 0, .external_lex_state = 5},
  [7507] = {.lex_state = 87, .external_lex_state = 7},
  [7508] = {.lex_state = 0, .external_lex_state = 7},
  [7509] = {.lex_state = 87, .external_lex_state = 7},
  [7510] = {.lex_state = 87, .external_lex_state = 6},
  [7511] = {.lex_state = 0, .external_lex_state = 5},
  [7512] = {.lex_state = 0, .external_lex_state = 7},
  [7513] = {.lex_state = 0, .external_lex_state = 5},
  [7514] = {.lex_state = 0, .external_lex_state = 5},
  [7515] = {.lex_state = 0, .external_lex_state = 7},
  [7516] = {.lex_state = 87, .external_lex_state = 6},
  [7517] = {.lex_state = 0, .external_lex_state = 5},
  [7518] = {.lex_state = 0, .external_lex_state = 5},
  [7519] = {.lex_state = 0, .external_lex_state = 5},
  [7520] = {.lex_state = 0, .external_lex_state = 7},
  [7521] = {.lex_state = 0, .external_lex_state = 7},
  [7522] = {.lex_state = 0, .external_lex_state = 7},
  [7523] = {.lex_state = 0, .external_lex_state = 5},
  [7524] = {.lex_state = 0, .external_lex_state = 5},
  [7525] = {.lex_state = 0, .external_lex_state = 5},
  [7526] = {.lex_state = 0, .external_lex_state = 5},
  [7527] = {.lex_state = 0, .external_lex_state = 5},
  [7528] = {.lex_state = 0, .external_lex_state = 7},
  [7529] = {.lex_state = 0, .external_lex_state = 5},
  [7530] = {.lex_state = 0, .external_lex_state = 7},
  [7531] = {.lex_state = 0, .external_lex_state = 7},
  [7532] = {.lex_state = 87, .external_lex_state = 6},
  [7533] = {.lex_state = 0, .external_lex_state = 7},
  [7534] = {.lex_state = 0, .external_lex_state = 7},
  [7535] = {.lex_state = 0, .external_lex_state = 7},
  [7536] = {.lex_state = 87, .external_lex_state = 6},
  [7537] = {.lex_state = 3, .external_lex_state = 11},
  [7538] = {.lex_state = 16, .external_lex_state = 6},
  [7539] = {.lex_state = 3, .external_lex_state = 11},
  [7540] = {.lex_state = 0, .external_lex_state = 7},
  [7541] = {.lex_state = 0, .external_lex_state = 7},
  [7542] = {.lex_state = 0, .external_lex_state = 7},
  [7543] = {.lex_state = 0, .external_lex_state = 6},
  [7544] = {.lex_state = 3, .external_lex_state = 11},
  [7545] = {.lex_state = 87, .external_lex_state = 6},
  [7546] = {.lex_state = 0, .external_lex_state = 7},
  [7547] = {.lex_state = 0, .external_lex_state = 6},
  [7548] = {.lex_state = 0, .external_lex_state = 5},
  [7549] = {.lex_state = 16, .external_lex_state = 6},
  [7550] = {.lex_state = 0, .external_lex_state = 6},
  [7551] = {.lex_state = 0, .external_lex_state = 7},
  [7552] = {.lex_state = 3, .external_lex_state = 11},
  [7553] = {.lex_state = 0, .external_lex_state = 7},
  [7554] = {.lex_state = 3, .external_lex_state = 11},
  [7555] = {.lex_state = 16, .external_lex_state = 6},
  [7556] = {.lex_state = 0, .external_lex_state = 7},
  [7557] = {.lex_state = 3, .external_lex_state = 11},
  [7558] = {.lex_state = 0, .external_lex_state = 7},
  [7559] = {.lex_state = 16, .external_lex_state = 6},
  [7560] = {.lex_state = 0, .external_lex_state = 7},
  [7561] = {.lex_state = 87, .external_lex_state = 6},
  [7562] = {.lex_state = 87, .external_lex_state = 6},
  [7563] = {.lex_state = 0, .external_lex_state = 7},
  [7564] = {.lex_state = 0, .external_lex_state = 7},
  [7565] = {.lex_state = 87, .external_lex_state = 6},
  [7566] = {.lex_state = 87, .external_lex_state = 6},
  [7567] = {.lex_state = 3, .external_lex_state = 11},
  [7568] = {.lex_state = 87, .external_lex_state = 6},
  [7569] = {.lex_state = 0, .external_lex_state = 7},
  [7570] = {.lex_state = 0, .external_lex_state = 7},
  [7571] = {.lex_state = 3, .external_lex_state = 11},
  [7572] = {.lex_state = 0, .external_lex_state = 7},
  [7573] = {.lex_state = 87, .external_lex_state = 6},
  [7574] = {.lex_state = 0, .external_lex_state = 6},
  [7575] = {.lex_state = 87, .external_lex_state = 6},
  [7576] = {.lex_state = 0, .external_lex_state = 7},
  [7577] = {.lex_state = 16, .external_lex_state = 6},
  [7578] = {.lex_state = 87, .external_lex_state = 6},
  [7579] = {.lex_state = 0, .external_lex_state = 7},
  [7580] = {.lex_state = 87, .external_lex_state = 6},
  [7581] = {.lex_state = 0, .external_lex_state = 7},
  [7582] = {.lex_state = 87, .external_lex_state = 6},
  [7583] = {.lex_state = 0, .external_lex_state = 7},
  [7584] = {.lex_state = 0, .external_lex_state = 7},
  [7585] = {.lex_state = 0, .external_lex_state = 7},
  [7586] = {.lex_state = 0, .external_lex_state = 7},
  [7587] = {.lex_state = 0, .external_lex_state = 6},
  [7588] = {.lex_state = 87, .external_lex_state = 6},
  [7589] = {.lex_state = 0, .external_lex_state = 7},
  [7590] = {.lex_state = 0, .external_lex_state = 7},
  [7591] = {.lex_state = 0, .external_lex_state = 6},
  [7592] = {.lex_state = 87, .external_lex_state = 6},
  [7593] = {.lex_state = 87, .external_lex_state = 6},
  [7594] = {.lex_state = 0, .external_lex_state = 7},
  [7595] = {.lex_state = 0, .external_lex_state = 7},
  [7596] = {.lex_state = 87, .external_lex_state = 6},
  [7597] = {.lex_state = 3, .external_lex_state = 11},
  [7598] = {.lex_state = 87, .external_lex_state = 6},
  [7599] = {.lex_state = 0, .external_lex_state = 7},
  [7600] = {.lex_state = 87, .external_lex_state = 6},
  [7601] = {.lex_state = 0, .external_lex_state = 7},
  [7602] = {.lex_state = 0, .external_lex_state = 6},
  [7603] = {.lex_state = 0, .external_lex_state = 7},
  [7604] = {.lex_state = 0, .external_lex_state = 7},
  [7605] = {.lex_state = 0, .external_lex_state = 7},
  [7606] = {.lex_state = 0, .external_lex_state = 7},
  [7607] = {.lex_state = 0, .external_lex_state = 7},
  [7608] = {.lex_state = 0, .external_lex_state = 7},
  [7609] = {.lex_state = 0, .external_lex_state = 7},
  [7610] = {.lex_state = 0, .external_lex_state = 7},
  [7611] = {.lex_state = 0, .external_lex_state = 7},
  [7612] = {.lex_state = 3, .external_lex_state = 11},
  [7613] = {.lex_state = 0, .external_lex_state = 7},
  [7614] = {.lex_state = 87, .external_lex_state = 6},
  [7615] = {.lex_state = 87, .external_lex_state = 6},
  [7616] = {.lex_state = 3, .external_lex_state = 11},
  [7617] = {.lex_state = 16, .external_lex_state = 6},
  [7618] = {.lex_state = 87, .external_lex_state = 6},
  [7619] = {.lex_state = 16, .external_lex_state = 6},
  [7620] = {.lex_state = 0, .external_lex_state = 7},
  [7621] = {.lex_state = 0, .external_lex_state = 7},
  [7622] = {.lex_state = 0, .external_lex_state = 7},
  [7623] = {.lex_state = 0, .external_lex_state = 7},
  [7624] = {.lex_state = 0, .external_lex_state = 7},
  [7625] = {.lex_state = 3, .external_lex_state = 11},
  [7626] = {.lex_state = 87, .external_lex_state = 6},
  [7627] = {.lex_state = 0, .external_lex_state = 6},
  [7628] = {.lex_state = 3, .external_lex_state = 11},
  [7629] = {.lex_state = 0, .external_lex_state = 7},
  [7630] = {.lex_state = 87, .external_lex_state = 6},
  [7631] = {.lex_state = 16, .external_lex_state = 6},
  [7632] = {.lex_state = 87, .external_lex_state = 6},
  [7633] = {.lex_state = 87, .external_lex_state = 6},
  [7634] = {.lex_state = 0, .external_lex_state = 7},
  [7635] = {.lex_state = 3, .external_lex_state = 11},
  [7636] = {.lex_state = 0, .external_lex_state = 7},
  [7637] = {.lex_state = 87, .external_lex_state = 6},
  [7638] = {.lex_state = 0, .external_lex_state = 7},
  [7639] = {.lex_state = 87, .external_lex_state = 6},
  [7640] = {.lex_state = 0, .external_lex_state = 7},
  [7641] = {.lex_state = 87, .external_lex_state = 6},
  [7642] = {.lex_state = 87, .external_lex_state = 6},
  [7643] = {.lex_state = 87, .external_lex_state = 6},
  [7644] = {.lex_state = 0, .external_lex_state = 7},
  [7645] = {.lex_state = 87, .external_lex_state = 6},
  [7646] = {.lex_state = 0, .external_lex_state = 7},
  [7647] = {.lex_state = 87, .external_lex_state = 6},
  [7648] = {.lex_state = 87, .external_lex_state = 6},
  [7649] = {.lex_state = 87, .external_lex_state = 6},
  [7650] = {.lex_state = 0, .external_lex_state = 7},
  [7651] = {.lex_state = 0, .external_lex_state = 7},
  [7652] = {.lex_state = 0, .external_lex_state = 7},
  [7653] = {.lex_state = 0, .external_lex_state = 7},
  [7654] = {.lex_state = 0, .external_lex_state = 7},
  [7655] = {.lex_state = 0, .external_lex_state = 7},
  [7656] = {.lex_state = 0, .external_lex_state = 7},
  [7657] = {.lex_state = 87, .external_lex_state = 6},
  [7658] = {.lex_state = 0, .external_lex_state = 5},
  [7659] = {.lex_state = 0, .external_lex_state = 7},
  [7660] = {.lex_state = 0, .external_lex_state = 7},
  [7661] = {.lex_state = 0, .external_lex_state = 7},
  [7662] = {.lex_state = 0, .external_lex_state = 7},
  [7663] = {.lex_state = 0, .external_lex_state = 7},
  [7664] = {.lex_state = 0, .external_lex_state = 6},
  [7665] = {.lex_state = 0, .external_lex_state = 7},
  [7666] = {.lex_state = 0, .external_lex_state = 5},
  [7667] = {.lex_state = 0, .external_lex_state = 7},
  [7668] = {.lex_state = 0, .external_lex_state = 6},
  [7669] = {.lex_state = 0, .external_lex_state = 7},
  [7670] = {.lex_state = 0, .external_lex_state = 7},
  [7671] = {.lex_state = 0, .external_lex_state = 7},
  [7672] = {.lex_state = 0, .external_lex_state = 7},
  [7673] = {.lex_state = 3, .external_lex_state = 11},
  [7674] = {.lex_state = 0, .external_lex_state = 7},
  [7675] = {.lex_state = 0, .external_lex_state = 5},
  [7676] = {.lex_state = 0, .external_lex_state = 7},
  [7677] = {.lex_state = 3, .external_lex_state = 11},
  [7678] = {.lex_state = 87, .external_lex_state = 6},
  [7679] = {.lex_state = 0, .external_lex_state = 7},
  [7680] = {.lex_state = 0, .external_lex_state = 5},
  [7681] = {.lex_state = 87, .external_lex_state = 6},
  [7682] = {.lex_state = 3, .external_lex_state = 11},
  [7683] = {.lex_state = 0, .external_lex_state = 7},
  [7684] = {.lex_state = 87, .external_lex_state = 6},
  [7685] = {.lex_state = 0, .external_lex_state = 7},
  [7686] = {.lex_state = 0, .external_lex_state = 7},
  [7687] = {.lex_state = 0, .external_lex_state = 7},
  [7688] = {.lex_state = 0, .external_lex_state = 7},
  [7689] = {.lex_state = 3, .external_lex_state = 11},
  [7690] = {.lex_state = 87, .external_lex_state = 6},
  [7691] = {.lex_state = 0, .external_lex_state = 7},
  [7692] = {.lex_state = 87, .external_lex_state = 6},
  [7693] = {.lex_state = 0, .external_lex_state = 7},
  [7694] = {.lex_state = 3, .external_lex_state = 11},
  [7695] = {.lex_state = 3, .external_lex_state = 11},
  [7696] = {.lex_state = 3, .external_lex_state = 11},
  [7697] = {.lex_state = 3, .external_lex_state = 11},
  [7698] = {.lex_state = 0, .external_lex_state = 7},
  [7699] = {.lex_state = 0, .external_lex_state = 7},
  [7700] = {.lex_state = 0, .external_lex_state = 7},
  [7701] = {.lex_state = 3, .external_lex_state = 11},
  [7702] = {.lex_state = 87, .external_lex_state = 6},
  [7703] = {.lex_state = 87, .external_lex_state = 6},
  [7704] = {.lex_state = 0, .external_lex_state = 7},
  [7705] = {.lex_state = 0, .external_lex_state = 7},
  [7706] = {.lex_state = 0, .external_lex_state = 7},
  [7707] = {.lex_state = 0, .external_lex_state = 7},
  [7708] = {.lex_state = 0, .external_lex_state = 7},
  [7709] = {.lex_state = 0, .external_lex_state = 7},
  [7710] = {.lex_state = 3, .external_lex_state = 11},
  [7711] = {.lex_state = 3, .external_lex_state = 11},
  [7712] = {.lex_state = 3, .external_lex_state = 11},
  [7713] = {.lex_state = 0, .external_lex_state = 7},
  [7714] = {.lex_state = 3, .external_lex_state = 11},
  [7715] = {.lex_state = 87, .external_lex_state = 6},
  [7716] = {.lex_state = 0, .external_lex_state = 6},
  [7717] = {.lex_state = 87, .external_lex_state = 6},
  [7718] = {.lex_state = 87, .external_lex_state = 6},
  [7719] = {.lex_state = 0, .external_lex_state = 7},
  [7720] = {.lex_state = 87, .external_lex_state = 6},
  [7721] = {.lex_state = 87, .external_lex_state = 6},
  [7722] = {.lex_state = 16, .external_lex_state = 6},
  [7723] = {.lex_state = 87, .external_lex_state = 6},
  [7724] = {.lex_state = 87, .external_lex_state = 7},
  [7725] = {.lex_state = 0, .external_lex_state = 7},
  [7726] = {.lex_state = 0, .external_lex_state = 7},
  [7727] = {.lex_state = 0, .external_lex_state = 7},
  [7728] = {.lex_state = 0, .external_lex_state = 7},
  [7729] = {.lex_state = 0, .external_lex_state = 7},
  [7730] = {.lex_state = 0, .external_lex_state = 7},
  [7731] = {.lex_state = 0, .external_lex_state = 7},
  [7732] = {.lex_state = 0, .external_lex_state = 7},
  [7733] = {.lex_state = 0, .external_lex_state = 7},
  [7734] = {.lex_state = 0, .external_lex_state = 7},
  [7735] = {.lex_state = 0, .external_lex_state = 7},
  [7736] = {.lex_state = 0, .external_lex_state = 7},
  [7737] = {.lex_state = 0, .external_lex_state = 7},
  [7738] = {.lex_state = 0, .external_lex_state = 7},
  [7739] = {.lex_state = 87, .external_lex_state = 6},
  [7740] = {.lex_state = 87, .external_lex_state = 6},
  [7741] = {.lex_state = 87, .external_lex_state = 6},
  [7742] = {.lex_state = 87, .external_lex_state = 6},
  [7743] = {.lex_state = 0, .external_lex_state = 7},
  [7744] = {.lex_state = 0, .external_lex_state = 7},
  [7745] = {.lex_state = 0, .external_lex_state = 7},
  [7746] = {.lex_state = 87, .external_lex_state = 6},
  [7747] = {.lex_state = 0, .external_lex_state = 7},
  [7748] = {.lex_state = 0, .external_lex_state = 6},
  [7749] = {.lex_state = 0, .external_lex_state = 6},
  [7750] = {.lex_state = 0, .external_lex_state = 7},
  [7751] = {.lex_state = 0, .external_lex_state = 7},
  [7752] = {.lex_state = 0, .external_lex_state = 7},
  [7753] = {.lex_state = 0, .external_lex_state = 7},
  [7754] = {.lex_state = 0, .external_lex_state = 7},
  [7755] = {.lex_state = 24, .external_lex_state = 7},
  [7756] = {.lex_state = 0, .external_lex_state = 7},
  [7757] = {.lex_state = 0, .external_lex_state = 7},
  [7758] = {.lex_state = 0, .external_lex_state = 7},
  [7759] = {.lex_state = 0, .external_lex_state = 7},
  [7760] = {.lex_state = 0, .external_lex_state = 7},
  [7761] = {.lex_state = 0, .external_lex_state = 7},
  [7762] = {.lex_state = 0, .external_lex_state = 7},
  [7763] = {.lex_state = 0, .external_lex_state = 7},
  [7764] = {.lex_state = 0, .external_lex_state = 7},
  [7765] = {.lex_state = 0, .external_lex_state = 7},
  [7766] = {.lex_state = 0, .external_lex_state = 7},
  [7767] = {.lex_state = 0, .external_lex_state = 7},
  [7768] = {.lex_state = 0, .external_lex_state = 7},
  [7769] = {.lex_state = 0, .external_lex_state = 7},
  [7770] = {.lex_state = 0, .external_lex_state = 6},
  [7771] = {.lex_state = 0, .external_lex_state = 7},
  [7772] = {.lex_state = 0, .external_lex_state = 7},
  [7773] = {.lex_state = 0, .external_lex_state = 7},
  [7774] = {.lex_state = 0, .external_lex_state = 7},
  [7775] = {.lex_state = 0, .external_lex_state = 6},
  [7776] = {.lex_state = 24, .external_lex_state = 7},
  [7777] = {.lex_state = 0, .external_lex_state = 7},
  [7778] = {.lex_state = 0, .external_lex_state = 7},
  [7779] = {.lex_state = 0, .external_lex_state = 7},
  [7780] = {.lex_state = 0, .external_lex_state = 7},
  [7781] = {.lex_state = 0, .external_lex_state = 7},
  [7782] = {.lex_state = 0, .external_lex_state = 7},
  [7783] = {.lex_state = 0, .external_lex_state = 7},
  [7784] = {.lex_state = 0, .external_lex_state = 7},
  [7785] = {.lex_state = 0, .external_lex_state = 7},
  [7786] = {.lex_state = 0, .external_lex_state = 7},
  [7787] = {.lex_state = 0, .external_lex_state = 6},
  [7788] = {.lex_state = 0, .external_lex_state = 6},
  [7789] = {.lex_state = 0, .external_lex_state = 7},
  [7790] = {.lex_state = 0, .external_lex_state = 7},
  [7791] = {.lex_state = 0, .external_lex_state = 7},
  [7792] = {.lex_state = 0, .external_lex_state = 7},
  [7793] = {.lex_state = 0, .external_lex_state = 7},
  [7794] = {.lex_state = 0, .external_lex_state = 7},
  [7795] = {.lex_state = 0, .external_lex_state = 7},
  [7796] = {.lex_state = 0, .external_lex_state = 7},
  [7797] = {.lex_state = 0, .external_lex_state = 7},
  [7798] = {.lex_state = 0, .external_lex_state = 7},
  [7799] = {.lex_state = 0, .external_lex_state = 7},
  [7800] = {.lex_state = 0, .external_lex_state = 5},
  [7801] = {.lex_state = 0, .external_lex_state = 7},
  [7802] = {.lex_state = 0, .external_lex_state = 7},
  [7803] = {.lex_state = 0, .external_lex_state = 7},
  [7804] = {.lex_state = 0, .external_lex_state = 6},
  [7805] = {.lex_state = 0, .external_lex_state = 7},
  [7806] = {.lex_state = 0, .external_lex_state = 7},
  [7807] = {.lex_state = 0, .external_lex_state = 7},
  [7808] = {.lex_state = 0, .external_lex_state = 5},
  [7809] = {.lex_state = 0, .external_lex_state = 6},
  [7810] = {.lex_state = 0, .external_lex_state = 7},
  [7811] = {.lex_state = 0, .external_lex_state = 7},
  [7812] = {.lex_state = 0, .external_lex_state = 5},
  [7813] = {.lex_state = 0, .external_lex_state = 7},
  [7814] = {.lex_state = 0, .external_lex_state = 7},
  [7815] = {.lex_state = 0, .external_lex_state = 7},
  [7816] = {.lex_state = 0, .external_lex_state = 7},
  [7817] = {.lex_state = 87, .external_lex_state = 6},
  [7818] = {.lex_state = 24, .external_lex_state = 7},
  [7819] = {.lex_state = 0, .external_lex_state = 7},
  [7820] = {.lex_state = 0, .external_lex_state = 6},
  [7821] = {.lex_state = 0, .external_lex_state = 6},
  [7822] = {.lex_state = 0, .external_lex_state = 7},
  [7823] = {.lex_state = 0, .external_lex_state = 6},
  [7824] = {.lex_state = 0, .external_lex_state = 7},
  [7825] = {.lex_state = 0, .external_lex_state = 7},
  [7826] = {.lex_state = 0, .external_lex_state = 7},
  [7827] = {.lex_state = 0, .external_lex_state = 7},
  [7828] = {.lex_state = 0, .external_lex_state = 7},
  [7829] = {.lex_state = 0, .external_lex_state = 6},
  [7830] = {.lex_state = 24, .external_lex_state = 7},
  [7831] = {.lex_state = 0, .external_lex_state = 6},
  [7832] = {.lex_state = 0, .external_lex_state = 7},
  [7833] = {.lex_state = 0, .external_lex_state = 7},
  [7834] = {.lex_state = 0, .external_lex_state = 7},
  [7835] = {.lex_state = 0, .external_lex_state = 7},
  [7836] = {.lex_state = 0, .external_lex_state = 7},
  [7837] = {.lex_state = 0, .external_lex_state = 6},
  [7838] = {.lex_state = 0, .external_lex_state = 7},
  [7839] = {.lex_state = 0, .external_lex_state = 7},
  [7840] = {.lex_state = 24, .external_lex_state = 7},
  [7841] = {.lex_state = 0, .external_lex_state = 7},
  [7842] = {.lex_state = 0, .external_lex_state = 7},
  [7843] = {.lex_state = 0, .external_lex_state = 7},
  [7844] = {.lex_state = 0, .external_lex_state = 6},
  [7845] = {.lex_state = 0, .external_lex_state = 6},
  [7846] = {.lex_state = 0, .external_lex_state = 7},
  [7847] = {.lex_state = 0, .external_lex_state = 7},
  [7848] = {.lex_state = 0, .external_lex_state = 7},
  [7849] = {.lex_state = 0, .external_lex_state = 7},
  [7850] = {.lex_state = 0, .external_lex_state = 6},
  [7851] = {.lex_state = 0, .external_lex_state = 7},
  [7852] = {.lex_state = 0, .external_lex_state = 7},
  [7853] = {.lex_state = 0, .external_lex_state = 6},
  [7854] = {.lex_state = 0, .external_lex_state = 7},
  [7855] = {.lex_state = 0, .external_lex_state = 6},
  [7856] = {.lex_state = 0, .external_lex_state = 7},
  [7857] = {.lex_state = 0, .external_lex_state = 7},
  [7858] = {.lex_state = 0, .external_lex_state = 6},
  [7859] = {.lex_state = 0, .external_lex_state = 7},
  [7860] = {.lex_state = 0, .external_lex_state = 7},
  [7861] = {.lex_state = 0, .external_lex_state = 7},
  [7862] = {.lex_state = 0, .external_lex_state = 7},
  [7863] = {.lex_state = 0, .external_lex_state = 7},
  [7864] = {.lex_state = 0, .external_lex_state = 7},
  [7865] = {.lex_state = 0, .external_lex_state = 7},
  [7866] = {.lex_state = 0, .external_lex_state = 7},
  [7867] = {.lex_state = 0, .external_lex_state = 6},
  [7868] = {.lex_state = 0, .external_lex_state = 6},
  [7869] = {.lex_state = 0, .external_lex_state = 7},
  [7870] = {.lex_state = 0, .external_lex_state = 7},
  [7871] = {.lex_state = 0, .external_lex_state = 7},
  [7872] = {.lex_state = 0, .external_lex_state = 6},
  [7873] = {.lex_state = 0, .external_lex_state = 7},
  [7874] = {.lex_state = 0, .external_lex_state = 7},
  [7875] = {.lex_state = 0, .external_lex_state = 7},
  [7876] = {.lex_state = 0, .external_lex_state = 7},
  [7877] = {.lex_state = 0, .external_lex_state = 6},
  [7878] = {.lex_state = 0, .external_lex_state = 7},
  [7879] = {.lex_state = 0, .external_lex_state = 7},
  [7880] = {.lex_state = 0, .external_lex_state = 7},
  [7881] = {.lex_state = 0, .external_lex_state = 7},
  [7882] = {.lex_state = 0, .external_lex_state = 7},
  [7883] = {.lex_state = 87, .external_lex_state = 7},
  [7884] = {.lex_state = 0, .external_lex_state = 7},
  [7885] = {.lex_state = 0, .external_lex_state = 7},
  [7886] = {.lex_state = 0, .external_lex_state = 7},
  [7887] = {.lex_state = 0, .external_lex_state = 7},
  [7888] = {.lex_state = 0, .external_lex_state = 7},
  [7889] = {.lex_state = 0, .external_lex_state = 7},
  [7890] = {.lex_state = 0, .external_lex_state = 7},
  [7891] = {.lex_state = 0, .external_lex_state = 7},
  [7892] = {.lex_state = 0, .external_lex_state = 6},
  [7893] = {.lex_state = 0, .external_lex_state = 7},
  [7894] = {.lex_state = 0, .external_lex_state = 7},
  [7895] = {.lex_state = 0, .external_lex_state = 7},
  [7896] = {.lex_state = 0, .external_lex_state = 7},
  [7897] = {.lex_state = 0, .external_lex_state = 6},
  [7898] = {.lex_state = 0, .external_lex_state = 7},
  [7899] = {.lex_state = 0, .external_lex_state = 7},
  [7900] = {.lex_state = 0, .external_lex_state = 7},
  [7901] = {.lex_state = 0, .external_lex_state = 7},
  [7902] = {.lex_state = 0, .external_lex_state = 7},
  [7903] = {.lex_state = 0, .external_lex_state = 5},
  [7904] = {.lex_state = 0, .external_lex_state = 7},
  [7905] = {.lex_state = 0, .external_lex_state = 7},
  [7906] = {.lex_state = 0, .external_lex_state = 7},
  [7907] = {.lex_state = 0, .external_lex_state = 6},
  [7908] = {.lex_state = 0, .external_lex_state = 7},
  [7909] = {.lex_state = 0, .external_lex_state = 7},
  [7910] = {.lex_state = 87, .external_lex_state = 6},
  [7911] = {.lex_state = 0, .external_lex_state = 7},
  [7912] = {.lex_state = 0, .external_lex_state = 7},
  [7913] = {.lex_state = 0, .external_lex_state = 7},
  [7914] = {.lex_state = 0, .external_lex_state = 7},
  [7915] = {.lex_state = 0, .external_lex_state = 6},
  [7916] = {.lex_state = 0, .external_lex_state = 7},
  [7917] = {.lex_state = 0, .external_lex_state = 7},
  [7918] = {.lex_state = 0, .external_lex_state = 6},
  [7919] = {.lex_state = 0, .external_lex_state = 7},
  [7920] = {.lex_state = 0, .external_lex_state = 7},
  [7921] = {.lex_state = 0, .external_lex_state = 6},
  [7922] = {.lex_state = 0, .external_lex_state = 7},
  [7923] = {.lex_state = 0, .external_lex_state = 7},
  [7924] = {.lex_state = 0, .external_lex_state = 7},
  [7925] = {.lex_state = 0, .external_lex_state = 7},
  [7926] = {.lex_state = 0, .external_lex_state = 7},
  [7927] = {.lex_state = 0, .external_lex_state = 7},
  [7928] = {.lex_state = 0, .external_lex_state = 7},
  [7929] = {.lex_state = 0, .external_lex_state = 7},
  [7930] = {.lex_state = 0, .external_lex_state = 7},
  [7931] = {.lex_state = 0, .external_lex_state = 7},
  [7932] = {.lex_state = 0, .external_lex_state = 7},
  [7933] = {.lex_state = 0, .external_lex_state = 7},
  [7934] = {.lex_state = 0, .external_lex_state = 6},
  [7935] = {.lex_state = 0, .external_lex_state = 7},
  [7936] = {.lex_state = 0, .external_lex_state = 6},
  [7937] = {.lex_state = 0, .external_lex_state = 7},
  [7938] = {.lex_state = 0, .external_lex_state = 6},
  [7939] = {.lex_state = 0, .external_lex_state = 7},
  [7940] = {.lex_state = 0, .external_lex_state = 7},
  [7941] = {.lex_state = 0, .external_lex_state = 7},
  [7942] = {.lex_state = 0, .external_lex_state = 7},
  [7943] = {.lex_state = 0, .external_lex_state = 7},
  [7944] = {.lex_state = 0, .external_lex_state = 6},
  [7945] = {.lex_state = 0, .external_lex_state = 7},
  [7946] = {.lex_state = 0, .external_lex_state = 7},
  [7947] = {.lex_state = 0, .external_lex_state = 7},
  [7948] = {.lex_state = 0, .external_lex_state = 7},
  [7949] = {.lex_state = 0, .external_lex_state = 7},
  [7950] = {.lex_state = 0, .external_lex_state = 5},
  [7951] = {.lex_state = 0, .external_lex_state = 7},
  [7952] = {.lex_state = 24, .external_lex_state = 7},
  [7953] = {.lex_state = 0, .external_lex_state = 7},
  [7954] = {.lex_state = 0, .external_lex_state = 6},
  [7955] = {.lex_state = 0, .external_lex_state = 7},
  [7956] = {.lex_state = 0, .external_lex_state = 7},
  [7957] = {.lex_state = 0, .external_lex_state = 6},
  [7958] = {.lex_state = 0, .external_lex_state = 6},
  [7959] = {.lex_state = 0, .external_lex_state = 7},
  [7960] = {.lex_state = 0, .external_lex_state = 7},
  [7961] = {.lex_state = 24, .external_lex_state = 7},
  [7962] = {.lex_state = 0, .external_lex_state = 7},
  [7963] = {.lex_state = 0, .external_lex_state = 7},
  [7964] = {.lex_state = 0, .external_lex_state = 7},
  [7965] = {.lex_state = 0, .external_lex_state = 7},
  [7966] = {.lex_state = 0, .external_lex_state = 7},
  [7967] = {.lex_state = 0, .external_lex_state = 7},
  [7968] = {.lex_state = 0, .external_lex_state = 7},
  [7969] = {.lex_state = 0, .external_lex_state = 7},
  [7970] = {.lex_state = 0, .external_lex_state = 7},
  [7971] = {.lex_state = 0, .external_lex_state = 6},
  [7972] = {.lex_state = 0, .external_lex_state = 7},
  [7973] = {.lex_state = 0, .external_lex_state = 6},
  [7974] = {.lex_state = 0, .external_lex_state = 7},
  [7975] = {.lex_state = 0, .external_lex_state = 6},
  [7976] = {.lex_state = 0, .external_lex_state = 7},
  [7977] = {.lex_state = 0, .external_lex_state = 7},
  [7978] = {.lex_state = 0, .external_lex_state = 6},
  [7979] = {.lex_state = 0, .external_lex_state = 7},
  [7980] = {.lex_state = 0, .external_lex_state = 6},
  [7981] = {.lex_state = 0, .external_lex_state = 7},
  [7982] = {.lex_state = 0, .external_lex_state = 6},
  [7983] = {.lex_state = 0, .external_lex_state = 7},
  [7984] = {.lex_state = 0, .external_lex_state = 7},
  [7985] = {.lex_state = 0, .external_lex_state = 7},
  [7986] = {.lex_state = 0, .external_lex_state = 7},
  [7987] = {.lex_state = 0, .external_lex_state = 7},
  [7988] = {.lex_state = 0, .external_lex_state = 7},
  [7989] = {.lex_state = 0, .external_lex_state = 7},
  [7990] = {.lex_state = 0, .external_lex_state = 6},
  [7991] = {.lex_state = 0, .external_lex_state = 7},
  [7992] = {.lex_state = 0, .external_lex_state = 7},
  [7993] = {.lex_state = 0, .external_lex_state = 7},
  [7994] = {.lex_state = 0, .external_lex_state = 7},
  [7995] = {.lex_state = 0, .external_lex_state = 7},
  [7996] = {.lex_state = 0, .external_lex_state = 7},
  [7997] = {.lex_state = 0, .external_lex_state = 7},
  [7998] = {.lex_state = 0, .external_lex_state = 7},
  [7999] = {.lex_state = 24, .external_lex_state = 7},
  [8000] = {.lex_state = 0, .external_lex_state = 7},
  [8001] = {.lex_state = 0, .external_lex_state = 7},
  [8002] = {.lex_state = 0, .external_lex_state = 7},
  [8003] = {.lex_state = 0, .external_lex_state = 7},
  [8004] = {.lex_state = 0, .external_lex_state = 7},
  [8005] = {.lex_state = 0, .external_lex_state = 7},
  [8006] = {.lex_state = 0, .external_lex_state = 7},
  [8007] = {.lex_state = 0, .external_lex_state = 7},
  [8008] = {.lex_state = 0, .external_lex_state = 7},
  [8009] = {.lex_state = 0, .external_lex_state = 7},
  [8010] = {.lex_state = 0, .external_lex_state = 7},
  [8011] = {.lex_state = 0, .external_lex_state = 7},
  [8012] = {.lex_state = 0, .external_lex_state = 7},
  [8013] = {.lex_state = 0, .external_lex_state = 7},
  [8014] = {.lex_state = 0, .external_lex_state = 7},
  [8015] = {.lex_state = 0, .external_lex_state = 7},
  [8016] = {.lex_state = 0, .external_lex_state = 7},
  [8017] = {.lex_state = 24, .external_lex_state = 7},
  [8018] = {.lex_state = 0, .external_lex_state = 7},
  [8019] = {.lex_state = 0, .external_lex_state = 7},
  [8020] = {.lex_state = 0, .external_lex_state = 7},
  [8021] = {.lex_state = 0, .external_lex_state = 7},
  [8022] = {.lex_state = 0, .external_lex_state = 6},
  [8023] = {.lex_state = 0, .external_lex_state = 7},
  [8024] = {.lex_state = 0, .external_lex_state = 7},
  [8025] = {.lex_state = 0, .external_lex_state = 7},
  [8026] = {.lex_state = 0, .external_lex_state = 7},
  [8027] = {.lex_state = 0, .external_lex_state = 7},
  [8028] = {.lex_state = 0, .external_lex_state = 7},
  [8029] = {.lex_state = 0, .external_lex_state = 7},
  [8030] = {.lex_state = 0, .external_lex_state = 7},
  [8031] = {.lex_state = 0, .external_lex_state = 7},
  [8032] = {.lex_state = 0, .external_lex_state = 7},
  [8033] = {.lex_state = 0, .external_lex_state = 7},
  [8034] = {.lex_state = 0, .external_lex_state = 7},
  [8035] = {.lex_state = 0, .external_lex_state = 7},
  [8036] = {.lex_state = 0, .external_lex_state = 7},
  [8037] = {.lex_state = 0, .external_lex_state = 7},
  [8038] = {.lex_state = 0, .external_lex_state = 7},
  [8039] = {.lex_state = 0, .external_lex_state = 7},
  [8040] = {.lex_state = 0, .external_lex_state = 7},
  [8041] = {.lex_state = 0, .external_lex_state = 7},
  [8042] = {.lex_state = 0, .external_lex_state = 7},
  [8043] = {.lex_state = 0, .external_lex_state = 7},
  [8044] = {.lex_state = 0, .external_lex_state = 7},
  [8045] = {.lex_state = 0, .external_lex_state = 7},
  [8046] = {.lex_state = 24, .external_lex_state = 7},
  [8047] = {.lex_state = 0, .external_lex_state = 7},
  [8048] = {.lex_state = 87, .external_lex_state = 6},
  [8049] = {.lex_state = 0, .external_lex_state = 7},
  [8050] = {.lex_state = 0, .external_lex_state = 7},
  [8051] = {.lex_state = 0, .external_lex_state = 7},
  [8052] = {.lex_state = 0, .external_lex_state = 7},
  [8053] = {.lex_state = 24, .external_lex_state = 7},
  [8054] = {.lex_state = 0, .external_lex_state = 7},
  [8055] = {.lex_state = 0, .external_lex_state = 7},
  [8056] = {.lex_state = 0, .external_lex_state = 7},
  [8057] = {.lex_state = 0, .external_lex_state = 7},
  [8058] = {.lex_state = 0, .external_lex_state = 7},
  [8059] = {.lex_state = 0, .external_lex_state = 7},
  [8060] = {.lex_state = 0, .external_lex_state = 7},
  [8061] = {.lex_state = 0, .external_lex_state = 7},
  [8062] = {.lex_state = 0, .external_lex_state = 6},
  [8063] = {.lex_state = 0, .external_lex_state = 7},
  [8064] = {.lex_state = 0, .external_lex_state = 7},
  [8065] = {.lex_state = 0, .external_lex_state = 7},
  [8066] = {.lex_state = 24, .external_lex_state = 7},
  [8067] = {.lex_state = 0, .external_lex_state = 7},
  [8068] = {.lex_state = 0, .external_lex_state = 7},
  [8069] = {.lex_state = 0, .external_lex_state = 7},
  [8070] = {.lex_state = 0, .external_lex_state = 7},
  [8071] = {.lex_state = 0, .external_lex_state = 7},
  [8072] = {.lex_state = 0, .external_lex_state = 7},
  [8073] = {.lex_state = 0, .external_lex_state = 7},
  [8074] = {.lex_state = 0, .external_lex_state = 7},
  [8075] = {.lex_state = 0, .external_lex_state = 7},
  [8076] = {.lex_state = 0, .external_lex_state = 7},
  [8077] = {.lex_state = 0, .external_lex_state = 7},
  [8078] = {.lex_state = 0, .external_lex_state = 7},
  [8079] = {.lex_state = 0, .external_lex_state = 7},
  [8080] = {.lex_state = 0, .external_lex_state = 7},
  [8081] = {.lex_state = 0, .external_lex_state = 7},
  [8082] = {.lex_state = 0, .external_lex_state = 7},
  [8083] = {.lex_state = 0, .external_lex_state = 7},
  [8084] = {.lex_state = 0, .external_lex_state = 7},
  [8085] = {.lex_state = 0, .external_lex_state = 7},
  [8086] = {.lex_state = 0, .external_lex_state = 7},
  [8087] = {.lex_state = 0, .external_lex_state = 7},
  [8088] = {.lex_state = 0, .external_lex_state = 7},
  [8089] = {.lex_state = 0, .external_lex_state = 7},
  [8090] = {.lex_state = 0, .external_lex_state = 7},
  [8091] = {.lex_state = 0, .external_lex_state = 7},
  [8092] = {.lex_state = 0, .external_lex_state = 7},
  [8093] = {.lex_state = 0, .external_lex_state = 7},
  [8094] = {.lex_state = 0, .external_lex_state = 7},
  [8095] = {.lex_state = 0, .external_lex_state = 7},
  [8096] = {.lex_state = 0, .external_lex_state = 7},
  [8097] = {.lex_state = 0, .external_lex_state = 7},
  [8098] = {.lex_state = 0, .external_lex_state = 7},
  [8099] = {.lex_state = 0, .external_lex_state = 7},
  [8100] = {.lex_state = 0, .external_lex_state = 7},
  [8101] = {.lex_state = 0, .external_lex_state = 7},
  [8102] = {.lex_state = 0, .external_lex_state = 7},
  [8103] = {.lex_state = 0, .external_lex_state = 7},
  [8104] = {.lex_state = 0, .external_lex_state = 7},
  [8105] = {.lex_state = 0, .external_lex_state = 7},
  [8106] = {.lex_state = 0, .external_lex_state = 7},
  [8107] = {.lex_state = 0, .external_lex_state = 7},
  [8108] = {.lex_state = 0, .external_lex_state = 7},
  [8109] = {.lex_state = 0, .external_lex_state = 7},
  [8110] = {.lex_state = 0, .external_lex_state = 7},
  [8111] = {.lex_state = 0, .external_lex_state = 7},
  [8112] = {.lex_state = 0, .external_lex_state = 7},
  [8113] = {.lex_state = 0, .external_lex_state = 7},
  [8114] = {.lex_state = 0, .external_lex_state = 7},
  [8115] = {.lex_state = 0, .external_lex_state = 7},
  [8116] = {.lex_state = 0, .external_lex_state = 7},
  [8117] = {.lex_state = 0, .external_lex_state = 7},
  [8118] = {.lex_state = 0, .external_lex_state = 7},
  [8119] = {.lex_state = 0, .external_lex_state = 7},
  [8120] = {.lex_state = 0, .external_lex_state = 7},
  [8121] = {.lex_state = 0, .external_lex_state = 7},
  [8122] = {.lex_state = 0, .external_lex_state = 7},
  [8123] = {.lex_state = 0, .external_lex_state = 7},
  [8124] = {.lex_state = 0, .external_lex_state = 7},
  [8125] = {.lex_state = 0, .external_lex_state = 7},
  [8126] = {.lex_state = 0, .external_lex_state = 7},
  [8127] = {.lex_state = 0, .external_lex_state = 7},
  [8128] = {.lex_state = 0, .external_lex_state = 7},
  [8129] = {.lex_state = 0, .external_lex_state = 7},
  [8130] = {.lex_state = 0, .external_lex_state = 7},
  [8131] = {.lex_state = 24, .external_lex_state = 7},
  [8132] = {.lex_state = 0, .external_lex_state = 7},
  [8133] = {.lex_state = 0, .external_lex_state = 7},
  [8134] = {.lex_state = 0, .external_lex_state = 6},
  [8135] = {.lex_state = 0, .external_lex_state = 7},
  [8136] = {.lex_state = 0, .external_lex_state = 7},
  [8137] = {.lex_state = 0, .external_lex_state = 7},
  [8138] = {.lex_state = 0, .external_lex_state = 7},
  [8139] = {.lex_state = 0, .external_lex_state = 7},
  [8140] = {.lex_state = 0, .external_lex_state = 7},
  [8141] = {.lex_state = 0, .external_lex_state = 7},
  [8142] = {.lex_state = 0, .external_lex_state = 7},
  [8143] = {.lex_state = 0, .external_lex_state = 7},
  [8144] = {.lex_state = 0, .external_lex_state = 7},
  [8145] = {.lex_state = 0, .external_lex_state = 7},
  [8146] = {.lex_state = 0, .external_lex_state = 7},
  [8147] = {.lex_state = 0, .external_lex_state = 7},
  [8148] = {.lex_state = 24, .external_lex_state = 7},
  [8149] = {.lex_state = 0, .external_lex_state = 7},
  [8150] = {.lex_state = 0, .external_lex_state = 7},
  [8151] = {.lex_state = 0, .external_lex_state = 7},
  [8152] = {.lex_state = 0, .external_lex_state = 7},
  [8153] = {.lex_state = 0, .external_lex_state = 7},
  [8154] = {.lex_state = 0, .external_lex_state = 7},
  [8155] = {.lex_state = 0, .external_lex_state = 7},
  [8156] = {.lex_state = 24, .external_lex_state = 7},
  [8157] = {.lex_state = 0, .external_lex_state = 7},
  [8158] = {.lex_state = 0, .external_lex_state = 7},
  [8159] = {.lex_state = 0, .external_lex_state = 7},
  [8160] = {.lex_state = 0, .external_lex_state = 7},
  [8161] = {.lex_state = 0, .external_lex_state = 6},
  [8162] = {.lex_state = 24, .external_lex_state = 7},
  [8163] = {.lex_state = 0, .external_lex_state = 7},
  [8164] = {.lex_state = 0, .external_lex_state = 7},
  [8165] = {.lex_state = 0, .external_lex_state = 7},
  [8166] = {.lex_state = 0, .external_lex_state = 7},
  [8167] = {.lex_state = 0, .external_lex_state = 7},
  [8168] = {.lex_state = 0, .external_lex_state = 7},
  [8169] = {.lex_state = 0, .external_lex_state = 7},
  [8170] = {.lex_state = 0, .external_lex_state = 7},
  [8171] = {.lex_state = 0, .external_lex_state = 7},
  [8172] = {.lex_state = 0, .external_lex_state = 7},
  [8173] = {.lex_state = 0, .external_lex_state = 7},
  [8174] = {.lex_state = 0, .external_lex_state = 7},
  [8175] = {.lex_state = 0, .external_lex_state = 7},
  [8176] = {.lex_state = 0, .external_lex_state = 7},
  [8177] = {.lex_state = 0, .external_lex_state = 7},
  [8178] = {.lex_state = 0, .external_lex_state = 7},
  [8179] = {.lex_state = 0, .external_lex_state = 7},
  [8180] = {.lex_state = 0, .external_lex_state = 7},
  [8181] = {.lex_state = 0, .external_lex_state = 7},
  [8182] = {.lex_state = 0, .external_lex_state = 7},
  [8183] = {.lex_state = 0, .external_lex_state = 7},
  [8184] = {.lex_state = 0, .external_lex_state = 7},
  [8185] = {.lex_state = 0, .external_lex_state = 7},
  [8186] = {.lex_state = 0, .external_lex_state = 7},
  [8187] = {.lex_state = 0, .external_lex_state = 7},
  [8188] = {.lex_state = 0, .external_lex_state = 7},
  [8189] = {.lex_state = 0, .external_lex_state = 7},
  [8190] = {.lex_state = 0, .external_lex_state = 7},
  [8191] = {.lex_state = 0, .external_lex_state = 6},
  [8192] = {.lex_state = 0, .external_lex_state = 6},
  [8193] = {.lex_state = 0, .external_lex_state = 7},
  [8194] = {.lex_state = 0, .external_lex_state = 7},
  [8195] = {.lex_state = 0, .external_lex_state = 7},
  [8196] = {.lex_state = 0, .external_lex_state = 7},
  [8197] = {.lex_state = 0, .external_lex_state = 7},
  [8198] = {.lex_state = 0, .external_lex_state = 7},
  [8199] = {.lex_state = 0, .external_lex_state = 7},
  [8200] = {.lex_state = 0, .external_lex_state = 7},
  [8201] = {.lex_state = 0, .external_lex_state = 7},
  [8202] = {.lex_state = 0, .external_lex_state = 7},
  [8203] = {.lex_state = 0, .external_lex_state = 7},
  [8204] = {.lex_state = 0, .external_lex_state = 7},
  [8205] = {.lex_state = 0, .external_lex_state = 7},
  [8206] = {.lex_state = 0, .external_lex_state = 7},
  [8207] = {.lex_state = 0, .external_lex_state = 7},
  [8208] = {.lex_state = 0, .external_lex_state = 7},
  [8209] = {.lex_state = 0, .external_lex_state = 7},
  [8210] = {.lex_state = 0, .external_lex_state = 7},
  [8211] = {.lex_state = 87, .external_lex_state = 6},
  [8212] = {.lex_state = 0, .external_lex_state = 7},
  [8213] = {.lex_state = 0, .external_lex_state = 7},
  [8214] = {.lex_state = 0, .external_lex_state = 7},
  [8215] = {.lex_state = 0, .external_lex_state = 7},
  [8216] = {.lex_state = 0, .external_lex_state = 7},
  [8217] = {.lex_state = 0, .external_lex_state = 7},
  [8218] = {.lex_state = 0, .external_lex_state = 7},
  [8219] = {.lex_state = 0, .external_lex_state = 7},
  [8220] = {.lex_state = 0, .external_lex_state = 7},
  [8221] = {.lex_state = 0, .external_lex_state = 7},
  [8222] = {.lex_state = 0, .external_lex_state = 7},
  [8223] = {.lex_state = 0, .external_lex_state = 7},
  [8224] = {.lex_state = 0, .external_lex_state = 7},
  [8225] = {.lex_state = 0, .external_lex_state = 7},
  [8226] = {.lex_state = 0, .external_lex_state = 7},
  [8227] = {.lex_state = 0, .external_lex_state = 7},
  [8228] = {.lex_state = 0, .external_lex_state = 7},
  [8229] = {.lex_state = 0, .external_lex_state = 7},
  [8230] = {.lex_state = 0, .external_lex_state = 7},
  [8231] = {.lex_state = 0, .external_lex_state = 7},
  [8232] = {.lex_state = 0, .external_lex_state = 7},
  [8233] = {.lex_state = 0, .external_lex_state = 7},
  [8234] = {.lex_state = 0, .external_lex_state = 7},
  [8235] = {.lex_state = 0, .external_lex_state = 7},
  [8236] = {.lex_state = 0, .external_lex_state = 7},
  [8237] = {.lex_state = 0, .external_lex_state = 7},
  [8238] = {.lex_state = 0, .external_lex_state = 7},
  [8239] = {.lex_state = 0, .external_lex_state = 7},
  [8240] = {.lex_state = 0, .external_lex_state = 7},
  [8241] = {.lex_state = 0, .external_lex_state = 7},
  [8242] = {.lex_state = 0, .external_lex_state = 7},
  [8243] = {.lex_state = 0, .external_lex_state = 7},
  [8244] = {.lex_state = 0, .external_lex_state = 7},
  [8245] = {.lex_state = 0, .external_lex_state = 7},
  [8246] = {.lex_state = 0, .external_lex_state = 7},
  [8247] = {.lex_state = 0, .external_lex_state = 7},
  [8248] = {.lex_state = 0, .external_lex_state = 7},
  [8249] = {.lex_state = 0, .external_lex_state = 7},
  [8250] = {.lex_state = 0, .external_lex_state = 7},
  [8251] = {.lex_state = 0, .external_lex_state = 7},
  [8252] = {.lex_state = 0, .external_lex_state = 7},
  [8253] = {.lex_state = 0, .external_lex_state = 7},
  [8254] = {.lex_state = 0, .external_lex_state = 7},
  [8255] = {.lex_state = 0, .external_lex_state = 7},
  [8256] = {.lex_state = 0, .external_lex_state = 7},
  [8257] = {.lex_state = 0, .external_lex_state = 7},
  [8258] = {.lex_state = 0, .external_lex_state = 7},
  [8259] = {.lex_state = 0, .external_lex_state = 7},
  [8260] = {.lex_state = 0, .external_lex_state = 7},
  [8261] = {.lex_state = 0, .external_lex_state = 7},
  [8262] = {.lex_state = 0, .external_lex_state = 7},
  [8263] = {.lex_state = 0, .external_lex_state = 7},
  [8264] = {.lex_state = 0, .external_lex_state = 7},
  [8265] = {.lex_state = 24, .external_lex_state = 7},
  [8266] = {.lex_state = 0, .external_lex_state = 7},
  [8267] = {.lex_state = 0, .external_lex_state = 7},
  [8268] = {.lex_state = 0, .external_lex_state = 7},
  [8269] = {.lex_state = 0, .external_lex_state = 7},
  [8270] = {.lex_state = 0, .external_lex_state = 7},
  [8271] = {.lex_state = 0, .external_lex_state = 6},
  [8272] = {.lex_state = 0, .external_lex_state = 7},
  [8273] = {.lex_state = 0, .external_lex_state = 7},
  [8274] = {.lex_state = 0, .external_lex_state = 7},
  [8275] = {.lex_state = 0, .external_lex_state = 7},
  [8276] = {.lex_state = 0, .external_lex_state = 7},
  [8277] = {.lex_state = 0, .external_lex_state = 7},
  [8278] = {.lex_state = 24, .external_lex_state = 7},
  [8279] = {.lex_state = 0, .external_lex_state = 7},
  [8280] = {.lex_state = 0, .external_lex_state = 7},
  [8281] = {.lex_state = 0, .external_lex_state = 7},
  [8282] = {.lex_state = 0, .external_lex_state = 7},
  [8283] = {.lex_state = 0, .external_lex_state = 7},
  [8284] = {.lex_state = 0, .external_lex_state = 7},
  [8285] = {.lex_state = 0, .external_lex_state = 7},
  [8286] = {.lex_state = 0, .external_lex_state = 7},
  [8287] = {.lex_state = 0, .external_lex_state = 6},
  [8288] = {.lex_state = 0, .external_lex_state = 7},
  [8289] = {.lex_state = 0, .external_lex_state = 7},
  [8290] = {.lex_state = 0, .external_lex_state = 7},
  [8291] = {.lex_state = 0, .external_lex_state = 7},
  [8292] = {.lex_state = 0, .external_lex_state = 7},
  [8293] = {.lex_state = 0, .external_lex_state = 7},
  [8294] = {.lex_state = 0, .external_lex_state = 7},
  [8295] = {.lex_state = 0, .external_lex_state = 7},
  [8296] = {.lex_state = 0, .external_lex_state = 7},
  [8297] = {.lex_state = 0, .external_lex_state = 7},
  [8298] = {.lex_state = 24, .external_lex_state = 7},
  [8299] = {.lex_state = 0, .external_lex_state = 7},
  [8300] = {.lex_state = 0, .external_lex_state = 7},
  [8301] = {.lex_state = 0, .external_lex_state = 6},
  [8302] = {.lex_state = 0, .external_lex_state = 7},
  [8303] = {.lex_state = 0, .external_lex_state = 7},
  [8304] = {.lex_state = 0, .external_lex_state = 7},
  [8305] = {.lex_state = 0, .external_lex_state = 7},
  [8306] = {.lex_state = 0, .external_lex_state = 7},
  [8307] = {.lex_state = 0, .external_lex_state = 7},
  [8308] = {.lex_state = 0, .external_lex_state = 7},
  [8309] = {.lex_state = 0, .external_lex_state = 7},
  [8310] = {.lex_state = 0, .external_lex_state = 7},
  [8311] = {.lex_state = 0, .external_lex_state = 7},
  [8312] = {.lex_state = 0, .external_lex_state = 7},
  [8313] = {.lex_state = 0, .external_lex_state = 7},
  [8314] = {.lex_state = 87, .external_lex_state = 6},
  [8315] = {.lex_state = 0, .external_lex_state = 6},
  [8316] = {.lex_state = 0, .external_lex_state = 6},
  [8317] = {.lex_state = 0, .external_lex_state = 7},
  [8318] = {.lex_state = 0, .external_lex_state = 7},
  [8319] = {.lex_state = 0, .external_lex_state = 7},
  [8320] = {.lex_state = 0, .external_lex_state = 7},
  [8321] = {.lex_state = 0, .external_lex_state = 7},
  [8322] = {.lex_state = 0, .external_lex_state = 7},
  [8323] = {.lex_state = 0, .external_lex_state = 7},
  [8324] = {.lex_state = 0, .external_lex_state = 7},
  [8325] = {.lex_state = 0, .external_lex_state = 7},
  [8326] = {.lex_state = 0, .external_lex_state = 7},
  [8327] = {.lex_state = 0, .external_lex_state = 6},
  [8328] = {.lex_state = 0, .external_lex_state = 7},
  [8329] = {.lex_state = 0, .external_lex_state = 7},
  [8330] = {.lex_state = 0, .external_lex_state = 7},
  [8331] = {.lex_state = 0, .external_lex_state = 7},
  [8332] = {.lex_state = 0, .external_lex_state = 7},
  [8333] = {.lex_state = 0, .external_lex_state = 7},
  [8334] = {.lex_state = 0, .external_lex_state = 7},
  [8335] = {.lex_state = 0, .external_lex_state = 7},
  [8336] = {.lex_state = 0, .external_lex_state = 7},
  [8337] = {.lex_state = 0, .external_lex_state = 7},
  [8338] = {.lex_state = 0, .external_lex_state = 7},
  [8339] = {.lex_state = 0, .external_lex_state = 6},
  [8340] = {.lex_state = 0, .external_lex_state = 7},
  [8341] = {.lex_state = 0, .external_lex_state = 7},
  [8342] = {.lex_state = 0, .external_lex_state = 7},
  [8343] = {.lex_state = 0, .external_lex_state = 7},
  [8344] = {.lex_state = 0, .external_lex_state = 7},
  [8345] = {.lex_state = 0, .external_lex_state = 7},
  [8346] = {.lex_state = 0, .external_lex_state = 7},
  [8347] = {.lex_state = 0, .external_lex_state = 6},
  [8348] = {.lex_state = 0, .external_lex_state = 7},
  [8349] = {.lex_state = 0, .external_lex_state = 7},
  [8350] = {.lex_state = 0, .external_lex_state = 6},
  [8351] = {.lex_state = 0, .external_lex_state = 7},
  [8352] = {.lex_state = 0, .external_lex_state = 7},
  [8353] = {.lex_state = 0, .external_lex_state = 7},
  [8354] = {.lex_state = 0, .external_lex_state = 7},
  [8355] = {.lex_state = 0, .external_lex_state = 7},
  [8356] = {.lex_state = 0, .external_lex_state = 7},
  [8357] = {.lex_state = 0, .external_lex_state = 7},
  [8358] = {.lex_state = 0, .external_lex_state = 7},
  [8359] = {.lex_state = 0, .external_lex_state = 7},
  [8360] = {.lex_state = 0, .external_lex_state = 7},
  [8361] = {.lex_state = 0, .external_lex_state = 6},
  [8362] = {.lex_state = 0, .external_lex_state = 7},
  [8363] = {.lex_state = 0, .external_lex_state = 7},
  [8364] = {.lex_state = 0, .external_lex_state = 7},
  [8365] = {.lex_state = 0, .external_lex_state = 7},
  [8366] = {.lex_state = 0, .external_lex_state = 7},
  [8367] = {.lex_state = 0, .external_lex_state = 7},
  [8368] = {.lex_state = 0, .external_lex_state = 7},
  [8369] = {.lex_state = 0, .external_lex_state = 7},
  [8370] = {.lex_state = 0, .external_lex_state = 7},
  [8371] = {.lex_state = 0, .external_lex_state = 7},
  [8372] = {.lex_state = 0, .external_lex_state = 6},
  [8373] = {.lex_state = 24, .external_lex_state = 7},
  [8374] = {.lex_state = 0, .external_lex_state = 7},
  [8375] = {.lex_state = 0, .external_lex_state = 7},
  [8376] = {.lex_state = 0, .external_lex_state = 7},
  [8377] = {.lex_state = 0, .external_lex_state = 7},
  [8378] = {.lex_state = 0, .external_lex_state = 7},
  [8379] = {.lex_state = 0, .external_lex_state = 7},
  [8380] = {.lex_state = 0, .external_lex_state = 7},
  [8381] = {.lex_state = 0, .external_lex_state = 7},
  [8382] = {.lex_state = 0, .external_lex_state = 7},
  [8383] = {.lex_state = 0, .external_lex_state = 7},
  [8384] = {.lex_state = 0, .external_lex_state = 7},
  [8385] = {.lex_state = 0, .external_lex_state = 6},
  [8386] = {.lex_state = 0, .external_lex_state = 7},
  [8387] = {.lex_state = 0, .external_lex_state = 7},
  [8388] = {.lex_state = 0, .external_lex_state = 7},
  [8389] = {.lex_state = 0, .external_lex_state = 7},
  [8390] = {.lex_state = 0, .external_lex_state = 7},
  [8391] = {.lex_state = 0, .external_lex_state = 7},
  [8392] = {.lex_state = 0, .external_lex_state = 7},
  [8393] = {.lex_state = 0, .external_lex_state = 7},
  [8394] = {.lex_state = 0, .external_lex_state = 7},
  [8395] = {.lex_state = 0, .external_lex_state = 7},
  [8396] = {.lex_state = 0, .external_lex_state = 6},
  [8397] = {.lex_state = 0, .external_lex_state = 7},
  [8398] = {.lex_state = 0, .external_lex_state = 7},
  [8399] = {.lex_state = 0, .external_lex_state = 7},
  [8400] = {.lex_state = 0, .external_lex_state = 7},
  [8401] = {.lex_state = 0, .external_lex_state = 7},
  [8402] = {.lex_state = 0, .external_lex_state = 7},
  [8403] = {.lex_state = 0, .external_lex_state = 7},
  [8404] = {.lex_state = 0, .external_lex_state = 7},
  [8405] = {.lex_state = 0, .external_lex_state = 7},
  [8406] = {.lex_state = 0, .external_lex_state = 6},
  [8407] = {.lex_state = 0, .external_lex_state = 7},
  [8408] = {.lex_state = 0, .external_lex_state = 7},
  [8409] = {.lex_state = 0, .external_lex_state = 7},
  [8410] = {.lex_state = 0, .external_lex_state = 6},
  [8411] = {.lex_state = 0, .external_lex_state = 7},
  [8412] = {.lex_state = 0, .external_lex_state = 7},
  [8413] = {.lex_state = 0, .external_lex_state = 6},
  [8414] = {.lex_state = 16, .external_lex_state = 6},
  [8415] = {.lex_state = 0, .external_lex_state = 7},
  [8416] = {.lex_state = 0, .external_lex_state = 7},
  [8417] = {.lex_state = 24, .external_lex_state = 7},
  [8418] = {.lex_state = 0, .external_lex_state = 6},
  [8419] = {.lex_state = 0, .external_lex_state = 7},
  [8420] = {.lex_state = 0, .external_lex_state = 7},
  [8421] = {.lex_state = 0, .external_lex_state = 7},
  [8422] = {.lex_state = 0, .external_lex_state = 7},
  [8423] = {.lex_state = 0, .external_lex_state = 6},
  [8424] = {.lex_state = 0, .external_lex_state = 7},
  [8425] = {.lex_state = 0, .external_lex_state = 7},
  [8426] = {.lex_state = 0, .external_lex_state = 7},
  [8427] = {.lex_state = 0, .external_lex_state = 7},
  [8428] = {.lex_state = 0, .external_lex_state = 7},
  [8429] = {.lex_state = 0, .external_lex_state = 7},
  [8430] = {.lex_state = 0, .external_lex_state = 7},
  [8431] = {.lex_state = 0, .external_lex_state = 7},
  [8432] = {.lex_state = 0, .external_lex_state = 7},
  [8433] = {.lex_state = 0, .external_lex_state = 7},
  [8434] = {.lex_state = 0, .external_lex_state = 7},
  [8435] = {.lex_state = 0, .external_lex_state = 7},
  [8436] = {.lex_state = 0, .external_lex_state = 6},
  [8437] = {.lex_state = 24, .external_lex_state = 7},
  [8438] = {.lex_state = 0, .external_lex_state = 7},
  [8439] = {.lex_state = 0, .external_lex_state = 7},
  [8440] = {.lex_state = 0, .external_lex_state = 7},
  [8441] = {.lex_state = 0, .external_lex_state = 7},
  [8442] = {.lex_state = 0, .external_lex_state = 7},
  [8443] = {.lex_state = 24, .external_lex_state = 7},
  [8444] = {.lex_state = 0, .external_lex_state = 7},
  [8445] = {.lex_state = 0, .external_lex_state = 7},
  [8446] = {.lex_state = 0, .external_lex_state = 7},
  [8447] = {.lex_state = 0, .external_lex_state = 7},
  [8448] = {.lex_state = 0, .external_lex_state = 6},
  [8449] = {.lex_state = 0, .external_lex_state = 7},
  [8450] = {.lex_state = 0, .external_lex_state = 7},
  [8451] = {.lex_state = 0, .external_lex_state = 7},
  [8452] = {.lex_state = 0, .external_lex_state = 7},
  [8453] = {.lex_state = 0, .external_lex_state = 6},
  [8454] = {.lex_state = 0, .external_lex_state = 7},
  [8455] = {.lex_state = 0, .external_lex_state = 6},
  [8456] = {.lex_state = 0, .external_lex_state = 7},
  [8457] = {.lex_state = 0, .external_lex_state = 7},
  [8458] = {.lex_state = 0, .external_lex_state = 7},
  [8459] = {.lex_state = 0, .external_lex_state = 6},
  [8460] = {.lex_state = 0, .external_lex_state = 7},
  [8461] = {.lex_state = 0, .external_lex_state = 7},
  [8462] = {.lex_state = 0, .external_lex_state = 6},
  [8463] = {.lex_state = 0, .external_lex_state = 7},
  [8464] = {.lex_state = 0, .external_lex_state = 7},
  [8465] = {.lex_state = 0, .external_lex_state = 6},
  [8466] = {.lex_state = 0, .external_lex_state = 6},
  [8467] = {.lex_state = 0, .external_lex_state = 7},
  [8468] = {.lex_state = 87, .external_lex_state = 6},
  [8469] = {.lex_state = 0, .external_lex_state = 7},
  [8470] = {.lex_state = 0, .external_lex_state = 6},
  [8471] = {.lex_state = 0, .external_lex_state = 7},
  [8472] = {.lex_state = 0, .external_lex_state = 7},
  [8473] = {.lex_state = 0, .external_lex_state = 7},
  [8474] = {.lex_state = 0, .external_lex_state = 7},
  [8475] = {.lex_state = 0, .external_lex_state = 7},
  [8476] = {.lex_state = 0, .external_lex_state = 7},
  [8477] = {.lex_state = 0, .external_lex_state = 7},
  [8478] = {.lex_state = 0, .external_lex_state = 7},
  [8479] = {.lex_state = 0, .external_lex_state = 7},
  [8480] = {.lex_state = 0, .external_lex_state = 7},
  [8481] = {.lex_state = 0, .external_lex_state = 7},
  [8482] = {.lex_state = 0, .external_lex_state = 7},
  [8483] = {.lex_state = 0, .external_lex_state = 7},
  [8484] = {.lex_state = 0, .external_lex_state = 7},
  [8485] = {.lex_state = 0, .external_lex_state = 7},
  [8486] = {.lex_state = 0, .external_lex_state = 7},
  [8487] = {.lex_state = 0, .external_lex_state = 7},
  [8488] = {.lex_state = 0, .external_lex_state = 7},
  [8489] = {.lex_state = 0, .external_lex_state = 7},
  [8490] = {.lex_state = 0, .external_lex_state = 7},
  [8491] = {.lex_state = 0, .external_lex_state = 7},
  [8492] = {.lex_state = 0, .external_lex_state = 7},
  [8493] = {.lex_state = 0, .external_lex_state = 7},
  [8494] = {.lex_state = 0, .external_lex_state = 7},
  [8495] = {.lex_state = 0, .external_lex_state = 7},
  [8496] = {.lex_state = 0, .external_lex_state = 7},
  [8497] = {.lex_state = 0, .external_lex_state = 7},
  [8498] = {.lex_state = 0, .external_lex_state = 7},
  [8499] = {.lex_state = 0, .external_lex_state = 7},
  [8500] = {.lex_state = 0, .external_lex_state = 7},
  [8501] = {.lex_state = 0, .external_lex_state = 7},
  [8502] = {.lex_state = 0, .external_lex_state = 7},
  [8503] = {.lex_state = 0, .external_lex_state = 7},
  [8504] = {.lex_state = 87, .external_lex_state = 6},
  [8505] = {.lex_state = 0, .external_lex_state = 7},
  [8506] = {.lex_state = 0, .external_lex_state = 7},
  [8507] = {.lex_state = 0, .external_lex_state = 7},
  [8508] = {.lex_state = 0, .external_lex_state = 7},
  [8509] = {.lex_state = 0, .external_lex_state = 7},
  [8510] = {.lex_state = 0, .external_lex_state = 7},
  [8511] = {.lex_state = 0, .external_lex_state = 7},
  [8512] = {.lex_state = 0, .external_lex_state = 7},
  [8513] = {.lex_state = 0, .external_lex_state = 7},
  [8514] = {.lex_state = 0, .external_lex_state = 7},
  [8515] = {.lex_state = 0, .external_lex_state = 7},
  [8516] = {.lex_state = 0, .external_lex_state = 7},
  [8517] = {.lex_state = 0, .external_lex_state = 7},
  [8518] = {.lex_state = 0, .external_lex_state = 7},
  [8519] = {.lex_state = 0, .external_lex_state = 7},
  [8520] = {.lex_state = 0, .external_lex_state = 7},
  [8521] = {.lex_state = 0, .external_lex_state = 7},
  [8522] = {.lex_state = 0, .external_lex_state = 7},
  [8523] = {.lex_state = 0, .external_lex_state = 7},
  [8524] = {.lex_state = 0, .external_lex_state = 7},
  [8525] = {.lex_state = 0, .external_lex_state = 7},
  [8526] = {.lex_state = 0, .external_lex_state = 7},
  [8527] = {.lex_state = 0, .external_lex_state = 7},
  [8528] = {.lex_state = 0, .external_lex_state = 7},
  [8529] = {.lex_state = 0, .external_lex_state = 7},
  [8530] = {.lex_state = 0, .external_lex_state = 7},
  [8531] = {.lex_state = 0, .external_lex_state = 5},
  [8532] = {.lex_state = 0, .external_lex_state = 7},
  [8533] = {.lex_state = 0, .external_lex_state = 7},
  [8534] = {.lex_state = 0, .external_lex_state = 7},
  [8535] = {.lex_state = 0, .external_lex_state = 7},
  [8536] = {.lex_state = 0, .external_lex_state = 7},
  [8537] = {.lex_state = 0, .external_lex_state = 7},
  [8538] = {.lex_state = 0, .external_lex_state = 7},
  [8539] = {.lex_state = 0, .external_lex_state = 7},
  [8540] = {.lex_state = 0, .external_lex_state = 7},
  [8541] = {.lex_state = 0, .external_lex_state = 7},
  [8542] = {.lex_state = 0, .external_lex_state = 7},
  [8543] = {.lex_state = 0, .external_lex_state = 7},
  [8544] = {.lex_state = 24, .external_lex_state = 7},
  [8545] = {.lex_state = 0, .external_lex_state = 7},
  [8546] = {.lex_state = 0, .external_lex_state = 7},
  [8547] = {.lex_state = 0, .external_lex_state = 7},
  [8548] = {.lex_state = 0, .external_lex_state = 7},
  [8549] = {.lex_state = 0, .external_lex_state = 7},
  [8550] = {.lex_state = 24, .external_lex_state = 7},
  [8551] = {.lex_state = 0, .external_lex_state = 6},
  [8552] = {.lex_state = 0, .external_lex_state = 7},
  [8553] = {.lex_state = 0, .external_lex_state = 7},
  [8554] = {.lex_state = 0, .external_lex_state = 7},
  [8555] = {.lex_state = 0, .external_lex_state = 7},
  [8556] = {.lex_state = 0, .external_lex_state = 7},
  [8557] = {.lex_state = 0, .external_lex_state = 7},
  [8558] = {.lex_state = 0, .external_lex_state = 7},
  [8559] = {.lex_state = 0, .external_lex_state = 7},
  [8560] = {.lex_state = 0, .external_lex_state = 7},
  [8561] = {.lex_state = 0, .external_lex_state = 6},
  [8562] = {.lex_state = 24, .external_lex_state = 7},
  [8563] = {.lex_state = 0, .external_lex_state = 7},
  [8564] = {.lex_state = 24, .external_lex_state = 7},
  [8565] = {.lex_state = 0, .external_lex_state = 7},
  [8566] = {.lex_state = 0, .external_lex_state = 7},
  [8567] = {.lex_state = 0, .external_lex_state = 7},
  [8568] = {.lex_state = 0, .external_lex_state = 7},
  [8569] = {.lex_state = 0, .external_lex_state = 7},
  [8570] = {.lex_state = 0, .external_lex_state = 7},
  [8571] = {.lex_state = 0, .external_lex_state = 7},
  [8572] = {.lex_state = 0, .external_lex_state = 7},
  [8573] = {.lex_state = 0, .external_lex_state = 7},
  [8574] = {.lex_state = 0, .external_lex_state = 7},
  [8575] = {.lex_state = 0, .external_lex_state = 7},
  [8576] = {.lex_state = 0, .external_lex_state = 7},
  [8577] = {.lex_state = 0, .external_lex_state = 7},
  [8578] = {.lex_state = 0, .external_lex_state = 7},
  [8579] = {.lex_state = 0, .external_lex_state = 7},
  [8580] = {.lex_state = 0, .external_lex_state = 6},
  [8581] = {.lex_state = 0, .external_lex_state = 6},
  [8582] = {.lex_state = 0, .external_lex_state = 7},
  [8583] = {.lex_state = 0, .external_lex_state = 7},
  [8584] = {.lex_state = 0, .external_lex_state = 7},
  [8585] = {.lex_state = 0, .external_lex_state = 7},
  [8586] = {.lex_state = 0, .external_lex_state = 6},
  [8587] = {.lex_state = 0, .external_lex_state = 6},
  [8588] = {.lex_state = 0, .external_lex_state = 7},
  [8589] = {.lex_state = 0, .external_lex_state = 6},
  [8590] = {.lex_state = 0, .external_lex_state = 7},
  [8591] = {.lex_state = 0, .external_lex_state = 6},
  [8592] = {.lex_state = 0, .external_lex_state = 6},
  [8593] = {.lex_state = 0, .external_lex_state = 7},
  [8594] = {.lex_state = 0, .external_lex_state = 6},
  [8595] = {.lex_state = 0, .external_lex_state = 6},
  [8596] = {.lex_state = 0, .external_lex_state = 6},
  [8597] = {.lex_state = 0, .external_lex_state = 6},
  [8598] = {.lex_state = 0, .external_lex_state = 6},
  [8599] = {.lex_state = 0, .external_lex_state = 6},
  [8600] = {.lex_state = 0, .external_lex_state = 6},
  [8601] = {.lex_state = 0, .external_lex_state = 6},
  [8602] = {.lex_state = 0, .external_lex_state = 6},
  [8603] = {.lex_state = 0, .external_lex_state = 6},
  [8604] = {.lex_state = 0, .external_lex_state = 6},
  [8605] = {.lex_state = 0, .external_lex_state = 7},
  [8606] = {.lex_state = 0, .external_lex_state = 7},
  [8607] = {.lex_state = 0, .external_lex_state = 7},
  [8608] = {.lex_state = 0, .external_lex_state = 7},
  [8609] = {.lex_state = 0, .external_lex_state = 7},
  [8610] = {.lex_state = 0, .external_lex_state = 7},
  [8611] = {.lex_state = 0, .external_lex_state = 7},
  [8612] = {.lex_state = 0, .external_lex_state = 7},
  [8613] = {.lex_state = 0, .external_lex_state = 7},
  [8614] = {.lex_state = 0, .external_lex_state = 7},
  [8615] = {.lex_state = 0, .external_lex_state = 7},
  [8616] = {.lex_state = 0, .external_lex_state = 7},
  [8617] = {.lex_state = 0, .external_lex_state = 7},
  [8618] = {.lex_state = 0, .external_lex_state = 7},
  [8619] = {.lex_state = 0, .external_lex_state = 7},
  [8620] = {.lex_state = 0, .external_lex_state = 7},
  [8621] = {.lex_state = 0, .external_lex_state = 7},
  [8622] = {.lex_state = 0, .external_lex_state = 7},
  [8623] = {.lex_state = 0, .external_lex_state = 7},
  [8624] = {.lex_state = 0, .external_lex_state = 7},
  [8625] = {.lex_state = 25, .external_lex_state = 7},
  [8626] = {.lex_state = 0, .external_lex_state = 7},
  [8627] = {.lex_state = 0, .external_lex_state = 7},
  [8628] = {.lex_state = 0, .external_lex_state = 6},
  [8629] = {.lex_state = 0, .external_lex_state = 7},
  [8630] = {.lex_state = 0, .external_lex_state = 6},
  [8631] = {.lex_state = 0, .external_lex_state = 7},
  [8632] = {.lex_state = 0, .external_lex_state = 7},
  [8633] = {.lex_state = 0, .external_lex_state = 7},
  [8634] = {.lex_state = 0, .external_lex_state = 7},
  [8635] = {.lex_state = 0, .external_lex_state = 7},
  [8636] = {.lex_state = 0, .external_lex_state = 7},
  [8637] = {.lex_state = 0, .external_lex_state = 7},
  [8638] = {.lex_state = 0, .external_lex_state = 7},
  [8639] = {.lex_state = 0, .external_lex_state = 7},
  [8640] = {.lex_state = 0, .external_lex_state = 7},
  [8641] = {.lex_state = 0, .external_lex_state = 7},
  [8642] = {.lex_state = 0, .external_lex_state = 7},
  [8643] = {.lex_state = 0, .external_lex_state = 7},
  [8644] = {.lex_state = 0, .external_lex_state = 7},
  [8645] = {.lex_state = 0, .external_lex_state = 7},
  [8646] = {.lex_state = 25, .external_lex_state = 7},
  [8647] = {.lex_state = 0, .external_lex_state = 7},
  [8648] = {.lex_state = 0, .external_lex_state = 7},
  [8649] = {.lex_state = 0, .external_lex_state = 7},
  [8650] = {.lex_state = 0, .external_lex_state = 7},
  [8651] = {.lex_state = 0, .external_lex_state = 7},
  [8652] = {.lex_state = 25, .external_lex_state = 7},
  [8653] = {.lex_state = 0, .external_lex_state = 6},
  [8654] = {.lex_state = 0, .external_lex_state = 7},
  [8655] = {.lex_state = 0, .external_lex_state = 7},
  [8656] = {.lex_state = 0, .external_lex_state = 7},
  [8657] = {.lex_state = 0, .external_lex_state = 7},
  [8658] = {.lex_state = 0, .external_lex_state = 7},
  [8659] = {.lex_state = 0, .external_lex_state = 7},
  [8660] = {.lex_state = 0, .external_lex_state = 7},
  [8661] = {.lex_state = 0, .external_lex_state = 7},
  [8662] = {.lex_state = 0, .external_lex_state = 7},
  [8663] = {.lex_state = 0, .external_lex_state = 7},
  [8664] = {.lex_state = 0, .external_lex_state = 7},
  [8665] = {.lex_state = 25, .external_lex_state = 7},
  [8666] = {.lex_state = 0, .external_lex_state = 7},
  [8667] = {.lex_state = 0, .external_lex_state = 7},
  [8668] = {.lex_state = 0, .external_lex_state = 7},
  [8669] = {.lex_state = 0, .external_lex_state = 6},
  [8670] = {.lex_state = 0, .external_lex_state = 7},
  [8671] = {.lex_state = 0, .external_lex_state = 7},
  [8672] = {.lex_state = 0, .external_lex_state = 7},
  [8673] = {.lex_state = 0, .external_lex_state = 7},
  [8674] = {.lex_state = 0, .external_lex_state = 7},
  [8675] = {.lex_state = 0, .external_lex_state = 7},
  [8676] = {.lex_state = 0, .external_lex_state = 7},
  [8677] = {.lex_state = 87, .external_lex_state = 6},
  [8678] = {.lex_state = 0, .external_lex_state = 7},
  [8679] = {.lex_state = 0, .external_lex_state = 7},
  [8680] = {.lex_state = 0, .external_lex_state = 7},
  [8681] = {.lex_state = 0, .external_lex_state = 7},
  [8682] = {.lex_state = 0, .external_lex_state = 7},
  [8683] = {.lex_state = 0, .external_lex_state = 7},
  [8684] = {.lex_state = 0, .external_lex_state = 7},
  [8685] = {.lex_state = 0, .external_lex_state = 7},
  [8686] = {.lex_state = 0, .external_lex_state = 7},
  [8687] = {.lex_state = 0, .external_lex_state = 7},
  [8688] = {.lex_state = 0, .external_lex_state = 7},
  [8689] = {.lex_state = 0, .external_lex_state = 7},
  [8690] = {.lex_state = 0, .external_lex_state = 7},
  [8691] = {.lex_state = 0, .external_lex_state = 7},
  [8692] = {.lex_state = 0, .external_lex_state = 7},
  [8693] = {.lex_state = 25, .external_lex_state = 7},
  [8694] = {.lex_state = 0, .external_lex_state = 6},
  [8695] = {.lex_state = 0, .external_lex_state = 7},
  [8696] = {.lex_state = 0, .external_lex_state = 7},
  [8697] = {.lex_state = 0, .external_lex_state = 7},
  [8698] = {.lex_state = 0, .external_lex_state = 7},
  [8699] = {.lex_state = 0, .external_lex_state = 7},
  [8700] = {.lex_state = 0, .external_lex_state = 7},
  [8701] = {.lex_state = 0, .external_lex_state = 7},
  [8702] = {.lex_state = 0, .external_lex_state = 6},
  [8703] = {.lex_state = 0, .external_lex_state = 7},
  [8704] = {.lex_state = 0, .external_lex_state = 7},
  [8705] = {.lex_state = 0, .external_lex_state = 7},
  [8706] = {.lex_state = 0, .external_lex_state = 7},
  [8707] = {.lex_state = 0, .external_lex_state = 7},
  [8708] = {.lex_state = 0, .external_lex_state = 7},
  [8709] = {.lex_state = 0, .external_lex_state = 7},
  [8710] = {.lex_state = 0, .external_lex_state = 7},
  [8711] = {.lex_state = 0, .external_lex_state = 7},
  [8712] = {.lex_state = 0, .external_lex_state = 7},
  [8713] = {.lex_state = 0, .external_lex_state = 7},
  [8714] = {.lex_state = 0, .external_lex_state = 7},
  [8715] = {.lex_state = 0, .external_lex_state = 7},
  [8716] = {.lex_state = 0, .external_lex_state = 7},
  [8717] = {.lex_state = 0, .external_lex_state = 7},
  [8718] = {.lex_state = 0, .external_lex_state = 7},
  [8719] = {.lex_state = 0, .external_lex_state = 7},
  [8720] = {.lex_state = 0, .external_lex_state = 7},
  [8721] = {.lex_state = 0, .external_lex_state = 7},
  [8722] = {.lex_state = 0, .external_lex_state = 7},
  [8723] = {.lex_state = 0, .external_lex_state = 7},
  [8724] = {.lex_state = 0, .external_lex_state = 7},
  [8725] = {.lex_state = 0, .external_lex_state = 7},
  [8726] = {.lex_state = 0, .external_lex_state = 7},
  [8727] = {.lex_state = 0, .external_lex_state = 7},
  [8728] = {.lex_state = 0, .external_lex_state = 7},
  [8729] = {.lex_state = 0, .external_lex_state = 7},
  [8730] = {.lex_state = 0, .external_lex_state = 7},
  [8731] = {.lex_state = 0, .external_lex_state = 7},
  [8732] = {.lex_state = 0, .external_lex_state = 7},
  [8733] = {.lex_state = 87, .external_lex_state = 6},
  [8734] = {.lex_state = 0, .external_lex_state = 7},
  [8735] = {.lex_state = 0, .external_lex_state = 7},
  [8736] = {.lex_state = 0, .external_lex_state = 7},
  [8737] = {.lex_state = 0, .external_lex_state = 7},
  [8738] = {.lex_state = 0, .external_lex_state = 7},
  [8739] = {.lex_state = 0, .external_lex_state = 7},
  [8740] = {.lex_state = 0, .external_lex_state = 7},
  [8741] = {.lex_state = 0, .external_lex_state = 7},
  [8742] = {.lex_state = 0, .external_lex_state = 7},
  [8743] = {.lex_state = 0, .external_lex_state = 7},
  [8744] = {.lex_state = 0, .external_lex_state = 7},
  [8745] = {.lex_state = 0, .external_lex_state = 7},
  [8746] = {.lex_state = 0, .external_lex_state = 7},
  [8747] = {.lex_state = 0, .external_lex_state = 7},
  [8748] = {.lex_state = 0, .external_lex_state = 7},
  [8749] = {.lex_state = 0, .external_lex_state = 7},
  [8750] = {.lex_state = 0, .external_lex_state = 7},
  [8751] = {.lex_state = 0, .external_lex_state = 7},
  [8752] = {.lex_state = 0, .external_lex_state = 7},
  [8753] = {.lex_state = 25, .external_lex_state = 7},
  [8754] = {.lex_state = 0, .external_lex_state = 7},
  [8755] = {.lex_state = 0, .external_lex_state = 7},
  [8756] = {.lex_state = 0, .external_lex_state = 7},
  [8757] = {.lex_state = 25, .external_lex_state = 7},
  [8758] = {.lex_state = 0, .external_lex_state = 7},
  [8759] = {.lex_state = 0, .external_lex_state = 6},
  [8760] = {.lex_state = 0, .external_lex_state = 7},
  [8761] = {.lex_state = 0, .external_lex_state = 7},
  [8762] = {.lex_state = 0, .external_lex_state = 7},
  [8763] = {.lex_state = 0, .external_lex_state = 7},
  [8764] = {.lex_state = 0, .external_lex_state = 7},
  [8765] = {.lex_state = 0, .external_lex_state = 7},
  [8766] = {.lex_state = 0, .external_lex_state = 6},
  [8767] = {.lex_state = 0, .external_lex_state = 7},
  [8768] = {.lex_state = 0, .external_lex_state = 6},
  [8769] = {.lex_state = 0, .external_lex_state = 7},
  [8770] = {.lex_state = 0, .external_lex_state = 7},
  [8771] = {.lex_state = 0, .external_lex_state = 7},
  [8772] = {.lex_state = 0, .external_lex_state = 7},
  [8773] = {.lex_state = 0, .external_lex_state = 7},
  [8774] = {.lex_state = 0, .external_lex_state = 7},
  [8775] = {.lex_state = 0, .external_lex_state = 7},
  [8776] = {.lex_state = 0, .external_lex_state = 7},
  [8777] = {.lex_state = 0, .external_lex_state = 7},
  [8778] = {.lex_state = 0, .external_lex_state = 7},
  [8779] = {.lex_state = 0, .external_lex_state = 7},
  [8780] = {.lex_state = 0, .external_lex_state = 7},
  [8781] = {.lex_state = 0, .external_lex_state = 7},
  [8782] = {.lex_state = 0, .external_lex_state = 7},
  [8783] = {.lex_state = 0, .external_lex_state = 7},
  [8784] = {.lex_state = 0, .external_lex_state = 7},
  [8785] = {.lex_state = 0, .external_lex_state = 7},
  [8786] = {.lex_state = 0, .external_lex_state = 7},
  [8787] = {.lex_state = 0, .external_lex_state = 7},
  [8788] = {.lex_state = 0, .external_lex_state = 7},
  [8789] = {.lex_state = 0, .external_lex_state = 6},
  [8790] = {.lex_state = 0, .external_lex_state = 7},
  [8791] = {.lex_state = 0, .external_lex_state = 7},
  [8792] = {.lex_state = 0, .external_lex_state = 7},
  [8793] = {.lex_state = 0, .external_lex_state = 7},
  [8794] = {.lex_state = 0, .external_lex_state = 7},
  [8795] = {.lex_state = 0, .external_lex_state = 7},
  [8796] = {.lex_state = 0, .external_lex_state = 7},
  [8797] = {.lex_state = 0, .external_lex_state = 7},
  [8798] = {.lex_state = 87, .external_lex_state = 6},
  [8799] = {.lex_state = 0, .external_lex_state = 7},
  [8800] = {.lex_state = 0, .external_lex_state = 7},
  [8801] = {.lex_state = 0, .external_lex_state = 7},
  [8802] = {.lex_state = 0, .external_lex_state = 7},
  [8803] = {.lex_state = 0, .external_lex_state = 7},
  [8804] = {.lex_state = 0, .external_lex_state = 7},
  [8805] = {.lex_state = 0, .external_lex_state = 7},
  [8806] = {.lex_state = 0, .external_lex_state = 7},
  [8807] = {.lex_state = 0, .external_lex_state = 7},
  [8808] = {.lex_state = 0, .external_lex_state = 7},
  [8809] = {.lex_state = 0, .external_lex_state = 7},
  [8810] = {.lex_state = 0, .external_lex_state = 7},
  [8811] = {.lex_state = 0, .external_lex_state = 7},
  [8812] = {.lex_state = 0, .external_lex_state = 7},
  [8813] = {.lex_state = 0, .external_lex_state = 7},
  [8814] = {.lex_state = 0, .external_lex_state = 7},
  [8815] = {.lex_state = 0, .external_lex_state = 7},
  [8816] = {.lex_state = 0, .external_lex_state = 7},
  [8817] = {.lex_state = 0, .external_lex_state = 7},
  [8818] = {.lex_state = 25, .external_lex_state = 7},
  [8819] = {.lex_state = 0, .external_lex_state = 7},
  [8820] = {.lex_state = 0, .external_lex_state = 7},
  [8821] = {.lex_state = 0, .external_lex_state = 7},
  [8822] = {.lex_state = 0, .external_lex_state = 7},
  [8823] = {.lex_state = 0, .external_lex_state = 7},
  [8824] = {.lex_state = 0, .external_lex_state = 6},
  [8825] = {.lex_state = 0, .external_lex_state = 7},
  [8826] = {.lex_state = 0, .external_lex_state = 7},
  [8827] = {.lex_state = 0, .external_lex_state = 7},
  [8828] = {.lex_state = 0, .external_lex_state = 7},
  [8829] = {.lex_state = 0, .external_lex_state = 7},
  [8830] = {.lex_state = 0, .external_lex_state = 7},
  [8831] = {.lex_state = 0, .external_lex_state = 7},
  [8832] = {.lex_state = 0, .external_lex_state = 7},
  [8833] = {.lex_state = 0, .external_lex_state = 7},
  [8834] = {.lex_state = 0, .external_lex_state = 7},
  [8835] = {.lex_state = 25, .external_lex_state = 7},
  [8836] = {.lex_state = 0, .external_lex_state = 7},
  [8837] = {.lex_state = 0, .external_lex_state = 7},
  [8838] = {.lex_state = 0, .external_lex_state = 7},
  [8839] = {.lex_state = 0, .external_lex_state = 7},
  [8840] = {.lex_state = 0, .external_lex_state = 7},
  [8841] = {.lex_state = 0, .external_lex_state = 7},
  [8842] = {.lex_state = 0, .external_lex_state = 7},
  [8843] = {.lex_state = 0, .external_lex_state = 7},
  [8844] = {.lex_state = 0, .external_lex_state = 7},
  [8845] = {.lex_state = 0, .external_lex_state = 7},
  [8846] = {.lex_state = 0, .external_lex_state = 7},
  [8847] = {.lex_state = 0, .external_lex_state = 7},
  [8848] = {.lex_state = 0, .external_lex_state = 7},
  [8849] = {.lex_state = 0, .external_lex_state = 7},
  [8850] = {.lex_state = 0, .external_lex_state = 7},
  [8851] = {.lex_state = 0, .external_lex_state = 7},
  [8852] = {.lex_state = 0, .external_lex_state = 7},
  [8853] = {.lex_state = 0, .external_lex_state = 7},
  [8854] = {.lex_state = 0, .external_lex_state = 7},
  [8855] = {.lex_state = 0, .external_lex_state = 7},
  [8856] = {.lex_state = 0, .external_lex_state = 6},
  [8857] = {.lex_state = 0, .external_lex_state = 7},
  [8858] = {.lex_state = 0, .external_lex_state = 7},
  [8859] = {.lex_state = 0, .external_lex_state = 7},
  [8860] = {.lex_state = 0, .external_lex_state = 7},
  [8861] = {.lex_state = 0, .external_lex_state = 7},
  [8862] = {.lex_state = 0, .external_lex_state = 7},
  [8863] = {.lex_state = 0, .external_lex_state = 7},
  [8864] = {.lex_state = 0, .external_lex_state = 7},
  [8865] = {.lex_state = 0, .external_lex_state = 7},
  [8866] = {.lex_state = 25, .external_lex_state = 7},
  [8867] = {.lex_state = 0, .external_lex_state = 7},
  [8868] = {.lex_state = 0, .external_lex_state = 7},
  [8869] = {.lex_state = 0, .external_lex_state = 7},
  [8870] = {.lex_state = 0, .external_lex_state = 6},
  [8871] = {.lex_state = 0, .external_lex_state = 7},
  [8872] = {.lex_state = 0, .external_lex_state = 7},
  [8873] = {.lex_state = 0, .external_lex_state = 7},
  [8874] = {.lex_state = 0, .external_lex_state = 7},
  [8875] = {.lex_state = 0, .external_lex_state = 7},
  [8876] = {.lex_state = 0, .external_lex_state = 7},
  [8877] = {.lex_state = 0, .external_lex_state = 7},
  [8878] = {.lex_state = 25, .external_lex_state = 7},
  [8879] = {.lex_state = 0, .external_lex_state = 7},
  [8880] = {.lex_state = 0, .external_lex_state = 7},
  [8881] = {.lex_state = 0, .external_lex_state = 6},
  [8882] = {.lex_state = 0, .external_lex_state = 7},
  [8883] = {.lex_state = 0, .external_lex_state = 7},
  [8884] = {.lex_state = 0, .external_lex_state = 7},
  [8885] = {.lex_state = 0, .external_lex_state = 7},
  [8886] = {.lex_state = 0, .external_lex_state = 7},
  [8887] = {.lex_state = 0, .external_lex_state = 7},
  [8888] = {.lex_state = 25, .external_lex_state = 7},
  [8889] = {.lex_state = 0, .external_lex_state = 7},
  [8890] = {.lex_state = 0, .external_lex_state = 7},
  [8891] = {.lex_state = 0, .external_lex_state = 7},
  [8892] = {.lex_state = 0, .external_lex_state = 6},
  [8893] = {.lex_state = 0, .external_lex_state = 7},
  [8894] = {.lex_state = 0, .external_lex_state = 7},
  [8895] = {.lex_state = 0, .external_lex_state = 7},
  [8896] = {.lex_state = 0, .external_lex_state = 7},
  [8897] = {.lex_state = 0, .external_lex_state = 7},
  [8898] = {.lex_state = 0, .external_lex_state = 7},
  [8899] = {.lex_state = 0, .external_lex_state = 7},
  [8900] = {.lex_state = 0, .external_lex_state = 7},
  [8901] = {.lex_state = 0, .external_lex_state = 7},
  [8902] = {.lex_state = 0, .external_lex_state = 7},
  [8903] = {.lex_state = 0, .external_lex_state = 7},
  [8904] = {.lex_state = 0, .external_lex_state = 7},
  [8905] = {.lex_state = 0, .external_lex_state = 7},
  [8906] = {.lex_state = 0, .external_lex_state = 7},
  [8907] = {.lex_state = 0, .external_lex_state = 7},
  [8908] = {.lex_state = 0, .external_lex_state = 7},
  [8909] = {.lex_state = 0, .external_lex_state = 7},
  [8910] = {.lex_state = 0, .external_lex_state = 7},
  [8911] = {.lex_state = 0, .external_lex_state = 7},
  [8912] = {.lex_state = 0, .external_lex_state = 7},
  [8913] = {.lex_state = 0, .external_lex_state = 7},
  [8914] = {.lex_state = 0, .external_lex_state = 7},
  [8915] = {.lex_state = 0, .external_lex_state = 7},
  [8916] = {.lex_state = 0, .external_lex_state = 7},
  [8917] = {.lex_state = 0, .external_lex_state = 7},
  [8918] = {.lex_state = 0, .external_lex_state = 7},
  [8919] = {.lex_state = 0, .external_lex_state = 7},
  [8920] = {.lex_state = 0, .external_lex_state = 7},
  [8921] = {.lex_state = 0, .external_lex_state = 7},
  [8922] = {.lex_state = 0, .external_lex_state = 7},
  [8923] = {.lex_state = 0, .external_lex_state = 7},
  [8924] = {.lex_state = 0, .external_lex_state = 7},
  [8925] = {.lex_state = 0, .external_lex_state = 7},
  [8926] = {.lex_state = 0, .external_lex_state = 7},
  [8927] = {.lex_state = 25, .external_lex_state = 7},
  [8928] = {.lex_state = 0, .external_lex_state = 7},
  [8929] = {.lex_state = 0, .external_lex_state = 7},
  [8930] = {.lex_state = 0, .external_lex_state = 7},
  [8931] = {.lex_state = 0, .external_lex_state = 7},
  [8932] = {.lex_state = 0, .external_lex_state = 7},
  [8933] = {.lex_state = 0, .external_lex_state = 7},
  [8934] = {.lex_state = 0, .external_lex_state = 7},
  [8935] = {.lex_state = 0, .external_lex_state = 7},
  [8936] = {.lex_state = 0, .external_lex_state = 6},
  [8937] = {.lex_state = 0, .external_lex_state = 7},
  [8938] = {.lex_state = 0, .external_lex_state = 7},
  [8939] = {.lex_state = 0, .external_lex_state = 7},
  [8940] = {.lex_state = 0, .external_lex_state = 7},
  [8941] = {.lex_state = 0, .external_lex_state = 7},
  [8942] = {.lex_state = 0, .external_lex_state = 7},
  [8943] = {.lex_state = 0, .external_lex_state = 7},
  [8944] = {.lex_state = 0, .external_lex_state = 7},
  [8945] = {.lex_state = 0, .external_lex_state = 7},
  [8946] = {.lex_state = 0, .external_lex_state = 7},
  [8947] = {.lex_state = 0, .external_lex_state = 7},
  [8948] = {.lex_state = 0, .external_lex_state = 7},
  [8949] = {.lex_state = 0, .external_lex_state = 7},
  [8950] = {.lex_state = 0, .external_lex_state = 7},
  [8951] = {.lex_state = 0, .external_lex_state = 7},
  [8952] = {.lex_state = 0, .external_lex_state = 7},
  [8953] = {.lex_state = 0, .external_lex_state = 6},
  [8954] = {.lex_state = 0, .external_lex_state = 6},
  [8955] = {.lex_state = 0, .external_lex_state = 7},
  [8956] = {.lex_state = 0, .external_lex_state = 7},
  [8957] = {.lex_state = 0, .external_lex_state = 7},
  [8958] = {.lex_state = 0, .external_lex_state = 7},
  [8959] = {.lex_state = 0, .external_lex_state = 6},
  [8960] = {.lex_state = 0, .external_lex_state = 7},
  [8961] = {.lex_state = 0, .external_lex_state = 7},
  [8962] = {.lex_state = 0, .external_lex_state = 7},
  [8963] = {.lex_state = 0, .external_lex_state = 6},
  [8964] = {.lex_state = 0, .external_lex_state = 7},
  [8965] = {.lex_state = 0, .external_lex_state = 7},
  [8966] = {.lex_state = 0, .external_lex_state = 7},
  [8967] = {.lex_state = 0, .external_lex_state = 7},
  [8968] = {.lex_state = 0, .external_lex_state = 7},
  [8969] = {.lex_state = 0, .external_lex_state = 7},
  [8970] = {.lex_state = 0, .external_lex_state = 7},
  [8971] = {.lex_state = 0, .external_lex_state = 7},
  [8972] = {.lex_state = 0, .external_lex_state = 7},
  [8973] = {.lex_state = 0, .external_lex_state = 7},
  [8974] = {.lex_state = 0, .external_lex_state = 7},
  [8975] = {.lex_state = 0, .external_lex_state = 6},
  [8976] = {.lex_state = 0, .external_lex_state = 7},
  [8977] = {.lex_state = 0, .external_lex_state = 6},
  [8978] = {.lex_state = 0, .external_lex_state = 7},
  [8979] = {.lex_state = 0, .external_lex_state = 7},
  [8980] = {.lex_state = 0, .external_lex_state = 6},
  [8981] = {.lex_state = 0, .external_lex_state = 7},
  [8982] = {.lex_state = 0, .external_lex_state = 7},
  [8983] = {.lex_state = 0, .external_lex_state = 7},
  [8984] = {.lex_state = 0, .external_lex_state = 7},
  [8985] = {.lex_state = 0, .external_lex_state = 7},
  [8986] = {.lex_state = 0, .external_lex_state = 7},
  [8987] = {.lex_state = 0, .external_lex_state = 7},
  [8988] = {.lex_state = 0, .external_lex_state = 6},
  [8989] = {.lex_state = 0, .external_lex_state = 7},
  [8990] = {.lex_state = 0, .external_lex_state = 7},
  [8991] = {.lex_state = 0, .external_lex_state = 7},
  [8992] = {.lex_state = 0, .external_lex_state = 7},
  [8993] = {.lex_state = 0, .external_lex_state = 6},
  [8994] = {.lex_state = 0, .external_lex_state = 7},
  [8995] = {.lex_state = 0, .external_lex_state = 7},
  [8996] = {.lex_state = 0, .external_lex_state = 7},
  [8997] = {.lex_state = 0, .external_lex_state = 7},
  [8998] = {.lex_state = 0, .external_lex_state = 7},
  [8999] = {.lex_state = 0, .external_lex_state = 6},
  [9000] = {.lex_state = 0, .external_lex_state = 7},
  [9001] = {.lex_state = 0, .external_lex_state = 6},
  [9002] = {.lex_state = 0, .external_lex_state = 7},
  [9003] = {.lex_state = 0, .external_lex_state = 7},
  [9004] = {.lex_state = 0, .external_lex_state = 7},
  [9005] = {.lex_state = 0, .external_lex_state = 7},
  [9006] = {.lex_state = 0, .external_lex_state = 7},
  [9007] = {.lex_state = 0, .external_lex_state = 7},
  [9008] = {.lex_state = 0, .external_lex_state = 7},
  [9009] = {.lex_state = 0, .external_lex_state = 7},
  [9010] = {.lex_state = 0, .external_lex_state = 7},
  [9011] = {.lex_state = 0, .external_lex_state = 7},
  [9012] = {.lex_state = 0, .external_lex_state = 7},
  [9013] = {.lex_state = 0, .external_lex_state = 7},
  [9014] = {.lex_state = 0, .external_lex_state = 6},
  [9015] = {.lex_state = 0, .external_lex_state = 7},
  [9016] = {.lex_state = 0, .external_lex_state = 7},
  [9017] = {.lex_state = 0, .external_lex_state = 7},
  [9018] = {.lex_state = 0, .external_lex_state = 7},
  [9019] = {.lex_state = 0, .external_lex_state = 7},
  [9020] = {.lex_state = 0, .external_lex_state = 7},
  [9021] = {.lex_state = 0, .external_lex_state = 6},
  [9022] = {.lex_state = 0, .external_lex_state = 6},
  [9023] = {.lex_state = 0, .external_lex_state = 7},
  [9024] = {.lex_state = 0, .external_lex_state = 7},
  [9025] = {.lex_state = 0, .external_lex_state = 7},
  [9026] = {.lex_state = 0, .external_lex_state = 7},
  [9027] = {.lex_state = 0, .external_lex_state = 7},
  [9028] = {.lex_state = 0, .external_lex_state = 6},
  [9029] = {.lex_state = 0, .external_lex_state = 7},
  [9030] = {.lex_state = 0, .external_lex_state = 7},
  [9031] = {.lex_state = 0, .external_lex_state = 7},
  [9032] = {.lex_state = 0, .external_lex_state = 7},
  [9033] = {.lex_state = 0, .external_lex_state = 7},
  [9034] = {.lex_state = 0, .external_lex_state = 6},
  [9035] = {.lex_state = 0, .external_lex_state = 6},
  [9036] = {.lex_state = 0, .external_lex_state = 7},
  [9037] = {.lex_state = 0, .external_lex_state = 7},
  [9038] = {.lex_state = 0, .external_lex_state = 7},
  [9039] = {.lex_state = 0, .external_lex_state = 7},
  [9040] = {.lex_state = 0, .external_lex_state = 7},
  [9041] = {.lex_state = 0, .external_lex_state = 7},
  [9042] = {.lex_state = 0, .external_lex_state = 7},
  [9043] = {.lex_state = 0, .external_lex_state = 6},
  [9044] = {.lex_state = 0, .external_lex_state = 7},
  [9045] = {.lex_state = 0, .external_lex_state = 7},
  [9046] = {.lex_state = 0, .external_lex_state = 7},
  [9047] = {.lex_state = 0, .external_lex_state = 7},
  [9048] = {.lex_state = 0, .external_lex_state = 7},
  [9049] = {.lex_state = 0, .external_lex_state = 7},
  [9050] = {.lex_state = 0, .external_lex_state = 7},
  [9051] = {.lex_state = 0, .external_lex_state = 7},
  [9052] = {.lex_state = 0, .external_lex_state = 7},
  [9053] = {.lex_state = 0, .external_lex_state = 7},
  [9054] = {.lex_state = 0, .external_lex_state = 7},
  [9055] = {.lex_state = 0, .external_lex_state = 7},
  [9056] = {.lex_state = 0, .external_lex_state = 7},
  [9057] = {.lex_state = 0, .external_lex_state = 6},
  [9058] = {.lex_state = 0, .external_lex_state = 7},
  [9059] = {.lex_state = 0, .external_lex_state = 7},
  [9060] = {.lex_state = 0, .external_lex_state = 7},
  [9061] = {.lex_state = 0, .external_lex_state = 6},
  [9062] = {.lex_state = 0, .external_lex_state = 7},
  [9063] = {.lex_state = 0, .external_lex_state = 7},
  [9064] = {.lex_state = 0, .external_lex_state = 6},
  [9065] = {.lex_state = 0, .external_lex_state = 7},
  [9066] = {.lex_state = 0, .external_lex_state = 7},
  [9067] = {.lex_state = 0, .external_lex_state = 7},
  [9068] = {.lex_state = 0, .external_lex_state = 7},
  [9069] = {.lex_state = 0, .external_lex_state = 7},
  [9070] = {.lex_state = 0, .external_lex_state = 7},
  [9071] = {.lex_state = 0, .external_lex_state = 7},
  [9072] = {.lex_state = 0, .external_lex_state = 7},
  [9073] = {.lex_state = 0, .external_lex_state = 7},
  [9074] = {.lex_state = 0, .external_lex_state = 7},
  [9075] = {.lex_state = 0, .external_lex_state = 7},
  [9076] = {.lex_state = 0, .external_lex_state = 7},
  [9077] = {.lex_state = 0, .external_lex_state = 6},
  [9078] = {.lex_state = 0, .external_lex_state = 7},
  [9079] = {.lex_state = 0, .external_lex_state = 7},
  [9080] = {.lex_state = 0, .external_lex_state = 7},
  [9081] = {.lex_state = 0, .external_lex_state = 7},
  [9082] = {.lex_state = 0, .external_lex_state = 6},
  [9083] = {.lex_state = 0, .external_lex_state = 7},
  [9084] = {.lex_state = 0, .external_lex_state = 6},
  [9085] = {.lex_state = 0, .external_lex_state = 7},
  [9086] = {.lex_state = 0, .external_lex_state = 7},
  [9087] = {.lex_state = 0, .external_lex_state = 6},
  [9088] = {.lex_state = 0, .external_lex_state = 7},
  [9089] = {.lex_state = 0, .external_lex_state = 7},
  [9090] = {.lex_state = 0, .external_lex_state = 7},
  [9091] = {.lex_state = 0, .external_lex_state = 7},
  [9092] = {.lex_state = 0, .external_lex_state = 7},
  [9093] = {.lex_state = 0, .external_lex_state = 7},
  [9094] = {.lex_state = 0, .external_lex_state = 7},
  [9095] = {.lex_state = 0, .external_lex_state = 7},
  [9096] = {.lex_state = 0, .external_lex_state = 7},
  [9097] = {.lex_state = 0, .external_lex_state = 6},
  [9098] = {.lex_state = 0, .external_lex_state = 7},
  [9099] = {.lex_state = 0, .external_lex_state = 7},
  [9100] = {.lex_state = 0, .external_lex_state = 6},
  [9101] = {.lex_state = 0, .external_lex_state = 7},
  [9102] = {.lex_state = 0, .external_lex_state = 7},
  [9103] = {.lex_state = 0, .external_lex_state = 7},
  [9104] = {.lex_state = 0, .external_lex_state = 6},
  [9105] = {.lex_state = 0, .external_lex_state = 7},
  [9106] = {.lex_state = 0, .external_lex_state = 7},
  [9107] = {.lex_state = 0, .external_lex_state = 7},
  [9108] = {.lex_state = 0, .external_lex_state = 7},
  [9109] = {.lex_state = 0, .external_lex_state = 6},
  [9110] = {.lex_state = 0, .external_lex_state = 7},
  [9111] = {.lex_state = 0, .external_lex_state = 7},
  [9112] = {.lex_state = 0, .external_lex_state = 7},
  [9113] = {.lex_state = 0, .external_lex_state = 6},
  [9114] = {.lex_state = 0, .external_lex_state = 6},
  [9115] = {.lex_state = 0, .external_lex_state = 7},
  [9116] = {.lex_state = 0, .external_lex_state = 7},
  [9117] = {.lex_state = 0, .external_lex_state = 7},
  [9118] = {.lex_state = 0, .external_lex_state = 7},
  [9119] = {.lex_state = 0, .external_lex_state = 6},
  [9120] = {.lex_state = 0, .external_lex_state = 7},
  [9121] = {.lex_state = 0, .external_lex_state = 7},
  [9122] = {.lex_state = 0, .external_lex_state = 7},
  [9123] = {.lex_state = 0, .external_lex_state = 7},
  [9124] = {.lex_state = 0, .external_lex_state = 6},
  [9125] = {.lex_state = 0, .external_lex_state = 7},
  [9126] = {.lex_state = 0, .external_lex_state = 6},
  [9127] = {.lex_state = 0, .external_lex_state = 6},
  [9128] = {.lex_state = 0, .external_lex_state = 7},
  [9129] = {.lex_state = 0, .external_lex_state = 7},
  [9130] = {.lex_state = 0, .external_lex_state = 7},
  [9131] = {.lex_state = 0, .external_lex_state = 7},
  [9132] = {.lex_state = 0, .external_lex_state = 7},
  [9133] = {.lex_state = 0, .external_lex_state = 7},
  [9134] = {.lex_state = 0, .external_lex_state = 7},
  [9135] = {.lex_state = 0, .external_lex_state = 7},
  [9136] = {.lex_state = 0, .external_lex_state = 7},
  [9137] = {.lex_state = 0, .external_lex_state = 7},
  [9138] = {.lex_state = 0, .external_lex_state = 7},
  [9139] = {.lex_state = 0, .external_lex_state = 7},
  [9140] = {.lex_state = 0, .external_lex_state = 7},
  [9141] = {.lex_state = 0, .external_lex_state = 7},
  [9142] = {.lex_state = 0, .external_lex_state = 7},
  [9143] = {.lex_state = 0, .external_lex_state = 7},
  [9144] = {.lex_state = 0, .external_lex_state = 7},
  [9145] = {.lex_state = 0, .external_lex_state = 7},
  [9146] = {.lex_state = 0, .external_lex_state = 7},
  [9147] = {.lex_state = 0, .external_lex_state = 7},
  [9148] = {.lex_state = 0, .external_lex_state = 7},
  [9149] = {.lex_state = 0, .external_lex_state = 7},
  [9150] = {.lex_state = 0, .external_lex_state = 7},
  [9151] = {.lex_state = 0, .external_lex_state = 6},
  [9152] = {.lex_state = 0, .external_lex_state = 7},
  [9153] = {.lex_state = 0, .external_lex_state = 7},
  [9154] = {.lex_state = 0, .external_lex_state = 7},
  [9155] = {.lex_state = 0, .external_lex_state = 7},
  [9156] = {.lex_state = 0, .external_lex_state = 7},
  [9157] = {.lex_state = 0, .external_lex_state = 7},
  [9158] = {.lex_state = 0, .external_lex_state = 7},
  [9159] = {.lex_state = 0, .external_lex_state = 7},
  [9160] = {.lex_state = 0, .external_lex_state = 7},
  [9161] = {.lex_state = 0, .external_lex_state = 7},
  [9162] = {.lex_state = 0, .external_lex_state = 7},
  [9163] = {.lex_state = 0, .external_lex_state = 7},
  [9164] = {.lex_state = 0, .external_lex_state = 7},
  [9165] = {.lex_state = 0, .external_lex_state = 7},
  [9166] = {.lex_state = 0, .external_lex_state = 7},
  [9167] = {.lex_state = 0, .external_lex_state = 7},
  [9168] = {.lex_state = 0, .external_lex_state = 6},
  [9169] = {.lex_state = 0, .external_lex_state = 7},
  [9170] = {.lex_state = 0, .external_lex_state = 7},
  [9171] = {.lex_state = 0, .external_lex_state = 7},
  [9172] = {.lex_state = 0, .external_lex_state = 7},
  [9173] = {.lex_state = 0, .external_lex_state = 7},
  [9174] = {.lex_state = 0, .external_lex_state = 7},
  [9175] = {.lex_state = 0, .external_lex_state = 7},
  [9176] = {.lex_state = 0, .external_lex_state = 7},
  [9177] = {.lex_state = 0, .external_lex_state = 7},
  [9178] = {.lex_state = 0, .external_lex_state = 7},
  [9179] = {.lex_state = 0, .external_lex_state = 6},
  [9180] = {.lex_state = 0, .external_lex_state = 7},
  [9181] = {.lex_state = 0, .external_lex_state = 6},
  [9182] = {.lex_state = 0, .external_lex_state = 7},
  [9183] = {.lex_state = 0, .external_lex_state = 7},
  [9184] = {.lex_state = 0, .external_lex_state = 7},
  [9185] = {.lex_state = 0, .external_lex_state = 7},
  [9186] = {.lex_state = 0, .external_lex_state = 7},
  [9187] = {.lex_state = 0, .external_lex_state = 7},
  [9188] = {.lex_state = 0, .external_lex_state = 7},
  [9189] = {.lex_state = 0, .external_lex_state = 7},
  [9190] = {.lex_state = 0, .external_lex_state = 7},
  [9191] = {.lex_state = 0, .external_lex_state = 7},
  [9192] = {.lex_state = 0, .external_lex_state = 6},
  [9193] = {.lex_state = 0, .external_lex_state = 7},
  [9194] = {.lex_state = 0, .external_lex_state = 7},
  [9195] = {.lex_state = 0, .external_lex_state = 7},
  [9196] = {.lex_state = 0, .external_lex_state = 7},
  [9197] = {.lex_state = 0, .external_lex_state = 7},
  [9198] = {.lex_state = 0, .external_lex_state = 7},
  [9199] = {.lex_state = 0, .external_lex_state = 7},
  [9200] = {.lex_state = 0, .external_lex_state = 7},
  [9201] = {.lex_state = 0, .external_lex_state = 7},
  [9202] = {.lex_state = 0, .external_lex_state = 7},
  [9203] = {.lex_state = 0, .external_lex_state = 7},
  [9204] = {.lex_state = 0, .external_lex_state = 7},
  [9205] = {.lex_state = 0, .external_lex_state = 7},
  [9206] = {.lex_state = 0, .external_lex_state = 7},
  [9207] = {.lex_state = 0, .external_lex_state = 6},
  [9208] = {.lex_state = 0, .external_lex_state = 7},
  [9209] = {.lex_state = 0, .external_lex_state = 7},
  [9210] = {.lex_state = 0, .external_lex_state = 7},
  [9211] = {.lex_state = 0, .external_lex_state = 7},
  [9212] = {.lex_state = 0, .external_lex_state = 7},
  [9213] = {.lex_state = 0, .external_lex_state = 7},
  [9214] = {.lex_state = 0, .external_lex_state = 7},
  [9215] = {.lex_state = 0, .external_lex_state = 7},
  [9216] = {.lex_state = 0, .external_lex_state = 7},
  [9217] = {.lex_state = 0, .external_lex_state = 6},
  [9218] = {.lex_state = 0, .external_lex_state = 7},
  [9219] = {.lex_state = 0, .external_lex_state = 7},
  [9220] = {.lex_state = 0, .external_lex_state = 7},
  [9221] = {.lex_state = 0, .external_lex_state = 7},
  [9222] = {.lex_state = 0, .external_lex_state = 7},
  [9223] = {.lex_state = 0, .external_lex_state = 6},
  [9224] = {.lex_state = 0, .external_lex_state = 7},
  [9225] = {.lex_state = 0, .external_lex_state = 6},
  [9226] = {.lex_state = 0, .external_lex_state = 7},
  [9227] = {.lex_state = 0, .external_lex_state = 7},
  [9228] = {.lex_state = 0, .external_lex_state = 7},
  [9229] = {.lex_state = 0, .external_lex_state = 7},
  [9230] = {.lex_state = 0, .external_lex_state = 6},
  [9231] = {.lex_state = 0, .external_lex_state = 7},
  [9232] = {.lex_state = 0, .external_lex_state = 7},
  [9233] = {.lex_state = 0, .external_lex_state = 7},
  [9234] = {.lex_state = 1, .external_lex_state = 7},
  [9235] = {.lex_state = 0, .external_lex_state = 7},
  [9236] = {.lex_state = 0, .external_lex_state = 7},
  [9237] = {.lex_state = 0, .external_lex_state = 7},
  [9238] = {.lex_state = 0, .external_lex_state = 7},
  [9239] = {.lex_state = 0, .external_lex_state = 7},
  [9240] = {.lex_state = 0, .external_lex_state = 7},
  [9241] = {.lex_state = 0, .external_lex_state = 7},
  [9242] = {.lex_state = 0, .external_lex_state = 7},
  [9243] = {.lex_state = 0, .external_lex_state = 7},
  [9244] = {.lex_state = 0, .external_lex_state = 7},
  [9245] = {.lex_state = 0, .external_lex_state = 7},
  [9246] = {.lex_state = 0, .external_lex_state = 7},
  [9247] = {.lex_state = 0, .external_lex_state = 7},
  [9248] = {.lex_state = 0, .external_lex_state = 7},
  [9249] = {.lex_state = 0, .external_lex_state = 6},
  [9250] = {.lex_state = 0, .external_lex_state = 7},
  [9251] = {.lex_state = 0, .external_lex_state = 7},
  [9252] = {.lex_state = 0, .external_lex_state = 6},
  [9253] = {.lex_state = 0, .external_lex_state = 7},
  [9254] = {.lex_state = 0, .external_lex_state = 6},
  [9255] = {.lex_state = 0, .external_lex_state = 7},
  [9256] = {.lex_state = 0, .external_lex_state = 7},
  [9257] = {.lex_state = 0, .external_lex_state = 7},
  [9258] = {.lex_state = 0, .external_lex_state = 7},
  [9259] = {.lex_state = 0, .external_lex_state = 7},
  [9260] = {.lex_state = 0, .external_lex_state = 7},
  [9261] = {.lex_state = 0, .external_lex_state = 7},
  [9262] = {.lex_state = 0, .external_lex_state = 7},
  [9263] = {.lex_state = 0, .external_lex_state = 6},
  [9264] = {.lex_state = 0, .external_lex_state = 7},
  [9265] = {.lex_state = 0, .external_lex_state = 7},
  [9266] = {.lex_state = 0, .external_lex_state = 7},
  [9267] = {.lex_state = 0, .external_lex_state = 7},
  [9268] = {.lex_state = 0, .external_lex_state = 7},
  [9269] = {.lex_state = 0, .external_lex_state = 7},
  [9270] = {.lex_state = 0, .external_lex_state = 7},
  [9271] = {.lex_state = 0, .external_lex_state = 7},
  [9272] = {.lex_state = 0, .external_lex_state = 7},
  [9273] = {.lex_state = 0, .external_lex_state = 7},
  [9274] = {.lex_state = 0, .external_lex_state = 7},
  [9275] = {.lex_state = 0, .external_lex_state = 6},
  [9276] = {.lex_state = 0, .external_lex_state = 7},
  [9277] = {.lex_state = 0, .external_lex_state = 7},
  [9278] = {.lex_state = 0, .external_lex_state = 7},
  [9279] = {.lex_state = 0, .external_lex_state = 7},
  [9280] = {.lex_state = 0, .external_lex_state = 7},
  [9281] = {.lex_state = 0, .external_lex_state = 7},
  [9282] = {.lex_state = 0, .external_lex_state = 7},
  [9283] = {.lex_state = 0, .external_lex_state = 6},
  [9284] = {.lex_state = 0, .external_lex_state = 7},
  [9285] = {.lex_state = 0, .external_lex_state = 6},
  [9286] = {.lex_state = 0, .external_lex_state = 7},
  [9287] = {.lex_state = 0, .external_lex_state = 7},
  [9288] = {.lex_state = 0, .external_lex_state = 7},
  [9289] = {.lex_state = 0, .external_lex_state = 7},
  [9290] = {.lex_state = 0, .external_lex_state = 7},
  [9291] = {.lex_state = 0, .external_lex_state = 7},
  [9292] = {.lex_state = 0, .external_lex_state = 7},
  [9293] = {.lex_state = 0, .external_lex_state = 6},
  [9294] = {.lex_state = 0, .external_lex_state = 7},
  [9295] = {.lex_state = 0, .external_lex_state = 7},
  [9296] = {.lex_state = 0, .external_lex_state = 7},
  [9297] = {.lex_state = 0, .external_lex_state = 7},
  [9298] = {.lex_state = 0, .external_lex_state = 7},
  [9299] = {.lex_state = 0, .external_lex_state = 7},
  [9300] = {.lex_state = 0, .external_lex_state = 7},
  [9301] = {.lex_state = 0, .external_lex_state = 7},
  [9302] = {.lex_state = 0, .external_lex_state = 7},
  [9303] = {.lex_state = 0, .external_lex_state = 7},
  [9304] = {.lex_state = 0, .external_lex_state = 7},
  [9305] = {.lex_state = 0, .external_lex_state = 7},
  [9306] = {.lex_state = 0, .external_lex_state = 7},
  [9307] = {.lex_state = 0, .external_lex_state = 7},
  [9308] = {.lex_state = 0, .external_lex_state = 7},
  [9309] = {.lex_state = 0, .external_lex_state = 7},
  [9310] = {.lex_state = 0, .external_lex_state = 6},
  [9311] = {.lex_state = 0, .external_lex_state = 7},
  [9312] = {.lex_state = 0, .external_lex_state = 7},
  [9313] = {.lex_state = 0, .external_lex_state = 7},
  [9314] = {.lex_state = 0, .external_lex_state = 7},
  [9315] = {.lex_state = 0, .external_lex_state = 7},
  [9316] = {.lex_state = 0, .external_lex_state = 7},
  [9317] = {.lex_state = 0, .external_lex_state = 7},
  [9318] = {.lex_state = 0, .external_lex_state = 7},
  [9319] = {.lex_state = 0, .external_lex_state = 7},
  [9320] = {.lex_state = 0, .external_lex_state = 6},
  [9321] = {.lex_state = 0, .external_lex_state = 7},
  [9322] = {.lex_state = 0, .external_lex_state = 7},
  [9323] = {.lex_state = 0, .external_lex_state = 7},
  [9324] = {.lex_state = 0, .external_lex_state = 7},
  [9325] = {.lex_state = 0, .external_lex_state = 7},
  [9326] = {.lex_state = 0, .external_lex_state = 7},
  [9327] = {.lex_state = 0, .external_lex_state = 7},
  [9328] = {.lex_state = 0, .external_lex_state = 7},
  [9329] = {.lex_state = 0, .external_lex_state = 6},
  [9330] = {.lex_state = 0, .external_lex_state = 7},
  [9331] = {.lex_state = 0, .external_lex_state = 7},
  [9332] = {.lex_state = 0, .external_lex_state = 7},
  [9333] = {.lex_state = 0, .external_lex_state = 6},
  [9334] = {.lex_state = 0, .external_lex_state = 7},
  [9335] = {.lex_state = 0, .external_lex_state = 7},
  [9336] = {.lex_state = 0, .external_lex_state = 7},
  [9337] = {.lex_state = 0, .external_lex_state = 7},
  [9338] = {.lex_state = 0, .external_lex_state = 6},
  [9339] = {.lex_state = 0, .external_lex_state = 7},
  [9340] = {.lex_state = 0, .external_lex_state = 7},
  [9341] = {.lex_state = 0, .external_lex_state = 7},
  [9342] = {.lex_state = 0, .external_lex_state = 7},
  [9343] = {.lex_state = 0, .external_lex_state = 7},
  [9344] = {.lex_state = 0, .external_lex_state = 7},
  [9345] = {.lex_state = 0, .external_lex_state = 7},
  [9346] = {.lex_state = 0, .external_lex_state = 6},
  [9347] = {.lex_state = 0, .external_lex_state = 7},
  [9348] = {.lex_state = 0, .external_lex_state = 7},
  [9349] = {.lex_state = 0, .external_lex_state = 7},
  [9350] = {.lex_state = 0, .external_lex_state = 7},
  [9351] = {.lex_state = 0, .external_lex_state = 7},
  [9352] = {.lex_state = 0, .external_lex_state = 6},
  [9353] = {.lex_state = 0, .external_lex_state = 7},
  [9354] = {.lex_state = 0, .external_lex_state = 7},
  [9355] = {.lex_state = 0, .external_lex_state = 7},
  [9356] = {.lex_state = 0, .external_lex_state = 7},
  [9357] = {.lex_state = 0, .external_lex_state = 6},
  [9358] = {.lex_state = 0, .external_lex_state = 7},
  [9359] = {.lex_state = 0, .external_lex_state = 7},
  [9360] = {.lex_state = 0, .external_lex_state = 7},
  [9361] = {.lex_state = 0, .external_lex_state = 7},
  [9362] = {.lex_state = 0, .external_lex_state = 7},
  [9363] = {.lex_state = 0, .external_lex_state = 7},
  [9364] = {.lex_state = 0, .external_lex_state = 6},
  [9365] = {.lex_state = 0, .external_lex_state = 6},
  [9366] = {.lex_state = 0, .external_lex_state = 7},
  [9367] = {.lex_state = 0, .external_lex_state = 7},
  [9368] = {.lex_state = 0, .external_lex_state = 7},
  [9369] = {.lex_state = 0, .external_lex_state = 7},
  [9370] = {.lex_state = 0, .external_lex_state = 7},
  [9371] = {.lex_state = 0, .external_lex_state = 7},
  [9372] = {.lex_state = 0, .external_lex_state = 7},
  [9373] = {.lex_state = 0, .external_lex_state = 7},
  [9374] = {.lex_state = 0, .external_lex_state = 7},
  [9375] = {.lex_state = 0, .external_lex_state = 7},
  [9376] = {.lex_state = 0, .external_lex_state = 7},
  [9377] = {.lex_state = 0, .external_lex_state = 7},
  [9378] = {.lex_state = 0, .external_lex_state = 7},
  [9379] = {.lex_state = 0, .external_lex_state = 7},
  [9380] = {.lex_state = 0, .external_lex_state = 7},
  [9381] = {.lex_state = 0, .external_lex_state = 7},
  [9382] = {.lex_state = 0, .external_lex_state = 7},
  [9383] = {.lex_state = 0, .external_lex_state = 7},
  [9384] = {.lex_state = 0, .external_lex_state = 7},
  [9385] = {.lex_state = 0, .external_lex_state = 7},
  [9386] = {.lex_state = 0, .external_lex_state = 6},
  [9387] = {.lex_state = 0, .external_lex_state = 7},
  [9388] = {.lex_state = 0, .external_lex_state = 7},
  [9389] = {.lex_state = 0, .external_lex_state = 7},
  [9390] = {.lex_state = 0, .external_lex_state = 6},
  [9391] = {.lex_state = 0, .external_lex_state = 7},
  [9392] = {.lex_state = 0, .external_lex_state = 7},
  [9393] = {.lex_state = 0, .external_lex_state = 7},
  [9394] = {.lex_state = 0, .external_lex_state = 7},
  [9395] = {.lex_state = 0, .external_lex_state = 7},
  [9396] = {.lex_state = 0, .external_lex_state = 7},
  [9397] = {.lex_state = 0, .external_lex_state = 7},
  [9398] = {.lex_state = 0, .external_lex_state = 7},
  [9399] = {.lex_state = 0, .external_lex_state = 7},
  [9400] = {.lex_state = 0, .external_lex_state = 7},
  [9401] = {.lex_state = 0, .external_lex_state = 7},
  [9402] = {.lex_state = 0, .external_lex_state = 7},
  [9403] = {.lex_state = 0, .external_lex_state = 7},
  [9404] = {.lex_state = 0, .external_lex_state = 7},
  [9405] = {.lex_state = 0, .external_lex_state = 7},
  [9406] = {.lex_state = 0, .external_lex_state = 7},
  [9407] = {.lex_state = 0, .external_lex_state = 7},
  [9408] = {.lex_state = 0, .external_lex_state = 7},
  [9409] = {.lex_state = 0, .external_lex_state = 7},
  [9410] = {.lex_state = 0, .external_lex_state = 7},
  [9411] = {.lex_state = 0, .external_lex_state = 7},
  [9412] = {.lex_state = 0, .external_lex_state = 6},
  [9413] = {.lex_state = 0, .external_lex_state = 7},
  [9414] = {.lex_state = 0, .external_lex_state = 7},
  [9415] = {.lex_state = 0, .external_lex_state = 6},
  [9416] = {.lex_state = 0, .external_lex_state = 6},
  [9417] = {.lex_state = 0, .external_lex_state = 7},
  [9418] = {.lex_state = 0, .external_lex_state = 7},
  [9419] = {.lex_state = 0, .external_lex_state = 6},
  [9420] = {.lex_state = 0, .external_lex_state = 7},
  [9421] = {.lex_state = 0, .external_lex_state = 6},
  [9422] = {.lex_state = 0, .external_lex_state = 7},
  [9423] = {.lex_state = 0, .external_lex_state = 7},
  [9424] = {.lex_state = 0, .external_lex_state = 7},
  [9425] = {.lex_state = 0, .external_lex_state = 6},
  [9426] = {.lex_state = 0, .external_lex_state = 7},
  [9427] = {.lex_state = 0, .external_lex_state = 7},
  [9428] = {.lex_state = 0, .external_lex_state = 7},
  [9429] = {.lex_state = 0, .external_lex_state = 7},
  [9430] = {.lex_state = 0, .external_lex_state = 6},
  [9431] = {.lex_state = 0, .external_lex_state = 7},
  [9432] = {.lex_state = 0, .external_lex_state = 7},
  [9433] = {.lex_state = 0, .external_lex_state = 7},
  [9434] = {.lex_state = 0, .external_lex_state = 7},
  [9435] = {.lex_state = 0, .external_lex_state = 7},
  [9436] = {.lex_state = 0, .external_lex_state = 7},
  [9437] = {.lex_state = 0, .external_lex_state = 7},
  [9438] = {.lex_state = 0, .external_lex_state = 7},
  [9439] = {.lex_state = 0, .external_lex_state = 7},
  [9440] = {.lex_state = 0, .external_lex_state = 7},
  [9441] = {.lex_state = 0, .external_lex_state = 7},
  [9442] = {.lex_state = 0, .external_lex_state = 7},
  [9443] = {.lex_state = 0, .external_lex_state = 7},
  [9444] = {.lex_state = 0, .external_lex_state = 7},
  [9445] = {.lex_state = 0, .external_lex_state = 7},
  [9446] = {.lex_state = 0, .external_lex_state = 7},
  [9447] = {.lex_state = 0, .external_lex_state = 7},
  [9448] = {.lex_state = 0, .external_lex_state = 7},
  [9449] = {.lex_state = 0, .external_lex_state = 7},
  [9450] = {.lex_state = 0, .external_lex_state = 7},
  [9451] = {.lex_state = 0, .external_lex_state = 7},
  [9452] = {.lex_state = 0, .external_lex_state = 7},
  [9453] = {.lex_state = 0, .external_lex_state = 7},
  [9454] = {.lex_state = 0, .external_lex_state = 7},
  [9455] = {.lex_state = 0, .external_lex_state = 7},
  [9456] = {.lex_state = 0, .external_lex_state = 7},
  [9457] = {.lex_state = 0, .external_lex_state = 7},
  [9458] = {.lex_state = 0, .external_lex_state = 7},
  [9459] = {.lex_state = 0, .external_lex_state = 7},
  [9460] = {.lex_state = 0, .external_lex_state = 7},
  [9461] = {.lex_state = 0, .external_lex_state = 7},
  [9462] = {.lex_state = 0, .external_lex_state = 7},
  [9463] = {.lex_state = 0, .external_lex_state = 7},
  [9464] = {.lex_state = 0, .external_lex_state = 7},
  [9465] = {.lex_state = 0, .external_lex_state = 7},
  [9466] = {.lex_state = 0, .external_lex_state = 7},
  [9467] = {.lex_state = 0, .external_lex_state = 6},
  [9468] = {.lex_state = 0, .external_lex_state = 7},
  [9469] = {.lex_state = 0, .external_lex_state = 7},
  [9470] = {.lex_state = 0, .external_lex_state = 7},
  [9471] = {.lex_state = 0, .external_lex_state = 7},
  [9472] = {.lex_state = 0, .external_lex_state = 7},
  [9473] = {.lex_state = 0, .external_lex_state = 7},
  [9474] = {.lex_state = 0, .external_lex_state = 6},
  [9475] = {.lex_state = 0, .external_lex_state = 7},
  [9476] = {.lex_state = 0, .external_lex_state = 7},
  [9477] = {.lex_state = 0, .external_lex_state = 6},
  [9478] = {.lex_state = 0, .external_lex_state = 7},
  [9479] = {.lex_state = 0, .external_lex_state = 7},
  [9480] = {.lex_state = 0, .external_lex_state = 7},
  [9481] = {.lex_state = 0, .external_lex_state = 7},
  [9482] = {.lex_state = 0, .external_lex_state = 7},
  [9483] = {.lex_state = 0, .external_lex_state = 7},
  [9484] = {.lex_state = 0, .external_lex_state = 6},
  [9485] = {.lex_state = 0, .external_lex_state = 7},
  [9486] = {.lex_state = 0, .external_lex_state = 7},
  [9487] = {.lex_state = 0, .external_lex_state = 7},
  [9488] = {.lex_state = 0, .external_lex_state = 7},
  [9489] = {.lex_state = 0, .external_lex_state = 7},
  [9490] = {.lex_state = 0, .external_lex_state = 7},
  [9491] = {.lex_state = 0, .external_lex_state = 7},
  [9492] = {.lex_state = 0, .external_lex_state = 7},
  [9493] = {.lex_state = 0, .external_lex_state = 6},
  [9494] = {.lex_state = 0, .external_lex_state = 7},
  [9495] = {.lex_state = 0, .external_lex_state = 7},
  [9496] = {.lex_state = 0, .external_lex_state = 7},
  [9497] = {.lex_state = 0, .external_lex_state = 7},
  [9498] = {.lex_state = 0, .external_lex_state = 7},
  [9499] = {.lex_state = 0, .external_lex_state = 7},
  [9500] = {.lex_state = 0, .external_lex_state = 7},
  [9501] = {.lex_state = 0, .external_lex_state = 7},
  [9502] = {.lex_state = 0, .external_lex_state = 7},
  [9503] = {.lex_state = 0, .external_lex_state = 6},
  [9504] = {.lex_state = 0, .external_lex_state = 7},
  [9505] = {.lex_state = 0, .external_lex_state = 7},
  [9506] = {.lex_state = 0, .external_lex_state = 7},
  [9507] = {.lex_state = 0, .external_lex_state = 7},
  [9508] = {.lex_state = 0, .external_lex_state = 7},
  [9509] = {.lex_state = 0, .external_lex_state = 7},
  [9510] = {.lex_state = 0, .external_lex_state = 7},
  [9511] = {.lex_state = 0, .external_lex_state = 7},
  [9512] = {.lex_state = 0, .external_lex_state = 7},
  [9513] = {.lex_state = 0, .external_lex_state = 7},
  [9514] = {.lex_state = 0, .external_lex_state = 7},
  [9515] = {.lex_state = 0, .external_lex_state = 7},
  [9516] = {.lex_state = 0, .external_lex_state = 7},
  [9517] = {.lex_state = 0, .external_lex_state = 7},
  [9518] = {.lex_state = 0, .external_lex_state = 7},
  [9519] = {.lex_state = 0, .external_lex_state = 7},
  [9520] = {.lex_state = 0, .external_lex_state = 7},
  [9521] = {.lex_state = 0, .external_lex_state = 7},
  [9522] = {.lex_state = 0, .external_lex_state = 7},
  [9523] = {.lex_state = 0, .external_lex_state = 7},
  [9524] = {.lex_state = 0, .external_lex_state = 7},
  [9525] = {.lex_state = 0, .external_lex_state = 7},
  [9526] = {.lex_state = 0, .external_lex_state = 7},
  [9527] = {.lex_state = 0, .external_lex_state = 7},
  [9528] = {.lex_state = 0, .external_lex_state = 7},
  [9529] = {.lex_state = 0, .external_lex_state = 7},
  [9530] = {.lex_state = 0, .external_lex_state = 7},
  [9531] = {.lex_state = 0, .external_lex_state = 7},
  [9532] = {.lex_state = 0, .external_lex_state = 7},
  [9533] = {.lex_state = 0, .external_lex_state = 7},
  [9534] = {.lex_state = 0, .external_lex_state = 7},
  [9535] = {.lex_state = 0, .external_lex_state = 7},
  [9536] = {.lex_state = 0, .external_lex_state = 7},
  [9537] = {.lex_state = 0, .external_lex_state = 7},
  [9538] = {.lex_state = 0, .external_lex_state = 7},
  [9539] = {.lex_state = 0, .external_lex_state = 7},
  [9540] = {.lex_state = 0, .external_lex_state = 7},
  [9541] = {.lex_state = 0, .external_lex_state = 7},
  [9542] = {.lex_state = 0, .external_lex_state = 7},
  [9543] = {.lex_state = 0, .external_lex_state = 7},
  [9544] = {.lex_state = 0, .external_lex_state = 7},
  [9545] = {.lex_state = 0, .external_lex_state = 7},
  [9546] = {.lex_state = 0, .external_lex_state = 7},
  [9547] = {.lex_state = 0, .external_lex_state = 7},
  [9548] = {.lex_state = 0, .external_lex_state = 6},
  [9549] = {.lex_state = 0, .external_lex_state = 7},
  [9550] = {.lex_state = 0, .external_lex_state = 7},
  [9551] = {.lex_state = 0, .external_lex_state = 7},
  [9552] = {.lex_state = 0, .external_lex_state = 7},
  [9553] = {.lex_state = 0, .external_lex_state = 7},
  [9554] = {.lex_state = 0, .external_lex_state = 7},
  [9555] = {.lex_state = 0, .external_lex_state = 7},
  [9556] = {.lex_state = 0, .external_lex_state = 7},
  [9557] = {.lex_state = 0, .external_lex_state = 7},
  [9558] = {.lex_state = 0, .external_lex_state = 7},
  [9559] = {.lex_state = 0, .external_lex_state = 7},
  [9560] = {.lex_state = 0, .external_lex_state = 7},
  [9561] = {.lex_state = 0, .external_lex_state = 7},
  [9562] = {.lex_state = 0, .external_lex_state = 7},
  [9563] = {.lex_state = 0, .external_lex_state = 7},
  [9564] = {.lex_state = 0, .external_lex_state = 7},
  [9565] = {.lex_state = 0, .external_lex_state = 7},
  [9566] = {.lex_state = 0, .external_lex_state = 7},
  [9567] = {.lex_state = 0, .external_lex_state = 7},
  [9568] = {.lex_state = 0, .external_lex_state = 7},
  [9569] = {.lex_state = 0, .external_lex_state = 7},
  [9570] = {.lex_state = 0, .external_lex_state = 6},
  [9571] = {.lex_state = 0, .external_lex_state = 7},
  [9572] = {.lex_state = 0, .external_lex_state = 7},
  [9573] = {.lex_state = 0, .external_lex_state = 7},
  [9574] = {.lex_state = 0, .external_lex_state = 6},
  [9575] = {.lex_state = 0, .external_lex_state = 6},
  [9576] = {.lex_state = 0, .external_lex_state = 7},
  [9577] = {.lex_state = 0, .external_lex_state = 7},
  [9578] = {.lex_state = 0, .external_lex_state = 7},
  [9579] = {.lex_state = 0, .external_lex_state = 7},
  [9580] = {.lex_state = 0, .external_lex_state = 7},
  [9581] = {.lex_state = 0, .external_lex_state = 7},
  [9582] = {.lex_state = 0, .external_lex_state = 7},
  [9583] = {.lex_state = 0, .external_lex_state = 6},
  [9584] = {.lex_state = 0, .external_lex_state = 6},
  [9585] = {.lex_state = 0, .external_lex_state = 7},
  [9586] = {.lex_state = 0, .external_lex_state = 7},
  [9587] = {.lex_state = 0, .external_lex_state = 6},
  [9588] = {.lex_state = 0, .external_lex_state = 7},
  [9589] = {.lex_state = 0, .external_lex_state = 7},
  [9590] = {.lex_state = 0, .external_lex_state = 7},
  [9591] = {.lex_state = 0, .external_lex_state = 7},
  [9592] = {.lex_state = 0, .external_lex_state = 7},
  [9593] = {.lex_state = 0, .external_lex_state = 7},
  [9594] = {.lex_state = 0, .external_lex_state = 7},
  [9595] = {.lex_state = 0, .external_lex_state = 7},
  [9596] = {.lex_state = 0, .external_lex_state = 7},
  [9597] = {.lex_state = 0, .external_lex_state = 7},
  [9598] = {.lex_state = 0, .external_lex_state = 6},
  [9599] = {.lex_state = 0, .external_lex_state = 7},
  [9600] = {.lex_state = 0, .external_lex_state = 7},
  [9601] = {.lex_state = 0, .external_lex_state = 7},
  [9602] = {.lex_state = 0, .external_lex_state = 7},
  [9603] = {.lex_state = 0, .external_lex_state = 7},
  [9604] = {.lex_state = 0, .external_lex_state = 6},
  [9605] = {.lex_state = 0, .external_lex_state = 7},
  [9606] = {.lex_state = 0, .external_lex_state = 7},
  [9607] = {.lex_state = 0, .external_lex_state = 7},
  [9608] = {.lex_state = 0, .external_lex_state = 6},
  [9609] = {.lex_state = 0, .external_lex_state = 7},
  [9610] = {.lex_state = 0, .external_lex_state = 7},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_POUND_PLUS] = ACTIONS(1),
    [anon_sym_package] = ACTIONS(1),
    [anon_sym_foreign] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_proc] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_where] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_using] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_bit_field] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_POUNDtype] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(1),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(1),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_when] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_defer] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [sym_fallthrough_statement] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_or_else] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_TILDE_EQ] = ACTIONS(1),
    [anon_sym_AMP_TILDE] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(1),
    [anon_sym_DOT_DOT_LT] = ACTIONS(1),
    [anon_sym_cast] = ACTIONS(1),
    [anon_sym_transmute] = ACTIONS(1),
    [anon_sym_auto_cast] = ACTIONS(1),
    [anon_sym_not_in] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_or_return] = ACTIONS(1),
    [anon_sym_or_continue] = ACTIONS(1),
    [anon_sym_or_break] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [anon_sym_dynamic] = ACTIONS(1),
    [anon_sym_map] = ACTIONS(1),
    [anon_sym_bit_set] = ACTIONS(1),
    [anon_sym_matrix] = ACTIONS(1),
    [anon_sym_DOT2] = ACTIONS(1),
    [anon_sym_distinct] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_BQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_nil] = ACTIONS(1),
    [sym_uninitialized] = ACTIONS(1),
    [sym_tag] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(1),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(1),
    [sym_float] = ACTIONS(1),
    [sym_block_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_source_file] = STATE(9289),
    [sym_declaration] = STATE(7680),
    [sym_build_tag] = STATE(8531),
    [sym_package_declaration] = STATE(8531),
    [sym_import_declaration] = STATE(8531),
    [sym_procedure_declaration] = STATE(8531),
    [sym_overloaded_procedure_declaration] = STATE(8531),
    [sym_struct_declaration] = STATE(8531),
    [sym_enum_declaration] = STATE(8531),
    [sym_union_declaration] = STATE(8531),
    [sym_bit_field_declaration] = STATE(8531),
    [sym_variable_declaration] = STATE(8531),
    [sym_const_declaration] = STATE(8531),
    [sym_const_type_declaration] = STATE(8531),
    [sym_foreign_block] = STATE(8531),
    [sym_attributes] = STATE(855),
    [sym_attribute] = STATE(6180),
    [sym_when_statement] = STATE(8531),
    [sym_var_declaration] = STATE(8531),
    [sym_expression] = STATE(5770),
    [sym__expression_no_tag] = STATE(4733),
    [sym_unary_expression] = STATE(4733),
    [sym_binary_expression] = STATE(4733),
    [sym_ternary_expression] = STATE(4733),
    [sym_call_expression] = STATE(4733),
    [sym_selector_call_expression] = STATE(4733),
    [sym_member_expression] = STATE(4733),
    [sym_index_expression] = STATE(4733),
    [sym_slice_expression] = STATE(4733),
    [sym_range_expression] = STATE(4733),
    [sym_cast_expression] = STATE(4733),
    [sym_in_expression] = STATE(4733),
    [sym_variadic_expression] = STATE(4733),
    [sym_parenthesized_expression] = STATE(4733),
    [sym_or_return_expression] = STATE(4733),
    [sym_or_continue_expression] = STATE(4733),
    [sym_or_break_expression] = STATE(4733),
    [sym_address] = STATE(4733),
    [sym_map_type] = STATE(4733),
    [sym_matrix_type] = STATE(4733),
    [sym_distinct_type] = STATE(4733),
    [sym_literal] = STATE(4733),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [aux_sym_source_file_repeat1] = STATE(204),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_POUND_PLUS] = ACTIONS(11),
    [anon_sym_package] = ACTIONS(13),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(19),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_QMARK] = ACTIONS(27),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(63),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7500),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [3] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7526),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [4] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7205),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [5] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7317),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [6] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7323),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [7] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7658),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [8] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7424),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [9] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7381),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [10] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7371),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [11] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7434),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [12] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7505),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [13] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7448),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [14] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7361),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [15] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7419),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [16] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7460),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [17] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7485),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [18] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7518),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [19] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7411),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [20] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7427),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [21] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7483),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [22] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7502),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [23] = {
    [sym_block] = STATE(7666),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7293),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [24] = {
    [sym_expression] = STATE(751),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [ts_builtin_sym_end] = ACTIONS(131),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(131),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_where] = ACTIONS(135),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(131),
    [anon_sym_DASH_EQ] = ACTIONS(131),
    [anon_sym_STAR_EQ] = ACTIONS(131),
    [anon_sym_SLASH_EQ] = ACTIONS(131),
    [anon_sym_PERCENT_EQ] = ACTIONS(131),
    [anon_sym_AMP_EQ] = ACTIONS(131),
    [anon_sym_PIPE_EQ] = ACTIONS(131),
    [anon_sym_CARET_EQ] = ACTIONS(131),
    [anon_sym_LT_LT_EQ] = ACTIONS(131),
    [anon_sym_GT_GT_EQ] = ACTIONS(131),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(131),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_else] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_case] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(137),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(135),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(135),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(135),
    [anon_sym_LT_LT] = ACTIONS(135),
    [anon_sym_GT_GT] = ACTIONS(135),
    [anon_sym_STAR] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(143),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(135),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(131),
    [sym_tag] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(131),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [25] = {
    [sym_expression] = STATE(744),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [ts_builtin_sym_end] = ACTIONS(165),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_COLON_COLON] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_where] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_PLUS_EQ] = ACTIONS(165),
    [anon_sym_DASH_EQ] = ACTIONS(165),
    [anon_sym_STAR_EQ] = ACTIONS(165),
    [anon_sym_SLASH_EQ] = ACTIONS(165),
    [anon_sym_PERCENT_EQ] = ACTIONS(165),
    [anon_sym_AMP_EQ] = ACTIONS(165),
    [anon_sym_PIPE_EQ] = ACTIONS(165),
    [anon_sym_CARET_EQ] = ACTIONS(165),
    [anon_sym_LT_LT_EQ] = ACTIONS(165),
    [anon_sym_GT_GT_EQ] = ACTIONS(165),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(165),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(165),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_else] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_case] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(137),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(137),
    [anon_sym_BANG] = ACTIONS(137),
    [anon_sym_AMP] = ACTIONS(137),
    [anon_sym_PIPE_PIPE] = ACTIONS(169),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(169),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(169),
    [anon_sym_LT_LT] = ACTIONS(169),
    [anon_sym_GT_GT] = ACTIONS(169),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(143),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(169),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(165),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [26] = {
    [sym_expression] = STATE(2450),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [ts_builtin_sym_end] = ACTIONS(131),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(131),
    [anon_sym_DASH_EQ] = ACTIONS(131),
    [anon_sym_STAR_EQ] = ACTIONS(131),
    [anon_sym_SLASH_EQ] = ACTIONS(131),
    [anon_sym_PERCENT_EQ] = ACTIONS(131),
    [anon_sym_AMP_EQ] = ACTIONS(131),
    [anon_sym_PIPE_EQ] = ACTIONS(131),
    [anon_sym_CARET_EQ] = ACTIONS(131),
    [anon_sym_LT_LT_EQ] = ACTIONS(131),
    [anon_sym_GT_GT_EQ] = ACTIONS(131),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(131),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_else] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_case] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(135),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(135),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(135),
    [anon_sym_LT_LT] = ACTIONS(135),
    [anon_sym_GT_GT] = ACTIONS(135),
    [anon_sym_STAR] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(191),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(135),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(131),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [27] = {
    [sym_expression] = STATE(2449),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [ts_builtin_sym_end] = ACTIONS(165),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_COLON_COLON] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_PLUS_EQ] = ACTIONS(165),
    [anon_sym_DASH_EQ] = ACTIONS(165),
    [anon_sym_STAR_EQ] = ACTIONS(165),
    [anon_sym_SLASH_EQ] = ACTIONS(165),
    [anon_sym_PERCENT_EQ] = ACTIONS(165),
    [anon_sym_AMP_EQ] = ACTIONS(165),
    [anon_sym_PIPE_EQ] = ACTIONS(165),
    [anon_sym_CARET_EQ] = ACTIONS(165),
    [anon_sym_LT_LT_EQ] = ACTIONS(165),
    [anon_sym_GT_GT_EQ] = ACTIONS(165),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(165),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(165),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_else] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_case] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(185),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_AMP] = ACTIONS(185),
    [anon_sym_PIPE_PIPE] = ACTIONS(169),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(169),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(169),
    [anon_sym_LT_LT] = ACTIONS(169),
    [anon_sym_GT_GT] = ACTIONS(169),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(191),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(169),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(165),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [28] = {
    [sym_expression] = STATE(2596),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_COLON_COLON] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_PLUS_EQ] = ACTIONS(165),
    [anon_sym_DASH_EQ] = ACTIONS(165),
    [anon_sym_STAR_EQ] = ACTIONS(165),
    [anon_sym_SLASH_EQ] = ACTIONS(165),
    [anon_sym_PERCENT_EQ] = ACTIONS(165),
    [anon_sym_AMP_EQ] = ACTIONS(165),
    [anon_sym_PIPE_EQ] = ACTIONS(165),
    [anon_sym_CARET_EQ] = ACTIONS(165),
    [anon_sym_LT_LT_EQ] = ACTIONS(165),
    [anon_sym_GT_GT_EQ] = ACTIONS(165),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(165),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(165),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_case] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(97),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(97),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(97),
    [anon_sym_PIPE_PIPE] = ACTIONS(169),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(169),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(169),
    [anon_sym_LT_LT] = ACTIONS(169),
    [anon_sym_GT_GT] = ACTIONS(169),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(169),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(165),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [29] = {
    [sym_expression] = STATE(2570),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(207),
    [anon_sym_COMMA] = ACTIONS(207),
    [anon_sym_COLON_COLON] = ACTIONS(207),
    [anon_sym_DASH_GT] = ACTIONS(207),
    [anon_sym_EQ] = ACTIONS(209),
    [anon_sym_COLON] = ACTIONS(209),
    [anon_sym_PIPE] = ACTIONS(209),
    [anon_sym_COLON_EQ] = ACTIONS(207),
    [anon_sym_LPAREN] = ACTIONS(207),
    [anon_sym_PLUS_EQ] = ACTIONS(207),
    [anon_sym_DASH_EQ] = ACTIONS(207),
    [anon_sym_STAR_EQ] = ACTIONS(207),
    [anon_sym_SLASH_EQ] = ACTIONS(207),
    [anon_sym_PERCENT_EQ] = ACTIONS(207),
    [anon_sym_AMP_EQ] = ACTIONS(207),
    [anon_sym_PIPE_EQ] = ACTIONS(207),
    [anon_sym_CARET_EQ] = ACTIONS(207),
    [anon_sym_LT_LT_EQ] = ACTIONS(207),
    [anon_sym_GT_GT_EQ] = ACTIONS(207),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(207),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(207),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(207),
    [anon_sym_if] = ACTIONS(209),
    [anon_sym_SEMI] = ACTIONS(207),
    [anon_sym_when] = ACTIONS(209),
    [anon_sym_in] = ACTIONS(209),
    [anon_sym_case] = ACTIONS(209),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_PLUS] = ACTIONS(209),
    [anon_sym_DASH] = ACTIONS(209),
    [anon_sym_TILDE] = ACTIONS(209),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(209),
    [anon_sym_PIPE_PIPE] = ACTIONS(209),
    [anon_sym_or_else] = ACTIONS(209),
    [anon_sym_AMP_AMP] = ACTIONS(209),
    [anon_sym_GT] = ACTIONS(209),
    [anon_sym_GT_EQ] = ACTIONS(207),
    [anon_sym_LT_EQ] = ACTIONS(207),
    [anon_sym_LT] = ACTIONS(209),
    [anon_sym_EQ_EQ] = ACTIONS(207),
    [anon_sym_BANG_EQ] = ACTIONS(207),
    [anon_sym_TILDE_EQ] = ACTIONS(207),
    [anon_sym_AMP_TILDE] = ACTIONS(209),
    [anon_sym_LT_LT] = ACTIONS(209),
    [anon_sym_GT_GT] = ACTIONS(209),
    [anon_sym_STAR] = ACTIONS(209),
    [anon_sym_SLASH] = ACTIONS(209),
    [anon_sym_PERCENT] = ACTIONS(209),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(207),
    [anon_sym_DOT] = ACTIONS(209),
    [anon_sym_LBRACK] = ACTIONS(207),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(207),
    [anon_sym_DOT_DOT_LT] = ACTIONS(207),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(209),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(209),
    [anon_sym_or_continue] = ACTIONS(209),
    [anon_sym_or_break] = ACTIONS(209),
    [anon_sym_CARET] = ACTIONS(209),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(207),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [30] = {
    [sym_expression] = STATE(2570),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(131),
    [anon_sym_DASH_EQ] = ACTIONS(131),
    [anon_sym_STAR_EQ] = ACTIONS(131),
    [anon_sym_SLASH_EQ] = ACTIONS(131),
    [anon_sym_PERCENT_EQ] = ACTIONS(131),
    [anon_sym_AMP_EQ] = ACTIONS(131),
    [anon_sym_PIPE_EQ] = ACTIONS(131),
    [anon_sym_CARET_EQ] = ACTIONS(131),
    [anon_sym_LT_LT_EQ] = ACTIONS(131),
    [anon_sym_GT_GT_EQ] = ACTIONS(131),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(131),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_case] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(97),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(135),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(135),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(135),
    [anon_sym_LT_LT] = ACTIONS(135),
    [anon_sym_GT_GT] = ACTIONS(135),
    [anon_sym_STAR] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(107),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(135),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(131),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [31] = {
    [sym_expression] = STATE(2417),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_COLON_COLON] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_where] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_PLUS_EQ] = ACTIONS(165),
    [anon_sym_DASH_EQ] = ACTIONS(165),
    [anon_sym_STAR_EQ] = ACTIONS(165),
    [anon_sym_SLASH_EQ] = ACTIONS(165),
    [anon_sym_PERCENT_EQ] = ACTIONS(165),
    [anon_sym_AMP_EQ] = ACTIONS(165),
    [anon_sym_PIPE_EQ] = ACTIONS(165),
    [anon_sym_CARET_EQ] = ACTIONS(165),
    [anon_sym_LT_LT_EQ] = ACTIONS(165),
    [anon_sym_GT_GT_EQ] = ACTIONS(165),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(165),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(165),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_do] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(219),
    [anon_sym_BANG] = ACTIONS(219),
    [anon_sym_AMP] = ACTIONS(219),
    [anon_sym_PIPE_PIPE] = ACTIONS(169),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(169),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(169),
    [anon_sym_LT_LT] = ACTIONS(169),
    [anon_sym_GT_GT] = ACTIONS(169),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(229),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(169),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [32] = {
    [sym_expression] = STATE(2427),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_where] = ACTIONS(135),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(131),
    [anon_sym_DASH_EQ] = ACTIONS(131),
    [anon_sym_STAR_EQ] = ACTIONS(131),
    [anon_sym_SLASH_EQ] = ACTIONS(131),
    [anon_sym_PERCENT_EQ] = ACTIONS(131),
    [anon_sym_AMP_EQ] = ACTIONS(131),
    [anon_sym_PIPE_EQ] = ACTIONS(131),
    [anon_sym_CARET_EQ] = ACTIONS(131),
    [anon_sym_LT_LT_EQ] = ACTIONS(131),
    [anon_sym_GT_GT_EQ] = ACTIONS(131),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(131),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_do] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(219),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(135),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(135),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(135),
    [anon_sym_LT_LT] = ACTIONS(135),
    [anon_sym_GT_GT] = ACTIONS(135),
    [anon_sym_STAR] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(229),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(135),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(131),
    [sym_tag] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [33] = {
    [sym_expression] = STATE(2751),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_PLUS_EQ] = ACTIONS(165),
    [anon_sym_DASH_EQ] = ACTIONS(165),
    [anon_sym_STAR_EQ] = ACTIONS(165),
    [anon_sym_SLASH_EQ] = ACTIONS(165),
    [anon_sym_PERCENT_EQ] = ACTIONS(165),
    [anon_sym_AMP_EQ] = ACTIONS(165),
    [anon_sym_PIPE_EQ] = ACTIONS(165),
    [anon_sym_CARET_EQ] = ACTIONS(165),
    [anon_sym_LT_LT_EQ] = ACTIONS(165),
    [anon_sym_GT_GT_EQ] = ACTIONS(165),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(165),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(165),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_do] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(261),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(261),
    [anon_sym_BANG] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(261),
    [anon_sym_PIPE_PIPE] = ACTIONS(169),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(169),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(169),
    [anon_sym_LT_LT] = ACTIONS(169),
    [anon_sym_GT_GT] = ACTIONS(169),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(271),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(169),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [34] = {
    [sym_expression] = STATE(2752),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(131),
    [anon_sym_DASH_EQ] = ACTIONS(131),
    [anon_sym_STAR_EQ] = ACTIONS(131),
    [anon_sym_SLASH_EQ] = ACTIONS(131),
    [anon_sym_PERCENT_EQ] = ACTIONS(131),
    [anon_sym_AMP_EQ] = ACTIONS(131),
    [anon_sym_PIPE_EQ] = ACTIONS(131),
    [anon_sym_CARET_EQ] = ACTIONS(131),
    [anon_sym_LT_LT_EQ] = ACTIONS(131),
    [anon_sym_GT_GT_EQ] = ACTIONS(131),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(131),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_do] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(135),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(135),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(135),
    [anon_sym_LT_LT] = ACTIONS(135),
    [anon_sym_GT_GT] = ACTIONS(135),
    [anon_sym_STAR] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(271),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(135),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [35] = {
    [sym_expression] = STATE(2772),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(131),
    [anon_sym_DASH_EQ] = ACTIONS(131),
    [anon_sym_STAR_EQ] = ACTIONS(131),
    [anon_sym_SLASH_EQ] = ACTIONS(131),
    [anon_sym_PERCENT_EQ] = ACTIONS(131),
    [anon_sym_AMP_EQ] = ACTIONS(131),
    [anon_sym_PIPE_EQ] = ACTIONS(131),
    [anon_sym_CARET_EQ] = ACTIONS(131),
    [anon_sym_LT_LT_EQ] = ACTIONS(131),
    [anon_sym_GT_GT_EQ] = ACTIONS(131),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(131),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_do] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(135),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(135),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(135),
    [anon_sym_LT_LT] = ACTIONS(135),
    [anon_sym_GT_GT] = ACTIONS(135),
    [anon_sym_STAR] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(301),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(135),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [36] = {
    [sym_expression] = STATE(2903),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_PLUS_EQ] = ACTIONS(131),
    [anon_sym_DASH_EQ] = ACTIONS(131),
    [anon_sym_STAR_EQ] = ACTIONS(131),
    [anon_sym_SLASH_EQ] = ACTIONS(131),
    [anon_sym_PERCENT_EQ] = ACTIONS(131),
    [anon_sym_AMP_EQ] = ACTIONS(131),
    [anon_sym_PIPE_EQ] = ACTIONS(131),
    [anon_sym_CARET_EQ] = ACTIONS(131),
    [anon_sym_LT_LT_EQ] = ACTIONS(131),
    [anon_sym_GT_GT_EQ] = ACTIONS(131),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(131),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(135),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(309),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(135),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(135),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(135),
    [anon_sym_LT_LT] = ACTIONS(135),
    [anon_sym_GT_GT] = ACTIONS(135),
    [anon_sym_STAR] = ACTIONS(135),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(315),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(135),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [37] = {
    [sym_expression] = STATE(2901),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_COLON_COLON] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_PLUS_EQ] = ACTIONS(165),
    [anon_sym_DASH_EQ] = ACTIONS(165),
    [anon_sym_STAR_EQ] = ACTIONS(165),
    [anon_sym_SLASH_EQ] = ACTIONS(165),
    [anon_sym_PERCENT_EQ] = ACTIONS(165),
    [anon_sym_AMP_EQ] = ACTIONS(165),
    [anon_sym_PIPE_EQ] = ACTIONS(165),
    [anon_sym_CARET_EQ] = ACTIONS(165),
    [anon_sym_LT_LT_EQ] = ACTIONS(165),
    [anon_sym_GT_GT_EQ] = ACTIONS(165),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(165),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(165),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(309),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(309),
    [anon_sym_BANG] = ACTIONS(309),
    [anon_sym_AMP] = ACTIONS(309),
    [anon_sym_PIPE_PIPE] = ACTIONS(169),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(169),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(169),
    [anon_sym_LT_LT] = ACTIONS(169),
    [anon_sym_GT_GT] = ACTIONS(169),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(315),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(169),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [38] = {
    [sym_expression] = STATE(4885),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(207),
    [anon_sym_COMMA] = ACTIONS(207),
    [anon_sym_DASH_GT] = ACTIONS(207),
    [anon_sym_EQ] = ACTIONS(209),
    [anon_sym_COLON] = ACTIONS(209),
    [anon_sym_PIPE] = ACTIONS(209),
    [anon_sym_COLON_EQ] = ACTIONS(207),
    [anon_sym_LPAREN] = ACTIONS(207),
    [anon_sym_PLUS_EQ] = ACTIONS(207),
    [anon_sym_DASH_EQ] = ACTIONS(207),
    [anon_sym_STAR_EQ] = ACTIONS(207),
    [anon_sym_SLASH_EQ] = ACTIONS(207),
    [anon_sym_PERCENT_EQ] = ACTIONS(207),
    [anon_sym_AMP_EQ] = ACTIONS(207),
    [anon_sym_PIPE_EQ] = ACTIONS(207),
    [anon_sym_CARET_EQ] = ACTIONS(207),
    [anon_sym_LT_LT_EQ] = ACTIONS(207),
    [anon_sym_GT_GT_EQ] = ACTIONS(207),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(207),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(207),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(207),
    [anon_sym_if] = ACTIONS(209),
    [anon_sym_do] = ACTIONS(209),
    [anon_sym_when] = ACTIONS(209),
    [anon_sym_in] = ACTIONS(209),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_PLUS] = ACTIONS(209),
    [anon_sym_DASH] = ACTIONS(209),
    [anon_sym_TILDE] = ACTIONS(209),
    [anon_sym_BANG] = ACTIONS(349),
    [anon_sym_AMP] = ACTIONS(209),
    [anon_sym_PIPE_PIPE] = ACTIONS(209),
    [anon_sym_or_else] = ACTIONS(209),
    [anon_sym_AMP_AMP] = ACTIONS(209),
    [anon_sym_GT] = ACTIONS(209),
    [anon_sym_GT_EQ] = ACTIONS(207),
    [anon_sym_LT_EQ] = ACTIONS(207),
    [anon_sym_LT] = ACTIONS(209),
    [anon_sym_EQ_EQ] = ACTIONS(207),
    [anon_sym_BANG_EQ] = ACTIONS(207),
    [anon_sym_TILDE_EQ] = ACTIONS(207),
    [anon_sym_AMP_TILDE] = ACTIONS(209),
    [anon_sym_LT_LT] = ACTIONS(209),
    [anon_sym_GT_GT] = ACTIONS(209),
    [anon_sym_STAR] = ACTIONS(209),
    [anon_sym_SLASH] = ACTIONS(209),
    [anon_sym_PERCENT] = ACTIONS(209),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(207),
    [anon_sym_DOT] = ACTIONS(209),
    [anon_sym_LBRACK] = ACTIONS(207),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(207),
    [anon_sym_DOT_DOT_LT] = ACTIONS(207),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_not_in] = ACTIONS(209),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_or_return] = ACTIONS(209),
    [anon_sym_or_continue] = ACTIONS(209),
    [anon_sym_or_break] = ACTIONS(209),
    [anon_sym_CARET] = ACTIONS(209),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [39] = {
    [sym_expression] = STATE(2802),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_PLUS_EQ] = ACTIONS(165),
    [anon_sym_DASH_EQ] = ACTIONS(165),
    [anon_sym_STAR_EQ] = ACTIONS(165),
    [anon_sym_SLASH_EQ] = ACTIONS(165),
    [anon_sym_PERCENT_EQ] = ACTIONS(165),
    [anon_sym_AMP_EQ] = ACTIONS(165),
    [anon_sym_PIPE_EQ] = ACTIONS(165),
    [anon_sym_CARET_EQ] = ACTIONS(165),
    [anon_sym_LT_LT_EQ] = ACTIONS(165),
    [anon_sym_GT_GT_EQ] = ACTIONS(165),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(165),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(165),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_do] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(295),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(295),
    [anon_sym_BANG] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(295),
    [anon_sym_PIPE_PIPE] = ACTIONS(169),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(169),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(169),
    [anon_sym_LT_LT] = ACTIONS(169),
    [anon_sym_GT_GT] = ACTIONS(169),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(301),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(169),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [40] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7548),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(385),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_SEMI] = ACTIONS(385),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_case] = ACTIONS(387),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(393),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(385),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [41] = {
    [sym_expression] = STATE(6021),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(395),
    [anon_sym_LBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_LPAREN] = ACTIONS(397),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_do] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(349),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [42] = {
    [sym_expression] = STATE(6110),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(395),
    [anon_sym_LBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_LPAREN] = ACTIONS(397),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_do] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(349),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [43] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7377),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3053),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_struct_field] = STATE(8000),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(401),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(403),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [44] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7226),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(405),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_case] = ACTIONS(407),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(409),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [45] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7150),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(411),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_case] = ACTIONS(413),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(415),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [46] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7238),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(405),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_case] = ACTIONS(407),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(417),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [47] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7377),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3053),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_struct_field] = STATE(7953),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(401),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(403),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [48] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7377),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3053),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_struct_field] = STATE(8377),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(419),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(403),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [49] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7297),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(421),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_case] = ACTIONS(423),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(425),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [50] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7377),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3053),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_struct_field] = STATE(8077),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(427),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(403),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [51] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7473),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(429),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(431),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [52] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7462),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(433),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(435),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [53] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7377),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(437),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(403),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [54] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7418),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(439),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(441),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [55] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7514),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(443),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(445),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [56] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7410),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(447),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(449),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [57] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7517),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(451),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(453),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [58] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7391),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(455),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(457),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [59] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7474),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(459),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(461),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [60] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7441),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(463),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(465),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [61] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7525),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(467),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(469),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [62] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7414),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(471),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(473),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [63] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7490),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(475),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(477),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [64] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7454),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(479),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(481),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [65] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7479),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(483),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [66] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7511),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(487),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(489),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [67] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7457),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_RBRACE] = ACTIONS(491),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(493),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [68] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7275),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [69] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7270),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [70] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7272),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [71] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7277),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [72] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7291),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [73] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7292),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [74] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7152),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [75] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7122),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [76] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7048),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [77] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7268),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [78] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7275),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [79] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7332),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [80] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7037),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [81] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7273),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [82] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7301),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [83] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7029),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [84] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7149),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [85] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7095),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [86] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7109),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [87] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7174),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [88] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7341),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [89] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7046),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [90] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7134),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [91] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7139),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [92] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7141),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [93] = {
    [sym_expression] = STATE(3230),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_COLON_COLON] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_where] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_RPAREN] = ACTIONS(165),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_do] = ACTIONS(169),
    [anon_sym_else] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(519),
    [anon_sym_BANG] = ACTIONS(519),
    [anon_sym_AMP] = ACTIONS(519),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_RBRACK] = ACTIONS(165),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(529),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [94] = {
    [sym_expression] = STATE(3236),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(131),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_where] = ACTIONS(135),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_RPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_do] = ACTIONS(135),
    [anon_sym_else] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(519),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_RBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(529),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(131),
    [sym_tag] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [95] = {
    [sym_expression] = STATE(3304),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [ts_builtin_sym_end] = ACTIONS(165),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_COLON_COLON] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_where] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_else] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_case] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(563),
    [anon_sym_AMP] = ACTIONS(563),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(573),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(165),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [96] = {
    [sym_expression] = STATE(3309),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [ts_builtin_sym_end] = ACTIONS(131),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(131),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_where] = ACTIONS(135),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_else] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_case] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(563),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(573),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(131),
    [sym_tag] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(131),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [97] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7001),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [98] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7149),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [99] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7174),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [100] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7341),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [101] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7134),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [102] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7139),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [103] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7141),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [104] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7143),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [105] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7147),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [106] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7270),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [107] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7272),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [108] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7277),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [109] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7291),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [110] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7292),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [111] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7268),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [112] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7143),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [113] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7332),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [114] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7301),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [115] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7147),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3302),
    [sym__expression_no_tag] = STATE(2561),
    [sym_unary_expression] = STATE(2561),
    [sym_binary_expression] = STATE(2561),
    [sym_ternary_expression] = STATE(2561),
    [sym_call_expression] = STATE(2561),
    [sym_selector_call_expression] = STATE(2561),
    [sym_member_expression] = STATE(2561),
    [sym_index_expression] = STATE(2561),
    [sym_slice_expression] = STATE(2561),
    [sym_range_expression] = STATE(2561),
    [sym_cast_expression] = STATE(2561),
    [sym_in_expression] = STATE(2561),
    [sym_variadic_expression] = STATE(2561),
    [sym_parenthesized_expression] = STATE(2561),
    [sym_or_return_expression] = STATE(2561),
    [sym_or_continue_expression] = STATE(2561),
    [sym_or_break_expression] = STATE(2561),
    [sym_address] = STATE(2561),
    [sym_map_type] = STATE(2561),
    [sym_matrix_type] = STATE(2561),
    [sym_distinct_type] = STATE(2561),
    [sym_literal] = STATE(2561),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_when] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(81),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [116] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(6961),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [117] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7152),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [118] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(6979),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [119] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(6940),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [120] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(6944),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [121] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(6947),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [122] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7041),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [123] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(6970),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [124] = {
    [sym_block] = STATE(7164),
    [sym_tagged_block] = STATE(7164),
    [sym_import_declaration] = STATE(7164),
    [sym_procedure_declaration] = STATE(7164),
    [sym_overloaded_procedure_declaration] = STATE(7164),
    [sym_struct_declaration] = STATE(7164),
    [sym_enum_declaration] = STATE(7164),
    [sym_union_declaration] = STATE(7164),
    [sym_bit_field_declaration] = STATE(7164),
    [sym_const_declaration] = STATE(7164),
    [sym_foreign_block] = STATE(7164),
    [sym_attributes] = STATE(741),
    [sym_attribute] = STATE(6180),
    [sym_statement] = STATE(7122),
    [sym_assignment_statement] = STATE(7164),
    [sym_update_statement] = STATE(7164),
    [sym_if_statement] = STATE(7164),
    [sym_when_statement] = STATE(7164),
    [sym_for_statement] = STATE(7164),
    [sym_switch_statement] = STATE(7164),
    [sym_defer_statement] = STATE(7164),
    [sym_break_statement] = STATE(7164),
    [sym_continue_statement] = STATE(7164),
    [sym_var_declaration] = STATE(7164),
    [sym_return_statement] = STATE(7164),
    [sym_label_statement] = STATE(7164),
    [sym_using_statement] = STATE(7164),
    [sym_expression] = STATE(3404),
    [sym__expression_no_tag] = STATE(2261),
    [sym_unary_expression] = STATE(2261),
    [sym_binary_expression] = STATE(2261),
    [sym_ternary_expression] = STATE(2261),
    [sym_call_expression] = STATE(2261),
    [sym_selector_call_expression] = STATE(2261),
    [sym_member_expression] = STATE(2261),
    [sym_index_expression] = STATE(2261),
    [sym_slice_expression] = STATE(2261),
    [sym_range_expression] = STATE(2261),
    [sym_cast_expression] = STATE(2261),
    [sym_in_expression] = STATE(2261),
    [sym_variadic_expression] = STATE(2261),
    [sym_parenthesized_expression] = STATE(2261),
    [sym_or_return_expression] = STATE(2261),
    [sym_or_continue_expression] = STATE(2261),
    [sym_or_break_expression] = STATE(2261),
    [sym_address] = STATE(2261),
    [sym_map_type] = STATE(2261),
    [sym_matrix_type] = STATE(2261),
    [sym_distinct_type] = STATE(2261),
    [sym_literal] = STATE(2261),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(71),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_if] = ACTIONS(495),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(497),
    [anon_sym_switch] = ACTIONS(83),
    [anon_sym_defer] = ACTIONS(499),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_continue] = ACTIONS(89),
    [sym_fallthrough_statement] = ACTIONS(91),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(501),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [125] = {
    [sym_procedure] = STATE(7331),
    [sym_expression] = STATE(4955),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_pointer_type] = STATE(7014),
    [sym_array_type] = STATE(7014),
    [sym_map_type] = STATE(4697),
    [sym_bit_set_type] = STATE(7014),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(69),
    [sym_identifier] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_POUNDtype] = ACTIONS(601),
    [anon_sym_LPAREN] = ACTIONS(603),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(609),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(617),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(619),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [126] = {
    [sym_procedure] = STATE(7208),
    [sym_expression] = STATE(4958),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_pointer_type] = STATE(7007),
    [sym_array_type] = STATE(7007),
    [sym_map_type] = STATE(4697),
    [sym_bit_set_type] = STATE(7007),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(69),
    [sym_identifier] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_POUNDtype] = ACTIONS(621),
    [anon_sym_LPAREN] = ACTIONS(603),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(609),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(617),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(619),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [127] = {
    [sym_expression] = STATE(3663),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [ts_builtin_sym_end] = ACTIONS(131),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(131),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_where] = ACTIONS(135),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_else] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_case] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(625),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(631),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(131),
    [sym_tag] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(131),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(131),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [128] = {
    [sym_expression] = STATE(4181),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(131),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_else] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_case] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(31),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(653),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(131),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [129] = {
    [sym_expression] = STATE(4261),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_COLON_COLON] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(165),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_else] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(667),
    [anon_sym_BANG] = ACTIONS(667),
    [anon_sym_AMP] = ACTIONS(667),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(165),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(677),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [130] = {
    [sym_expression] = STATE(4215),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_RPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_else] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(667),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_RBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(677),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [131] = {
    [sym_expression] = STATE(4183),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(165),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_COLON_COLON] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_else] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_case] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_BANG] = ACTIONS(31),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(653),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(165),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [132] = {
    [sym_expression] = STATE(3657),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [ts_builtin_sym_end] = ACTIONS(165),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_where] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_else] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_case] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(625),
    [anon_sym_BANG] = ACTIONS(625),
    [anon_sym_AMP] = ACTIONS(625),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(631),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(165),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(165),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [133] = {
    [sym_procedure] = STATE(4572),
    [sym_expression] = STATE(4914),
    [sym__expression_no_tag] = STATE(4543),
    [sym_unary_expression] = STATE(4543),
    [sym_binary_expression] = STATE(4543),
    [sym_ternary_expression] = STATE(4543),
    [sym_call_expression] = STATE(4543),
    [sym_selector_call_expression] = STATE(4543),
    [sym_member_expression] = STATE(4543),
    [sym_index_expression] = STATE(4543),
    [sym_slice_expression] = STATE(4543),
    [sym_range_expression] = STATE(4543),
    [sym_cast_expression] = STATE(4543),
    [sym_in_expression] = STATE(4543),
    [sym_variadic_expression] = STATE(4543),
    [sym_parenthesized_expression] = STATE(4543),
    [sym_or_return_expression] = STATE(4543),
    [sym_or_continue_expression] = STATE(4543),
    [sym_or_break_expression] = STATE(4543),
    [sym_address] = STATE(4543),
    [sym_map_type] = STATE(4543),
    [sym_matrix_type] = STATE(4543),
    [sym__procedure_type] = STATE(6967),
    [sym_distinct_type] = STATE(4543),
    [sym_literal] = STATE(4543),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [ts_builtin_sym_end] = ACTIONS(717),
    [sym_identifier] = ACTIONS(719),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(717),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(723),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(725),
    [anon_sym_SEMI] = ACTIONS(717),
    [anon_sym_else] = ACTIONS(727),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(727),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(733),
    [anon_sym_BANG] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(733),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(743),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(69),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [134] = {
    [sym_procedure] = STATE(719),
    [sym_type] = STATE(832),
    [sym_pointer_type] = STATE(802),
    [sym_variadic_type] = STATE(802),
    [sym_array_type] = STATE(802),
    [sym_map_type] = STATE(802),
    [sym_union_type] = STATE(802),
    [sym_bit_set_type] = STATE(802),
    [sym_matrix_type] = STATE(802),
    [sym_field_type] = STATE(802),
    [sym_tuple_type] = STATE(802),
    [sym_struct_type] = STATE(802),
    [sym_enum_type] = STATE(802),
    [sym_bit_field_type] = STATE(802),
    [sym_constant_type] = STATE(802),
    [sym_specialized_type] = STATE(802),
    [sym__procedure_type] = STATE(802),
    [sym_distinct_type] = STATE(802),
    [sym_empty_type] = STATE(802),
    [sym_polymorphic_type] = STATE(802),
    [sym_conditional_type] = STATE(802),
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(769),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(771),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_where] = ACTIONS(773),
    [anon_sym_struct] = ACTIONS(775),
    [anon_sym_enum] = ACTIONS(777),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(779),
    [anon_sym_bit_field] = ACTIONS(781),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(783),
    [anon_sym_DOLLAR] = ACTIONS(786),
    [anon_sym_PLUS_EQ] = ACTIONS(767),
    [anon_sym_DASH_EQ] = ACTIONS(767),
    [anon_sym_STAR_EQ] = ACTIONS(767),
    [anon_sym_SLASH_EQ] = ACTIONS(767),
    [anon_sym_PERCENT_EQ] = ACTIONS(767),
    [anon_sym_AMP_EQ] = ACTIONS(767),
    [anon_sym_PIPE_EQ] = ACTIONS(767),
    [anon_sym_CARET_EQ] = ACTIONS(767),
    [anon_sym_LT_LT_EQ] = ACTIONS(767),
    [anon_sym_GT_GT_EQ] = ACTIONS(767),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(767),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_case] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(788),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(773),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(773),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(790),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(793),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(795),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(798),
    [anon_sym_map] = ACTIONS(800),
    [anon_sym_bit_set] = ACTIONS(802),
    [anon_sym_matrix] = ACTIONS(804),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_uninitialized] = ACTIONS(767),
    [sym_tag] = ACTIONS(806),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [135] = {
    [sym_procedure] = STATE(719),
    [sym_type] = STATE(837),
    [sym_pointer_type] = STATE(802),
    [sym_variadic_type] = STATE(802),
    [sym_array_type] = STATE(802),
    [sym_map_type] = STATE(802),
    [sym_union_type] = STATE(802),
    [sym_bit_set_type] = STATE(802),
    [sym_matrix_type] = STATE(802),
    [sym_field_type] = STATE(802),
    [sym_tuple_type] = STATE(802),
    [sym_struct_type] = STATE(802),
    [sym_enum_type] = STATE(802),
    [sym_bit_field_type] = STATE(802),
    [sym_constant_type] = STATE(802),
    [sym_specialized_type] = STATE(802),
    [sym__procedure_type] = STATE(802),
    [sym_distinct_type] = STATE(802),
    [sym_empty_type] = STATE(802),
    [sym_polymorphic_type] = STATE(802),
    [sym_conditional_type] = STATE(802),
    [ts_builtin_sym_end] = ACTIONS(809),
    [sym_identifier] = ACTIONS(769),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(771),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_where] = ACTIONS(812),
    [anon_sym_struct] = ACTIONS(775),
    [anon_sym_enum] = ACTIONS(777),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(779),
    [anon_sym_bit_field] = ACTIONS(781),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(815),
    [anon_sym_DOLLAR] = ACTIONS(786),
    [anon_sym_PLUS_EQ] = ACTIONS(809),
    [anon_sym_DASH_EQ] = ACTIONS(809),
    [anon_sym_STAR_EQ] = ACTIONS(809),
    [anon_sym_SLASH_EQ] = ACTIONS(809),
    [anon_sym_PERCENT_EQ] = ACTIONS(809),
    [anon_sym_AMP_EQ] = ACTIONS(809),
    [anon_sym_PIPE_EQ] = ACTIONS(809),
    [anon_sym_CARET_EQ] = ACTIONS(809),
    [anon_sym_LT_LT_EQ] = ACTIONS(809),
    [anon_sym_GT_GT_EQ] = ACTIONS(809),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(809),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_case] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(812),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(788),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(812),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(812),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(812),
    [anon_sym_LT_LT] = ACTIONS(812),
    [anon_sym_GT_GT] = ACTIONS(812),
    [anon_sym_STAR] = ACTIONS(812),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(819),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(793),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(823),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(798),
    [anon_sym_map] = ACTIONS(800),
    [anon_sym_bit_set] = ACTIONS(802),
    [anon_sym_matrix] = ACTIONS(804),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_uninitialized] = ACTIONS(809),
    [sym_tag] = ACTIONS(827),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [136] = {
    [sym_expression] = STATE(4969),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_pointer_type] = STATE(7038),
    [sym_array_type] = STATE(7038),
    [sym_map_type] = STATE(4697),
    [sym_bit_set_type] = STATE(7038),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(69),
    [sym_identifier] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_POUNDtype] = ACTIONS(831),
    [anon_sym_LPAREN] = ACTIONS(603),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(609),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(617),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(619),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [137] = {
    [sym_expression] = STATE(4955),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_pointer_type] = STATE(7014),
    [sym_array_type] = STATE(7014),
    [sym_map_type] = STATE(4697),
    [sym_bit_set_type] = STATE(7014),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(69),
    [sym_identifier] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_POUNDtype] = ACTIONS(601),
    [anon_sym_LPAREN] = ACTIONS(603),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(609),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(617),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(619),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [138] = {
    [sym_procedure] = STATE(719),
    [sym_type] = STATE(870),
    [sym_pointer_type] = STATE(802),
    [sym_variadic_type] = STATE(802),
    [sym_array_type] = STATE(802),
    [sym_map_type] = STATE(802),
    [sym_union_type] = STATE(802),
    [sym_bit_set_type] = STATE(802),
    [sym_matrix_type] = STATE(802),
    [sym_field_type] = STATE(802),
    [sym_tuple_type] = STATE(802),
    [sym_struct_type] = STATE(802),
    [sym_enum_type] = STATE(802),
    [sym_bit_field_type] = STATE(802),
    [sym_constant_type] = STATE(802),
    [sym_specialized_type] = STATE(802),
    [sym__procedure_type] = STATE(802),
    [sym_distinct_type] = STATE(802),
    [sym_empty_type] = STATE(802),
    [sym_polymorphic_type] = STATE(802),
    [sym_conditional_type] = STATE(802),
    [ts_builtin_sym_end] = ACTIONS(833),
    [sym_identifier] = ACTIONS(769),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(771),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_where] = ACTIONS(836),
    [anon_sym_struct] = ACTIONS(775),
    [anon_sym_enum] = ACTIONS(777),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(779),
    [anon_sym_bit_field] = ACTIONS(781),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(839),
    [anon_sym_DOLLAR] = ACTIONS(786),
    [anon_sym_PLUS_EQ] = ACTIONS(833),
    [anon_sym_DASH_EQ] = ACTIONS(833),
    [anon_sym_STAR_EQ] = ACTIONS(833),
    [anon_sym_SLASH_EQ] = ACTIONS(833),
    [anon_sym_PERCENT_EQ] = ACTIONS(833),
    [anon_sym_AMP_EQ] = ACTIONS(833),
    [anon_sym_PIPE_EQ] = ACTIONS(833),
    [anon_sym_CARET_EQ] = ACTIONS(833),
    [anon_sym_LT_LT_EQ] = ACTIONS(833),
    [anon_sym_GT_GT_EQ] = ACTIONS(833),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(833),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(833),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(788),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(836),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(836),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(843),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(793),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(798),
    [anon_sym_map] = ACTIONS(800),
    [anon_sym_bit_set] = ACTIONS(802),
    [anon_sym_matrix] = ACTIONS(804),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_uninitialized] = ACTIONS(833),
    [sym_tag] = ACTIONS(851),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(833),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [139] = {
    [sym_procedure] = STATE(719),
    [sym_type] = STATE(797),
    [sym_pointer_type] = STATE(802),
    [sym_variadic_type] = STATE(802),
    [sym_array_type] = STATE(802),
    [sym_map_type] = STATE(802),
    [sym_union_type] = STATE(802),
    [sym_bit_set_type] = STATE(802),
    [sym_matrix_type] = STATE(802),
    [sym_field_type] = STATE(802),
    [sym_tuple_type] = STATE(802),
    [sym_struct_type] = STATE(802),
    [sym_enum_type] = STATE(802),
    [sym_bit_field_type] = STATE(802),
    [sym_constant_type] = STATE(802),
    [sym_specialized_type] = STATE(802),
    [sym__procedure_type] = STATE(802),
    [sym_distinct_type] = STATE(802),
    [sym_empty_type] = STATE(802),
    [sym_polymorphic_type] = STATE(802),
    [sym_conditional_type] = STATE(802),
    [ts_builtin_sym_end] = ACTIONS(855),
    [sym_identifier] = ACTIONS(769),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(771),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_where] = ACTIONS(857),
    [anon_sym_struct] = ACTIONS(775),
    [anon_sym_enum] = ACTIONS(777),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(779),
    [anon_sym_bit_field] = ACTIONS(781),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(859),
    [anon_sym_DOLLAR] = ACTIONS(786),
    [anon_sym_PLUS_EQ] = ACTIONS(855),
    [anon_sym_DASH_EQ] = ACTIONS(855),
    [anon_sym_STAR_EQ] = ACTIONS(855),
    [anon_sym_SLASH_EQ] = ACTIONS(855),
    [anon_sym_PERCENT_EQ] = ACTIONS(855),
    [anon_sym_AMP_EQ] = ACTIONS(855),
    [anon_sym_PIPE_EQ] = ACTIONS(855),
    [anon_sym_CARET_EQ] = ACTIONS(855),
    [anon_sym_LT_LT_EQ] = ACTIONS(855),
    [anon_sym_GT_GT_EQ] = ACTIONS(855),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(855),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(855),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(857),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(788),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(857),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(857),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(862),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(793),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(865),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(798),
    [anon_sym_map] = ACTIONS(800),
    [anon_sym_bit_set] = ACTIONS(802),
    [anon_sym_matrix] = ACTIONS(804),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_uninitialized] = ACTIONS(855),
    [sym_tag] = ACTIONS(868),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(855),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [140] = {
    [sym_procedure] = STATE(719),
    [sym_type] = STATE(841),
    [sym_pointer_type] = STATE(802),
    [sym_variadic_type] = STATE(802),
    [sym_array_type] = STATE(802),
    [sym_map_type] = STATE(802),
    [sym_union_type] = STATE(802),
    [sym_bit_set_type] = STATE(802),
    [sym_matrix_type] = STATE(802),
    [sym_field_type] = STATE(802),
    [sym_tuple_type] = STATE(802),
    [sym_struct_type] = STATE(802),
    [sym_enum_type] = STATE(802),
    [sym_bit_field_type] = STATE(802),
    [sym_constant_type] = STATE(802),
    [sym_specialized_type] = STATE(802),
    [sym__procedure_type] = STATE(802),
    [sym_distinct_type] = STATE(802),
    [sym_empty_type] = STATE(802),
    [sym_polymorphic_type] = STATE(802),
    [sym_conditional_type] = STATE(802),
    [ts_builtin_sym_end] = ACTIONS(871),
    [sym_identifier] = ACTIONS(769),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(771),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_where] = ACTIONS(874),
    [anon_sym_struct] = ACTIONS(775),
    [anon_sym_enum] = ACTIONS(777),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(779),
    [anon_sym_bit_field] = ACTIONS(781),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(877),
    [anon_sym_DOLLAR] = ACTIONS(786),
    [anon_sym_PLUS_EQ] = ACTIONS(871),
    [anon_sym_DASH_EQ] = ACTIONS(871),
    [anon_sym_STAR_EQ] = ACTIONS(871),
    [anon_sym_SLASH_EQ] = ACTIONS(871),
    [anon_sym_PERCENT_EQ] = ACTIONS(871),
    [anon_sym_AMP_EQ] = ACTIONS(871),
    [anon_sym_PIPE_EQ] = ACTIONS(871),
    [anon_sym_CARET_EQ] = ACTIONS(871),
    [anon_sym_LT_LT_EQ] = ACTIONS(871),
    [anon_sym_GT_GT_EQ] = ACTIONS(871),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(871),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(871),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_case] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(874),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(788),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(874),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(874),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(874),
    [anon_sym_LT_LT] = ACTIONS(874),
    [anon_sym_GT_GT] = ACTIONS(874),
    [anon_sym_STAR] = ACTIONS(874),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(881),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(793),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(885),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(798),
    [anon_sym_map] = ACTIONS(800),
    [anon_sym_bit_set] = ACTIONS(802),
    [anon_sym_matrix] = ACTIONS(804),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_uninitialized] = ACTIONS(871),
    [sym_tag] = ACTIONS(889),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [141] = {
    [sym_procedure] = STATE(719),
    [sym_type] = STATE(706),
    [sym_pointer_type] = STATE(802),
    [sym_variadic_type] = STATE(802),
    [sym_array_type] = STATE(802),
    [sym_map_type] = STATE(802),
    [sym_union_type] = STATE(802),
    [sym_bit_set_type] = STATE(802),
    [sym_matrix_type] = STATE(802),
    [sym_field_type] = STATE(802),
    [sym_tuple_type] = STATE(802),
    [sym_struct_type] = STATE(802),
    [sym_enum_type] = STATE(802),
    [sym_bit_field_type] = STATE(802),
    [sym_constant_type] = STATE(802),
    [sym_specialized_type] = STATE(802),
    [sym__procedure_type] = STATE(802),
    [sym_distinct_type] = STATE(802),
    [sym_empty_type] = STATE(802),
    [sym_polymorphic_type] = STATE(802),
    [sym_conditional_type] = STATE(802),
    [ts_builtin_sym_end] = ACTIONS(893),
    [sym_identifier] = ACTIONS(769),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(771),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_where] = ACTIONS(895),
    [anon_sym_struct] = ACTIONS(775),
    [anon_sym_enum] = ACTIONS(777),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(779),
    [anon_sym_bit_field] = ACTIONS(781),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(897),
    [anon_sym_DOLLAR] = ACTIONS(786),
    [anon_sym_PLUS_EQ] = ACTIONS(893),
    [anon_sym_DASH_EQ] = ACTIONS(893),
    [anon_sym_STAR_EQ] = ACTIONS(893),
    [anon_sym_SLASH_EQ] = ACTIONS(893),
    [anon_sym_PERCENT_EQ] = ACTIONS(893),
    [anon_sym_AMP_EQ] = ACTIONS(893),
    [anon_sym_PIPE_EQ] = ACTIONS(893),
    [anon_sym_CARET_EQ] = ACTIONS(893),
    [anon_sym_LT_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_GT_EQ] = ACTIONS(893),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(893),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_case] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(788),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(895),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(895),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(900),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(793),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(903),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(798),
    [anon_sym_map] = ACTIONS(800),
    [anon_sym_bit_set] = ACTIONS(802),
    [anon_sym_matrix] = ACTIONS(804),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_uninitialized] = ACTIONS(893),
    [sym_tag] = ACTIONS(906),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [142] = {
    [sym_procedure] = STATE(719),
    [sym_type] = STATE(709),
    [sym_pointer_type] = STATE(802),
    [sym_variadic_type] = STATE(802),
    [sym_array_type] = STATE(802),
    [sym_map_type] = STATE(802),
    [sym_union_type] = STATE(802),
    [sym_bit_set_type] = STATE(802),
    [sym_matrix_type] = STATE(802),
    [sym_field_type] = STATE(802),
    [sym_tuple_type] = STATE(802),
    [sym_struct_type] = STATE(802),
    [sym_enum_type] = STATE(802),
    [sym_bit_field_type] = STATE(802),
    [sym_constant_type] = STATE(802),
    [sym_specialized_type] = STATE(802),
    [sym__procedure_type] = STATE(802),
    [sym_distinct_type] = STATE(802),
    [sym_empty_type] = STATE(802),
    [sym_polymorphic_type] = STATE(802),
    [sym_conditional_type] = STATE(802),
    [ts_builtin_sym_end] = ACTIONS(909),
    [sym_identifier] = ACTIONS(769),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(771),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_where] = ACTIONS(911),
    [anon_sym_struct] = ACTIONS(775),
    [anon_sym_enum] = ACTIONS(777),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(779),
    [anon_sym_bit_field] = ACTIONS(781),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(913),
    [anon_sym_DOLLAR] = ACTIONS(786),
    [anon_sym_PLUS_EQ] = ACTIONS(909),
    [anon_sym_DASH_EQ] = ACTIONS(909),
    [anon_sym_STAR_EQ] = ACTIONS(909),
    [anon_sym_SLASH_EQ] = ACTIONS(909),
    [anon_sym_PERCENT_EQ] = ACTIONS(909),
    [anon_sym_AMP_EQ] = ACTIONS(909),
    [anon_sym_PIPE_EQ] = ACTIONS(909),
    [anon_sym_CARET_EQ] = ACTIONS(909),
    [anon_sym_LT_LT_EQ] = ACTIONS(909),
    [anon_sym_GT_GT_EQ] = ACTIONS(909),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(909),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(909),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_case] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(911),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(788),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(911),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(911),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(911),
    [anon_sym_LT_LT] = ACTIONS(911),
    [anon_sym_GT_GT] = ACTIONS(911),
    [anon_sym_STAR] = ACTIONS(911),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(916),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(793),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(919),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(798),
    [anon_sym_map] = ACTIONS(800),
    [anon_sym_bit_set] = ACTIONS(802),
    [anon_sym_matrix] = ACTIONS(804),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_uninitialized] = ACTIONS(909),
    [sym_tag] = ACTIONS(922),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [143] = {
    [sym_expression] = STATE(4611),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [ts_builtin_sym_end] = ACTIONS(207),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(207),
    [anon_sym_COMMA] = ACTIONS(207),
    [anon_sym_DASH_GT] = ACTIONS(207),
    [anon_sym_PIPE] = ACTIONS(209),
    [anon_sym_LPAREN] = ACTIONS(207),
    [anon_sym_if] = ACTIONS(209),
    [anon_sym_SEMI] = ACTIONS(207),
    [anon_sym_else] = ACTIONS(209),
    [anon_sym_when] = ACTIONS(209),
    [anon_sym_in] = ACTIONS(209),
    [anon_sym_case] = ACTIONS(209),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_PLUS] = ACTIONS(207),
    [anon_sym_DASH] = ACTIONS(209),
    [anon_sym_TILDE] = ACTIONS(209),
    [anon_sym_BANG] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(209),
    [anon_sym_PIPE_PIPE] = ACTIONS(207),
    [anon_sym_or_else] = ACTIONS(209),
    [anon_sym_AMP_AMP] = ACTIONS(207),
    [anon_sym_GT] = ACTIONS(209),
    [anon_sym_GT_EQ] = ACTIONS(207),
    [anon_sym_LT_EQ] = ACTIONS(207),
    [anon_sym_LT] = ACTIONS(209),
    [anon_sym_EQ_EQ] = ACTIONS(207),
    [anon_sym_BANG_EQ] = ACTIONS(207),
    [anon_sym_TILDE_EQ] = ACTIONS(207),
    [anon_sym_AMP_TILDE] = ACTIONS(207),
    [anon_sym_LT_LT] = ACTIONS(207),
    [anon_sym_GT_GT] = ACTIONS(207),
    [anon_sym_STAR] = ACTIONS(207),
    [anon_sym_SLASH] = ACTIONS(209),
    [anon_sym_PERCENT] = ACTIONS(209),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(207),
    [anon_sym_DOT] = ACTIONS(209),
    [anon_sym_LBRACK] = ACTIONS(207),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(207),
    [anon_sym_DOT_DOT_LT] = ACTIONS(207),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_not_in] = ACTIONS(209),
    [anon_sym_DOT_DOT] = ACTIONS(743),
    [anon_sym_or_return] = ACTIONS(209),
    [anon_sym_or_continue] = ACTIONS(209),
    [anon_sym_or_break] = ACTIONS(209),
    [anon_sym_CARET] = ACTIONS(207),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(207),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(207),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [144] = {
    [sym_expression] = STATE(4611),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [ts_builtin_sym_end] = ACTIONS(131),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_else] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_case] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(743),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(131),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(131),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [145] = {
    [sym_expression] = STATE(4604),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [ts_builtin_sym_end] = ACTIONS(165),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_else] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_case] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(733),
    [anon_sym_BANG] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(733),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(743),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(165),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(165),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [146] = {
    [sym_procedure] = STATE(7027),
    [sym_expression] = STATE(4957),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(69),
    [sym_identifier] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(603),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(607),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [147] = {
    [sym_expression] = STATE(4720),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(165),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_else] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_case] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(607),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(165),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [148] = {
    [sym_procedure] = STATE(7000),
    [sym_expression] = STATE(4959),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(69),
    [sym_identifier] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(603),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(607),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [149] = {
    [sym_expression] = STATE(4722),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(131),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_else] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_case] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(131),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [150] = {
    [sym_procedure] = STATE(6997),
    [sym_expression] = STATE(4960),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(69),
    [sym_identifier] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(603),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(607),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [151] = {
    [sym_procedure] = STATE(2182),
    [sym_type] = STATE(1958),
    [sym_pointer_type] = STATE(1624),
    [sym_variadic_type] = STATE(1624),
    [sym_array_type] = STATE(1624),
    [sym_map_type] = STATE(1624),
    [sym_union_type] = STATE(1624),
    [sym_bit_set_type] = STATE(1624),
    [sym_matrix_type] = STATE(1624),
    [sym_field_type] = STATE(1624),
    [sym_tuple_type] = STATE(1624),
    [sym_struct_type] = STATE(1624),
    [sym_enum_type] = STATE(1624),
    [sym_bit_field_type] = STATE(1624),
    [sym_constant_type] = STATE(1624),
    [sym_specialized_type] = STATE(1624),
    [sym__procedure_type] = STATE(1624),
    [sym_distinct_type] = STATE(1624),
    [sym_empty_type] = STATE(1624),
    [sym_polymorphic_type] = STATE(1624),
    [sym_conditional_type] = STATE(1624),
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(943),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(945),
    [anon_sym_enum] = ACTIONS(947),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(949),
    [anon_sym_bit_field] = ACTIONS(951),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(953),
    [anon_sym_DOLLAR] = ACTIONS(956),
    [anon_sym_PLUS_EQ] = ACTIONS(767),
    [anon_sym_DASH_EQ] = ACTIONS(767),
    [anon_sym_STAR_EQ] = ACTIONS(767),
    [anon_sym_SLASH_EQ] = ACTIONS(767),
    [anon_sym_PERCENT_EQ] = ACTIONS(767),
    [anon_sym_AMP_EQ] = ACTIONS(767),
    [anon_sym_PIPE_EQ] = ACTIONS(767),
    [anon_sym_CARET_EQ] = ACTIONS(767),
    [anon_sym_LT_LT_EQ] = ACTIONS(767),
    [anon_sym_GT_GT_EQ] = ACTIONS(767),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(767),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_case] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(958),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(773),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(773),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(960),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(963),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(965),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(968),
    [anon_sym_map] = ACTIONS(970),
    [anon_sym_bit_set] = ACTIONS(972),
    [anon_sym_matrix] = ACTIONS(974),
    [anon_sym_distinct] = ACTIONS(976),
    [sym_tag] = ACTIONS(978),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [152] = {
    [sym_procedure] = STATE(2182),
    [sym_type] = STATE(2003),
    [sym_pointer_type] = STATE(1624),
    [sym_variadic_type] = STATE(1624),
    [sym_array_type] = STATE(1624),
    [sym_map_type] = STATE(1624),
    [sym_union_type] = STATE(1624),
    [sym_bit_set_type] = STATE(1624),
    [sym_matrix_type] = STATE(1624),
    [sym_field_type] = STATE(1624),
    [sym_tuple_type] = STATE(1624),
    [sym_struct_type] = STATE(1624),
    [sym_enum_type] = STATE(1624),
    [sym_bit_field_type] = STATE(1624),
    [sym_constant_type] = STATE(1624),
    [sym_specialized_type] = STATE(1624),
    [sym__procedure_type] = STATE(1624),
    [sym_distinct_type] = STATE(1624),
    [sym_empty_type] = STATE(1624),
    [sym_polymorphic_type] = STATE(1624),
    [sym_conditional_type] = STATE(1624),
    [ts_builtin_sym_end] = ACTIONS(855),
    [sym_identifier] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(943),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_struct] = ACTIONS(945),
    [anon_sym_enum] = ACTIONS(947),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(949),
    [anon_sym_bit_field] = ACTIONS(951),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(980),
    [anon_sym_DOLLAR] = ACTIONS(956),
    [anon_sym_PLUS_EQ] = ACTIONS(855),
    [anon_sym_DASH_EQ] = ACTIONS(855),
    [anon_sym_STAR_EQ] = ACTIONS(855),
    [anon_sym_SLASH_EQ] = ACTIONS(855),
    [anon_sym_PERCENT_EQ] = ACTIONS(855),
    [anon_sym_AMP_EQ] = ACTIONS(855),
    [anon_sym_PIPE_EQ] = ACTIONS(855),
    [anon_sym_CARET_EQ] = ACTIONS(855),
    [anon_sym_LT_LT_EQ] = ACTIONS(855),
    [anon_sym_GT_GT_EQ] = ACTIONS(855),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(855),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(855),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(857),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(958),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(857),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(857),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(983),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(963),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(986),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(968),
    [anon_sym_map] = ACTIONS(970),
    [anon_sym_bit_set] = ACTIONS(972),
    [anon_sym_matrix] = ACTIONS(974),
    [anon_sym_distinct] = ACTIONS(976),
    [sym_tag] = ACTIONS(978),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(855),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [153] = {
    [sym_procedure] = STATE(2182),
    [sym_type] = STATE(1458),
    [sym_pointer_type] = STATE(1624),
    [sym_variadic_type] = STATE(1624),
    [sym_array_type] = STATE(1624),
    [sym_map_type] = STATE(1624),
    [sym_union_type] = STATE(1624),
    [sym_bit_set_type] = STATE(1624),
    [sym_matrix_type] = STATE(1624),
    [sym_field_type] = STATE(1624),
    [sym_tuple_type] = STATE(1624),
    [sym_struct_type] = STATE(1624),
    [sym_enum_type] = STATE(1624),
    [sym_bit_field_type] = STATE(1624),
    [sym_constant_type] = STATE(1624),
    [sym_specialized_type] = STATE(1624),
    [sym__procedure_type] = STATE(1624),
    [sym_distinct_type] = STATE(1624),
    [sym_empty_type] = STATE(1624),
    [sym_polymorphic_type] = STATE(1624),
    [sym_conditional_type] = STATE(1624),
    [ts_builtin_sym_end] = ACTIONS(893),
    [sym_identifier] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(943),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(945),
    [anon_sym_enum] = ACTIONS(947),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(949),
    [anon_sym_bit_field] = ACTIONS(951),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(989),
    [anon_sym_DOLLAR] = ACTIONS(956),
    [anon_sym_PLUS_EQ] = ACTIONS(893),
    [anon_sym_DASH_EQ] = ACTIONS(893),
    [anon_sym_STAR_EQ] = ACTIONS(893),
    [anon_sym_SLASH_EQ] = ACTIONS(893),
    [anon_sym_PERCENT_EQ] = ACTIONS(893),
    [anon_sym_AMP_EQ] = ACTIONS(893),
    [anon_sym_PIPE_EQ] = ACTIONS(893),
    [anon_sym_CARET_EQ] = ACTIONS(893),
    [anon_sym_LT_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_GT_EQ] = ACTIONS(893),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(893),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_case] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(958),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(895),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(895),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(992),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(963),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(995),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(968),
    [anon_sym_map] = ACTIONS(970),
    [anon_sym_bit_set] = ACTIONS(972),
    [anon_sym_matrix] = ACTIONS(974),
    [anon_sym_distinct] = ACTIONS(976),
    [sym_tag] = ACTIONS(978),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [154] = {
    [sym_procedure] = STATE(2182),
    [sym_type] = STATE(1460),
    [sym_pointer_type] = STATE(1624),
    [sym_variadic_type] = STATE(1624),
    [sym_array_type] = STATE(1624),
    [sym_map_type] = STATE(1624),
    [sym_union_type] = STATE(1624),
    [sym_bit_set_type] = STATE(1624),
    [sym_matrix_type] = STATE(1624),
    [sym_field_type] = STATE(1624),
    [sym_tuple_type] = STATE(1624),
    [sym_struct_type] = STATE(1624),
    [sym_enum_type] = STATE(1624),
    [sym_bit_field_type] = STATE(1624),
    [sym_constant_type] = STATE(1624),
    [sym_specialized_type] = STATE(1624),
    [sym__procedure_type] = STATE(1624),
    [sym_distinct_type] = STATE(1624),
    [sym_empty_type] = STATE(1624),
    [sym_polymorphic_type] = STATE(1624),
    [sym_conditional_type] = STATE(1624),
    [ts_builtin_sym_end] = ACTIONS(909),
    [sym_identifier] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(943),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(945),
    [anon_sym_enum] = ACTIONS(947),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(949),
    [anon_sym_bit_field] = ACTIONS(951),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(998),
    [anon_sym_DOLLAR] = ACTIONS(956),
    [anon_sym_PLUS_EQ] = ACTIONS(909),
    [anon_sym_DASH_EQ] = ACTIONS(909),
    [anon_sym_STAR_EQ] = ACTIONS(909),
    [anon_sym_SLASH_EQ] = ACTIONS(909),
    [anon_sym_PERCENT_EQ] = ACTIONS(909),
    [anon_sym_AMP_EQ] = ACTIONS(909),
    [anon_sym_PIPE_EQ] = ACTIONS(909),
    [anon_sym_CARET_EQ] = ACTIONS(909),
    [anon_sym_LT_LT_EQ] = ACTIONS(909),
    [anon_sym_GT_GT_EQ] = ACTIONS(909),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(909),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(909),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_case] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(911),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(958),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(911),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(911),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(911),
    [anon_sym_LT_LT] = ACTIONS(911),
    [anon_sym_GT_GT] = ACTIONS(911),
    [anon_sym_STAR] = ACTIONS(911),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(1001),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(963),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(1004),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(968),
    [anon_sym_map] = ACTIONS(970),
    [anon_sym_bit_set] = ACTIONS(972),
    [anon_sym_matrix] = ACTIONS(974),
    [anon_sym_distinct] = ACTIONS(976),
    [sym_tag] = ACTIONS(978),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [155] = {
    [sym_expression] = STATE(4722),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(207),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(207),
    [anon_sym_COMMA] = ACTIONS(207),
    [anon_sym_DASH_GT] = ACTIONS(207),
    [anon_sym_PIPE] = ACTIONS(209),
    [anon_sym_LPAREN] = ACTIONS(207),
    [anon_sym_if] = ACTIONS(209),
    [anon_sym_SEMI] = ACTIONS(207),
    [anon_sym_else] = ACTIONS(209),
    [anon_sym_when] = ACTIONS(209),
    [anon_sym_in] = ACTIONS(209),
    [anon_sym_case] = ACTIONS(209),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_PLUS] = ACTIONS(207),
    [anon_sym_DASH] = ACTIONS(209),
    [anon_sym_TILDE] = ACTIONS(209),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(209),
    [anon_sym_PIPE_PIPE] = ACTIONS(207),
    [anon_sym_or_else] = ACTIONS(209),
    [anon_sym_AMP_AMP] = ACTIONS(207),
    [anon_sym_GT] = ACTIONS(209),
    [anon_sym_GT_EQ] = ACTIONS(207),
    [anon_sym_LT_EQ] = ACTIONS(207),
    [anon_sym_LT] = ACTIONS(209),
    [anon_sym_EQ_EQ] = ACTIONS(207),
    [anon_sym_BANG_EQ] = ACTIONS(207),
    [anon_sym_TILDE_EQ] = ACTIONS(207),
    [anon_sym_AMP_TILDE] = ACTIONS(207),
    [anon_sym_LT_LT] = ACTIONS(207),
    [anon_sym_GT_GT] = ACTIONS(207),
    [anon_sym_STAR] = ACTIONS(207),
    [anon_sym_SLASH] = ACTIONS(209),
    [anon_sym_PERCENT] = ACTIONS(209),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(207),
    [anon_sym_DOT] = ACTIONS(209),
    [anon_sym_LBRACK] = ACTIONS(207),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(207),
    [anon_sym_DOT_DOT_LT] = ACTIONS(207),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(209),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(209),
    [anon_sym_or_continue] = ACTIONS(209),
    [anon_sym_or_break] = ACTIONS(209),
    [anon_sym_CARET] = ACTIONS(207),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(207),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [156] = {
    [sym_procedure] = STATE(7016),
    [sym_expression] = STATE(4961),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(69),
    [sym_identifier] = ACTIONS(597),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(603),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(607),
    [anon_sym_AMP] = ACTIONS(607),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(615),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [157] = {
    [sym_procedure] = STATE(2182),
    [sym_type] = STATE(1459),
    [sym_pointer_type] = STATE(1624),
    [sym_variadic_type] = STATE(1624),
    [sym_array_type] = STATE(1624),
    [sym_map_type] = STATE(1624),
    [sym_union_type] = STATE(1624),
    [sym_bit_set_type] = STATE(1624),
    [sym_matrix_type] = STATE(1624),
    [sym_field_type] = STATE(1624),
    [sym_tuple_type] = STATE(1624),
    [sym_struct_type] = STATE(1624),
    [sym_enum_type] = STATE(1624),
    [sym_bit_field_type] = STATE(1624),
    [sym_constant_type] = STATE(1624),
    [sym_specialized_type] = STATE(1624),
    [sym__procedure_type] = STATE(1624),
    [sym_distinct_type] = STATE(1624),
    [sym_empty_type] = STATE(1624),
    [sym_polymorphic_type] = STATE(1624),
    [sym_conditional_type] = STATE(1624),
    [ts_builtin_sym_end] = ACTIONS(833),
    [sym_identifier] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(943),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(945),
    [anon_sym_enum] = ACTIONS(947),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(949),
    [anon_sym_bit_field] = ACTIONS(951),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(1007),
    [anon_sym_DOLLAR] = ACTIONS(956),
    [anon_sym_PLUS_EQ] = ACTIONS(833),
    [anon_sym_DASH_EQ] = ACTIONS(833),
    [anon_sym_STAR_EQ] = ACTIONS(833),
    [anon_sym_SLASH_EQ] = ACTIONS(833),
    [anon_sym_PERCENT_EQ] = ACTIONS(833),
    [anon_sym_AMP_EQ] = ACTIONS(833),
    [anon_sym_PIPE_EQ] = ACTIONS(833),
    [anon_sym_CARET_EQ] = ACTIONS(833),
    [anon_sym_LT_LT_EQ] = ACTIONS(833),
    [anon_sym_GT_GT_EQ] = ACTIONS(833),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(833),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(833),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(958),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(836),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(836),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1011),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(963),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(1015),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(968),
    [anon_sym_map] = ACTIONS(970),
    [anon_sym_bit_set] = ACTIONS(972),
    [anon_sym_matrix] = ACTIONS(974),
    [anon_sym_distinct] = ACTIONS(976),
    [sym_tag] = ACTIONS(978),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(833),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [158] = {
    [sym_procedure] = STATE(2182),
    [sym_type] = STATE(1462),
    [sym_pointer_type] = STATE(1624),
    [sym_variadic_type] = STATE(1624),
    [sym_array_type] = STATE(1624),
    [sym_map_type] = STATE(1624),
    [sym_union_type] = STATE(1624),
    [sym_bit_set_type] = STATE(1624),
    [sym_matrix_type] = STATE(1624),
    [sym_field_type] = STATE(1624),
    [sym_tuple_type] = STATE(1624),
    [sym_struct_type] = STATE(1624),
    [sym_enum_type] = STATE(1624),
    [sym_bit_field_type] = STATE(1624),
    [sym_constant_type] = STATE(1624),
    [sym_specialized_type] = STATE(1624),
    [sym__procedure_type] = STATE(1624),
    [sym_distinct_type] = STATE(1624),
    [sym_empty_type] = STATE(1624),
    [sym_polymorphic_type] = STATE(1624),
    [sym_conditional_type] = STATE(1624),
    [ts_builtin_sym_end] = ACTIONS(809),
    [sym_identifier] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(943),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(945),
    [anon_sym_enum] = ACTIONS(947),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(949),
    [anon_sym_bit_field] = ACTIONS(951),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(1019),
    [anon_sym_DOLLAR] = ACTIONS(956),
    [anon_sym_PLUS_EQ] = ACTIONS(809),
    [anon_sym_DASH_EQ] = ACTIONS(809),
    [anon_sym_STAR_EQ] = ACTIONS(809),
    [anon_sym_SLASH_EQ] = ACTIONS(809),
    [anon_sym_PERCENT_EQ] = ACTIONS(809),
    [anon_sym_AMP_EQ] = ACTIONS(809),
    [anon_sym_PIPE_EQ] = ACTIONS(809),
    [anon_sym_CARET_EQ] = ACTIONS(809),
    [anon_sym_LT_LT_EQ] = ACTIONS(809),
    [anon_sym_GT_GT_EQ] = ACTIONS(809),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(809),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_case] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(812),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(958),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(812),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(812),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(812),
    [anon_sym_LT_LT] = ACTIONS(812),
    [anon_sym_GT_GT] = ACTIONS(812),
    [anon_sym_STAR] = ACTIONS(812),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(1023),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(963),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(1027),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(968),
    [anon_sym_map] = ACTIONS(970),
    [anon_sym_bit_set] = ACTIONS(972),
    [anon_sym_matrix] = ACTIONS(974),
    [anon_sym_distinct] = ACTIONS(976),
    [sym_tag] = ACTIONS(978),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [159] = {
    [sym_procedure] = STATE(2182),
    [sym_type] = STATE(1466),
    [sym_pointer_type] = STATE(1624),
    [sym_variadic_type] = STATE(1624),
    [sym_array_type] = STATE(1624),
    [sym_map_type] = STATE(1624),
    [sym_union_type] = STATE(1624),
    [sym_bit_set_type] = STATE(1624),
    [sym_matrix_type] = STATE(1624),
    [sym_field_type] = STATE(1624),
    [sym_tuple_type] = STATE(1624),
    [sym_struct_type] = STATE(1624),
    [sym_enum_type] = STATE(1624),
    [sym_bit_field_type] = STATE(1624),
    [sym_constant_type] = STATE(1624),
    [sym_specialized_type] = STATE(1624),
    [sym__procedure_type] = STATE(1624),
    [sym_distinct_type] = STATE(1624),
    [sym_empty_type] = STATE(1624),
    [sym_polymorphic_type] = STATE(1624),
    [sym_conditional_type] = STATE(1624),
    [ts_builtin_sym_end] = ACTIONS(871),
    [sym_identifier] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(943),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_struct] = ACTIONS(945),
    [anon_sym_enum] = ACTIONS(947),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(949),
    [anon_sym_bit_field] = ACTIONS(951),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(1031),
    [anon_sym_DOLLAR] = ACTIONS(956),
    [anon_sym_PLUS_EQ] = ACTIONS(871),
    [anon_sym_DASH_EQ] = ACTIONS(871),
    [anon_sym_STAR_EQ] = ACTIONS(871),
    [anon_sym_SLASH_EQ] = ACTIONS(871),
    [anon_sym_PERCENT_EQ] = ACTIONS(871),
    [anon_sym_AMP_EQ] = ACTIONS(871),
    [anon_sym_PIPE_EQ] = ACTIONS(871),
    [anon_sym_CARET_EQ] = ACTIONS(871),
    [anon_sym_LT_LT_EQ] = ACTIONS(871),
    [anon_sym_GT_GT_EQ] = ACTIONS(871),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(871),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(871),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_case] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(874),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(958),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(874),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(874),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(874),
    [anon_sym_LT_LT] = ACTIONS(874),
    [anon_sym_GT_GT] = ACTIONS(874),
    [anon_sym_STAR] = ACTIONS(874),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(1035),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(963),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(1039),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(968),
    [anon_sym_map] = ACTIONS(970),
    [anon_sym_bit_set] = ACTIONS(972),
    [anon_sym_matrix] = ACTIONS(974),
    [anon_sym_distinct] = ACTIONS(976),
    [sym_tag] = ACTIONS(978),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [160] = {
    [sym_procedure] = STATE(2265),
    [sym_type] = STATE(2348),
    [sym_pointer_type] = STATE(2346),
    [sym_variadic_type] = STATE(2346),
    [sym_array_type] = STATE(2346),
    [sym_map_type] = STATE(2346),
    [sym_union_type] = STATE(2346),
    [sym_bit_set_type] = STATE(2346),
    [sym_matrix_type] = STATE(2346),
    [sym_field_type] = STATE(2346),
    [sym_tuple_type] = STATE(2346),
    [sym_struct_type] = STATE(2346),
    [sym_enum_type] = STATE(2346),
    [sym_bit_field_type] = STATE(2346),
    [sym_constant_type] = STATE(2346),
    [sym_specialized_type] = STATE(2346),
    [sym__procedure_type] = STATE(2346),
    [sym_distinct_type] = STATE(2346),
    [sym_empty_type] = STATE(2346),
    [sym_polymorphic_type] = STATE(2346),
    [sym_conditional_type] = STATE(2346),
    [ts_builtin_sym_end] = ACTIONS(871),
    [sym_identifier] = ACTIONS(1043),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(1045),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_struct] = ACTIONS(1047),
    [anon_sym_enum] = ACTIONS(1049),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(1051),
    [anon_sym_bit_field] = ACTIONS(1053),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(1055),
    [anon_sym_DOLLAR] = ACTIONS(1059),
    [anon_sym_PLUS_EQ] = ACTIONS(871),
    [anon_sym_DASH_EQ] = ACTIONS(871),
    [anon_sym_STAR_EQ] = ACTIONS(871),
    [anon_sym_SLASH_EQ] = ACTIONS(871),
    [anon_sym_PERCENT_EQ] = ACTIONS(871),
    [anon_sym_AMP_EQ] = ACTIONS(871),
    [anon_sym_PIPE_EQ] = ACTIONS(871),
    [anon_sym_CARET_EQ] = ACTIONS(871),
    [anon_sym_LT_LT_EQ] = ACTIONS(871),
    [anon_sym_GT_GT_EQ] = ACTIONS(871),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(871),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(871),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_case] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(874),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(1061),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(874),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(874),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(874),
    [anon_sym_LT_LT] = ACTIONS(874),
    [anon_sym_GT_GT] = ACTIONS(874),
    [anon_sym_STAR] = ACTIONS(874),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(1067),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(1069),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1073),
    [anon_sym_map] = ACTIONS(1075),
    [anon_sym_bit_set] = ACTIONS(1077),
    [anon_sym_matrix] = ACTIONS(1079),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_tag] = ACTIONS(1081),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [161] = {
    [sym_expression] = STATE(4836),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COMMA] = ACTIONS(207),
    [anon_sym_COLON_COLON] = ACTIONS(207),
    [anon_sym_DASH_GT] = ACTIONS(207),
    [anon_sym_EQ] = ACTIONS(209),
    [anon_sym_COLON] = ACTIONS(209),
    [anon_sym_PIPE] = ACTIONS(209),
    [anon_sym_COLON_EQ] = ACTIONS(207),
    [anon_sym_LPAREN] = ACTIONS(207),
    [anon_sym_if] = ACTIONS(209),
    [anon_sym_SEMI] = ACTIONS(207),
    [anon_sym_when] = ACTIONS(209),
    [anon_sym_in] = ACTIONS(209),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_PLUS] = ACTIONS(207),
    [anon_sym_DASH] = ACTIONS(209),
    [anon_sym_TILDE] = ACTIONS(209),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(209),
    [anon_sym_PIPE_PIPE] = ACTIONS(207),
    [anon_sym_or_else] = ACTIONS(209),
    [anon_sym_AMP_AMP] = ACTIONS(207),
    [anon_sym_GT] = ACTIONS(209),
    [anon_sym_GT_EQ] = ACTIONS(207),
    [anon_sym_LT_EQ] = ACTIONS(207),
    [anon_sym_LT] = ACTIONS(209),
    [anon_sym_EQ_EQ] = ACTIONS(207),
    [anon_sym_BANG_EQ] = ACTIONS(207),
    [anon_sym_TILDE_EQ] = ACTIONS(207),
    [anon_sym_AMP_TILDE] = ACTIONS(207),
    [anon_sym_LT_LT] = ACTIONS(207),
    [anon_sym_GT_GT] = ACTIONS(207),
    [anon_sym_STAR] = ACTIONS(207),
    [anon_sym_SLASH] = ACTIONS(209),
    [anon_sym_PERCENT] = ACTIONS(209),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(207),
    [anon_sym_DOT] = ACTIONS(209),
    [anon_sym_LBRACK] = ACTIONS(207),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(207),
    [anon_sym_DOT_DOT_LT] = ACTIONS(207),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_not_in] = ACTIONS(209),
    [anon_sym_DOT_DOT] = ACTIONS(1089),
    [anon_sym_or_return] = ACTIONS(209),
    [anon_sym_or_continue] = ACTIONS(209),
    [anon_sym_or_break] = ACTIONS(209),
    [anon_sym_CARET] = ACTIONS(207),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [162] = {
    [sym_procedure] = STATE(2265),
    [sym_type] = STATE(2296),
    [sym_pointer_type] = STATE(2346),
    [sym_variadic_type] = STATE(2346),
    [sym_array_type] = STATE(2346),
    [sym_map_type] = STATE(2346),
    [sym_union_type] = STATE(2346),
    [sym_bit_set_type] = STATE(2346),
    [sym_matrix_type] = STATE(2346),
    [sym_field_type] = STATE(2346),
    [sym_tuple_type] = STATE(2346),
    [sym_struct_type] = STATE(2346),
    [sym_enum_type] = STATE(2346),
    [sym_bit_field_type] = STATE(2346),
    [sym_constant_type] = STATE(2346),
    [sym_specialized_type] = STATE(2346),
    [sym__procedure_type] = STATE(2346),
    [sym_distinct_type] = STATE(2346),
    [sym_empty_type] = STATE(2346),
    [sym_polymorphic_type] = STATE(2346),
    [sym_conditional_type] = STATE(2346),
    [ts_builtin_sym_end] = ACTIONS(833),
    [sym_identifier] = ACTIONS(1043),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(1045),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(1047),
    [anon_sym_enum] = ACTIONS(1049),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(1051),
    [anon_sym_bit_field] = ACTIONS(1053),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(1093),
    [anon_sym_DOLLAR] = ACTIONS(1059),
    [anon_sym_PLUS_EQ] = ACTIONS(833),
    [anon_sym_DASH_EQ] = ACTIONS(833),
    [anon_sym_STAR_EQ] = ACTIONS(833),
    [anon_sym_SLASH_EQ] = ACTIONS(833),
    [anon_sym_PERCENT_EQ] = ACTIONS(833),
    [anon_sym_AMP_EQ] = ACTIONS(833),
    [anon_sym_PIPE_EQ] = ACTIONS(833),
    [anon_sym_CARET_EQ] = ACTIONS(833),
    [anon_sym_LT_LT_EQ] = ACTIONS(833),
    [anon_sym_GT_GT_EQ] = ACTIONS(833),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(833),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(833),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(1061),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(836),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(836),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1097),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(1067),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(1101),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1073),
    [anon_sym_map] = ACTIONS(1075),
    [anon_sym_bit_set] = ACTIONS(1077),
    [anon_sym_matrix] = ACTIONS(1079),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_tag] = ACTIONS(1081),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(833),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [163] = {
    [sym_procedure] = STATE(2265),
    [sym_type] = STATE(2306),
    [sym_pointer_type] = STATE(2346),
    [sym_variadic_type] = STATE(2346),
    [sym_array_type] = STATE(2346),
    [sym_map_type] = STATE(2346),
    [sym_union_type] = STATE(2346),
    [sym_bit_set_type] = STATE(2346),
    [sym_matrix_type] = STATE(2346),
    [sym_field_type] = STATE(2346),
    [sym_tuple_type] = STATE(2346),
    [sym_struct_type] = STATE(2346),
    [sym_enum_type] = STATE(2346),
    [sym_bit_field_type] = STATE(2346),
    [sym_constant_type] = STATE(2346),
    [sym_specialized_type] = STATE(2346),
    [sym__procedure_type] = STATE(2346),
    [sym_distinct_type] = STATE(2346),
    [sym_empty_type] = STATE(2346),
    [sym_polymorphic_type] = STATE(2346),
    [sym_conditional_type] = STATE(2346),
    [ts_builtin_sym_end] = ACTIONS(809),
    [sym_identifier] = ACTIONS(1043),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(1045),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(1047),
    [anon_sym_enum] = ACTIONS(1049),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(1051),
    [anon_sym_bit_field] = ACTIONS(1053),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(1105),
    [anon_sym_DOLLAR] = ACTIONS(1059),
    [anon_sym_PLUS_EQ] = ACTIONS(809),
    [anon_sym_DASH_EQ] = ACTIONS(809),
    [anon_sym_STAR_EQ] = ACTIONS(809),
    [anon_sym_SLASH_EQ] = ACTIONS(809),
    [anon_sym_PERCENT_EQ] = ACTIONS(809),
    [anon_sym_AMP_EQ] = ACTIONS(809),
    [anon_sym_PIPE_EQ] = ACTIONS(809),
    [anon_sym_CARET_EQ] = ACTIONS(809),
    [anon_sym_LT_LT_EQ] = ACTIONS(809),
    [anon_sym_GT_GT_EQ] = ACTIONS(809),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(809),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_case] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(812),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(1061),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(812),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(812),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(812),
    [anon_sym_LT_LT] = ACTIONS(812),
    [anon_sym_GT_GT] = ACTIONS(812),
    [anon_sym_STAR] = ACTIONS(812),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(1109),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(1067),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(1113),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1073),
    [anon_sym_map] = ACTIONS(1075),
    [anon_sym_bit_set] = ACTIONS(1077),
    [anon_sym_matrix] = ACTIONS(1079),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_tag] = ACTIONS(1081),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [164] = {
    [sym_procedure] = STATE(2265),
    [sym_type] = STATE(2373),
    [sym_pointer_type] = STATE(2346),
    [sym_variadic_type] = STATE(2346),
    [sym_array_type] = STATE(2346),
    [sym_map_type] = STATE(2346),
    [sym_union_type] = STATE(2346),
    [sym_bit_set_type] = STATE(2346),
    [sym_matrix_type] = STATE(2346),
    [sym_field_type] = STATE(2346),
    [sym_tuple_type] = STATE(2346),
    [sym_struct_type] = STATE(2346),
    [sym_enum_type] = STATE(2346),
    [sym_bit_field_type] = STATE(2346),
    [sym_constant_type] = STATE(2346),
    [sym_specialized_type] = STATE(2346),
    [sym__procedure_type] = STATE(2346),
    [sym_distinct_type] = STATE(2346),
    [sym_empty_type] = STATE(2346),
    [sym_polymorphic_type] = STATE(2346),
    [sym_conditional_type] = STATE(2346),
    [ts_builtin_sym_end] = ACTIONS(855),
    [sym_identifier] = ACTIONS(1043),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(1045),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_struct] = ACTIONS(1047),
    [anon_sym_enum] = ACTIONS(1049),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(1051),
    [anon_sym_bit_field] = ACTIONS(1053),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(1117),
    [anon_sym_DOLLAR] = ACTIONS(1059),
    [anon_sym_PLUS_EQ] = ACTIONS(855),
    [anon_sym_DASH_EQ] = ACTIONS(855),
    [anon_sym_STAR_EQ] = ACTIONS(855),
    [anon_sym_SLASH_EQ] = ACTIONS(855),
    [anon_sym_PERCENT_EQ] = ACTIONS(855),
    [anon_sym_AMP_EQ] = ACTIONS(855),
    [anon_sym_PIPE_EQ] = ACTIONS(855),
    [anon_sym_CARET_EQ] = ACTIONS(855),
    [anon_sym_LT_LT_EQ] = ACTIONS(855),
    [anon_sym_GT_GT_EQ] = ACTIONS(855),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(855),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(855),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(857),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(1061),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(857),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(857),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(1120),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(1067),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(1123),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1073),
    [anon_sym_map] = ACTIONS(1075),
    [anon_sym_bit_set] = ACTIONS(1077),
    [anon_sym_matrix] = ACTIONS(1079),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_tag] = ACTIONS(1081),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(855),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [165] = {
    [sym_expression] = STATE(4835),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_COLON_COLON] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(1089),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [166] = {
    [sym_procedure] = STATE(2265),
    [sym_type] = STATE(2510),
    [sym_pointer_type] = STATE(2346),
    [sym_variadic_type] = STATE(2346),
    [sym_array_type] = STATE(2346),
    [sym_map_type] = STATE(2346),
    [sym_union_type] = STATE(2346),
    [sym_bit_set_type] = STATE(2346),
    [sym_matrix_type] = STATE(2346),
    [sym_field_type] = STATE(2346),
    [sym_tuple_type] = STATE(2346),
    [sym_struct_type] = STATE(2346),
    [sym_enum_type] = STATE(2346),
    [sym_bit_field_type] = STATE(2346),
    [sym_constant_type] = STATE(2346),
    [sym_specialized_type] = STATE(2346),
    [sym__procedure_type] = STATE(2346),
    [sym_distinct_type] = STATE(2346),
    [sym_empty_type] = STATE(2346),
    [sym_polymorphic_type] = STATE(2346),
    [sym_conditional_type] = STATE(2346),
    [ts_builtin_sym_end] = ACTIONS(909),
    [sym_identifier] = ACTIONS(1043),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(1045),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(1047),
    [anon_sym_enum] = ACTIONS(1049),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(1051),
    [anon_sym_bit_field] = ACTIONS(1053),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(1134),
    [anon_sym_DOLLAR] = ACTIONS(1059),
    [anon_sym_PLUS_EQ] = ACTIONS(909),
    [anon_sym_DASH_EQ] = ACTIONS(909),
    [anon_sym_STAR_EQ] = ACTIONS(909),
    [anon_sym_SLASH_EQ] = ACTIONS(909),
    [anon_sym_PERCENT_EQ] = ACTIONS(909),
    [anon_sym_AMP_EQ] = ACTIONS(909),
    [anon_sym_PIPE_EQ] = ACTIONS(909),
    [anon_sym_CARET_EQ] = ACTIONS(909),
    [anon_sym_LT_LT_EQ] = ACTIONS(909),
    [anon_sym_GT_GT_EQ] = ACTIONS(909),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(909),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(909),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_case] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(911),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(1061),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(911),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(911),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(911),
    [anon_sym_LT_LT] = ACTIONS(911),
    [anon_sym_GT_GT] = ACTIONS(911),
    [anon_sym_STAR] = ACTIONS(911),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(1137),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(1067),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(1140),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1073),
    [anon_sym_map] = ACTIONS(1075),
    [anon_sym_bit_set] = ACTIONS(1077),
    [anon_sym_matrix] = ACTIONS(1079),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_tag] = ACTIONS(1081),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [167] = {
    [sym_procedure] = STATE(2265),
    [sym_type] = STATE(2330),
    [sym_pointer_type] = STATE(2346),
    [sym_variadic_type] = STATE(2346),
    [sym_array_type] = STATE(2346),
    [sym_map_type] = STATE(2346),
    [sym_union_type] = STATE(2346),
    [sym_bit_set_type] = STATE(2346),
    [sym_matrix_type] = STATE(2346),
    [sym_field_type] = STATE(2346),
    [sym_tuple_type] = STATE(2346),
    [sym_struct_type] = STATE(2346),
    [sym_enum_type] = STATE(2346),
    [sym_bit_field_type] = STATE(2346),
    [sym_constant_type] = STATE(2346),
    [sym_specialized_type] = STATE(2346),
    [sym__procedure_type] = STATE(2346),
    [sym_distinct_type] = STATE(2346),
    [sym_empty_type] = STATE(2346),
    [sym_polymorphic_type] = STATE(2346),
    [sym_conditional_type] = STATE(2346),
    [ts_builtin_sym_end] = ACTIONS(893),
    [sym_identifier] = ACTIONS(1043),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(1045),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(1047),
    [anon_sym_enum] = ACTIONS(1049),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(1051),
    [anon_sym_bit_field] = ACTIONS(1053),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(1143),
    [anon_sym_DOLLAR] = ACTIONS(1059),
    [anon_sym_PLUS_EQ] = ACTIONS(893),
    [anon_sym_DASH_EQ] = ACTIONS(893),
    [anon_sym_STAR_EQ] = ACTIONS(893),
    [anon_sym_SLASH_EQ] = ACTIONS(893),
    [anon_sym_PERCENT_EQ] = ACTIONS(893),
    [anon_sym_AMP_EQ] = ACTIONS(893),
    [anon_sym_PIPE_EQ] = ACTIONS(893),
    [anon_sym_CARET_EQ] = ACTIONS(893),
    [anon_sym_LT_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_GT_EQ] = ACTIONS(893),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(893),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_case] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(1061),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(895),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(895),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1146),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(1067),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(1149),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1073),
    [anon_sym_map] = ACTIONS(1075),
    [anon_sym_bit_set] = ACTIONS(1077),
    [anon_sym_matrix] = ACTIONS(1079),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_tag] = ACTIONS(1081),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [168] = {
    [sym_expression] = STATE(4836),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_COLON_COLON] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_COLON] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(1089),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [169] = {
    [sym_procedure] = STATE(2265),
    [sym_type] = STATE(2229),
    [sym_pointer_type] = STATE(2346),
    [sym_variadic_type] = STATE(2346),
    [sym_array_type] = STATE(2346),
    [sym_map_type] = STATE(2346),
    [sym_union_type] = STATE(2346),
    [sym_bit_set_type] = STATE(2346),
    [sym_matrix_type] = STATE(2346),
    [sym_field_type] = STATE(2346),
    [sym_tuple_type] = STATE(2346),
    [sym_struct_type] = STATE(2346),
    [sym_enum_type] = STATE(2346),
    [sym_bit_field_type] = STATE(2346),
    [sym_constant_type] = STATE(2346),
    [sym_specialized_type] = STATE(2346),
    [sym__procedure_type] = STATE(2346),
    [sym_distinct_type] = STATE(2346),
    [sym_empty_type] = STATE(2346),
    [sym_polymorphic_type] = STATE(2346),
    [sym_conditional_type] = STATE(2346),
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(1043),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(1045),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(1047),
    [anon_sym_enum] = ACTIONS(1049),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(1051),
    [anon_sym_bit_field] = ACTIONS(1053),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(1152),
    [anon_sym_DOLLAR] = ACTIONS(1059),
    [anon_sym_PLUS_EQ] = ACTIONS(767),
    [anon_sym_DASH_EQ] = ACTIONS(767),
    [anon_sym_STAR_EQ] = ACTIONS(767),
    [anon_sym_SLASH_EQ] = ACTIONS(767),
    [anon_sym_PERCENT_EQ] = ACTIONS(767),
    [anon_sym_AMP_EQ] = ACTIONS(767),
    [anon_sym_PIPE_EQ] = ACTIONS(767),
    [anon_sym_CARET_EQ] = ACTIONS(767),
    [anon_sym_LT_LT_EQ] = ACTIONS(767),
    [anon_sym_GT_GT_EQ] = ACTIONS(767),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(767),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_case] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(1061),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(773),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(773),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(1155),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(1067),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(1158),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1073),
    [anon_sym_map] = ACTIONS(1075),
    [anon_sym_bit_set] = ACTIONS(1077),
    [anon_sym_matrix] = ACTIONS(1079),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_tag] = ACTIONS(1081),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [170] = {
    [sym_procedure] = STATE(2453),
    [sym_type] = STATE(2430),
    [sym_pointer_type] = STATE(2471),
    [sym_variadic_type] = STATE(2471),
    [sym_array_type] = STATE(2471),
    [sym_map_type] = STATE(2471),
    [sym_union_type] = STATE(2471),
    [sym_bit_set_type] = STATE(2471),
    [sym_matrix_type] = STATE(2471),
    [sym_field_type] = STATE(2471),
    [sym_tuple_type] = STATE(2471),
    [sym_struct_type] = STATE(2471),
    [sym_enum_type] = STATE(2471),
    [sym_bit_field_type] = STATE(2471),
    [sym_constant_type] = STATE(2471),
    [sym_specialized_type] = STATE(2471),
    [sym__procedure_type] = STATE(2471),
    [sym_distinct_type] = STATE(2471),
    [sym_empty_type] = STATE(2471),
    [sym_polymorphic_type] = STATE(2471),
    [sym_conditional_type] = STATE(2471),
    [sym_identifier] = ACTIONS(1161),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(1163),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_where] = ACTIONS(895),
    [anon_sym_struct] = ACTIONS(1165),
    [anon_sym_enum] = ACTIONS(1167),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(1169),
    [anon_sym_bit_field] = ACTIONS(1171),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(1173),
    [anon_sym_DOLLAR] = ACTIONS(1176),
    [anon_sym_PLUS_EQ] = ACTIONS(893),
    [anon_sym_DASH_EQ] = ACTIONS(893),
    [anon_sym_STAR_EQ] = ACTIONS(893),
    [anon_sym_SLASH_EQ] = ACTIONS(893),
    [anon_sym_PERCENT_EQ] = ACTIONS(893),
    [anon_sym_AMP_EQ] = ACTIONS(893),
    [anon_sym_PIPE_EQ] = ACTIONS(893),
    [anon_sym_CARET_EQ] = ACTIONS(893),
    [anon_sym_LT_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_GT_EQ] = ACTIONS(893),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(893),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_do] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(1178),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(895),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(895),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1180),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(1183),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(1185),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1188),
    [anon_sym_map] = ACTIONS(1190),
    [anon_sym_bit_set] = ACTIONS(1192),
    [anon_sym_matrix] = ACTIONS(1194),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_uninitialized] = ACTIONS(893),
    [sym_tag] = ACTIONS(1196),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [171] = {
    [sym_procedure] = STATE(2453),
    [sym_type] = STATE(2432),
    [sym_pointer_type] = STATE(2471),
    [sym_variadic_type] = STATE(2471),
    [sym_array_type] = STATE(2471),
    [sym_map_type] = STATE(2471),
    [sym_union_type] = STATE(2471),
    [sym_bit_set_type] = STATE(2471),
    [sym_matrix_type] = STATE(2471),
    [sym_field_type] = STATE(2471),
    [sym_tuple_type] = STATE(2471),
    [sym_struct_type] = STATE(2471),
    [sym_enum_type] = STATE(2471),
    [sym_bit_field_type] = STATE(2471),
    [sym_constant_type] = STATE(2471),
    [sym_specialized_type] = STATE(2471),
    [sym__procedure_type] = STATE(2471),
    [sym_distinct_type] = STATE(2471),
    [sym_empty_type] = STATE(2471),
    [sym_polymorphic_type] = STATE(2471),
    [sym_conditional_type] = STATE(2471),
    [sym_identifier] = ACTIONS(1161),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(1163),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_where] = ACTIONS(773),
    [anon_sym_struct] = ACTIONS(1165),
    [anon_sym_enum] = ACTIONS(1167),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(1169),
    [anon_sym_bit_field] = ACTIONS(1171),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(1199),
    [anon_sym_DOLLAR] = ACTIONS(1176),
    [anon_sym_PLUS_EQ] = ACTIONS(767),
    [anon_sym_DASH_EQ] = ACTIONS(767),
    [anon_sym_STAR_EQ] = ACTIONS(767),
    [anon_sym_SLASH_EQ] = ACTIONS(767),
    [anon_sym_PERCENT_EQ] = ACTIONS(767),
    [anon_sym_AMP_EQ] = ACTIONS(767),
    [anon_sym_PIPE_EQ] = ACTIONS(767),
    [anon_sym_CARET_EQ] = ACTIONS(767),
    [anon_sym_LT_LT_EQ] = ACTIONS(767),
    [anon_sym_GT_GT_EQ] = ACTIONS(767),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(767),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_do] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(1178),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(773),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(773),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(1183),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(1205),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1188),
    [anon_sym_map] = ACTIONS(1190),
    [anon_sym_bit_set] = ACTIONS(1192),
    [anon_sym_matrix] = ACTIONS(1194),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_uninitialized] = ACTIONS(767),
    [sym_tag] = ACTIONS(1208),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [172] = {
    [sym_expression] = STATE(4876),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_COLON_EQ] = ACTIONS(165),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_SEMI] = ACTIONS(165),
    [anon_sym_do] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(349),
    [anon_sym_BANG] = ACTIONS(349),
    [anon_sym_AMP] = ACTIONS(349),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [173] = {
    [sym_procedure] = STATE(2453),
    [sym_type] = STATE(2418),
    [sym_pointer_type] = STATE(2471),
    [sym_variadic_type] = STATE(2471),
    [sym_array_type] = STATE(2471),
    [sym_map_type] = STATE(2471),
    [sym_union_type] = STATE(2471),
    [sym_bit_set_type] = STATE(2471),
    [sym_matrix_type] = STATE(2471),
    [sym_field_type] = STATE(2471),
    [sym_tuple_type] = STATE(2471),
    [sym_struct_type] = STATE(2471),
    [sym_enum_type] = STATE(2471),
    [sym_bit_field_type] = STATE(2471),
    [sym_constant_type] = STATE(2471),
    [sym_specialized_type] = STATE(2471),
    [sym__procedure_type] = STATE(2471),
    [sym_distinct_type] = STATE(2471),
    [sym_empty_type] = STATE(2471),
    [sym_polymorphic_type] = STATE(2471),
    [sym_conditional_type] = STATE(2471),
    [sym_identifier] = ACTIONS(1161),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(1163),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_where] = ACTIONS(836),
    [anon_sym_struct] = ACTIONS(1165),
    [anon_sym_enum] = ACTIONS(1167),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(1169),
    [anon_sym_bit_field] = ACTIONS(1171),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(1223),
    [anon_sym_DOLLAR] = ACTIONS(1176),
    [anon_sym_PLUS_EQ] = ACTIONS(833),
    [anon_sym_DASH_EQ] = ACTIONS(833),
    [anon_sym_STAR_EQ] = ACTIONS(833),
    [anon_sym_SLASH_EQ] = ACTIONS(833),
    [anon_sym_PERCENT_EQ] = ACTIONS(833),
    [anon_sym_AMP_EQ] = ACTIONS(833),
    [anon_sym_PIPE_EQ] = ACTIONS(833),
    [anon_sym_CARET_EQ] = ACTIONS(833),
    [anon_sym_LT_LT_EQ] = ACTIONS(833),
    [anon_sym_GT_GT_EQ] = ACTIONS(833),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(833),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(833),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_do] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(1178),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(836),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(836),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1227),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(1183),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(1231),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1188),
    [anon_sym_map] = ACTIONS(1190),
    [anon_sym_bit_set] = ACTIONS(1192),
    [anon_sym_matrix] = ACTIONS(1194),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_uninitialized] = ACTIONS(833),
    [sym_tag] = ACTIONS(1235),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [174] = {
    [sym_procedure] = STATE(2453),
    [sym_type] = STATE(2426),
    [sym_pointer_type] = STATE(2471),
    [sym_variadic_type] = STATE(2471),
    [sym_array_type] = STATE(2471),
    [sym_map_type] = STATE(2471),
    [sym_union_type] = STATE(2471),
    [sym_bit_set_type] = STATE(2471),
    [sym_matrix_type] = STATE(2471),
    [sym_field_type] = STATE(2471),
    [sym_tuple_type] = STATE(2471),
    [sym_struct_type] = STATE(2471),
    [sym_enum_type] = STATE(2471),
    [sym_bit_field_type] = STATE(2471),
    [sym_constant_type] = STATE(2471),
    [sym_specialized_type] = STATE(2471),
    [sym__procedure_type] = STATE(2471),
    [sym_distinct_type] = STATE(2471),
    [sym_empty_type] = STATE(2471),
    [sym_polymorphic_type] = STATE(2471),
    [sym_conditional_type] = STATE(2471),
    [sym_identifier] = ACTIONS(1161),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(1163),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_where] = ACTIONS(812),
    [anon_sym_struct] = ACTIONS(1165),
    [anon_sym_enum] = ACTIONS(1167),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(1169),
    [anon_sym_bit_field] = ACTIONS(1171),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(1239),
    [anon_sym_DOLLAR] = ACTIONS(1176),
    [anon_sym_PLUS_EQ] = ACTIONS(809),
    [anon_sym_DASH_EQ] = ACTIONS(809),
    [anon_sym_STAR_EQ] = ACTIONS(809),
    [anon_sym_SLASH_EQ] = ACTIONS(809),
    [anon_sym_PERCENT_EQ] = ACTIONS(809),
    [anon_sym_AMP_EQ] = ACTIONS(809),
    [anon_sym_PIPE_EQ] = ACTIONS(809),
    [anon_sym_CARET_EQ] = ACTIONS(809),
    [anon_sym_LT_LT_EQ] = ACTIONS(809),
    [anon_sym_GT_GT_EQ] = ACTIONS(809),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(809),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_do] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(812),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(1178),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(812),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(812),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(812),
    [anon_sym_LT_LT] = ACTIONS(812),
    [anon_sym_GT_GT] = ACTIONS(812),
    [anon_sym_STAR] = ACTIONS(812),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(1243),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(1183),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(1247),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1188),
    [anon_sym_map] = ACTIONS(1190),
    [anon_sym_bit_set] = ACTIONS(1192),
    [anon_sym_matrix] = ACTIONS(1194),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_uninitialized] = ACTIONS(809),
    [sym_tag] = ACTIONS(1251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [175] = {
    [sym_procedure] = STATE(2453),
    [sym_type] = STATE(2416),
    [sym_pointer_type] = STATE(2471),
    [sym_variadic_type] = STATE(2471),
    [sym_array_type] = STATE(2471),
    [sym_map_type] = STATE(2471),
    [sym_union_type] = STATE(2471),
    [sym_bit_set_type] = STATE(2471),
    [sym_matrix_type] = STATE(2471),
    [sym_field_type] = STATE(2471),
    [sym_tuple_type] = STATE(2471),
    [sym_struct_type] = STATE(2471),
    [sym_enum_type] = STATE(2471),
    [sym_bit_field_type] = STATE(2471),
    [sym_constant_type] = STATE(2471),
    [sym_specialized_type] = STATE(2471),
    [sym__procedure_type] = STATE(2471),
    [sym_distinct_type] = STATE(2471),
    [sym_empty_type] = STATE(2471),
    [sym_polymorphic_type] = STATE(2471),
    [sym_conditional_type] = STATE(2471),
    [sym_identifier] = ACTIONS(1161),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(1163),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_where] = ACTIONS(857),
    [anon_sym_struct] = ACTIONS(1165),
    [anon_sym_enum] = ACTIONS(1167),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(1169),
    [anon_sym_bit_field] = ACTIONS(1171),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(1255),
    [anon_sym_DOLLAR] = ACTIONS(1176),
    [anon_sym_PLUS_EQ] = ACTIONS(855),
    [anon_sym_DASH_EQ] = ACTIONS(855),
    [anon_sym_STAR_EQ] = ACTIONS(855),
    [anon_sym_SLASH_EQ] = ACTIONS(855),
    [anon_sym_PERCENT_EQ] = ACTIONS(855),
    [anon_sym_AMP_EQ] = ACTIONS(855),
    [anon_sym_PIPE_EQ] = ACTIONS(855),
    [anon_sym_CARET_EQ] = ACTIONS(855),
    [anon_sym_LT_LT_EQ] = ACTIONS(855),
    [anon_sym_GT_GT_EQ] = ACTIONS(855),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(855),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(855),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_do] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(857),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(1178),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(857),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(857),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(1258),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(1183),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(1261),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1188),
    [anon_sym_map] = ACTIONS(1190),
    [anon_sym_bit_set] = ACTIONS(1192),
    [anon_sym_matrix] = ACTIONS(1194),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_uninitialized] = ACTIONS(855),
    [sym_tag] = ACTIONS(1264),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [176] = {
    [sym_expression] = STATE(4885),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_COLON_EQ] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_do] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(349),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [177] = {
    [sym_procedure] = STATE(2453),
    [sym_type] = STATE(2433),
    [sym_pointer_type] = STATE(2471),
    [sym_variadic_type] = STATE(2471),
    [sym_array_type] = STATE(2471),
    [sym_map_type] = STATE(2471),
    [sym_union_type] = STATE(2471),
    [sym_bit_set_type] = STATE(2471),
    [sym_matrix_type] = STATE(2471),
    [sym_field_type] = STATE(2471),
    [sym_tuple_type] = STATE(2471),
    [sym_struct_type] = STATE(2471),
    [sym_enum_type] = STATE(2471),
    [sym_bit_field_type] = STATE(2471),
    [sym_constant_type] = STATE(2471),
    [sym_specialized_type] = STATE(2471),
    [sym__procedure_type] = STATE(2471),
    [sym_distinct_type] = STATE(2471),
    [sym_empty_type] = STATE(2471),
    [sym_polymorphic_type] = STATE(2471),
    [sym_conditional_type] = STATE(2471),
    [sym_identifier] = ACTIONS(1161),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(1163),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_where] = ACTIONS(874),
    [anon_sym_struct] = ACTIONS(1165),
    [anon_sym_enum] = ACTIONS(1167),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(1169),
    [anon_sym_bit_field] = ACTIONS(1171),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(1267),
    [anon_sym_DOLLAR] = ACTIONS(1176),
    [anon_sym_PLUS_EQ] = ACTIONS(871),
    [anon_sym_DASH_EQ] = ACTIONS(871),
    [anon_sym_STAR_EQ] = ACTIONS(871),
    [anon_sym_SLASH_EQ] = ACTIONS(871),
    [anon_sym_PERCENT_EQ] = ACTIONS(871),
    [anon_sym_AMP_EQ] = ACTIONS(871),
    [anon_sym_PIPE_EQ] = ACTIONS(871),
    [anon_sym_CARET_EQ] = ACTIONS(871),
    [anon_sym_LT_LT_EQ] = ACTIONS(871),
    [anon_sym_GT_GT_EQ] = ACTIONS(871),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(871),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(871),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_do] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(874),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(1178),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(874),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(874),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(874),
    [anon_sym_LT_LT] = ACTIONS(874),
    [anon_sym_GT_GT] = ACTIONS(874),
    [anon_sym_STAR] = ACTIONS(874),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(1271),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(1183),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(1275),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1188),
    [anon_sym_map] = ACTIONS(1190),
    [anon_sym_bit_set] = ACTIONS(1192),
    [anon_sym_matrix] = ACTIONS(1194),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_uninitialized] = ACTIONS(871),
    [sym_tag] = ACTIONS(1279),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [178] = {
    [sym_procedure] = STATE(2453),
    [sym_type] = STATE(2431),
    [sym_pointer_type] = STATE(2471),
    [sym_variadic_type] = STATE(2471),
    [sym_array_type] = STATE(2471),
    [sym_map_type] = STATE(2471),
    [sym_union_type] = STATE(2471),
    [sym_bit_set_type] = STATE(2471),
    [sym_matrix_type] = STATE(2471),
    [sym_field_type] = STATE(2471),
    [sym_tuple_type] = STATE(2471),
    [sym_struct_type] = STATE(2471),
    [sym_enum_type] = STATE(2471),
    [sym_bit_field_type] = STATE(2471),
    [sym_constant_type] = STATE(2471),
    [sym_specialized_type] = STATE(2471),
    [sym__procedure_type] = STATE(2471),
    [sym_distinct_type] = STATE(2471),
    [sym_empty_type] = STATE(2471),
    [sym_polymorphic_type] = STATE(2471),
    [sym_conditional_type] = STATE(2471),
    [sym_identifier] = ACTIONS(1161),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(1163),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_where] = ACTIONS(911),
    [anon_sym_struct] = ACTIONS(1165),
    [anon_sym_enum] = ACTIONS(1167),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(1169),
    [anon_sym_bit_field] = ACTIONS(1171),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(1283),
    [anon_sym_DOLLAR] = ACTIONS(1176),
    [anon_sym_PLUS_EQ] = ACTIONS(909),
    [anon_sym_DASH_EQ] = ACTIONS(909),
    [anon_sym_STAR_EQ] = ACTIONS(909),
    [anon_sym_SLASH_EQ] = ACTIONS(909),
    [anon_sym_PERCENT_EQ] = ACTIONS(909),
    [anon_sym_AMP_EQ] = ACTIONS(909),
    [anon_sym_PIPE_EQ] = ACTIONS(909),
    [anon_sym_CARET_EQ] = ACTIONS(909),
    [anon_sym_LT_LT_EQ] = ACTIONS(909),
    [anon_sym_GT_GT_EQ] = ACTIONS(909),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(909),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(909),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_do] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(911),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(1178),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(911),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(911),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(911),
    [anon_sym_LT_LT] = ACTIONS(911),
    [anon_sym_GT_GT] = ACTIONS(911),
    [anon_sym_STAR] = ACTIONS(911),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(1286),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(1183),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(1289),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1188),
    [anon_sym_map] = ACTIONS(1190),
    [anon_sym_bit_set] = ACTIONS(1192),
    [anon_sym_matrix] = ACTIONS(1194),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_uninitialized] = ACTIONS(909),
    [sym_tag] = ACTIONS(1292),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [179] = {
    [sym_expression] = STATE(4637),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_where] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_RPAREN] = ACTIONS(165),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1299),
    [anon_sym_BANG] = ACTIONS(1299),
    [anon_sym_AMP] = ACTIONS(1299),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(1307),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [180] = {
    [sym_expression] = STATE(4461),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_RBRACE] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(165),
    [anon_sym_DASH_GT] = ACTIONS(165),
    [anon_sym_where] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_when] = ACTIONS(169),
    [anon_sym_in] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1325),
    [anon_sym_BANG] = ACTIONS(1325),
    [anon_sym_AMP] = ACTIONS(1325),
    [anon_sym_PIPE_PIPE] = ACTIONS(165),
    [anon_sym_or_else] = ACTIONS(169),
    [anon_sym_AMP_AMP] = ACTIONS(165),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(165),
    [anon_sym_LT_EQ] = ACTIONS(165),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_EQ_EQ] = ACTIONS(165),
    [anon_sym_BANG_EQ] = ACTIONS(165),
    [anon_sym_TILDE_EQ] = ACTIONS(165),
    [anon_sym_AMP_TILDE] = ACTIONS(165),
    [anon_sym_LT_LT] = ACTIONS(165),
    [anon_sym_GT_GT] = ACTIONS(165),
    [anon_sym_STAR] = ACTIONS(165),
    [anon_sym_SLASH] = ACTIONS(169),
    [anon_sym_PERCENT] = ACTIONS(169),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(165),
    [anon_sym_DOT_DOT_LT] = ACTIONS(165),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_not_in] = ACTIONS(169),
    [anon_sym_DOT_DOT] = ACTIONS(1335),
    [anon_sym_or_return] = ACTIONS(169),
    [anon_sym_or_continue] = ACTIONS(169),
    [anon_sym_or_break] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(165),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [181] = {
    [sym_expression] = STATE(4638),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_where] = ACTIONS(135),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_RPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(1299),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(1307),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(131),
    [sym_tag] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [182] = {
    [sym_expression] = STATE(4464),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(131),
    [anon_sym_RBRACE] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(131),
    [anon_sym_where] = ACTIONS(135),
    [anon_sym_EQ] = ACTIONS(135),
    [anon_sym_PIPE] = ACTIONS(135),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_if] = ACTIONS(135),
    [anon_sym_when] = ACTIONS(135),
    [anon_sym_in] = ACTIONS(135),
    [anon_sym_QMARK] = ACTIONS(131),
    [anon_sym_PLUS] = ACTIONS(131),
    [anon_sym_DASH] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(135),
    [anon_sym_BANG] = ACTIONS(1325),
    [anon_sym_AMP] = ACTIONS(135),
    [anon_sym_PIPE_PIPE] = ACTIONS(131),
    [anon_sym_or_else] = ACTIONS(135),
    [anon_sym_AMP_AMP] = ACTIONS(131),
    [anon_sym_GT] = ACTIONS(135),
    [anon_sym_GT_EQ] = ACTIONS(131),
    [anon_sym_LT_EQ] = ACTIONS(131),
    [anon_sym_LT] = ACTIONS(135),
    [anon_sym_EQ_EQ] = ACTIONS(131),
    [anon_sym_BANG_EQ] = ACTIONS(131),
    [anon_sym_TILDE_EQ] = ACTIONS(131),
    [anon_sym_AMP_TILDE] = ACTIONS(131),
    [anon_sym_LT_LT] = ACTIONS(131),
    [anon_sym_GT_GT] = ACTIONS(131),
    [anon_sym_STAR] = ACTIONS(131),
    [anon_sym_SLASH] = ACTIONS(135),
    [anon_sym_PERCENT] = ACTIONS(135),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(131),
    [anon_sym_DOT] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(131),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_not_in] = ACTIONS(135),
    [anon_sym_DOT_DOT] = ACTIONS(1335),
    [anon_sym_or_return] = ACTIONS(135),
    [anon_sym_or_continue] = ACTIONS(135),
    [anon_sym_or_break] = ACTIONS(135),
    [anon_sym_CARET] = ACTIONS(131),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(131),
    [anon_sym_BQUOTE] = ACTIONS(131),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(131),
    [sym_tag] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [183] = {
    [sym_procedure] = STATE(2652),
    [sym_type] = STATE(2657),
    [sym_pointer_type] = STATE(2661),
    [sym_variadic_type] = STATE(2661),
    [sym_array_type] = STATE(2661),
    [sym_map_type] = STATE(2661),
    [sym_union_type] = STATE(2661),
    [sym_bit_set_type] = STATE(2661),
    [sym_matrix_type] = STATE(2661),
    [sym_field_type] = STATE(2661),
    [sym_tuple_type] = STATE(2661),
    [sym_struct_type] = STATE(2661),
    [sym_enum_type] = STATE(2661),
    [sym_bit_field_type] = STATE(2661),
    [sym_constant_type] = STATE(2661),
    [sym_specialized_type] = STATE(2661),
    [sym__procedure_type] = STATE(2661),
    [sym_distinct_type] = STATE(2661),
    [sym_empty_type] = STATE(2661),
    [sym_polymorphic_type] = STATE(2661),
    [sym_conditional_type] = STATE(2661),
    [sym_identifier] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(1361),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(1363),
    [anon_sym_enum] = ACTIONS(1365),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(1367),
    [anon_sym_bit_field] = ACTIONS(1369),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(1371),
    [anon_sym_DOLLAR] = ACTIONS(1374),
    [anon_sym_PLUS_EQ] = ACTIONS(909),
    [anon_sym_DASH_EQ] = ACTIONS(909),
    [anon_sym_STAR_EQ] = ACTIONS(909),
    [anon_sym_SLASH_EQ] = ACTIONS(909),
    [anon_sym_PERCENT_EQ] = ACTIONS(909),
    [anon_sym_AMP_EQ] = ACTIONS(909),
    [anon_sym_PIPE_EQ] = ACTIONS(909),
    [anon_sym_CARET_EQ] = ACTIONS(909),
    [anon_sym_LT_LT_EQ] = ACTIONS(909),
    [anon_sym_GT_GT_EQ] = ACTIONS(909),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(909),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(909),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_do] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(911),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(1376),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(911),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(911),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(911),
    [anon_sym_LT_LT] = ACTIONS(911),
    [anon_sym_GT_GT] = ACTIONS(911),
    [anon_sym_STAR] = ACTIONS(911),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(1378),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(1381),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(1383),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1386),
    [anon_sym_map] = ACTIONS(1388),
    [anon_sym_bit_set] = ACTIONS(1390),
    [anon_sym_matrix] = ACTIONS(1392),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_tag] = ACTIONS(1394),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [184] = {
    [sym_procedure] = STATE(2652),
    [sym_type] = STATE(2621),
    [sym_pointer_type] = STATE(2661),
    [sym_variadic_type] = STATE(2661),
    [sym_array_type] = STATE(2661),
    [sym_map_type] = STATE(2661),
    [sym_union_type] = STATE(2661),
    [sym_bit_set_type] = STATE(2661),
    [sym_matrix_type] = STATE(2661),
    [sym_field_type] = STATE(2661),
    [sym_tuple_type] = STATE(2661),
    [sym_struct_type] = STATE(2661),
    [sym_enum_type] = STATE(2661),
    [sym_bit_field_type] = STATE(2661),
    [sym_constant_type] = STATE(2661),
    [sym_specialized_type] = STATE(2661),
    [sym__procedure_type] = STATE(2661),
    [sym_distinct_type] = STATE(2661),
    [sym_empty_type] = STATE(2661),
    [sym_polymorphic_type] = STATE(2661),
    [sym_conditional_type] = STATE(2661),
    [sym_identifier] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(1361),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(1363),
    [anon_sym_enum] = ACTIONS(1365),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(1367),
    [anon_sym_bit_field] = ACTIONS(1369),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(1396),
    [anon_sym_DOLLAR] = ACTIONS(1374),
    [anon_sym_PLUS_EQ] = ACTIONS(833),
    [anon_sym_DASH_EQ] = ACTIONS(833),
    [anon_sym_STAR_EQ] = ACTIONS(833),
    [anon_sym_SLASH_EQ] = ACTIONS(833),
    [anon_sym_PERCENT_EQ] = ACTIONS(833),
    [anon_sym_AMP_EQ] = ACTIONS(833),
    [anon_sym_PIPE_EQ] = ACTIONS(833),
    [anon_sym_CARET_EQ] = ACTIONS(833),
    [anon_sym_LT_LT_EQ] = ACTIONS(833),
    [anon_sym_GT_GT_EQ] = ACTIONS(833),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(833),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(833),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_do] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(1376),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(836),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(836),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(1381),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(1404),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1386),
    [anon_sym_map] = ACTIONS(1388),
    [anon_sym_bit_set] = ACTIONS(1390),
    [anon_sym_matrix] = ACTIONS(1392),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_tag] = ACTIONS(1394),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [185] = {
    [sym_procedure] = STATE(2652),
    [sym_type] = STATE(2654),
    [sym_pointer_type] = STATE(2661),
    [sym_variadic_type] = STATE(2661),
    [sym_array_type] = STATE(2661),
    [sym_map_type] = STATE(2661),
    [sym_union_type] = STATE(2661),
    [sym_bit_set_type] = STATE(2661),
    [sym_matrix_type] = STATE(2661),
    [sym_field_type] = STATE(2661),
    [sym_tuple_type] = STATE(2661),
    [sym_struct_type] = STATE(2661),
    [sym_enum_type] = STATE(2661),
    [sym_bit_field_type] = STATE(2661),
    [sym_constant_type] = STATE(2661),
    [sym_specialized_type] = STATE(2661),
    [sym__procedure_type] = STATE(2661),
    [sym_distinct_type] = STATE(2661),
    [sym_empty_type] = STATE(2661),
    [sym_polymorphic_type] = STATE(2661),
    [sym_conditional_type] = STATE(2661),
    [sym_identifier] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(1361),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(1363),
    [anon_sym_enum] = ACTIONS(1365),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(1367),
    [anon_sym_bit_field] = ACTIONS(1369),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(1408),
    [anon_sym_DOLLAR] = ACTIONS(1374),
    [anon_sym_PLUS_EQ] = ACTIONS(893),
    [anon_sym_DASH_EQ] = ACTIONS(893),
    [anon_sym_STAR_EQ] = ACTIONS(893),
    [anon_sym_SLASH_EQ] = ACTIONS(893),
    [anon_sym_PERCENT_EQ] = ACTIONS(893),
    [anon_sym_AMP_EQ] = ACTIONS(893),
    [anon_sym_PIPE_EQ] = ACTIONS(893),
    [anon_sym_CARET_EQ] = ACTIONS(893),
    [anon_sym_LT_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_GT_EQ] = ACTIONS(893),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(893),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_do] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(1376),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(895),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(895),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1411),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(1381),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(1414),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1386),
    [anon_sym_map] = ACTIONS(1388),
    [anon_sym_bit_set] = ACTIONS(1390),
    [anon_sym_matrix] = ACTIONS(1392),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_tag] = ACTIONS(1394),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [186] = {
    [sym_procedure] = STATE(2652),
    [sym_type] = STATE(2662),
    [sym_pointer_type] = STATE(2661),
    [sym_variadic_type] = STATE(2661),
    [sym_array_type] = STATE(2661),
    [sym_map_type] = STATE(2661),
    [sym_union_type] = STATE(2661),
    [sym_bit_set_type] = STATE(2661),
    [sym_matrix_type] = STATE(2661),
    [sym_field_type] = STATE(2661),
    [sym_tuple_type] = STATE(2661),
    [sym_struct_type] = STATE(2661),
    [sym_enum_type] = STATE(2661),
    [sym_bit_field_type] = STATE(2661),
    [sym_constant_type] = STATE(2661),
    [sym_specialized_type] = STATE(2661),
    [sym__procedure_type] = STATE(2661),
    [sym_distinct_type] = STATE(2661),
    [sym_empty_type] = STATE(2661),
    [sym_polymorphic_type] = STATE(2661),
    [sym_conditional_type] = STATE(2661),
    [sym_identifier] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(1361),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_struct] = ACTIONS(1363),
    [anon_sym_enum] = ACTIONS(1365),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(1367),
    [anon_sym_bit_field] = ACTIONS(1369),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(1417),
    [anon_sym_DOLLAR] = ACTIONS(1374),
    [anon_sym_PLUS_EQ] = ACTIONS(871),
    [anon_sym_DASH_EQ] = ACTIONS(871),
    [anon_sym_STAR_EQ] = ACTIONS(871),
    [anon_sym_SLASH_EQ] = ACTIONS(871),
    [anon_sym_PERCENT_EQ] = ACTIONS(871),
    [anon_sym_AMP_EQ] = ACTIONS(871),
    [anon_sym_PIPE_EQ] = ACTIONS(871),
    [anon_sym_CARET_EQ] = ACTIONS(871),
    [anon_sym_LT_LT_EQ] = ACTIONS(871),
    [anon_sym_GT_GT_EQ] = ACTIONS(871),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(871),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(871),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_do] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(874),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(1376),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(874),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(874),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(874),
    [anon_sym_LT_LT] = ACTIONS(874),
    [anon_sym_GT_GT] = ACTIONS(874),
    [anon_sym_STAR] = ACTIONS(874),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(1421),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(1381),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(1425),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1386),
    [anon_sym_map] = ACTIONS(1388),
    [anon_sym_bit_set] = ACTIONS(1390),
    [anon_sym_matrix] = ACTIONS(1392),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_tag] = ACTIONS(1394),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [187] = {
    [sym_procedure] = STATE(2652),
    [sym_type] = STATE(2614),
    [sym_pointer_type] = STATE(2661),
    [sym_variadic_type] = STATE(2661),
    [sym_array_type] = STATE(2661),
    [sym_map_type] = STATE(2661),
    [sym_union_type] = STATE(2661),
    [sym_bit_set_type] = STATE(2661),
    [sym_matrix_type] = STATE(2661),
    [sym_field_type] = STATE(2661),
    [sym_tuple_type] = STATE(2661),
    [sym_struct_type] = STATE(2661),
    [sym_enum_type] = STATE(2661),
    [sym_bit_field_type] = STATE(2661),
    [sym_constant_type] = STATE(2661),
    [sym_specialized_type] = STATE(2661),
    [sym__procedure_type] = STATE(2661),
    [sym_distinct_type] = STATE(2661),
    [sym_empty_type] = STATE(2661),
    [sym_polymorphic_type] = STATE(2661),
    [sym_conditional_type] = STATE(2661),
    [sym_identifier] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(1361),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_struct] = ACTIONS(1363),
    [anon_sym_enum] = ACTIONS(1365),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(1367),
    [anon_sym_bit_field] = ACTIONS(1369),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(1429),
    [anon_sym_DOLLAR] = ACTIONS(1374),
    [anon_sym_PLUS_EQ] = ACTIONS(855),
    [anon_sym_DASH_EQ] = ACTIONS(855),
    [anon_sym_STAR_EQ] = ACTIONS(855),
    [anon_sym_SLASH_EQ] = ACTIONS(855),
    [anon_sym_PERCENT_EQ] = ACTIONS(855),
    [anon_sym_AMP_EQ] = ACTIONS(855),
    [anon_sym_PIPE_EQ] = ACTIONS(855),
    [anon_sym_CARET_EQ] = ACTIONS(855),
    [anon_sym_LT_LT_EQ] = ACTIONS(855),
    [anon_sym_GT_GT_EQ] = ACTIONS(855),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(855),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(855),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_do] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(857),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(1376),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(857),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(857),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(1432),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(1381),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(1435),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1386),
    [anon_sym_map] = ACTIONS(1388),
    [anon_sym_bit_set] = ACTIONS(1390),
    [anon_sym_matrix] = ACTIONS(1392),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_tag] = ACTIONS(1394),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [188] = {
    [sym_expression] = STATE(5910),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(1438),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(1089),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [189] = {
    [sym_procedure] = STATE(2652),
    [sym_type] = STATE(2610),
    [sym_pointer_type] = STATE(2661),
    [sym_variadic_type] = STATE(2661),
    [sym_array_type] = STATE(2661),
    [sym_map_type] = STATE(2661),
    [sym_union_type] = STATE(2661),
    [sym_bit_set_type] = STATE(2661),
    [sym_matrix_type] = STATE(2661),
    [sym_field_type] = STATE(2661),
    [sym_tuple_type] = STATE(2661),
    [sym_struct_type] = STATE(2661),
    [sym_enum_type] = STATE(2661),
    [sym_bit_field_type] = STATE(2661),
    [sym_constant_type] = STATE(2661),
    [sym_specialized_type] = STATE(2661),
    [sym__procedure_type] = STATE(2661),
    [sym_distinct_type] = STATE(2661),
    [sym_empty_type] = STATE(2661),
    [sym_polymorphic_type] = STATE(2661),
    [sym_conditional_type] = STATE(2661),
    [sym_identifier] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(1361),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(1363),
    [anon_sym_enum] = ACTIONS(1365),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(1367),
    [anon_sym_bit_field] = ACTIONS(1369),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(1444),
    [anon_sym_DOLLAR] = ACTIONS(1374),
    [anon_sym_PLUS_EQ] = ACTIONS(767),
    [anon_sym_DASH_EQ] = ACTIONS(767),
    [anon_sym_STAR_EQ] = ACTIONS(767),
    [anon_sym_SLASH_EQ] = ACTIONS(767),
    [anon_sym_PERCENT_EQ] = ACTIONS(767),
    [anon_sym_AMP_EQ] = ACTIONS(767),
    [anon_sym_PIPE_EQ] = ACTIONS(767),
    [anon_sym_CARET_EQ] = ACTIONS(767),
    [anon_sym_LT_LT_EQ] = ACTIONS(767),
    [anon_sym_GT_GT_EQ] = ACTIONS(767),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(767),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_do] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(1376),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(773),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(773),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(1447),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(1381),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(1450),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1386),
    [anon_sym_map] = ACTIONS(1388),
    [anon_sym_bit_set] = ACTIONS(1390),
    [anon_sym_matrix] = ACTIONS(1392),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_tag] = ACTIONS(1394),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [190] = {
    [sym_procedure] = STATE(2652),
    [sym_type] = STATE(2630),
    [sym_pointer_type] = STATE(2661),
    [sym_variadic_type] = STATE(2661),
    [sym_array_type] = STATE(2661),
    [sym_map_type] = STATE(2661),
    [sym_union_type] = STATE(2661),
    [sym_bit_set_type] = STATE(2661),
    [sym_matrix_type] = STATE(2661),
    [sym_field_type] = STATE(2661),
    [sym_tuple_type] = STATE(2661),
    [sym_struct_type] = STATE(2661),
    [sym_enum_type] = STATE(2661),
    [sym_bit_field_type] = STATE(2661),
    [sym_constant_type] = STATE(2661),
    [sym_specialized_type] = STATE(2661),
    [sym__procedure_type] = STATE(2661),
    [sym_distinct_type] = STATE(2661),
    [sym_empty_type] = STATE(2661),
    [sym_polymorphic_type] = STATE(2661),
    [sym_conditional_type] = STATE(2661),
    [sym_identifier] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(1361),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(1363),
    [anon_sym_enum] = ACTIONS(1365),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(1367),
    [anon_sym_bit_field] = ACTIONS(1369),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(1453),
    [anon_sym_DOLLAR] = ACTIONS(1374),
    [anon_sym_PLUS_EQ] = ACTIONS(809),
    [anon_sym_DASH_EQ] = ACTIONS(809),
    [anon_sym_STAR_EQ] = ACTIONS(809),
    [anon_sym_SLASH_EQ] = ACTIONS(809),
    [anon_sym_PERCENT_EQ] = ACTIONS(809),
    [anon_sym_AMP_EQ] = ACTIONS(809),
    [anon_sym_PIPE_EQ] = ACTIONS(809),
    [anon_sym_CARET_EQ] = ACTIONS(809),
    [anon_sym_LT_LT_EQ] = ACTIONS(809),
    [anon_sym_GT_GT_EQ] = ACTIONS(809),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(809),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_do] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(812),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(1376),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(812),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(812),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(812),
    [anon_sym_LT_LT] = ACTIONS(812),
    [anon_sym_GT_GT] = ACTIONS(812),
    [anon_sym_STAR] = ACTIONS(812),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(1457),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(1381),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(1461),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1386),
    [anon_sym_map] = ACTIONS(1388),
    [anon_sym_bit_set] = ACTIONS(1390),
    [anon_sym_matrix] = ACTIONS(1392),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_tag] = ACTIONS(1394),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [191] = {
    [sym_procedure] = STATE(7856),
    [sym_expression] = STATE(6064),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(1438),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(1089),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [192] = {
    [sym_procedure] = STATE(7926),
    [sym_expression] = STATE(6051),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(1438),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(1089),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [193] = {
    [sym_procedure] = STATE(7902),
    [sym_expression] = STATE(6033),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(1438),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(1089),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [194] = {
    [sym_expression] = STATE(5921),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(1438),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(1089),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [195] = {
    [sym_procedure] = STATE(7777),
    [sym_expression] = STATE(5971),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(1438),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(1089),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [196] = {
    [sym_expression] = STATE(4885),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(207),
    [anon_sym_DASH_GT] = ACTIONS(207),
    [anon_sym_PIPE] = ACTIONS(209),
    [anon_sym_LPAREN] = ACTIONS(207),
    [anon_sym_if] = ACTIONS(209),
    [anon_sym_do] = ACTIONS(209),
    [anon_sym_when] = ACTIONS(209),
    [anon_sym_in] = ACTIONS(209),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_PLUS] = ACTIONS(207),
    [anon_sym_DASH] = ACTIONS(209),
    [anon_sym_TILDE] = ACTIONS(209),
    [anon_sym_BANG] = ACTIONS(349),
    [anon_sym_AMP] = ACTIONS(209),
    [anon_sym_PIPE_PIPE] = ACTIONS(207),
    [anon_sym_or_else] = ACTIONS(209),
    [anon_sym_AMP_AMP] = ACTIONS(207),
    [anon_sym_GT] = ACTIONS(209),
    [anon_sym_GT_EQ] = ACTIONS(207),
    [anon_sym_LT_EQ] = ACTIONS(207),
    [anon_sym_LT] = ACTIONS(209),
    [anon_sym_EQ_EQ] = ACTIONS(207),
    [anon_sym_BANG_EQ] = ACTIONS(207),
    [anon_sym_TILDE_EQ] = ACTIONS(207),
    [anon_sym_AMP_TILDE] = ACTIONS(207),
    [anon_sym_LT_LT] = ACTIONS(207),
    [anon_sym_GT_GT] = ACTIONS(207),
    [anon_sym_STAR] = ACTIONS(207),
    [anon_sym_SLASH] = ACTIONS(209),
    [anon_sym_PERCENT] = ACTIONS(209),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(207),
    [anon_sym_DOT] = ACTIONS(209),
    [anon_sym_LBRACK] = ACTIONS(207),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(207),
    [anon_sym_DOT_DOT_LT] = ACTIONS(207),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_not_in] = ACTIONS(209),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_or_return] = ACTIONS(209),
    [anon_sym_or_continue] = ACTIONS(209),
    [anon_sym_or_break] = ACTIONS(209),
    [anon_sym_CARET] = ACTIONS(207),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [197] = {
    [sym_procedure] = STATE(2805),
    [sym_type] = STATE(2935),
    [sym_pointer_type] = STATE(2885),
    [sym_variadic_type] = STATE(2885),
    [sym_array_type] = STATE(2885),
    [sym_map_type] = STATE(2885),
    [sym_union_type] = STATE(2885),
    [sym_bit_set_type] = STATE(2885),
    [sym_matrix_type] = STATE(2885),
    [sym_field_type] = STATE(2885),
    [sym_tuple_type] = STATE(2885),
    [sym_struct_type] = STATE(2885),
    [sym_enum_type] = STATE(2885),
    [sym_bit_field_type] = STATE(2885),
    [sym_constant_type] = STATE(2885),
    [sym_specialized_type] = STATE(2885),
    [sym__procedure_type] = STATE(2885),
    [sym_distinct_type] = STATE(2885),
    [sym_empty_type] = STATE(2885),
    [sym_polymorphic_type] = STATE(2885),
    [sym_conditional_type] = STATE(2885),
    [sym_identifier] = ACTIONS(1467),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(1469),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_struct] = ACTIONS(1471),
    [anon_sym_enum] = ACTIONS(1473),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(1475),
    [anon_sym_bit_field] = ACTIONS(1477),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(1479),
    [anon_sym_DOLLAR] = ACTIONS(1483),
    [anon_sym_PLUS_EQ] = ACTIONS(871),
    [anon_sym_DASH_EQ] = ACTIONS(871),
    [anon_sym_STAR_EQ] = ACTIONS(871),
    [anon_sym_SLASH_EQ] = ACTIONS(871),
    [anon_sym_PERCENT_EQ] = ACTIONS(871),
    [anon_sym_AMP_EQ] = ACTIONS(871),
    [anon_sym_PIPE_EQ] = ACTIONS(871),
    [anon_sym_CARET_EQ] = ACTIONS(871),
    [anon_sym_LT_LT_EQ] = ACTIONS(871),
    [anon_sym_GT_GT_EQ] = ACTIONS(871),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(871),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(871),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(874),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(874),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(874),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(874),
    [anon_sym_LT_LT] = ACTIONS(874),
    [anon_sym_GT_GT] = ACTIONS(874),
    [anon_sym_STAR] = ACTIONS(874),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(1487),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(1491),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(1493),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1497),
    [anon_sym_map] = ACTIONS(1499),
    [anon_sym_bit_set] = ACTIONS(1501),
    [anon_sym_matrix] = ACTIONS(1503),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_tag] = ACTIONS(1505),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [198] = {
    [sym_procedure] = STATE(2805),
    [sym_type] = STATE(2857),
    [sym_pointer_type] = STATE(2885),
    [sym_variadic_type] = STATE(2885),
    [sym_array_type] = STATE(2885),
    [sym_map_type] = STATE(2885),
    [sym_union_type] = STATE(2885),
    [sym_bit_set_type] = STATE(2885),
    [sym_matrix_type] = STATE(2885),
    [sym_field_type] = STATE(2885),
    [sym_tuple_type] = STATE(2885),
    [sym_struct_type] = STATE(2885),
    [sym_enum_type] = STATE(2885),
    [sym_bit_field_type] = STATE(2885),
    [sym_constant_type] = STATE(2885),
    [sym_specialized_type] = STATE(2885),
    [sym__procedure_type] = STATE(2885),
    [sym_distinct_type] = STATE(2885),
    [sym_empty_type] = STATE(2885),
    [sym_polymorphic_type] = STATE(2885),
    [sym_conditional_type] = STATE(2885),
    [sym_identifier] = ACTIONS(1467),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(1469),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(1471),
    [anon_sym_enum] = ACTIONS(1473),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(1475),
    [anon_sym_bit_field] = ACTIONS(1477),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(1507),
    [anon_sym_DOLLAR] = ACTIONS(1483),
    [anon_sym_PLUS_EQ] = ACTIONS(893),
    [anon_sym_DASH_EQ] = ACTIONS(893),
    [anon_sym_STAR_EQ] = ACTIONS(893),
    [anon_sym_SLASH_EQ] = ACTIONS(893),
    [anon_sym_PERCENT_EQ] = ACTIONS(893),
    [anon_sym_AMP_EQ] = ACTIONS(893),
    [anon_sym_PIPE_EQ] = ACTIONS(893),
    [anon_sym_CARET_EQ] = ACTIONS(893),
    [anon_sym_LT_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_GT_EQ] = ACTIONS(893),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(893),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(895),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(895),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1510),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(1491),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1497),
    [anon_sym_map] = ACTIONS(1499),
    [anon_sym_bit_set] = ACTIONS(1501),
    [anon_sym_matrix] = ACTIONS(1503),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_tag] = ACTIONS(1505),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [199] = {
    [sym_procedure] = STATE(2805),
    [sym_type] = STATE(2880),
    [sym_pointer_type] = STATE(2885),
    [sym_variadic_type] = STATE(2885),
    [sym_array_type] = STATE(2885),
    [sym_map_type] = STATE(2885),
    [sym_union_type] = STATE(2885),
    [sym_bit_set_type] = STATE(2885),
    [sym_matrix_type] = STATE(2885),
    [sym_field_type] = STATE(2885),
    [sym_tuple_type] = STATE(2885),
    [sym_struct_type] = STATE(2885),
    [sym_enum_type] = STATE(2885),
    [sym_bit_field_type] = STATE(2885),
    [sym_constant_type] = STATE(2885),
    [sym_specialized_type] = STATE(2885),
    [sym__procedure_type] = STATE(2885),
    [sym_distinct_type] = STATE(2885),
    [sym_empty_type] = STATE(2885),
    [sym_polymorphic_type] = STATE(2885),
    [sym_conditional_type] = STATE(2885),
    [sym_identifier] = ACTIONS(1467),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(1469),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_struct] = ACTIONS(1471),
    [anon_sym_enum] = ACTIONS(1473),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(1475),
    [anon_sym_bit_field] = ACTIONS(1477),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(1516),
    [anon_sym_DOLLAR] = ACTIONS(1483),
    [anon_sym_PLUS_EQ] = ACTIONS(855),
    [anon_sym_DASH_EQ] = ACTIONS(855),
    [anon_sym_STAR_EQ] = ACTIONS(855),
    [anon_sym_SLASH_EQ] = ACTIONS(855),
    [anon_sym_PERCENT_EQ] = ACTIONS(855),
    [anon_sym_AMP_EQ] = ACTIONS(855),
    [anon_sym_PIPE_EQ] = ACTIONS(855),
    [anon_sym_CARET_EQ] = ACTIONS(855),
    [anon_sym_LT_LT_EQ] = ACTIONS(855),
    [anon_sym_GT_GT_EQ] = ACTIONS(855),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(855),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(855),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(857),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(857),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(857),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(1519),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(1491),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(1522),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1497),
    [anon_sym_map] = ACTIONS(1499),
    [anon_sym_bit_set] = ACTIONS(1501),
    [anon_sym_matrix] = ACTIONS(1503),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_tag] = ACTIONS(1505),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [200] = {
    [sym_procedure] = STATE(2805),
    [sym_type] = STATE(2835),
    [sym_pointer_type] = STATE(2885),
    [sym_variadic_type] = STATE(2885),
    [sym_array_type] = STATE(2885),
    [sym_map_type] = STATE(2885),
    [sym_union_type] = STATE(2885),
    [sym_bit_set_type] = STATE(2885),
    [sym_matrix_type] = STATE(2885),
    [sym_field_type] = STATE(2885),
    [sym_tuple_type] = STATE(2885),
    [sym_struct_type] = STATE(2885),
    [sym_enum_type] = STATE(2885),
    [sym_bit_field_type] = STATE(2885),
    [sym_constant_type] = STATE(2885),
    [sym_specialized_type] = STATE(2885),
    [sym__procedure_type] = STATE(2885),
    [sym_distinct_type] = STATE(2885),
    [sym_empty_type] = STATE(2885),
    [sym_polymorphic_type] = STATE(2885),
    [sym_conditional_type] = STATE(2885),
    [sym_identifier] = ACTIONS(1467),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(1469),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(1471),
    [anon_sym_enum] = ACTIONS(1473),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(1475),
    [anon_sym_bit_field] = ACTIONS(1477),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(1525),
    [anon_sym_DOLLAR] = ACTIONS(1483),
    [anon_sym_PLUS_EQ] = ACTIONS(767),
    [anon_sym_DASH_EQ] = ACTIONS(767),
    [anon_sym_STAR_EQ] = ACTIONS(767),
    [anon_sym_SLASH_EQ] = ACTIONS(767),
    [anon_sym_PERCENT_EQ] = ACTIONS(767),
    [anon_sym_AMP_EQ] = ACTIONS(767),
    [anon_sym_PIPE_EQ] = ACTIONS(767),
    [anon_sym_CARET_EQ] = ACTIONS(767),
    [anon_sym_LT_LT_EQ] = ACTIONS(767),
    [anon_sym_GT_GT_EQ] = ACTIONS(767),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(767),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(773),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(773),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(1528),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(1491),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(1531),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1497),
    [anon_sym_map] = ACTIONS(1499),
    [anon_sym_bit_set] = ACTIONS(1501),
    [anon_sym_matrix] = ACTIONS(1503),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_tag] = ACTIONS(1505),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [201] = {
    [sym_procedure] = STATE(2805),
    [sym_type] = STATE(2864),
    [sym_pointer_type] = STATE(2885),
    [sym_variadic_type] = STATE(2885),
    [sym_array_type] = STATE(2885),
    [sym_map_type] = STATE(2885),
    [sym_union_type] = STATE(2885),
    [sym_bit_set_type] = STATE(2885),
    [sym_matrix_type] = STATE(2885),
    [sym_field_type] = STATE(2885),
    [sym_tuple_type] = STATE(2885),
    [sym_struct_type] = STATE(2885),
    [sym_enum_type] = STATE(2885),
    [sym_bit_field_type] = STATE(2885),
    [sym_constant_type] = STATE(2885),
    [sym_specialized_type] = STATE(2885),
    [sym__procedure_type] = STATE(2885),
    [sym_distinct_type] = STATE(2885),
    [sym_empty_type] = STATE(2885),
    [sym_polymorphic_type] = STATE(2885),
    [sym_conditional_type] = STATE(2885),
    [sym_identifier] = ACTIONS(1467),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(1469),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(1471),
    [anon_sym_enum] = ACTIONS(1473),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(1475),
    [anon_sym_bit_field] = ACTIONS(1477),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(1534),
    [anon_sym_DOLLAR] = ACTIONS(1483),
    [anon_sym_PLUS_EQ] = ACTIONS(909),
    [anon_sym_DASH_EQ] = ACTIONS(909),
    [anon_sym_STAR_EQ] = ACTIONS(909),
    [anon_sym_SLASH_EQ] = ACTIONS(909),
    [anon_sym_PERCENT_EQ] = ACTIONS(909),
    [anon_sym_AMP_EQ] = ACTIONS(909),
    [anon_sym_PIPE_EQ] = ACTIONS(909),
    [anon_sym_CARET_EQ] = ACTIONS(909),
    [anon_sym_LT_LT_EQ] = ACTIONS(909),
    [anon_sym_GT_GT_EQ] = ACTIONS(909),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(909),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(909),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(911),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(911),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(911),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(911),
    [anon_sym_LT_LT] = ACTIONS(911),
    [anon_sym_GT_GT] = ACTIONS(911),
    [anon_sym_STAR] = ACTIONS(911),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(1537),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(1491),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(1540),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1497),
    [anon_sym_map] = ACTIONS(1499),
    [anon_sym_bit_set] = ACTIONS(1501),
    [anon_sym_matrix] = ACTIONS(1503),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_tag] = ACTIONS(1505),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [202] = {
    [sym_procedure] = STATE(2805),
    [sym_type] = STATE(2870),
    [sym_pointer_type] = STATE(2885),
    [sym_variadic_type] = STATE(2885),
    [sym_array_type] = STATE(2885),
    [sym_map_type] = STATE(2885),
    [sym_union_type] = STATE(2885),
    [sym_bit_set_type] = STATE(2885),
    [sym_matrix_type] = STATE(2885),
    [sym_field_type] = STATE(2885),
    [sym_tuple_type] = STATE(2885),
    [sym_struct_type] = STATE(2885),
    [sym_enum_type] = STATE(2885),
    [sym_bit_field_type] = STATE(2885),
    [sym_constant_type] = STATE(2885),
    [sym_specialized_type] = STATE(2885),
    [sym__procedure_type] = STATE(2885),
    [sym_distinct_type] = STATE(2885),
    [sym_empty_type] = STATE(2885),
    [sym_polymorphic_type] = STATE(2885),
    [sym_conditional_type] = STATE(2885),
    [sym_identifier] = ACTIONS(1467),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(1469),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(1471),
    [anon_sym_enum] = ACTIONS(1473),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(1475),
    [anon_sym_bit_field] = ACTIONS(1477),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(1543),
    [anon_sym_DOLLAR] = ACTIONS(1483),
    [anon_sym_PLUS_EQ] = ACTIONS(809),
    [anon_sym_DASH_EQ] = ACTIONS(809),
    [anon_sym_STAR_EQ] = ACTIONS(809),
    [anon_sym_SLASH_EQ] = ACTIONS(809),
    [anon_sym_PERCENT_EQ] = ACTIONS(809),
    [anon_sym_AMP_EQ] = ACTIONS(809),
    [anon_sym_PIPE_EQ] = ACTIONS(809),
    [anon_sym_CARET_EQ] = ACTIONS(809),
    [anon_sym_LT_LT_EQ] = ACTIONS(809),
    [anon_sym_GT_GT_EQ] = ACTIONS(809),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(809),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(812),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(812),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(812),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(812),
    [anon_sym_LT_LT] = ACTIONS(812),
    [anon_sym_GT_GT] = ACTIONS(812),
    [anon_sym_STAR] = ACTIONS(812),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(1491),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(1551),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1497),
    [anon_sym_map] = ACTIONS(1499),
    [anon_sym_bit_set] = ACTIONS(1501),
    [anon_sym_matrix] = ACTIONS(1503),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_tag] = ACTIONS(1505),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [203] = {
    [sym_procedure] = STATE(2805),
    [sym_type] = STATE(2843),
    [sym_pointer_type] = STATE(2885),
    [sym_variadic_type] = STATE(2885),
    [sym_array_type] = STATE(2885),
    [sym_map_type] = STATE(2885),
    [sym_union_type] = STATE(2885),
    [sym_bit_set_type] = STATE(2885),
    [sym_matrix_type] = STATE(2885),
    [sym_field_type] = STATE(2885),
    [sym_tuple_type] = STATE(2885),
    [sym_struct_type] = STATE(2885),
    [sym_enum_type] = STATE(2885),
    [sym_bit_field_type] = STATE(2885),
    [sym_constant_type] = STATE(2885),
    [sym_specialized_type] = STATE(2885),
    [sym__procedure_type] = STATE(2885),
    [sym_distinct_type] = STATE(2885),
    [sym_empty_type] = STATE(2885),
    [sym_polymorphic_type] = STATE(2885),
    [sym_conditional_type] = STATE(2885),
    [sym_identifier] = ACTIONS(1467),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(1469),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(1471),
    [anon_sym_enum] = ACTIONS(1473),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(1475),
    [anon_sym_bit_field] = ACTIONS(1477),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_DOLLAR] = ACTIONS(1483),
    [anon_sym_PLUS_EQ] = ACTIONS(833),
    [anon_sym_DASH_EQ] = ACTIONS(833),
    [anon_sym_STAR_EQ] = ACTIONS(833),
    [anon_sym_SLASH_EQ] = ACTIONS(833),
    [anon_sym_PERCENT_EQ] = ACTIONS(833),
    [anon_sym_AMP_EQ] = ACTIONS(833),
    [anon_sym_PIPE_EQ] = ACTIONS(833),
    [anon_sym_CARET_EQ] = ACTIONS(833),
    [anon_sym_LT_LT_EQ] = ACTIONS(833),
    [anon_sym_GT_GT_EQ] = ACTIONS(833),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(833),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(833),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(836),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(836),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1559),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(1491),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(1563),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1497),
    [anon_sym_map] = ACTIONS(1499),
    [anon_sym_bit_set] = ACTIONS(1501),
    [anon_sym_matrix] = ACTIONS(1503),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_tag] = ACTIONS(1505),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [204] = {
    [sym_declaration] = STATE(7675),
    [sym_build_tag] = STATE(8531),
    [sym_package_declaration] = STATE(8531),
    [sym_import_declaration] = STATE(8531),
    [sym_procedure_declaration] = STATE(8531),
    [sym_overloaded_procedure_declaration] = STATE(8531),
    [sym_struct_declaration] = STATE(8531),
    [sym_enum_declaration] = STATE(8531),
    [sym_union_declaration] = STATE(8531),
    [sym_bit_field_declaration] = STATE(8531),
    [sym_variable_declaration] = STATE(8531),
    [sym_const_declaration] = STATE(8531),
    [sym_const_type_declaration] = STATE(8531),
    [sym_foreign_block] = STATE(8531),
    [sym_attributes] = STATE(855),
    [sym_attribute] = STATE(6180),
    [sym_when_statement] = STATE(8531),
    [sym_var_declaration] = STATE(8531),
    [sym_expression] = STATE(5770),
    [sym__expression_no_tag] = STATE(4733),
    [sym_unary_expression] = STATE(4733),
    [sym_binary_expression] = STATE(4733),
    [sym_ternary_expression] = STATE(4733),
    [sym_call_expression] = STATE(4733),
    [sym_selector_call_expression] = STATE(4733),
    [sym_member_expression] = STATE(4733),
    [sym_index_expression] = STATE(4733),
    [sym_slice_expression] = STATE(4733),
    [sym_range_expression] = STATE(4733),
    [sym_cast_expression] = STATE(4733),
    [sym_in_expression] = STATE(4733),
    [sym_variadic_expression] = STATE(4733),
    [sym_parenthesized_expression] = STATE(4733),
    [sym_or_return_expression] = STATE(4733),
    [sym_or_continue_expression] = STATE(4733),
    [sym_or_break_expression] = STATE(4733),
    [sym_address] = STATE(4733),
    [sym_map_type] = STATE(4733),
    [sym_matrix_type] = STATE(4733),
    [sym_distinct_type] = STATE(4733),
    [sym_literal] = STATE(4733),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [aux_sym_source_file_repeat1] = STATE(205),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [ts_builtin_sym_end] = ACTIONS(1567),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_POUND_PLUS] = ACTIONS(11),
    [anon_sym_package] = ACTIONS(13),
    [anon_sym_foreign] = ACTIONS(15),
    [anon_sym_import] = ACTIONS(17),
    [anon_sym_using] = ACTIONS(19),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_when] = ACTIONS(25),
    [anon_sym_QMARK] = ACTIONS(27),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(63),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [205] = {
    [sym_declaration] = STATE(7800),
    [sym_build_tag] = STATE(8531),
    [sym_package_declaration] = STATE(8531),
    [sym_import_declaration] = STATE(8531),
    [sym_procedure_declaration] = STATE(8531),
    [sym_overloaded_procedure_declaration] = STATE(8531),
    [sym_struct_declaration] = STATE(8531),
    [sym_enum_declaration] = STATE(8531),
    [sym_union_declaration] = STATE(8531),
    [sym_bit_field_declaration] = STATE(8531),
    [sym_variable_declaration] = STATE(8531),
    [sym_const_declaration] = STATE(8531),
    [sym_const_type_declaration] = STATE(8531),
    [sym_foreign_block] = STATE(8531),
    [sym_attributes] = STATE(855),
    [sym_attribute] = STATE(6180),
    [sym_when_statement] = STATE(8531),
    [sym_var_declaration] = STATE(8531),
    [sym_expression] = STATE(5770),
    [sym__expression_no_tag] = STATE(4733),
    [sym_unary_expression] = STATE(4733),
    [sym_binary_expression] = STATE(4733),
    [sym_ternary_expression] = STATE(4733),
    [sym_call_expression] = STATE(4733),
    [sym_selector_call_expression] = STATE(4733),
    [sym_member_expression] = STATE(4733),
    [sym_index_expression] = STATE(4733),
    [sym_slice_expression] = STATE(4733),
    [sym_range_expression] = STATE(4733),
    [sym_cast_expression] = STATE(4733),
    [sym_in_expression] = STATE(4733),
    [sym_variadic_expression] = STATE(4733),
    [sym_parenthesized_expression] = STATE(4733),
    [sym_or_return_expression] = STATE(4733),
    [sym_or_continue_expression] = STATE(4733),
    [sym_or_break_expression] = STATE(4733),
    [sym_address] = STATE(4733),
    [sym_map_type] = STATE(4733),
    [sym_matrix_type] = STATE(4733),
    [sym_distinct_type] = STATE(4733),
    [sym_literal] = STATE(4733),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [aux_sym_source_file_repeat1] = STATE(205),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [ts_builtin_sym_end] = ACTIONS(1569),
    [sym_identifier] = ACTIONS(1571),
    [anon_sym_LBRACE] = ACTIONS(1574),
    [anon_sym_POUND_PLUS] = ACTIONS(1577),
    [anon_sym_package] = ACTIONS(1580),
    [anon_sym_foreign] = ACTIONS(1583),
    [anon_sym_import] = ACTIONS(1586),
    [anon_sym_using] = ACTIONS(1589),
    [anon_sym_AT] = ACTIONS(1592),
    [anon_sym_LPAREN] = ACTIONS(1595),
    [anon_sym_when] = ACTIONS(1598),
    [anon_sym_QMARK] = ACTIONS(1601),
    [anon_sym_PLUS] = ACTIONS(1604),
    [anon_sym_DASH] = ACTIONS(1607),
    [anon_sym_TILDE] = ACTIONS(1604),
    [anon_sym_BANG] = ACTIONS(1604),
    [anon_sym_AMP] = ACTIONS(1604),
    [anon_sym_DOT] = ACTIONS(1610),
    [anon_sym_LBRACK] = ACTIONS(1613),
    [anon_sym_cast] = ACTIONS(1616),
    [anon_sym_transmute] = ACTIONS(1616),
    [anon_sym_auto_cast] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1622),
    [anon_sym_map] = ACTIONS(1625),
    [anon_sym_bit_set] = ACTIONS(1628),
    [anon_sym_matrix] = ACTIONS(1631),
    [anon_sym_distinct] = ACTIONS(1634),
    [sym_number] = ACTIONS(1637),
    [anon_sym_DQUOTE] = ACTIONS(1640),
    [anon_sym_BQUOTE] = ACTIONS(1643),
    [anon_sym_SQUOTE] = ACTIONS(1646),
    [anon_sym_true] = ACTIONS(1649),
    [anon_sym_false] = ACTIONS(1649),
    [sym_nil] = ACTIONS(1652),
    [sym_uninitialized] = ACTIONS(1637),
    [sym_tag] = ACTIONS(1655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1637),
    [sym_block_comment] = ACTIONS(3),
  },
  [206] = {
    [sym_expression] = STATE(5994),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(1658),
    [anon_sym_LBRACE] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(1660),
    [anon_sym_do] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(349),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [207] = {
    [sym_expression] = STATE(6000),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(1658),
    [anon_sym_LBRACE] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(1660),
    [anon_sym_do] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(349),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [208] = {
    [sym_expression] = STATE(6041),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(1658),
    [anon_sym_LBRACE] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(1660),
    [anon_sym_do] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(349),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [209] = {
    [sym_expression] = STATE(6134),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(1658),
    [anon_sym_LBRACE] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(1660),
    [anon_sym_do] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(349),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(69),
    [anon_sym_LT_LT] = ACTIONS(69),
    [anon_sym_GT_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [210] = {
    [sym_procedure] = STATE(3237),
    [sym_type] = STATE(3343),
    [sym_pointer_type] = STATE(3312),
    [sym_variadic_type] = STATE(3312),
    [sym_array_type] = STATE(3312),
    [sym_map_type] = STATE(3312),
    [sym_union_type] = STATE(3312),
    [sym_bit_set_type] = STATE(3312),
    [sym_matrix_type] = STATE(3312),
    [sym_field_type] = STATE(3312),
    [sym_tuple_type] = STATE(3312),
    [sym_struct_type] = STATE(3312),
    [sym_enum_type] = STATE(3312),
    [sym_bit_field_type] = STATE(3312),
    [sym_constant_type] = STATE(3312),
    [sym_specialized_type] = STATE(3312),
    [sym__procedure_type] = STATE(3312),
    [sym_distinct_type] = STATE(3312),
    [sym_empty_type] = STATE(3312),
    [sym_polymorphic_type] = STATE(3312),
    [sym_conditional_type] = STATE(3312),
    [ts_builtin_sym_end] = ACTIONS(833),
    [sym_identifier] = ACTIONS(1662),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(1664),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_where] = ACTIONS(836),
    [anon_sym_struct] = ACTIONS(1666),
    [anon_sym_enum] = ACTIONS(1668),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(1670),
    [anon_sym_bit_field] = ACTIONS(1672),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(1674),
    [anon_sym_DOLLAR] = ACTIONS(1678),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(1680),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1682),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(1686),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(1688),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1692),
    [anon_sym_map] = ACTIONS(1694),
    [anon_sym_bit_set] = ACTIONS(1696),
    [anon_sym_matrix] = ACTIONS(1698),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_uninitialized] = ACTIONS(833),
    [sym_tag] = ACTIONS(1700),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(833),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [211] = {
    [sym_procedure] = STATE(3237),
    [sym_type] = STATE(3372),
    [sym_pointer_type] = STATE(3312),
    [sym_variadic_type] = STATE(3312),
    [sym_array_type] = STATE(3312),
    [sym_map_type] = STATE(3312),
    [sym_union_type] = STATE(3312),
    [sym_bit_set_type] = STATE(3312),
    [sym_matrix_type] = STATE(3312),
    [sym_field_type] = STATE(3312),
    [sym_tuple_type] = STATE(3312),
    [sym_struct_type] = STATE(3312),
    [sym_enum_type] = STATE(3312),
    [sym_bit_field_type] = STATE(3312),
    [sym_constant_type] = STATE(3312),
    [sym_specialized_type] = STATE(3312),
    [sym__procedure_type] = STATE(3312),
    [sym_distinct_type] = STATE(3312),
    [sym_empty_type] = STATE(3312),
    [sym_polymorphic_type] = STATE(3312),
    [sym_conditional_type] = STATE(3312),
    [ts_builtin_sym_end] = ACTIONS(809),
    [sym_identifier] = ACTIONS(1662),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(1664),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_where] = ACTIONS(812),
    [anon_sym_struct] = ACTIONS(1666),
    [anon_sym_enum] = ACTIONS(1668),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(1670),
    [anon_sym_bit_field] = ACTIONS(1672),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(1704),
    [anon_sym_DOLLAR] = ACTIONS(1678),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_case] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(1680),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(1708),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(1686),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(1712),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1692),
    [anon_sym_map] = ACTIONS(1694),
    [anon_sym_bit_set] = ACTIONS(1696),
    [anon_sym_matrix] = ACTIONS(1698),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_uninitialized] = ACTIONS(809),
    [sym_tag] = ACTIONS(1716),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [212] = {
    [sym_procedure] = STATE(3237),
    [sym_type] = STATE(3231),
    [sym_pointer_type] = STATE(3312),
    [sym_variadic_type] = STATE(3312),
    [sym_array_type] = STATE(3312),
    [sym_map_type] = STATE(3312),
    [sym_union_type] = STATE(3312),
    [sym_bit_set_type] = STATE(3312),
    [sym_matrix_type] = STATE(3312),
    [sym_field_type] = STATE(3312),
    [sym_tuple_type] = STATE(3312),
    [sym_struct_type] = STATE(3312),
    [sym_enum_type] = STATE(3312),
    [sym_bit_field_type] = STATE(3312),
    [sym_constant_type] = STATE(3312),
    [sym_specialized_type] = STATE(3312),
    [sym__procedure_type] = STATE(3312),
    [sym_distinct_type] = STATE(3312),
    [sym_empty_type] = STATE(3312),
    [sym_polymorphic_type] = STATE(3312),
    [sym_conditional_type] = STATE(3312),
    [ts_builtin_sym_end] = ACTIONS(855),
    [sym_identifier] = ACTIONS(1662),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(1664),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_where] = ACTIONS(857),
    [anon_sym_struct] = ACTIONS(1666),
    [anon_sym_enum] = ACTIONS(1668),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(1670),
    [anon_sym_bit_field] = ACTIONS(1672),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(1720),
    [anon_sym_DOLLAR] = ACTIONS(1678),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(1680),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(1723),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(1686),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(1726),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1692),
    [anon_sym_map] = ACTIONS(1694),
    [anon_sym_bit_set] = ACTIONS(1696),
    [anon_sym_matrix] = ACTIONS(1698),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_uninitialized] = ACTIONS(855),
    [sym_tag] = ACTIONS(1729),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(855),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [213] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3078),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(1732),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(1734),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_where] = ACTIONS(836),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(1744),
    [anon_sym_RPAREN] = ACTIONS(833),
    [anon_sym_DOLLAR] = ACTIONS(1748),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_do] = ACTIONS(836),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1752),
    [anon_sym_RBRACK] = ACTIONS(833),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(1756),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(1758),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(1764),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(1768),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_uninitialized] = ACTIONS(833),
    [sym_tag] = ACTIONS(1770),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [214] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3108),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(1732),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(1734),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_where] = ACTIONS(812),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(1774),
    [anon_sym_RPAREN] = ACTIONS(809),
    [anon_sym_DOLLAR] = ACTIONS(1748),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_do] = ACTIONS(812),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(1778),
    [anon_sym_RBRACK] = ACTIONS(809),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(1756),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(1782),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(1764),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(1768),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_uninitialized] = ACTIONS(809),
    [sym_tag] = ACTIONS(1786),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [215] = {
    [sym_procedure] = STATE(3237),
    [sym_type] = STATE(3266),
    [sym_pointer_type] = STATE(3312),
    [sym_variadic_type] = STATE(3312),
    [sym_array_type] = STATE(3312),
    [sym_map_type] = STATE(3312),
    [sym_union_type] = STATE(3312),
    [sym_bit_set_type] = STATE(3312),
    [sym_matrix_type] = STATE(3312),
    [sym_field_type] = STATE(3312),
    [sym_tuple_type] = STATE(3312),
    [sym_struct_type] = STATE(3312),
    [sym_enum_type] = STATE(3312),
    [sym_bit_field_type] = STATE(3312),
    [sym_constant_type] = STATE(3312),
    [sym_specialized_type] = STATE(3312),
    [sym__procedure_type] = STATE(3312),
    [sym_distinct_type] = STATE(3312),
    [sym_empty_type] = STATE(3312),
    [sym_polymorphic_type] = STATE(3312),
    [sym_conditional_type] = STATE(3312),
    [ts_builtin_sym_end] = ACTIONS(871),
    [sym_identifier] = ACTIONS(1662),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(1664),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_where] = ACTIONS(874),
    [anon_sym_struct] = ACTIONS(1666),
    [anon_sym_enum] = ACTIONS(1668),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(1670),
    [anon_sym_bit_field] = ACTIONS(1672),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(1790),
    [anon_sym_DOLLAR] = ACTIONS(1678),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_case] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(1680),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(1794),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(1686),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(1798),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1692),
    [anon_sym_map] = ACTIONS(1694),
    [anon_sym_bit_set] = ACTIONS(1696),
    [anon_sym_matrix] = ACTIONS(1698),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_uninitialized] = ACTIONS(871),
    [sym_tag] = ACTIONS(1802),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [216] = {
    [sym_procedure] = STATE(3237),
    [sym_type] = STATE(3308),
    [sym_pointer_type] = STATE(3312),
    [sym_variadic_type] = STATE(3312),
    [sym_array_type] = STATE(3312),
    [sym_map_type] = STATE(3312),
    [sym_union_type] = STATE(3312),
    [sym_bit_set_type] = STATE(3312),
    [sym_matrix_type] = STATE(3312),
    [sym_field_type] = STATE(3312),
    [sym_tuple_type] = STATE(3312),
    [sym_struct_type] = STATE(3312),
    [sym_enum_type] = STATE(3312),
    [sym_bit_field_type] = STATE(3312),
    [sym_constant_type] = STATE(3312),
    [sym_specialized_type] = STATE(3312),
    [sym__procedure_type] = STATE(3312),
    [sym_distinct_type] = STATE(3312),
    [sym_empty_type] = STATE(3312),
    [sym_polymorphic_type] = STATE(3312),
    [sym_conditional_type] = STATE(3312),
    [ts_builtin_sym_end] = ACTIONS(893),
    [sym_identifier] = ACTIONS(1662),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(1664),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_where] = ACTIONS(895),
    [anon_sym_struct] = ACTIONS(1666),
    [anon_sym_enum] = ACTIONS(1668),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(1670),
    [anon_sym_bit_field] = ACTIONS(1672),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(1806),
    [anon_sym_DOLLAR] = ACTIONS(1678),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_case] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(1680),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1809),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(1686),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(1812),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1692),
    [anon_sym_map] = ACTIONS(1694),
    [anon_sym_bit_set] = ACTIONS(1696),
    [anon_sym_matrix] = ACTIONS(1698),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_uninitialized] = ACTIONS(893),
    [sym_tag] = ACTIONS(1815),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [217] = {
    [sym_procedure] = STATE(3237),
    [sym_type] = STATE(3310),
    [sym_pointer_type] = STATE(3312),
    [sym_variadic_type] = STATE(3312),
    [sym_array_type] = STATE(3312),
    [sym_map_type] = STATE(3312),
    [sym_union_type] = STATE(3312),
    [sym_bit_set_type] = STATE(3312),
    [sym_matrix_type] = STATE(3312),
    [sym_field_type] = STATE(3312),
    [sym_tuple_type] = STATE(3312),
    [sym_struct_type] = STATE(3312),
    [sym_enum_type] = STATE(3312),
    [sym_bit_field_type] = STATE(3312),
    [sym_constant_type] = STATE(3312),
    [sym_specialized_type] = STATE(3312),
    [sym__procedure_type] = STATE(3312),
    [sym_distinct_type] = STATE(3312),
    [sym_empty_type] = STATE(3312),
    [sym_polymorphic_type] = STATE(3312),
    [sym_conditional_type] = STATE(3312),
    [ts_builtin_sym_end] = ACTIONS(909),
    [sym_identifier] = ACTIONS(1662),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(1664),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_where] = ACTIONS(911),
    [anon_sym_struct] = ACTIONS(1666),
    [anon_sym_enum] = ACTIONS(1668),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(1670),
    [anon_sym_bit_field] = ACTIONS(1672),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(1818),
    [anon_sym_DOLLAR] = ACTIONS(1678),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_case] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(1680),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(1821),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(1686),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(1824),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1692),
    [anon_sym_map] = ACTIONS(1694),
    [anon_sym_bit_set] = ACTIONS(1696),
    [anon_sym_matrix] = ACTIONS(1698),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_uninitialized] = ACTIONS(909),
    [sym_tag] = ACTIONS(1827),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [218] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3043),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(1732),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(1734),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_where] = ACTIONS(895),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_RPAREN] = ACTIONS(893),
    [anon_sym_DOLLAR] = ACTIONS(1748),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_do] = ACTIONS(895),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(1833),
    [anon_sym_RBRACK] = ACTIONS(893),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(1756),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(1836),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(1764),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(1768),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_uninitialized] = ACTIONS(893),
    [sym_tag] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [219] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3051),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(1732),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(1734),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_where] = ACTIONS(874),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(1842),
    [anon_sym_RPAREN] = ACTIONS(871),
    [anon_sym_DOLLAR] = ACTIONS(1748),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_do] = ACTIONS(874),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(1846),
    [anon_sym_RBRACK] = ACTIONS(871),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(1756),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(1850),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(1764),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(1768),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_uninitialized] = ACTIONS(871),
    [sym_tag] = ACTIONS(1854),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [220] = {
    [sym_procedure] = STATE(3237),
    [sym_type] = STATE(3391),
    [sym_pointer_type] = STATE(3312),
    [sym_variadic_type] = STATE(3312),
    [sym_array_type] = STATE(3312),
    [sym_map_type] = STATE(3312),
    [sym_union_type] = STATE(3312),
    [sym_bit_set_type] = STATE(3312),
    [sym_matrix_type] = STATE(3312),
    [sym_field_type] = STATE(3312),
    [sym_tuple_type] = STATE(3312),
    [sym_struct_type] = STATE(3312),
    [sym_enum_type] = STATE(3312),
    [sym_bit_field_type] = STATE(3312),
    [sym_constant_type] = STATE(3312),
    [sym_specialized_type] = STATE(3312),
    [sym__procedure_type] = STATE(3312),
    [sym_distinct_type] = STATE(3312),
    [sym_empty_type] = STATE(3312),
    [sym_polymorphic_type] = STATE(3312),
    [sym_conditional_type] = STATE(3312),
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(1662),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(1664),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_where] = ACTIONS(773),
    [anon_sym_struct] = ACTIONS(1666),
    [anon_sym_enum] = ACTIONS(1668),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(1670),
    [anon_sym_bit_field] = ACTIONS(1672),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(1858),
    [anon_sym_DOLLAR] = ACTIONS(1678),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_case] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(1680),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(1861),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(1686),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(1864),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1692),
    [anon_sym_map] = ACTIONS(1694),
    [anon_sym_bit_set] = ACTIONS(1696),
    [anon_sym_matrix] = ACTIONS(1698),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_uninitialized] = ACTIONS(767),
    [sym_tag] = ACTIONS(1867),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [221] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3165),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(1732),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(1734),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_where] = ACTIONS(773),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(1870),
    [anon_sym_RPAREN] = ACTIONS(767),
    [anon_sym_DOLLAR] = ACTIONS(1748),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_do] = ACTIONS(773),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(1873),
    [anon_sym_RBRACK] = ACTIONS(767),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(1756),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(1876),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(1764),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(1768),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_uninitialized] = ACTIONS(767),
    [sym_tag] = ACTIONS(1879),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [222] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3017),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(1732),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(1734),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_where] = ACTIONS(857),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(1882),
    [anon_sym_RPAREN] = ACTIONS(855),
    [anon_sym_DOLLAR] = ACTIONS(1748),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_do] = ACTIONS(857),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(1885),
    [anon_sym_RBRACK] = ACTIONS(855),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(1756),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(1888),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(1764),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(1768),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_uninitialized] = ACTIONS(855),
    [sym_tag] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [223] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3046),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(1732),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(1734),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_where] = ACTIONS(911),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(1894),
    [anon_sym_RPAREN] = ACTIONS(909),
    [anon_sym_DOLLAR] = ACTIONS(1748),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_do] = ACTIONS(911),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(1897),
    [anon_sym_RBRACK] = ACTIONS(909),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(1756),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(1900),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(1764),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(1768),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_uninitialized] = ACTIONS(909),
    [sym_tag] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [224] = {
    [sym_procedure] = STATE(3757),
    [sym_type] = STATE(3751),
    [sym_pointer_type] = STATE(3789),
    [sym_variadic_type] = STATE(3789),
    [sym_array_type] = STATE(3789),
    [sym_map_type] = STATE(3789),
    [sym_union_type] = STATE(3789),
    [sym_bit_set_type] = STATE(3789),
    [sym_matrix_type] = STATE(3789),
    [sym_field_type] = STATE(3789),
    [sym_tuple_type] = STATE(3789),
    [sym_struct_type] = STATE(3789),
    [sym_enum_type] = STATE(3789),
    [sym_bit_field_type] = STATE(3789),
    [sym_constant_type] = STATE(3789),
    [sym_specialized_type] = STATE(3789),
    [sym__procedure_type] = STATE(3789),
    [sym_distinct_type] = STATE(3789),
    [sym_empty_type] = STATE(3789),
    [sym_polymorphic_type] = STATE(3789),
    [sym_conditional_type] = STATE(3789),
    [sym_identifier] = ACTIONS(1906),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(1908),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(1910),
    [anon_sym_enum] = ACTIONS(1912),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(1914),
    [anon_sym_bit_field] = ACTIONS(1916),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(1918),
    [anon_sym_RPAREN] = ACTIONS(809),
    [anon_sym_DOLLAR] = ACTIONS(1922),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_do] = ACTIONS(812),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(1924),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(1926),
    [anon_sym_RBRACK] = ACTIONS(809),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(1930),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(1932),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1936),
    [anon_sym_map] = ACTIONS(1938),
    [anon_sym_bit_set] = ACTIONS(1940),
    [anon_sym_matrix] = ACTIONS(1942),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_tag] = ACTIONS(1944),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [225] = {
    [sym_procedure] = STATE(3757),
    [sym_type] = STATE(3787),
    [sym_pointer_type] = STATE(3789),
    [sym_variadic_type] = STATE(3789),
    [sym_array_type] = STATE(3789),
    [sym_map_type] = STATE(3789),
    [sym_union_type] = STATE(3789),
    [sym_bit_set_type] = STATE(3789),
    [sym_matrix_type] = STATE(3789),
    [sym_field_type] = STATE(3789),
    [sym_tuple_type] = STATE(3789),
    [sym_struct_type] = STATE(3789),
    [sym_enum_type] = STATE(3789),
    [sym_bit_field_type] = STATE(3789),
    [sym_constant_type] = STATE(3789),
    [sym_specialized_type] = STATE(3789),
    [sym__procedure_type] = STATE(3789),
    [sym_distinct_type] = STATE(3789),
    [sym_empty_type] = STATE(3789),
    [sym_polymorphic_type] = STATE(3789),
    [sym_conditional_type] = STATE(3789),
    [sym_identifier] = ACTIONS(1906),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(1908),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(1910),
    [anon_sym_enum] = ACTIONS(1912),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(1914),
    [anon_sym_bit_field] = ACTIONS(1916),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(1946),
    [anon_sym_RPAREN] = ACTIONS(767),
    [anon_sym_DOLLAR] = ACTIONS(1922),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_do] = ACTIONS(773),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(1924),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(1949),
    [anon_sym_RBRACK] = ACTIONS(767),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(1930),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(1952),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1936),
    [anon_sym_map] = ACTIONS(1938),
    [anon_sym_bit_set] = ACTIONS(1940),
    [anon_sym_matrix] = ACTIONS(1942),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_tag] = ACTIONS(1944),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [226] = {
    [sym_procedure] = STATE(3570),
    [sym_type] = STATE(3688),
    [sym_pointer_type] = STATE(3604),
    [sym_variadic_type] = STATE(3604),
    [sym_array_type] = STATE(3604),
    [sym_map_type] = STATE(3604),
    [sym_union_type] = STATE(3604),
    [sym_bit_set_type] = STATE(3604),
    [sym_matrix_type] = STATE(3604),
    [sym_field_type] = STATE(3604),
    [sym_tuple_type] = STATE(3604),
    [sym_struct_type] = STATE(3604),
    [sym_enum_type] = STATE(3604),
    [sym_bit_field_type] = STATE(3604),
    [sym_constant_type] = STATE(3604),
    [sym_specialized_type] = STATE(3604),
    [sym__procedure_type] = STATE(3604),
    [sym_distinct_type] = STATE(3604),
    [sym_empty_type] = STATE(3604),
    [sym_polymorphic_type] = STATE(3604),
    [sym_conditional_type] = STATE(3604),
    [ts_builtin_sym_end] = ACTIONS(833),
    [sym_identifier] = ACTIONS(1955),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(1957),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_where] = ACTIONS(836),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1961),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_bit_field] = ACTIONS(1965),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(1967),
    [anon_sym_DOLLAR] = ACTIONS(1971),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(1973),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(1975),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(1979),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(1981),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1985),
    [anon_sym_map] = ACTIONS(1987),
    [anon_sym_bit_set] = ACTIONS(1989),
    [anon_sym_matrix] = ACTIONS(1991),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_uninitialized] = ACTIONS(833),
    [sym_tag] = ACTIONS(1993),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(833),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(833),
    [sym_block_comment] = ACTIONS(3),
  },
  [227] = {
    [sym_procedure] = STATE(3570),
    [sym_type] = STATE(3689),
    [sym_pointer_type] = STATE(3604),
    [sym_variadic_type] = STATE(3604),
    [sym_array_type] = STATE(3604),
    [sym_map_type] = STATE(3604),
    [sym_union_type] = STATE(3604),
    [sym_bit_set_type] = STATE(3604),
    [sym_matrix_type] = STATE(3604),
    [sym_field_type] = STATE(3604),
    [sym_tuple_type] = STATE(3604),
    [sym_struct_type] = STATE(3604),
    [sym_enum_type] = STATE(3604),
    [sym_bit_field_type] = STATE(3604),
    [sym_constant_type] = STATE(3604),
    [sym_specialized_type] = STATE(3604),
    [sym__procedure_type] = STATE(3604),
    [sym_distinct_type] = STATE(3604),
    [sym_empty_type] = STATE(3604),
    [sym_polymorphic_type] = STATE(3604),
    [sym_conditional_type] = STATE(3604),
    [ts_builtin_sym_end] = ACTIONS(809),
    [sym_identifier] = ACTIONS(1955),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(1957),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_where] = ACTIONS(812),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1961),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_bit_field] = ACTIONS(1965),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_LPAREN] = ACTIONS(1997),
    [anon_sym_DOLLAR] = ACTIONS(1971),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_case] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(1973),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(2001),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(1979),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(2005),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1985),
    [anon_sym_map] = ACTIONS(1987),
    [anon_sym_bit_set] = ACTIONS(1989),
    [anon_sym_matrix] = ACTIONS(1991),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_uninitialized] = ACTIONS(809),
    [sym_tag] = ACTIONS(2009),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(809),
    [sym_block_comment] = ACTIONS(3),
  },
  [228] = {
    [sym_procedure] = STATE(3570),
    [sym_type] = STATE(3524),
    [sym_pointer_type] = STATE(3604),
    [sym_variadic_type] = STATE(3604),
    [sym_array_type] = STATE(3604),
    [sym_map_type] = STATE(3604),
    [sym_union_type] = STATE(3604),
    [sym_bit_set_type] = STATE(3604),
    [sym_matrix_type] = STATE(3604),
    [sym_field_type] = STATE(3604),
    [sym_tuple_type] = STATE(3604),
    [sym_struct_type] = STATE(3604),
    [sym_enum_type] = STATE(3604),
    [sym_bit_field_type] = STATE(3604),
    [sym_constant_type] = STATE(3604),
    [sym_specialized_type] = STATE(3604),
    [sym__procedure_type] = STATE(3604),
    [sym_distinct_type] = STATE(3604),
    [sym_empty_type] = STATE(3604),
    [sym_polymorphic_type] = STATE(3604),
    [sym_conditional_type] = STATE(3604),
    [ts_builtin_sym_end] = ACTIONS(855),
    [sym_identifier] = ACTIONS(1955),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(1957),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_where] = ACTIONS(857),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1961),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_bit_field] = ACTIONS(1965),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(2013),
    [anon_sym_DOLLAR] = ACTIONS(1971),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(1973),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(2016),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(1979),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(2019),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1985),
    [anon_sym_map] = ACTIONS(1987),
    [anon_sym_bit_set] = ACTIONS(1989),
    [anon_sym_matrix] = ACTIONS(1991),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_uninitialized] = ACTIONS(855),
    [sym_tag] = ACTIONS(2022),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(855),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(855),
    [sym_block_comment] = ACTIONS(3),
  },
  [229] = {
    [sym_procedure] = STATE(3570),
    [sym_type] = STATE(3705),
    [sym_pointer_type] = STATE(3604),
    [sym_variadic_type] = STATE(3604),
    [sym_array_type] = STATE(3604),
    [sym_map_type] = STATE(3604),
    [sym_union_type] = STATE(3604),
    [sym_bit_set_type] = STATE(3604),
    [sym_matrix_type] = STATE(3604),
    [sym_field_type] = STATE(3604),
    [sym_tuple_type] = STATE(3604),
    [sym_struct_type] = STATE(3604),
    [sym_enum_type] = STATE(3604),
    [sym_bit_field_type] = STATE(3604),
    [sym_constant_type] = STATE(3604),
    [sym_specialized_type] = STATE(3604),
    [sym__procedure_type] = STATE(3604),
    [sym_distinct_type] = STATE(3604),
    [sym_empty_type] = STATE(3604),
    [sym_polymorphic_type] = STATE(3604),
    [sym_conditional_type] = STATE(3604),
    [ts_builtin_sym_end] = ACTIONS(871),
    [sym_identifier] = ACTIONS(1955),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(1957),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_where] = ACTIONS(874),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1961),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_bit_field] = ACTIONS(1965),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_LPAREN] = ACTIONS(2025),
    [anon_sym_DOLLAR] = ACTIONS(1971),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_case] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(1973),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(2029),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(1979),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(2033),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1985),
    [anon_sym_map] = ACTIONS(1987),
    [anon_sym_bit_set] = ACTIONS(1989),
    [anon_sym_matrix] = ACTIONS(1991),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_uninitialized] = ACTIONS(871),
    [sym_tag] = ACTIONS(2037),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(871),
    [sym_block_comment] = ACTIONS(3),
  },
  [230] = {
    [sym_procedure] = STATE(3570),
    [sym_type] = STATE(3700),
    [sym_pointer_type] = STATE(3604),
    [sym_variadic_type] = STATE(3604),
    [sym_array_type] = STATE(3604),
    [sym_map_type] = STATE(3604),
    [sym_union_type] = STATE(3604),
    [sym_bit_set_type] = STATE(3604),
    [sym_matrix_type] = STATE(3604),
    [sym_field_type] = STATE(3604),
    [sym_tuple_type] = STATE(3604),
    [sym_struct_type] = STATE(3604),
    [sym_enum_type] = STATE(3604),
    [sym_bit_field_type] = STATE(3604),
    [sym_constant_type] = STATE(3604),
    [sym_specialized_type] = STATE(3604),
    [sym__procedure_type] = STATE(3604),
    [sym_distinct_type] = STATE(3604),
    [sym_empty_type] = STATE(3604),
    [sym_polymorphic_type] = STATE(3604),
    [sym_conditional_type] = STATE(3604),
    [ts_builtin_sym_end] = ACTIONS(893),
    [sym_identifier] = ACTIONS(1955),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(1957),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_where] = ACTIONS(895),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1961),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_bit_field] = ACTIONS(1965),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_LPAREN] = ACTIONS(2041),
    [anon_sym_DOLLAR] = ACTIONS(1971),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_case] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(1973),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(2044),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(1979),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(2047),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1985),
    [anon_sym_map] = ACTIONS(1987),
    [anon_sym_bit_set] = ACTIONS(1989),
    [anon_sym_matrix] = ACTIONS(1991),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_uninitialized] = ACTIONS(893),
    [sym_tag] = ACTIONS(2050),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(893),
    [sym_block_comment] = ACTIONS(3),
  },
  [231] = {
    [sym_procedure] = STATE(3570),
    [sym_type] = STATE(3703),
    [sym_pointer_type] = STATE(3604),
    [sym_variadic_type] = STATE(3604),
    [sym_array_type] = STATE(3604),
    [sym_map_type] = STATE(3604),
    [sym_union_type] = STATE(3604),
    [sym_bit_set_type] = STATE(3604),
    [sym_matrix_type] = STATE(3604),
    [sym_field_type] = STATE(3604),
    [sym_tuple_type] = STATE(3604),
    [sym_struct_type] = STATE(3604),
    [sym_enum_type] = STATE(3604),
    [sym_bit_field_type] = STATE(3604),
    [sym_constant_type] = STATE(3604),
    [sym_specialized_type] = STATE(3604),
    [sym__procedure_type] = STATE(3604),
    [sym_distinct_type] = STATE(3604),
    [sym_empty_type] = STATE(3604),
    [sym_polymorphic_type] = STATE(3604),
    [sym_conditional_type] = STATE(3604),
    [ts_builtin_sym_end] = ACTIONS(909),
    [sym_identifier] = ACTIONS(1955),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(1957),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_where] = ACTIONS(911),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1961),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_bit_field] = ACTIONS(1965),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(2053),
    [anon_sym_DOLLAR] = ACTIONS(1971),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_case] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(1973),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(2056),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(1979),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(2059),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1985),
    [anon_sym_map] = ACTIONS(1987),
    [anon_sym_bit_set] = ACTIONS(1989),
    [anon_sym_matrix] = ACTIONS(1991),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_uninitialized] = ACTIONS(909),
    [sym_tag] = ACTIONS(2062),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(909),
    [sym_block_comment] = ACTIONS(3),
  },
  [232] = {
    [sym_procedure] = STATE(3757),
    [sym_type] = STATE(3783),
    [sym_pointer_type] = STATE(3789),
    [sym_variadic_type] = STATE(3789),
    [sym_array_type] = STATE(3789),
    [sym_map_type] = STATE(3789),
    [sym_union_type] = STATE(3789),
    [sym_bit_set_type] = STATE(3789),
    [sym_matrix_type] = STATE(3789),
    [sym_field_type] = STATE(3789),
    [sym_tuple_type] = STATE(3789),
    [sym_struct_type] = STATE(3789),
    [sym_enum_type] = STATE(3789),
    [sym_bit_field_type] = STATE(3789),
    [sym_constant_type] = STATE(3789),
    [sym_specialized_type] = STATE(3789),
    [sym__procedure_type] = STATE(3789),
    [sym_distinct_type] = STATE(3789),
    [sym_empty_type] = STATE(3789),
    [sym_polymorphic_type] = STATE(3789),
    [sym_conditional_type] = STATE(3789),
    [sym_identifier] = ACTIONS(1906),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(1908),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(1910),
    [anon_sym_enum] = ACTIONS(1912),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(1914),
    [anon_sym_bit_field] = ACTIONS(1916),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(2065),
    [anon_sym_RPAREN] = ACTIONS(833),
    [anon_sym_DOLLAR] = ACTIONS(1922),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_do] = ACTIONS(836),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(1924),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2069),
    [anon_sym_RBRACK] = ACTIONS(833),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(1930),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(2073),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1936),
    [anon_sym_map] = ACTIONS(1938),
    [anon_sym_bit_set] = ACTIONS(1940),
    [anon_sym_matrix] = ACTIONS(1942),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_tag] = ACTIONS(1944),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [233] = {
    [sym_procedure] = STATE(3757),
    [sym_type] = STATE(3753),
    [sym_pointer_type] = STATE(3789),
    [sym_variadic_type] = STATE(3789),
    [sym_array_type] = STATE(3789),
    [sym_map_type] = STATE(3789),
    [sym_union_type] = STATE(3789),
    [sym_bit_set_type] = STATE(3789),
    [sym_matrix_type] = STATE(3789),
    [sym_field_type] = STATE(3789),
    [sym_tuple_type] = STATE(3789),
    [sym_struct_type] = STATE(3789),
    [sym_enum_type] = STATE(3789),
    [sym_bit_field_type] = STATE(3789),
    [sym_constant_type] = STATE(3789),
    [sym_specialized_type] = STATE(3789),
    [sym__procedure_type] = STATE(3789),
    [sym_distinct_type] = STATE(3789),
    [sym_empty_type] = STATE(3789),
    [sym_polymorphic_type] = STATE(3789),
    [sym_conditional_type] = STATE(3789),
    [sym_identifier] = ACTIONS(1906),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(1908),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_struct] = ACTIONS(1910),
    [anon_sym_enum] = ACTIONS(1912),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(1914),
    [anon_sym_bit_field] = ACTIONS(1916),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(2077),
    [anon_sym_RPAREN] = ACTIONS(871),
    [anon_sym_DOLLAR] = ACTIONS(1922),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_do] = ACTIONS(874),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(1924),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(2081),
    [anon_sym_RBRACK] = ACTIONS(871),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(1930),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(2085),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1936),
    [anon_sym_map] = ACTIONS(1938),
    [anon_sym_bit_set] = ACTIONS(1940),
    [anon_sym_matrix] = ACTIONS(1942),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_tag] = ACTIONS(1944),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [234] = {
    [sym_procedure] = STATE(3757),
    [sym_type] = STATE(3755),
    [sym_pointer_type] = STATE(3789),
    [sym_variadic_type] = STATE(3789),
    [sym_array_type] = STATE(3789),
    [sym_map_type] = STATE(3789),
    [sym_union_type] = STATE(3789),
    [sym_bit_set_type] = STATE(3789),
    [sym_matrix_type] = STATE(3789),
    [sym_field_type] = STATE(3789),
    [sym_tuple_type] = STATE(3789),
    [sym_struct_type] = STATE(3789),
    [sym_enum_type] = STATE(3789),
    [sym_bit_field_type] = STATE(3789),
    [sym_constant_type] = STATE(3789),
    [sym_specialized_type] = STATE(3789),
    [sym__procedure_type] = STATE(3789),
    [sym_distinct_type] = STATE(3789),
    [sym_empty_type] = STATE(3789),
    [sym_polymorphic_type] = STATE(3789),
    [sym_conditional_type] = STATE(3789),
    [sym_identifier] = ACTIONS(1906),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(1908),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_struct] = ACTIONS(1910),
    [anon_sym_enum] = ACTIONS(1912),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(1914),
    [anon_sym_bit_field] = ACTIONS(1916),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_RPAREN] = ACTIONS(855),
    [anon_sym_DOLLAR] = ACTIONS(1922),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_do] = ACTIONS(857),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(1924),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(2092),
    [anon_sym_RBRACK] = ACTIONS(855),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(1930),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1936),
    [anon_sym_map] = ACTIONS(1938),
    [anon_sym_bit_set] = ACTIONS(1940),
    [anon_sym_matrix] = ACTIONS(1942),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_tag] = ACTIONS(1944),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [235] = {
    [sym_procedure] = STATE(3757),
    [sym_type] = STATE(3726),
    [sym_pointer_type] = STATE(3789),
    [sym_variadic_type] = STATE(3789),
    [sym_array_type] = STATE(3789),
    [sym_map_type] = STATE(3789),
    [sym_union_type] = STATE(3789),
    [sym_bit_set_type] = STATE(3789),
    [sym_matrix_type] = STATE(3789),
    [sym_field_type] = STATE(3789),
    [sym_tuple_type] = STATE(3789),
    [sym_struct_type] = STATE(3789),
    [sym_enum_type] = STATE(3789),
    [sym_bit_field_type] = STATE(3789),
    [sym_constant_type] = STATE(3789),
    [sym_specialized_type] = STATE(3789),
    [sym__procedure_type] = STATE(3789),
    [sym_distinct_type] = STATE(3789),
    [sym_empty_type] = STATE(3789),
    [sym_polymorphic_type] = STATE(3789),
    [sym_conditional_type] = STATE(3789),
    [sym_identifier] = ACTIONS(1906),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(1908),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(1910),
    [anon_sym_enum] = ACTIONS(1912),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(1914),
    [anon_sym_bit_field] = ACTIONS(1916),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(2098),
    [anon_sym_RPAREN] = ACTIONS(893),
    [anon_sym_DOLLAR] = ACTIONS(1922),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_do] = ACTIONS(895),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(1924),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(2101),
    [anon_sym_RBRACK] = ACTIONS(893),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(1930),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(2104),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1936),
    [anon_sym_map] = ACTIONS(1938),
    [anon_sym_bit_set] = ACTIONS(1940),
    [anon_sym_matrix] = ACTIONS(1942),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_tag] = ACTIONS(1944),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [236] = {
    [sym_procedure] = STATE(3757),
    [sym_type] = STATE(3758),
    [sym_pointer_type] = STATE(3789),
    [sym_variadic_type] = STATE(3789),
    [sym_array_type] = STATE(3789),
    [sym_map_type] = STATE(3789),
    [sym_union_type] = STATE(3789),
    [sym_bit_set_type] = STATE(3789),
    [sym_matrix_type] = STATE(3789),
    [sym_field_type] = STATE(3789),
    [sym_tuple_type] = STATE(3789),
    [sym_struct_type] = STATE(3789),
    [sym_enum_type] = STATE(3789),
    [sym_bit_field_type] = STATE(3789),
    [sym_constant_type] = STATE(3789),
    [sym_specialized_type] = STATE(3789),
    [sym__procedure_type] = STATE(3789),
    [sym_distinct_type] = STATE(3789),
    [sym_empty_type] = STATE(3789),
    [sym_polymorphic_type] = STATE(3789),
    [sym_conditional_type] = STATE(3789),
    [sym_identifier] = ACTIONS(1906),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(1908),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(1910),
    [anon_sym_enum] = ACTIONS(1912),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(1914),
    [anon_sym_bit_field] = ACTIONS(1916),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(2107),
    [anon_sym_RPAREN] = ACTIONS(909),
    [anon_sym_DOLLAR] = ACTIONS(1922),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_do] = ACTIONS(911),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(1924),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(2110),
    [anon_sym_RBRACK] = ACTIONS(909),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(1930),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(2113),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1936),
    [anon_sym_map] = ACTIONS(1938),
    [anon_sym_bit_set] = ACTIONS(1940),
    [anon_sym_matrix] = ACTIONS(1942),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_tag] = ACTIONS(1944),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [237] = {
    [sym_procedure] = STATE(3570),
    [sym_type] = STATE(3638),
    [sym_pointer_type] = STATE(3604),
    [sym_variadic_type] = STATE(3604),
    [sym_array_type] = STATE(3604),
    [sym_map_type] = STATE(3604),
    [sym_union_type] = STATE(3604),
    [sym_bit_set_type] = STATE(3604),
    [sym_matrix_type] = STATE(3604),
    [sym_field_type] = STATE(3604),
    [sym_tuple_type] = STATE(3604),
    [sym_struct_type] = STATE(3604),
    [sym_enum_type] = STATE(3604),
    [sym_bit_field_type] = STATE(3604),
    [sym_constant_type] = STATE(3604),
    [sym_specialized_type] = STATE(3604),
    [sym__procedure_type] = STATE(3604),
    [sym_distinct_type] = STATE(3604),
    [sym_empty_type] = STATE(3604),
    [sym_polymorphic_type] = STATE(3604),
    [sym_conditional_type] = STATE(3604),
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(1955),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(1957),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_where] = ACTIONS(773),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1961),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_bit_field] = ACTIONS(1965),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(2116),
    [anon_sym_DOLLAR] = ACTIONS(1971),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_case] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(1973),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(2119),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(1979),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(2122),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1985),
    [anon_sym_map] = ACTIONS(1987),
    [anon_sym_bit_set] = ACTIONS(1989),
    [anon_sym_matrix] = ACTIONS(1991),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_uninitialized] = ACTIONS(767),
    [sym_tag] = ACTIONS(2125),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(767),
    [sym_block_comment] = ACTIONS(3),
  },
  [238] = {
    [sym_procedure] = STATE(3839),
    [sym_type] = STATE(3923),
    [sym_pointer_type] = STATE(3855),
    [sym_variadic_type] = STATE(3855),
    [sym_array_type] = STATE(3855),
    [sym_map_type] = STATE(3855),
    [sym_union_type] = STATE(3855),
    [sym_bit_set_type] = STATE(3855),
    [sym_matrix_type] = STATE(3855),
    [sym_field_type] = STATE(3855),
    [sym_tuple_type] = STATE(3855),
    [sym_struct_type] = STATE(3855),
    [sym_enum_type] = STATE(3855),
    [sym_bit_field_type] = STATE(3855),
    [sym_constant_type] = STATE(3855),
    [sym_specialized_type] = STATE(3855),
    [sym__procedure_type] = STATE(3855),
    [sym_distinct_type] = STATE(3855),
    [sym_empty_type] = STATE(3855),
    [sym_polymorphic_type] = STATE(3855),
    [sym_conditional_type] = STATE(3855),
    [ts_builtin_sym_end] = ACTIONS(893),
    [sym_identifier] = ACTIONS(2128),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(2130),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(2132),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2136),
    [anon_sym_bit_field] = ACTIONS(2138),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(2140),
    [anon_sym_DOLLAR] = ACTIONS(2143),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_case] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(2145),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(2147),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(2150),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(2152),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2155),
    [anon_sym_map] = ACTIONS(2157),
    [anon_sym_bit_set] = ACTIONS(2159),
    [anon_sym_matrix] = ACTIONS(2161),
    [anon_sym_distinct] = ACTIONS(2163),
    [sym_tag] = ACTIONS(2165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [239] = {
    [sym_procedure] = STATE(3839),
    [sym_type] = STATE(3993),
    [sym_pointer_type] = STATE(3855),
    [sym_variadic_type] = STATE(3855),
    [sym_array_type] = STATE(3855),
    [sym_map_type] = STATE(3855),
    [sym_union_type] = STATE(3855),
    [sym_bit_set_type] = STATE(3855),
    [sym_matrix_type] = STATE(3855),
    [sym_field_type] = STATE(3855),
    [sym_tuple_type] = STATE(3855),
    [sym_struct_type] = STATE(3855),
    [sym_enum_type] = STATE(3855),
    [sym_bit_field_type] = STATE(3855),
    [sym_constant_type] = STATE(3855),
    [sym_specialized_type] = STATE(3855),
    [sym__procedure_type] = STATE(3855),
    [sym_distinct_type] = STATE(3855),
    [sym_empty_type] = STATE(3855),
    [sym_polymorphic_type] = STATE(3855),
    [sym_conditional_type] = STATE(3855),
    [ts_builtin_sym_end] = ACTIONS(855),
    [sym_identifier] = ACTIONS(2128),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(2130),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_struct] = ACTIONS(2132),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2136),
    [anon_sym_bit_field] = ACTIONS(2138),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(2167),
    [anon_sym_DOLLAR] = ACTIONS(2143),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(2145),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(2150),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(2173),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2155),
    [anon_sym_map] = ACTIONS(2157),
    [anon_sym_bit_set] = ACTIONS(2159),
    [anon_sym_matrix] = ACTIONS(2161),
    [anon_sym_distinct] = ACTIONS(2163),
    [sym_tag] = ACTIONS(2165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(855),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [240] = {
    [sym_procedure] = STATE(3839),
    [sym_type] = STATE(3882),
    [sym_pointer_type] = STATE(3855),
    [sym_variadic_type] = STATE(3855),
    [sym_array_type] = STATE(3855),
    [sym_map_type] = STATE(3855),
    [sym_union_type] = STATE(3855),
    [sym_bit_set_type] = STATE(3855),
    [sym_matrix_type] = STATE(3855),
    [sym_field_type] = STATE(3855),
    [sym_tuple_type] = STATE(3855),
    [sym_struct_type] = STATE(3855),
    [sym_enum_type] = STATE(3855),
    [sym_bit_field_type] = STATE(3855),
    [sym_constant_type] = STATE(3855),
    [sym_specialized_type] = STATE(3855),
    [sym__procedure_type] = STATE(3855),
    [sym_distinct_type] = STATE(3855),
    [sym_empty_type] = STATE(3855),
    [sym_polymorphic_type] = STATE(3855),
    [sym_conditional_type] = STATE(3855),
    [ts_builtin_sym_end] = ACTIONS(909),
    [sym_identifier] = ACTIONS(2128),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(2130),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(2132),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2136),
    [anon_sym_bit_field] = ACTIONS(2138),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(2176),
    [anon_sym_DOLLAR] = ACTIONS(2143),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_case] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(2145),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(2179),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(2150),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(2182),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2155),
    [anon_sym_map] = ACTIONS(2157),
    [anon_sym_bit_set] = ACTIONS(2159),
    [anon_sym_matrix] = ACTIONS(2161),
    [anon_sym_distinct] = ACTIONS(2163),
    [sym_tag] = ACTIONS(2165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [241] = {
    [sym_procedure] = STATE(3839),
    [sym_type] = STATE(3954),
    [sym_pointer_type] = STATE(3855),
    [sym_variadic_type] = STATE(3855),
    [sym_array_type] = STATE(3855),
    [sym_map_type] = STATE(3855),
    [sym_union_type] = STATE(3855),
    [sym_bit_set_type] = STATE(3855),
    [sym_matrix_type] = STATE(3855),
    [sym_field_type] = STATE(3855),
    [sym_tuple_type] = STATE(3855),
    [sym_struct_type] = STATE(3855),
    [sym_enum_type] = STATE(3855),
    [sym_bit_field_type] = STATE(3855),
    [sym_constant_type] = STATE(3855),
    [sym_specialized_type] = STATE(3855),
    [sym__procedure_type] = STATE(3855),
    [sym_distinct_type] = STATE(3855),
    [sym_empty_type] = STATE(3855),
    [sym_polymorphic_type] = STATE(3855),
    [sym_conditional_type] = STATE(3855),
    [ts_builtin_sym_end] = ACTIONS(833),
    [sym_identifier] = ACTIONS(2128),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(2130),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(2132),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2136),
    [anon_sym_bit_field] = ACTIONS(2138),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(2185),
    [anon_sym_DOLLAR] = ACTIONS(2143),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(2145),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2189),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(2150),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(2193),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2155),
    [anon_sym_map] = ACTIONS(2157),
    [anon_sym_bit_set] = ACTIONS(2159),
    [anon_sym_matrix] = ACTIONS(2161),
    [anon_sym_distinct] = ACTIONS(2163),
    [sym_tag] = ACTIONS(2165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(833),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [242] = {
    [sym_procedure] = STATE(3839),
    [sym_type] = STATE(3957),
    [sym_pointer_type] = STATE(3855),
    [sym_variadic_type] = STATE(3855),
    [sym_array_type] = STATE(3855),
    [sym_map_type] = STATE(3855),
    [sym_union_type] = STATE(3855),
    [sym_bit_set_type] = STATE(3855),
    [sym_matrix_type] = STATE(3855),
    [sym_field_type] = STATE(3855),
    [sym_tuple_type] = STATE(3855),
    [sym_struct_type] = STATE(3855),
    [sym_enum_type] = STATE(3855),
    [sym_bit_field_type] = STATE(3855),
    [sym_constant_type] = STATE(3855),
    [sym_specialized_type] = STATE(3855),
    [sym__procedure_type] = STATE(3855),
    [sym_distinct_type] = STATE(3855),
    [sym_empty_type] = STATE(3855),
    [sym_polymorphic_type] = STATE(3855),
    [sym_conditional_type] = STATE(3855),
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(2128),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(2130),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(2132),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2136),
    [anon_sym_bit_field] = ACTIONS(2138),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(2197),
    [anon_sym_DOLLAR] = ACTIONS(2143),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_case] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(2145),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(2200),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(2150),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(2203),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2155),
    [anon_sym_map] = ACTIONS(2157),
    [anon_sym_bit_set] = ACTIONS(2159),
    [anon_sym_matrix] = ACTIONS(2161),
    [anon_sym_distinct] = ACTIONS(2163),
    [sym_tag] = ACTIONS(2165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [243] = {
    [sym_procedure] = STATE(3839),
    [sym_type] = STATE(3982),
    [sym_pointer_type] = STATE(3855),
    [sym_variadic_type] = STATE(3855),
    [sym_array_type] = STATE(3855),
    [sym_map_type] = STATE(3855),
    [sym_union_type] = STATE(3855),
    [sym_bit_set_type] = STATE(3855),
    [sym_matrix_type] = STATE(3855),
    [sym_field_type] = STATE(3855),
    [sym_tuple_type] = STATE(3855),
    [sym_struct_type] = STATE(3855),
    [sym_enum_type] = STATE(3855),
    [sym_bit_field_type] = STATE(3855),
    [sym_constant_type] = STATE(3855),
    [sym_specialized_type] = STATE(3855),
    [sym__procedure_type] = STATE(3855),
    [sym_distinct_type] = STATE(3855),
    [sym_empty_type] = STATE(3855),
    [sym_polymorphic_type] = STATE(3855),
    [sym_conditional_type] = STATE(3855),
    [ts_builtin_sym_end] = ACTIONS(809),
    [sym_identifier] = ACTIONS(2128),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(2130),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(2132),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2136),
    [anon_sym_bit_field] = ACTIONS(2138),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(2206),
    [anon_sym_DOLLAR] = ACTIONS(2143),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_case] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(2145),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(2210),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(2150),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(2214),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2155),
    [anon_sym_map] = ACTIONS(2157),
    [anon_sym_bit_set] = ACTIONS(2159),
    [anon_sym_matrix] = ACTIONS(2161),
    [anon_sym_distinct] = ACTIONS(2163),
    [sym_tag] = ACTIONS(2165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [244] = {
    [sym_procedure] = STATE(3839),
    [sym_type] = STATE(3894),
    [sym_pointer_type] = STATE(3855),
    [sym_variadic_type] = STATE(3855),
    [sym_array_type] = STATE(3855),
    [sym_map_type] = STATE(3855),
    [sym_union_type] = STATE(3855),
    [sym_bit_set_type] = STATE(3855),
    [sym_matrix_type] = STATE(3855),
    [sym_field_type] = STATE(3855),
    [sym_tuple_type] = STATE(3855),
    [sym_struct_type] = STATE(3855),
    [sym_enum_type] = STATE(3855),
    [sym_bit_field_type] = STATE(3855),
    [sym_constant_type] = STATE(3855),
    [sym_specialized_type] = STATE(3855),
    [sym__procedure_type] = STATE(3855),
    [sym_distinct_type] = STATE(3855),
    [sym_empty_type] = STATE(3855),
    [sym_polymorphic_type] = STATE(3855),
    [sym_conditional_type] = STATE(3855),
    [ts_builtin_sym_end] = ACTIONS(871),
    [sym_identifier] = ACTIONS(2128),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(2130),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_struct] = ACTIONS(2132),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2136),
    [anon_sym_bit_field] = ACTIONS(2138),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(2218),
    [anon_sym_DOLLAR] = ACTIONS(2143),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_case] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(2145),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(2222),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(2150),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(2226),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2155),
    [anon_sym_map] = ACTIONS(2157),
    [anon_sym_bit_set] = ACTIONS(2159),
    [anon_sym_matrix] = ACTIONS(2161),
    [anon_sym_distinct] = ACTIONS(2163),
    [sym_tag] = ACTIONS(2165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [245] = {
    [sym_procedure] = STATE(3909),
    [sym_type] = STATE(3893),
    [sym_pointer_type] = STATE(3931),
    [sym_variadic_type] = STATE(3931),
    [sym_array_type] = STATE(3931),
    [sym_map_type] = STATE(3931),
    [sym_union_type] = STATE(3931),
    [sym_bit_set_type] = STATE(3931),
    [sym_matrix_type] = STATE(3931),
    [sym_field_type] = STATE(3931),
    [sym_tuple_type] = STATE(3931),
    [sym_struct_type] = STATE(3931),
    [sym_enum_type] = STATE(3931),
    [sym_bit_field_type] = STATE(3931),
    [sym_constant_type] = STATE(3931),
    [sym_specialized_type] = STATE(3931),
    [sym__procedure_type] = STATE(3931),
    [sym_distinct_type] = STATE(3931),
    [sym_empty_type] = STATE(3931),
    [sym_polymorphic_type] = STATE(3931),
    [sym_conditional_type] = STATE(3931),
    [ts_builtin_sym_end] = ACTIONS(833),
    [sym_identifier] = ACTIONS(2230),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(2232),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2238),
    [anon_sym_bit_field] = ACTIONS(2240),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(2242),
    [anon_sym_DOLLAR] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(2248),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2250),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(2254),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(2256),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2260),
    [anon_sym_map] = ACTIONS(2262),
    [anon_sym_bit_set] = ACTIONS(2264),
    [anon_sym_matrix] = ACTIONS(2266),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_tag] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(833),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [246] = {
    [sym_procedure] = STATE(3909),
    [sym_type] = STATE(3798),
    [sym_pointer_type] = STATE(3931),
    [sym_variadic_type] = STATE(3931),
    [sym_array_type] = STATE(3931),
    [sym_map_type] = STATE(3931),
    [sym_union_type] = STATE(3931),
    [sym_bit_set_type] = STATE(3931),
    [sym_matrix_type] = STATE(3931),
    [sym_field_type] = STATE(3931),
    [sym_tuple_type] = STATE(3931),
    [sym_struct_type] = STATE(3931),
    [sym_enum_type] = STATE(3931),
    [sym_bit_field_type] = STATE(3931),
    [sym_constant_type] = STATE(3931),
    [sym_specialized_type] = STATE(3931),
    [sym__procedure_type] = STATE(3931),
    [sym_distinct_type] = STATE(3931),
    [sym_empty_type] = STATE(3931),
    [sym_polymorphic_type] = STATE(3931),
    [sym_conditional_type] = STATE(3931),
    [ts_builtin_sym_end] = ACTIONS(809),
    [sym_identifier] = ACTIONS(2230),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(2232),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2238),
    [anon_sym_bit_field] = ACTIONS(2240),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(2270),
    [anon_sym_DOLLAR] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_case] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(2248),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(2274),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(2254),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(2278),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2260),
    [anon_sym_map] = ACTIONS(2262),
    [anon_sym_bit_set] = ACTIONS(2264),
    [anon_sym_matrix] = ACTIONS(2266),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_tag] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [247] = {
    [sym_procedure] = STATE(3930),
    [sym_type] = STATE(3808),
    [sym_pointer_type] = STATE(3928),
    [sym_variadic_type] = STATE(3928),
    [sym_array_type] = STATE(3928),
    [sym_map_type] = STATE(3928),
    [sym_union_type] = STATE(3928),
    [sym_bit_set_type] = STATE(3928),
    [sym_matrix_type] = STATE(3928),
    [sym_field_type] = STATE(3928),
    [sym_tuple_type] = STATE(3928),
    [sym_struct_type] = STATE(3928),
    [sym_enum_type] = STATE(3928),
    [sym_bit_field_type] = STATE(3928),
    [sym_constant_type] = STATE(3928),
    [sym_specialized_type] = STATE(3928),
    [sym__procedure_type] = STATE(3928),
    [sym_distinct_type] = STATE(3928),
    [sym_empty_type] = STATE(3928),
    [sym_polymorphic_type] = STATE(3928),
    [sym_conditional_type] = STATE(3928),
    [sym_identifier] = ACTIONS(2282),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(2284),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(2290),
    [anon_sym_bit_field] = ACTIONS(2292),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(2294),
    [anon_sym_RPAREN] = ACTIONS(871),
    [anon_sym_DOLLAR] = ACTIONS(2298),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(2300),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(2302),
    [anon_sym_RBRACK] = ACTIONS(871),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(2306),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(2308),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2312),
    [anon_sym_map] = ACTIONS(2314),
    [anon_sym_bit_set] = ACTIONS(2316),
    [anon_sym_matrix] = ACTIONS(2318),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_tag] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [248] = {
    [sym_procedure] = STATE(3930),
    [sym_type] = STATE(3976),
    [sym_pointer_type] = STATE(3928),
    [sym_variadic_type] = STATE(3928),
    [sym_array_type] = STATE(3928),
    [sym_map_type] = STATE(3928),
    [sym_union_type] = STATE(3928),
    [sym_bit_set_type] = STATE(3928),
    [sym_matrix_type] = STATE(3928),
    [sym_field_type] = STATE(3928),
    [sym_tuple_type] = STATE(3928),
    [sym_struct_type] = STATE(3928),
    [sym_enum_type] = STATE(3928),
    [sym_bit_field_type] = STATE(3928),
    [sym_constant_type] = STATE(3928),
    [sym_specialized_type] = STATE(3928),
    [sym__procedure_type] = STATE(3928),
    [sym_distinct_type] = STATE(3928),
    [sym_empty_type] = STATE(3928),
    [sym_polymorphic_type] = STATE(3928),
    [sym_conditional_type] = STATE(3928),
    [sym_identifier] = ACTIONS(2282),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(2284),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(2290),
    [anon_sym_bit_field] = ACTIONS(2292),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(2322),
    [anon_sym_RPAREN] = ACTIONS(893),
    [anon_sym_DOLLAR] = ACTIONS(2298),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(2300),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(2325),
    [anon_sym_RBRACK] = ACTIONS(893),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(2306),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(2328),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2312),
    [anon_sym_map] = ACTIONS(2314),
    [anon_sym_bit_set] = ACTIONS(2316),
    [anon_sym_matrix] = ACTIONS(2318),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_tag] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [249] = {
    [sym_procedure] = STATE(3909),
    [sym_type] = STATE(3952),
    [sym_pointer_type] = STATE(3931),
    [sym_variadic_type] = STATE(3931),
    [sym_array_type] = STATE(3931),
    [sym_map_type] = STATE(3931),
    [sym_union_type] = STATE(3931),
    [sym_bit_set_type] = STATE(3931),
    [sym_matrix_type] = STATE(3931),
    [sym_field_type] = STATE(3931),
    [sym_tuple_type] = STATE(3931),
    [sym_struct_type] = STATE(3931),
    [sym_enum_type] = STATE(3931),
    [sym_bit_field_type] = STATE(3931),
    [sym_constant_type] = STATE(3931),
    [sym_specialized_type] = STATE(3931),
    [sym__procedure_type] = STATE(3931),
    [sym_distinct_type] = STATE(3931),
    [sym_empty_type] = STATE(3931),
    [sym_polymorphic_type] = STATE(3931),
    [sym_conditional_type] = STATE(3931),
    [ts_builtin_sym_end] = ACTIONS(893),
    [sym_identifier] = ACTIONS(2230),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(2232),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2238),
    [anon_sym_bit_field] = ACTIONS(2240),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(2331),
    [anon_sym_DOLLAR] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_case] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(2248),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(2334),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(2254),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(2337),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2260),
    [anon_sym_map] = ACTIONS(2262),
    [anon_sym_bit_set] = ACTIONS(2264),
    [anon_sym_matrix] = ACTIONS(2266),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_tag] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [250] = {
    [sym_procedure] = STATE(3930),
    [sym_type] = STATE(4007),
    [sym_pointer_type] = STATE(3928),
    [sym_variadic_type] = STATE(3928),
    [sym_array_type] = STATE(3928),
    [sym_map_type] = STATE(3928),
    [sym_union_type] = STATE(3928),
    [sym_bit_set_type] = STATE(3928),
    [sym_matrix_type] = STATE(3928),
    [sym_field_type] = STATE(3928),
    [sym_tuple_type] = STATE(3928),
    [sym_struct_type] = STATE(3928),
    [sym_enum_type] = STATE(3928),
    [sym_bit_field_type] = STATE(3928),
    [sym_constant_type] = STATE(3928),
    [sym_specialized_type] = STATE(3928),
    [sym__procedure_type] = STATE(3928),
    [sym_distinct_type] = STATE(3928),
    [sym_empty_type] = STATE(3928),
    [sym_polymorphic_type] = STATE(3928),
    [sym_conditional_type] = STATE(3928),
    [sym_identifier] = ACTIONS(2282),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(2284),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(2290),
    [anon_sym_bit_field] = ACTIONS(2292),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(2340),
    [anon_sym_RPAREN] = ACTIONS(909),
    [anon_sym_DOLLAR] = ACTIONS(2298),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(2300),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(2343),
    [anon_sym_RBRACK] = ACTIONS(909),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(2306),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(2346),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2312),
    [anon_sym_map] = ACTIONS(2314),
    [anon_sym_bit_set] = ACTIONS(2316),
    [anon_sym_matrix] = ACTIONS(2318),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_tag] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [251] = {
    [sym_procedure] = STATE(3909),
    [sym_type] = STATE(3951),
    [sym_pointer_type] = STATE(3931),
    [sym_variadic_type] = STATE(3931),
    [sym_array_type] = STATE(3931),
    [sym_map_type] = STATE(3931),
    [sym_union_type] = STATE(3931),
    [sym_bit_set_type] = STATE(3931),
    [sym_matrix_type] = STATE(3931),
    [sym_field_type] = STATE(3931),
    [sym_tuple_type] = STATE(3931),
    [sym_struct_type] = STATE(3931),
    [sym_enum_type] = STATE(3931),
    [sym_bit_field_type] = STATE(3931),
    [sym_constant_type] = STATE(3931),
    [sym_specialized_type] = STATE(3931),
    [sym__procedure_type] = STATE(3931),
    [sym_distinct_type] = STATE(3931),
    [sym_empty_type] = STATE(3931),
    [sym_polymorphic_type] = STATE(3931),
    [sym_conditional_type] = STATE(3931),
    [ts_builtin_sym_end] = ACTIONS(855),
    [sym_identifier] = ACTIONS(2230),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(2232),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2238),
    [anon_sym_bit_field] = ACTIONS(2240),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(2349),
    [anon_sym_DOLLAR] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(2248),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(2352),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(2254),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(2355),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2260),
    [anon_sym_map] = ACTIONS(2262),
    [anon_sym_bit_set] = ACTIONS(2264),
    [anon_sym_matrix] = ACTIONS(2266),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_tag] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(855),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [252] = {
    [sym_procedure] = STATE(3909),
    [sym_type] = STATE(3859),
    [sym_pointer_type] = STATE(3931),
    [sym_variadic_type] = STATE(3931),
    [sym_array_type] = STATE(3931),
    [sym_map_type] = STATE(3931),
    [sym_union_type] = STATE(3931),
    [sym_bit_set_type] = STATE(3931),
    [sym_matrix_type] = STATE(3931),
    [sym_field_type] = STATE(3931),
    [sym_tuple_type] = STATE(3931),
    [sym_struct_type] = STATE(3931),
    [sym_enum_type] = STATE(3931),
    [sym_bit_field_type] = STATE(3931),
    [sym_constant_type] = STATE(3931),
    [sym_specialized_type] = STATE(3931),
    [sym__procedure_type] = STATE(3931),
    [sym_distinct_type] = STATE(3931),
    [sym_empty_type] = STATE(3931),
    [sym_polymorphic_type] = STATE(3931),
    [sym_conditional_type] = STATE(3931),
    [ts_builtin_sym_end] = ACTIONS(909),
    [sym_identifier] = ACTIONS(2230),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(2232),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2238),
    [anon_sym_bit_field] = ACTIONS(2240),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(2358),
    [anon_sym_DOLLAR] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_case] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(2248),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(2361),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(2254),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(2364),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2260),
    [anon_sym_map] = ACTIONS(2262),
    [anon_sym_bit_set] = ACTIONS(2264),
    [anon_sym_matrix] = ACTIONS(2266),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_tag] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [253] = {
    [sym_procedure] = STATE(3930),
    [sym_type] = STATE(3841),
    [sym_pointer_type] = STATE(3928),
    [sym_variadic_type] = STATE(3928),
    [sym_array_type] = STATE(3928),
    [sym_map_type] = STATE(3928),
    [sym_union_type] = STATE(3928),
    [sym_bit_set_type] = STATE(3928),
    [sym_matrix_type] = STATE(3928),
    [sym_field_type] = STATE(3928),
    [sym_tuple_type] = STATE(3928),
    [sym_struct_type] = STATE(3928),
    [sym_enum_type] = STATE(3928),
    [sym_bit_field_type] = STATE(3928),
    [sym_constant_type] = STATE(3928),
    [sym_specialized_type] = STATE(3928),
    [sym__procedure_type] = STATE(3928),
    [sym_distinct_type] = STATE(3928),
    [sym_empty_type] = STATE(3928),
    [sym_polymorphic_type] = STATE(3928),
    [sym_conditional_type] = STATE(3928),
    [sym_identifier] = ACTIONS(2282),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_COLON_COLON] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(2284),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(2290),
    [anon_sym_bit_field] = ACTIONS(2292),
    [anon_sym_COLON] = ACTIONS(836),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_COLON_EQ] = ACTIONS(833),
    [anon_sym_LPAREN] = ACTIONS(2367),
    [anon_sym_RPAREN] = ACTIONS(833),
    [anon_sym_DOLLAR] = ACTIONS(2298),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(2300),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2371),
    [anon_sym_RBRACK] = ACTIONS(833),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(2306),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(2375),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2312),
    [anon_sym_map] = ACTIONS(2314),
    [anon_sym_bit_set] = ACTIONS(2316),
    [anon_sym_matrix] = ACTIONS(2318),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_tag] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [254] = {
    [sym_procedure] = STATE(3930),
    [sym_type] = STATE(3945),
    [sym_pointer_type] = STATE(3928),
    [sym_variadic_type] = STATE(3928),
    [sym_array_type] = STATE(3928),
    [sym_map_type] = STATE(3928),
    [sym_union_type] = STATE(3928),
    [sym_bit_set_type] = STATE(3928),
    [sym_matrix_type] = STATE(3928),
    [sym_field_type] = STATE(3928),
    [sym_tuple_type] = STATE(3928),
    [sym_struct_type] = STATE(3928),
    [sym_enum_type] = STATE(3928),
    [sym_bit_field_type] = STATE(3928),
    [sym_constant_type] = STATE(3928),
    [sym_specialized_type] = STATE(3928),
    [sym__procedure_type] = STATE(3928),
    [sym_distinct_type] = STATE(3928),
    [sym_empty_type] = STATE(3928),
    [sym_polymorphic_type] = STATE(3928),
    [sym_conditional_type] = STATE(3928),
    [sym_identifier] = ACTIONS(2282),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(2284),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(2290),
    [anon_sym_bit_field] = ACTIONS(2292),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(2379),
    [anon_sym_RPAREN] = ACTIONS(809),
    [anon_sym_DOLLAR] = ACTIONS(2298),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(2300),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_RBRACK] = ACTIONS(809),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(2306),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(2387),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2312),
    [anon_sym_map] = ACTIONS(2314),
    [anon_sym_bit_set] = ACTIONS(2316),
    [anon_sym_matrix] = ACTIONS(2318),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_tag] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [255] = {
    [sym_procedure] = STATE(3930),
    [sym_type] = STATE(3998),
    [sym_pointer_type] = STATE(3928),
    [sym_variadic_type] = STATE(3928),
    [sym_array_type] = STATE(3928),
    [sym_map_type] = STATE(3928),
    [sym_union_type] = STATE(3928),
    [sym_bit_set_type] = STATE(3928),
    [sym_matrix_type] = STATE(3928),
    [sym_field_type] = STATE(3928),
    [sym_tuple_type] = STATE(3928),
    [sym_struct_type] = STATE(3928),
    [sym_enum_type] = STATE(3928),
    [sym_bit_field_type] = STATE(3928),
    [sym_constant_type] = STATE(3928),
    [sym_specialized_type] = STATE(3928),
    [sym__procedure_type] = STATE(3928),
    [sym_distinct_type] = STATE(3928),
    [sym_empty_type] = STATE(3928),
    [sym_polymorphic_type] = STATE(3928),
    [sym_conditional_type] = STATE(3928),
    [sym_identifier] = ACTIONS(2282),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_COLON_COLON] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(2284),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(2290),
    [anon_sym_bit_field] = ACTIONS(2292),
    [anon_sym_COLON] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_COLON_EQ] = ACTIONS(855),
    [anon_sym_LPAREN] = ACTIONS(2391),
    [anon_sym_RPAREN] = ACTIONS(855),
    [anon_sym_DOLLAR] = ACTIONS(2298),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(2300),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(2394),
    [anon_sym_RBRACK] = ACTIONS(855),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(2306),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(2397),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2312),
    [anon_sym_map] = ACTIONS(2314),
    [anon_sym_bit_set] = ACTIONS(2316),
    [anon_sym_matrix] = ACTIONS(2318),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_tag] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [256] = {
    [sym_procedure] = STATE(3930),
    [sym_type] = STATE(3938),
    [sym_pointer_type] = STATE(3928),
    [sym_variadic_type] = STATE(3928),
    [sym_array_type] = STATE(3928),
    [sym_map_type] = STATE(3928),
    [sym_union_type] = STATE(3928),
    [sym_bit_set_type] = STATE(3928),
    [sym_matrix_type] = STATE(3928),
    [sym_field_type] = STATE(3928),
    [sym_tuple_type] = STATE(3928),
    [sym_struct_type] = STATE(3928),
    [sym_enum_type] = STATE(3928),
    [sym_bit_field_type] = STATE(3928),
    [sym_constant_type] = STATE(3928),
    [sym_specialized_type] = STATE(3928),
    [sym__procedure_type] = STATE(3928),
    [sym_distinct_type] = STATE(3928),
    [sym_empty_type] = STATE(3928),
    [sym_polymorphic_type] = STATE(3928),
    [sym_conditional_type] = STATE(3928),
    [sym_identifier] = ACTIONS(2282),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(2284),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(2290),
    [anon_sym_bit_field] = ACTIONS(2292),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(2400),
    [anon_sym_RPAREN] = ACTIONS(767),
    [anon_sym_DOLLAR] = ACTIONS(2298),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(2300),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(2403),
    [anon_sym_RBRACK] = ACTIONS(767),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(2306),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(2406),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2312),
    [anon_sym_map] = ACTIONS(2314),
    [anon_sym_bit_set] = ACTIONS(2316),
    [anon_sym_matrix] = ACTIONS(2318),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_tag] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [257] = {
    [sym_procedure] = STATE(3909),
    [sym_type] = STATE(3943),
    [sym_pointer_type] = STATE(3931),
    [sym_variadic_type] = STATE(3931),
    [sym_array_type] = STATE(3931),
    [sym_map_type] = STATE(3931),
    [sym_union_type] = STATE(3931),
    [sym_bit_set_type] = STATE(3931),
    [sym_matrix_type] = STATE(3931),
    [sym_field_type] = STATE(3931),
    [sym_tuple_type] = STATE(3931),
    [sym_struct_type] = STATE(3931),
    [sym_enum_type] = STATE(3931),
    [sym_bit_field_type] = STATE(3931),
    [sym_constant_type] = STATE(3931),
    [sym_specialized_type] = STATE(3931),
    [sym__procedure_type] = STATE(3931),
    [sym_distinct_type] = STATE(3931),
    [sym_empty_type] = STATE(3931),
    [sym_polymorphic_type] = STATE(3931),
    [sym_conditional_type] = STATE(3931),
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(2230),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(2232),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2238),
    [anon_sym_bit_field] = ACTIONS(2240),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(2409),
    [anon_sym_DOLLAR] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_case] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(2248),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(2254),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(2415),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2260),
    [anon_sym_map] = ACTIONS(2262),
    [anon_sym_bit_set] = ACTIONS(2264),
    [anon_sym_matrix] = ACTIONS(2266),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_tag] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [258] = {
    [sym_procedure] = STATE(3909),
    [sym_type] = STATE(3980),
    [sym_pointer_type] = STATE(3931),
    [sym_variadic_type] = STATE(3931),
    [sym_array_type] = STATE(3931),
    [sym_map_type] = STATE(3931),
    [sym_union_type] = STATE(3931),
    [sym_bit_set_type] = STATE(3931),
    [sym_matrix_type] = STATE(3931),
    [sym_field_type] = STATE(3931),
    [sym_tuple_type] = STATE(3931),
    [sym_struct_type] = STATE(3931),
    [sym_enum_type] = STATE(3931),
    [sym_bit_field_type] = STATE(3931),
    [sym_constant_type] = STATE(3931),
    [sym_specialized_type] = STATE(3931),
    [sym__procedure_type] = STATE(3931),
    [sym_distinct_type] = STATE(3931),
    [sym_empty_type] = STATE(3931),
    [sym_polymorphic_type] = STATE(3931),
    [sym_conditional_type] = STATE(3931),
    [ts_builtin_sym_end] = ACTIONS(871),
    [sym_identifier] = ACTIONS(2230),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(2232),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_struct] = ACTIONS(2234),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2238),
    [anon_sym_bit_field] = ACTIONS(2240),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(2418),
    [anon_sym_DOLLAR] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_case] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(2248),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(2422),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(2254),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(2426),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2260),
    [anon_sym_map] = ACTIONS(2262),
    [anon_sym_bit_set] = ACTIONS(2264),
    [anon_sym_matrix] = ACTIONS(2266),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_tag] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [259] = {
    [sym_procedure] = STATE(4282),
    [sym_type] = STATE(4380),
    [sym_pointer_type] = STATE(4299),
    [sym_variadic_type] = STATE(4299),
    [sym_array_type] = STATE(4299),
    [sym_map_type] = STATE(4299),
    [sym_union_type] = STATE(4299),
    [sym_bit_set_type] = STATE(4299),
    [sym_matrix_type] = STATE(4299),
    [sym_field_type] = STATE(4299),
    [sym_tuple_type] = STATE(4299),
    [sym_struct_type] = STATE(4299),
    [sym_enum_type] = STATE(4299),
    [sym_bit_field_type] = STATE(4299),
    [sym_constant_type] = STATE(4299),
    [sym_specialized_type] = STATE(4299),
    [sym__procedure_type] = STATE(4299),
    [sym_distinct_type] = STATE(4299),
    [sym_empty_type] = STATE(4299),
    [sym_polymorphic_type] = STATE(4299),
    [sym_conditional_type] = STATE(4299),
    [ts_builtin_sym_end] = ACTIONS(871),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(2432),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_struct] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2438),
    [anon_sym_bit_field] = ACTIONS(2440),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_LPAREN] = ACTIONS(2442),
    [anon_sym_DOLLAR] = ACTIONS(2446),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_case] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(2448),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(2450),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(2454),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(2456),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2460),
    [anon_sym_map] = ACTIONS(2462),
    [anon_sym_bit_set] = ACTIONS(2464),
    [anon_sym_matrix] = ACTIONS(2466),
    [anon_sym_distinct] = ACTIONS(2468),
    [sym_tag] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(871),
    [sym_block_comment] = ACTIONS(3),
  },
  [260] = {
    [sym_procedure] = STATE(4282),
    [sym_type] = STATE(4375),
    [sym_pointer_type] = STATE(4299),
    [sym_variadic_type] = STATE(4299),
    [sym_array_type] = STATE(4299),
    [sym_map_type] = STATE(4299),
    [sym_union_type] = STATE(4299),
    [sym_bit_set_type] = STATE(4299),
    [sym_matrix_type] = STATE(4299),
    [sym_field_type] = STATE(4299),
    [sym_tuple_type] = STATE(4299),
    [sym_struct_type] = STATE(4299),
    [sym_enum_type] = STATE(4299),
    [sym_bit_field_type] = STATE(4299),
    [sym_constant_type] = STATE(4299),
    [sym_specialized_type] = STATE(4299),
    [sym__procedure_type] = STATE(4299),
    [sym_distinct_type] = STATE(4299),
    [sym_empty_type] = STATE(4299),
    [sym_polymorphic_type] = STATE(4299),
    [sym_conditional_type] = STATE(4299),
    [ts_builtin_sym_end] = ACTIONS(893),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(2432),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2438),
    [anon_sym_bit_field] = ACTIONS(2440),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_LPAREN] = ACTIONS(2472),
    [anon_sym_DOLLAR] = ACTIONS(2446),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_case] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(2448),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(2475),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(2454),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(2478),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2460),
    [anon_sym_map] = ACTIONS(2462),
    [anon_sym_bit_set] = ACTIONS(2464),
    [anon_sym_matrix] = ACTIONS(2466),
    [anon_sym_distinct] = ACTIONS(2468),
    [sym_tag] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(893),
    [sym_block_comment] = ACTIONS(3),
  },
  [261] = {
    [sym_procedure] = STATE(4282),
    [sym_type] = STATE(4356),
    [sym_pointer_type] = STATE(4299),
    [sym_variadic_type] = STATE(4299),
    [sym_array_type] = STATE(4299),
    [sym_map_type] = STATE(4299),
    [sym_union_type] = STATE(4299),
    [sym_bit_set_type] = STATE(4299),
    [sym_matrix_type] = STATE(4299),
    [sym_field_type] = STATE(4299),
    [sym_tuple_type] = STATE(4299),
    [sym_struct_type] = STATE(4299),
    [sym_enum_type] = STATE(4299),
    [sym_bit_field_type] = STATE(4299),
    [sym_constant_type] = STATE(4299),
    [sym_specialized_type] = STATE(4299),
    [sym__procedure_type] = STATE(4299),
    [sym_distinct_type] = STATE(4299),
    [sym_empty_type] = STATE(4299),
    [sym_polymorphic_type] = STATE(4299),
    [sym_conditional_type] = STATE(4299),
    [ts_builtin_sym_end] = ACTIONS(809),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(2432),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2438),
    [anon_sym_bit_field] = ACTIONS(2440),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_LPAREN] = ACTIONS(2481),
    [anon_sym_DOLLAR] = ACTIONS(2446),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_case] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(2448),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(2485),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(2454),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(2489),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2460),
    [anon_sym_map] = ACTIONS(2462),
    [anon_sym_bit_set] = ACTIONS(2464),
    [anon_sym_matrix] = ACTIONS(2466),
    [anon_sym_distinct] = ACTIONS(2468),
    [sym_tag] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(809),
    [sym_block_comment] = ACTIONS(3),
  },
  [262] = {
    [sym_procedure] = STATE(4282),
    [sym_type] = STATE(4343),
    [sym_pointer_type] = STATE(4299),
    [sym_variadic_type] = STATE(4299),
    [sym_array_type] = STATE(4299),
    [sym_map_type] = STATE(4299),
    [sym_union_type] = STATE(4299),
    [sym_bit_set_type] = STATE(4299),
    [sym_matrix_type] = STATE(4299),
    [sym_field_type] = STATE(4299),
    [sym_tuple_type] = STATE(4299),
    [sym_struct_type] = STATE(4299),
    [sym_enum_type] = STATE(4299),
    [sym_bit_field_type] = STATE(4299),
    [sym_constant_type] = STATE(4299),
    [sym_specialized_type] = STATE(4299),
    [sym__procedure_type] = STATE(4299),
    [sym_distinct_type] = STATE(4299),
    [sym_empty_type] = STATE(4299),
    [sym_polymorphic_type] = STATE(4299),
    [sym_conditional_type] = STATE(4299),
    [ts_builtin_sym_end] = ACTIONS(855),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(2432),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_struct] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2438),
    [anon_sym_bit_field] = ACTIONS(2440),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(2493),
    [anon_sym_DOLLAR] = ACTIONS(2446),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(2448),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(2496),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(2454),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(2499),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2460),
    [anon_sym_map] = ACTIONS(2462),
    [anon_sym_bit_set] = ACTIONS(2464),
    [anon_sym_matrix] = ACTIONS(2466),
    [anon_sym_distinct] = ACTIONS(2468),
    [sym_tag] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(855),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(855),
    [sym_block_comment] = ACTIONS(3),
  },
  [263] = {
    [sym_procedure] = STATE(4282),
    [sym_type] = STATE(4349),
    [sym_pointer_type] = STATE(4299),
    [sym_variadic_type] = STATE(4299),
    [sym_array_type] = STATE(4299),
    [sym_map_type] = STATE(4299),
    [sym_union_type] = STATE(4299),
    [sym_bit_set_type] = STATE(4299),
    [sym_matrix_type] = STATE(4299),
    [sym_field_type] = STATE(4299),
    [sym_tuple_type] = STATE(4299),
    [sym_struct_type] = STATE(4299),
    [sym_enum_type] = STATE(4299),
    [sym_bit_field_type] = STATE(4299),
    [sym_constant_type] = STATE(4299),
    [sym_specialized_type] = STATE(4299),
    [sym__procedure_type] = STATE(4299),
    [sym_distinct_type] = STATE(4299),
    [sym_empty_type] = STATE(4299),
    [sym_polymorphic_type] = STATE(4299),
    [sym_conditional_type] = STATE(4299),
    [ts_builtin_sym_end] = ACTIONS(833),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(2432),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2438),
    [anon_sym_bit_field] = ACTIONS(2440),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(2502),
    [anon_sym_DOLLAR] = ACTIONS(2446),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(2448),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2506),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(2454),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(2510),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2460),
    [anon_sym_map] = ACTIONS(2462),
    [anon_sym_bit_set] = ACTIONS(2464),
    [anon_sym_matrix] = ACTIONS(2466),
    [anon_sym_distinct] = ACTIONS(2468),
    [sym_tag] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(833),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(833),
    [sym_block_comment] = ACTIONS(3),
  },
  [264] = {
    [sym_procedure] = STATE(4282),
    [sym_type] = STATE(4377),
    [sym_pointer_type] = STATE(4299),
    [sym_variadic_type] = STATE(4299),
    [sym_array_type] = STATE(4299),
    [sym_map_type] = STATE(4299),
    [sym_union_type] = STATE(4299),
    [sym_bit_set_type] = STATE(4299),
    [sym_matrix_type] = STATE(4299),
    [sym_field_type] = STATE(4299),
    [sym_tuple_type] = STATE(4299),
    [sym_struct_type] = STATE(4299),
    [sym_enum_type] = STATE(4299),
    [sym_bit_field_type] = STATE(4299),
    [sym_constant_type] = STATE(4299),
    [sym_specialized_type] = STATE(4299),
    [sym__procedure_type] = STATE(4299),
    [sym_distinct_type] = STATE(4299),
    [sym_empty_type] = STATE(4299),
    [sym_polymorphic_type] = STATE(4299),
    [sym_conditional_type] = STATE(4299),
    [ts_builtin_sym_end] = ACTIONS(909),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(2432),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2438),
    [anon_sym_bit_field] = ACTIONS(2440),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(2514),
    [anon_sym_DOLLAR] = ACTIONS(2446),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_case] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(2448),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(2517),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(2454),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(2520),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2460),
    [anon_sym_map] = ACTIONS(2462),
    [anon_sym_bit_set] = ACTIONS(2464),
    [anon_sym_matrix] = ACTIONS(2466),
    [anon_sym_distinct] = ACTIONS(2468),
    [sym_tag] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(909),
    [sym_block_comment] = ACTIONS(3),
  },
  [265] = {
    [sym_procedure] = STATE(4282),
    [sym_type] = STATE(4493),
    [sym_pointer_type] = STATE(4299),
    [sym_variadic_type] = STATE(4299),
    [sym_array_type] = STATE(4299),
    [sym_map_type] = STATE(4299),
    [sym_union_type] = STATE(4299),
    [sym_bit_set_type] = STATE(4299),
    [sym_matrix_type] = STATE(4299),
    [sym_field_type] = STATE(4299),
    [sym_tuple_type] = STATE(4299),
    [sym_struct_type] = STATE(4299),
    [sym_enum_type] = STATE(4299),
    [sym_bit_field_type] = STATE(4299),
    [sym_constant_type] = STATE(4299),
    [sym_specialized_type] = STATE(4299),
    [sym__procedure_type] = STATE(4299),
    [sym_distinct_type] = STATE(4299),
    [sym_empty_type] = STATE(4299),
    [sym_polymorphic_type] = STATE(4299),
    [sym_conditional_type] = STATE(4299),
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(2430),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(2432),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(2434),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2438),
    [anon_sym_bit_field] = ACTIONS(2440),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(2523),
    [anon_sym_DOLLAR] = ACTIONS(2446),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_case] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(2448),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(2526),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(2454),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(2529),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2460),
    [anon_sym_map] = ACTIONS(2462),
    [anon_sym_bit_set] = ACTIONS(2464),
    [anon_sym_matrix] = ACTIONS(2466),
    [anon_sym_distinct] = ACTIONS(2468),
    [sym_tag] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(767),
    [sym_block_comment] = ACTIONS(3),
  },
  [266] = {
    [sym_procedure] = STATE(4297),
    [sym_type] = STATE(4317),
    [sym_pointer_type] = STATE(4337),
    [sym_variadic_type] = STATE(4337),
    [sym_array_type] = STATE(4337),
    [sym_map_type] = STATE(4337),
    [sym_union_type] = STATE(4337),
    [sym_bit_set_type] = STATE(4337),
    [sym_matrix_type] = STATE(4337),
    [sym_field_type] = STATE(4337),
    [sym_tuple_type] = STATE(4337),
    [sym_struct_type] = STATE(4337),
    [sym_enum_type] = STATE(4337),
    [sym_bit_field_type] = STATE(4337),
    [sym_constant_type] = STATE(4337),
    [sym_specialized_type] = STATE(4337),
    [sym__procedure_type] = STATE(4337),
    [sym_distinct_type] = STATE(4337),
    [sym_empty_type] = STATE(4337),
    [sym_polymorphic_type] = STATE(4337),
    [sym_conditional_type] = STATE(4337),
    [sym_identifier] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(2534),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_where] = ACTIONS(773),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2538),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_bit_field] = ACTIONS(2542),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(2544),
    [anon_sym_DOLLAR] = ACTIONS(2547),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(2549),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(2551),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(2554),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(2556),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2559),
    [anon_sym_map] = ACTIONS(2561),
    [anon_sym_bit_set] = ACTIONS(2563),
    [anon_sym_matrix] = ACTIONS(2565),
    [anon_sym_distinct] = ACTIONS(1343),
    [anon_sym_DQUOTE] = ACTIONS(767),
    [anon_sym_BQUOTE] = ACTIONS(767),
    [sym_uninitialized] = ACTIONS(767),
    [sym_tag] = ACTIONS(2567),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [267] = {
    [sym_procedure] = STATE(4297),
    [sym_type] = STATE(4382),
    [sym_pointer_type] = STATE(4337),
    [sym_variadic_type] = STATE(4337),
    [sym_array_type] = STATE(4337),
    [sym_map_type] = STATE(4337),
    [sym_union_type] = STATE(4337),
    [sym_bit_set_type] = STATE(4337),
    [sym_matrix_type] = STATE(4337),
    [sym_field_type] = STATE(4337),
    [sym_tuple_type] = STATE(4337),
    [sym_struct_type] = STATE(4337),
    [sym_enum_type] = STATE(4337),
    [sym_bit_field_type] = STATE(4337),
    [sym_constant_type] = STATE(4337),
    [sym_specialized_type] = STATE(4337),
    [sym__procedure_type] = STATE(4337),
    [sym_distinct_type] = STATE(4337),
    [sym_empty_type] = STATE(4337),
    [sym_polymorphic_type] = STATE(4337),
    [sym_conditional_type] = STATE(4337),
    [sym_identifier] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(2534),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_where] = ACTIONS(895),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2538),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_bit_field] = ACTIONS(2542),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_LPAREN] = ACTIONS(2570),
    [anon_sym_DOLLAR] = ACTIONS(2547),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(2549),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(2554),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(2576),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2559),
    [anon_sym_map] = ACTIONS(2561),
    [anon_sym_bit_set] = ACTIONS(2563),
    [anon_sym_matrix] = ACTIONS(2565),
    [anon_sym_distinct] = ACTIONS(1343),
    [anon_sym_DQUOTE] = ACTIONS(893),
    [anon_sym_BQUOTE] = ACTIONS(893),
    [sym_uninitialized] = ACTIONS(893),
    [sym_tag] = ACTIONS(2579),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [268] = {
    [sym_procedure] = STATE(4297),
    [sym_type] = STATE(4373),
    [sym_pointer_type] = STATE(4337),
    [sym_variadic_type] = STATE(4337),
    [sym_array_type] = STATE(4337),
    [sym_map_type] = STATE(4337),
    [sym_union_type] = STATE(4337),
    [sym_bit_set_type] = STATE(4337),
    [sym_matrix_type] = STATE(4337),
    [sym_field_type] = STATE(4337),
    [sym_tuple_type] = STATE(4337),
    [sym_struct_type] = STATE(4337),
    [sym_enum_type] = STATE(4337),
    [sym_bit_field_type] = STATE(4337),
    [sym_constant_type] = STATE(4337),
    [sym_specialized_type] = STATE(4337),
    [sym__procedure_type] = STATE(4337),
    [sym_distinct_type] = STATE(4337),
    [sym_empty_type] = STATE(4337),
    [sym_polymorphic_type] = STATE(4337),
    [sym_conditional_type] = STATE(4337),
    [sym_identifier] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(2534),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_where] = ACTIONS(857),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2538),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_bit_field] = ACTIONS(2542),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(2582),
    [anon_sym_DOLLAR] = ACTIONS(2547),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(2549),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(2585),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(2554),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(2588),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2559),
    [anon_sym_map] = ACTIONS(2561),
    [anon_sym_bit_set] = ACTIONS(2563),
    [anon_sym_matrix] = ACTIONS(2565),
    [anon_sym_distinct] = ACTIONS(1343),
    [anon_sym_DQUOTE] = ACTIONS(855),
    [anon_sym_BQUOTE] = ACTIONS(855),
    [sym_uninitialized] = ACTIONS(855),
    [sym_tag] = ACTIONS(2591),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [269] = {
    [sym_procedure] = STATE(4297),
    [sym_type] = STATE(4383),
    [sym_pointer_type] = STATE(4337),
    [sym_variadic_type] = STATE(4337),
    [sym_array_type] = STATE(4337),
    [sym_map_type] = STATE(4337),
    [sym_union_type] = STATE(4337),
    [sym_bit_set_type] = STATE(4337),
    [sym_matrix_type] = STATE(4337),
    [sym_field_type] = STATE(4337),
    [sym_tuple_type] = STATE(4337),
    [sym_struct_type] = STATE(4337),
    [sym_enum_type] = STATE(4337),
    [sym_bit_field_type] = STATE(4337),
    [sym_constant_type] = STATE(4337),
    [sym_specialized_type] = STATE(4337),
    [sym__procedure_type] = STATE(4337),
    [sym_distinct_type] = STATE(4337),
    [sym_empty_type] = STATE(4337),
    [sym_polymorphic_type] = STATE(4337),
    [sym_conditional_type] = STATE(4337),
    [sym_identifier] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(2534),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_where] = ACTIONS(911),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2538),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_bit_field] = ACTIONS(2542),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(2594),
    [anon_sym_DOLLAR] = ACTIONS(2547),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(2549),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(2597),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(2554),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(2600),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2559),
    [anon_sym_map] = ACTIONS(2561),
    [anon_sym_bit_set] = ACTIONS(2563),
    [anon_sym_matrix] = ACTIONS(2565),
    [anon_sym_distinct] = ACTIONS(1343),
    [anon_sym_DQUOTE] = ACTIONS(909),
    [anon_sym_BQUOTE] = ACTIONS(909),
    [sym_uninitialized] = ACTIONS(909),
    [sym_tag] = ACTIONS(2603),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [270] = {
    [sym_procedure] = STATE(4297),
    [sym_type] = STATE(4376),
    [sym_pointer_type] = STATE(4337),
    [sym_variadic_type] = STATE(4337),
    [sym_array_type] = STATE(4337),
    [sym_map_type] = STATE(4337),
    [sym_union_type] = STATE(4337),
    [sym_bit_set_type] = STATE(4337),
    [sym_matrix_type] = STATE(4337),
    [sym_field_type] = STATE(4337),
    [sym_tuple_type] = STATE(4337),
    [sym_struct_type] = STATE(4337),
    [sym_enum_type] = STATE(4337),
    [sym_bit_field_type] = STATE(4337),
    [sym_constant_type] = STATE(4337),
    [sym_specialized_type] = STATE(4337),
    [sym__procedure_type] = STATE(4337),
    [sym_distinct_type] = STATE(4337),
    [sym_empty_type] = STATE(4337),
    [sym_polymorphic_type] = STATE(4337),
    [sym_conditional_type] = STATE(4337),
    [sym_identifier] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(2534),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_where] = ACTIONS(836),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2538),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_bit_field] = ACTIONS(2542),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(2606),
    [anon_sym_DOLLAR] = ACTIONS(2547),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(2549),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2610),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(2554),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(2614),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2559),
    [anon_sym_map] = ACTIONS(2561),
    [anon_sym_bit_set] = ACTIONS(2563),
    [anon_sym_matrix] = ACTIONS(2565),
    [anon_sym_distinct] = ACTIONS(1343),
    [anon_sym_DQUOTE] = ACTIONS(833),
    [anon_sym_BQUOTE] = ACTIONS(833),
    [sym_uninitialized] = ACTIONS(833),
    [sym_tag] = ACTIONS(2618),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [271] = {
    [sym_procedure] = STATE(4297),
    [sym_type] = STATE(4378),
    [sym_pointer_type] = STATE(4337),
    [sym_variadic_type] = STATE(4337),
    [sym_array_type] = STATE(4337),
    [sym_map_type] = STATE(4337),
    [sym_union_type] = STATE(4337),
    [sym_bit_set_type] = STATE(4337),
    [sym_matrix_type] = STATE(4337),
    [sym_field_type] = STATE(4337),
    [sym_tuple_type] = STATE(4337),
    [sym_struct_type] = STATE(4337),
    [sym_enum_type] = STATE(4337),
    [sym_bit_field_type] = STATE(4337),
    [sym_constant_type] = STATE(4337),
    [sym_specialized_type] = STATE(4337),
    [sym__procedure_type] = STATE(4337),
    [sym_distinct_type] = STATE(4337),
    [sym_empty_type] = STATE(4337),
    [sym_polymorphic_type] = STATE(4337),
    [sym_conditional_type] = STATE(4337),
    [sym_identifier] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(2534),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_where] = ACTIONS(812),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2538),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_bit_field] = ACTIONS(2542),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_LPAREN] = ACTIONS(2622),
    [anon_sym_DOLLAR] = ACTIONS(2547),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(2549),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(2626),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(2554),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(2630),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2559),
    [anon_sym_map] = ACTIONS(2561),
    [anon_sym_bit_set] = ACTIONS(2563),
    [anon_sym_matrix] = ACTIONS(2565),
    [anon_sym_distinct] = ACTIONS(1343),
    [anon_sym_DQUOTE] = ACTIONS(809),
    [anon_sym_BQUOTE] = ACTIONS(809),
    [sym_uninitialized] = ACTIONS(809),
    [sym_tag] = ACTIONS(2634),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [272] = {
    [sym_procedure] = STATE(4297),
    [sym_type] = STATE(4384),
    [sym_pointer_type] = STATE(4337),
    [sym_variadic_type] = STATE(4337),
    [sym_array_type] = STATE(4337),
    [sym_map_type] = STATE(4337),
    [sym_union_type] = STATE(4337),
    [sym_bit_set_type] = STATE(4337),
    [sym_matrix_type] = STATE(4337),
    [sym_field_type] = STATE(4337),
    [sym_tuple_type] = STATE(4337),
    [sym_struct_type] = STATE(4337),
    [sym_enum_type] = STATE(4337),
    [sym_bit_field_type] = STATE(4337),
    [sym_constant_type] = STATE(4337),
    [sym_specialized_type] = STATE(4337),
    [sym__procedure_type] = STATE(4337),
    [sym_distinct_type] = STATE(4337),
    [sym_empty_type] = STATE(4337),
    [sym_polymorphic_type] = STATE(4337),
    [sym_conditional_type] = STATE(4337),
    [sym_identifier] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(2534),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_where] = ACTIONS(874),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2538),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_bit_field] = ACTIONS(2542),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_LPAREN] = ACTIONS(2638),
    [anon_sym_DOLLAR] = ACTIONS(2547),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(2549),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(2642),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(2554),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(2646),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2559),
    [anon_sym_map] = ACTIONS(2561),
    [anon_sym_bit_set] = ACTIONS(2563),
    [anon_sym_matrix] = ACTIONS(2565),
    [anon_sym_distinct] = ACTIONS(1343),
    [anon_sym_DQUOTE] = ACTIONS(871),
    [anon_sym_BQUOTE] = ACTIONS(871),
    [sym_uninitialized] = ACTIONS(871),
    [sym_tag] = ACTIONS(2650),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [273] = {
    [sym_procedure] = STATE(4572),
    [sym_type] = STATE(4557),
    [sym_pointer_type] = STATE(4568),
    [sym_variadic_type] = STATE(4568),
    [sym_array_type] = STATE(4568),
    [sym_map_type] = STATE(4568),
    [sym_union_type] = STATE(4568),
    [sym_bit_set_type] = STATE(4568),
    [sym_matrix_type] = STATE(4568),
    [sym_field_type] = STATE(4568),
    [sym_tuple_type] = STATE(4568),
    [sym_struct_type] = STATE(4568),
    [sym_enum_type] = STATE(4568),
    [sym_bit_field_type] = STATE(4568),
    [sym_constant_type] = STATE(4568),
    [sym_specialized_type] = STATE(4568),
    [sym__procedure_type] = STATE(4568),
    [sym_distinct_type] = STATE(4568),
    [sym_empty_type] = STATE(4568),
    [sym_polymorphic_type] = STATE(4568),
    [sym_conditional_type] = STATE(4568),
    [ts_builtin_sym_end] = ACTIONS(871),
    [sym_identifier] = ACTIONS(2654),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(2656),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_struct] = ACTIONS(2658),
    [anon_sym_enum] = ACTIONS(2660),
    [anon_sym_union] = ACTIONS(2662),
    [anon_sym_bit_field] = ACTIONS(2664),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_LPAREN] = ACTIONS(2666),
    [anon_sym_DOLLAR] = ACTIONS(2670),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_case] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(2672),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(2674),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(2678),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(2680),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2684),
    [anon_sym_map] = ACTIONS(2686),
    [anon_sym_bit_set] = ACTIONS(2688),
    [anon_sym_matrix] = ACTIONS(2690),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_tag] = ACTIONS(2692),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(871),
    [sym_block_comment] = ACTIONS(3),
  },
  [274] = {
    [sym_procedure] = STATE(4572),
    [sym_type] = STATE(4524),
    [sym_pointer_type] = STATE(4568),
    [sym_variadic_type] = STATE(4568),
    [sym_array_type] = STATE(4568),
    [sym_map_type] = STATE(4568),
    [sym_union_type] = STATE(4568),
    [sym_bit_set_type] = STATE(4568),
    [sym_matrix_type] = STATE(4568),
    [sym_field_type] = STATE(4568),
    [sym_tuple_type] = STATE(4568),
    [sym_struct_type] = STATE(4568),
    [sym_enum_type] = STATE(4568),
    [sym_bit_field_type] = STATE(4568),
    [sym_constant_type] = STATE(4568),
    [sym_specialized_type] = STATE(4568),
    [sym__procedure_type] = STATE(4568),
    [sym_distinct_type] = STATE(4568),
    [sym_empty_type] = STATE(4568),
    [sym_polymorphic_type] = STATE(4568),
    [sym_conditional_type] = STATE(4568),
    [ts_builtin_sym_end] = ACTIONS(833),
    [sym_identifier] = ACTIONS(2654),
    [anon_sym_RBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(2656),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_struct] = ACTIONS(2658),
    [anon_sym_enum] = ACTIONS(2660),
    [anon_sym_union] = ACTIONS(2662),
    [anon_sym_bit_field] = ACTIONS(2664),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(2694),
    [anon_sym_DOLLAR] = ACTIONS(2670),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(833),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_case] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(2672),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2698),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(2678),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(2702),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2684),
    [anon_sym_map] = ACTIONS(2686),
    [anon_sym_bit_set] = ACTIONS(2688),
    [anon_sym_matrix] = ACTIONS(2690),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_tag] = ACTIONS(2692),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(833),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(833),
    [sym_block_comment] = ACTIONS(3),
  },
  [275] = {
    [sym_procedure] = STATE(4572),
    [sym_type] = STATE(4530),
    [sym_pointer_type] = STATE(4568),
    [sym_variadic_type] = STATE(4568),
    [sym_array_type] = STATE(4568),
    [sym_map_type] = STATE(4568),
    [sym_union_type] = STATE(4568),
    [sym_bit_set_type] = STATE(4568),
    [sym_matrix_type] = STATE(4568),
    [sym_field_type] = STATE(4568),
    [sym_tuple_type] = STATE(4568),
    [sym_struct_type] = STATE(4568),
    [sym_enum_type] = STATE(4568),
    [sym_bit_field_type] = STATE(4568),
    [sym_constant_type] = STATE(4568),
    [sym_specialized_type] = STATE(4568),
    [sym__procedure_type] = STATE(4568),
    [sym_distinct_type] = STATE(4568),
    [sym_empty_type] = STATE(4568),
    [sym_polymorphic_type] = STATE(4568),
    [sym_conditional_type] = STATE(4568),
    [ts_builtin_sym_end] = ACTIONS(809),
    [sym_identifier] = ACTIONS(2654),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(2656),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_struct] = ACTIONS(2658),
    [anon_sym_enum] = ACTIONS(2660),
    [anon_sym_union] = ACTIONS(2662),
    [anon_sym_bit_field] = ACTIONS(2664),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_LPAREN] = ACTIONS(2706),
    [anon_sym_DOLLAR] = ACTIONS(2670),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_case] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(2672),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(2710),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(2678),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(2714),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2684),
    [anon_sym_map] = ACTIONS(2686),
    [anon_sym_bit_set] = ACTIONS(2688),
    [anon_sym_matrix] = ACTIONS(2690),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_tag] = ACTIONS(2692),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(809),
    [sym_block_comment] = ACTIONS(3),
  },
  [276] = {
    [sym_procedure] = STATE(4572),
    [sym_type] = STATE(4555),
    [sym_pointer_type] = STATE(4568),
    [sym_variadic_type] = STATE(4568),
    [sym_array_type] = STATE(4568),
    [sym_map_type] = STATE(4568),
    [sym_union_type] = STATE(4568),
    [sym_bit_set_type] = STATE(4568),
    [sym_matrix_type] = STATE(4568),
    [sym_field_type] = STATE(4568),
    [sym_tuple_type] = STATE(4568),
    [sym_struct_type] = STATE(4568),
    [sym_enum_type] = STATE(4568),
    [sym_bit_field_type] = STATE(4568),
    [sym_constant_type] = STATE(4568),
    [sym_specialized_type] = STATE(4568),
    [sym__procedure_type] = STATE(4568),
    [sym_distinct_type] = STATE(4568),
    [sym_empty_type] = STATE(4568),
    [sym_polymorphic_type] = STATE(4568),
    [sym_conditional_type] = STATE(4568),
    [ts_builtin_sym_end] = ACTIONS(909),
    [sym_identifier] = ACTIONS(2654),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(2656),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_struct] = ACTIONS(2658),
    [anon_sym_enum] = ACTIONS(2660),
    [anon_sym_union] = ACTIONS(2662),
    [anon_sym_bit_field] = ACTIONS(2664),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(2718),
    [anon_sym_DOLLAR] = ACTIONS(2670),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_case] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(2672),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(2721),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(2678),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(2724),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2684),
    [anon_sym_map] = ACTIONS(2686),
    [anon_sym_bit_set] = ACTIONS(2688),
    [anon_sym_matrix] = ACTIONS(2690),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_tag] = ACTIONS(2692),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(909),
    [sym_block_comment] = ACTIONS(3),
  },
  [277] = {
    [sym_procedure] = STATE(4572),
    [sym_type] = STATE(4553),
    [sym_pointer_type] = STATE(4568),
    [sym_variadic_type] = STATE(4568),
    [sym_array_type] = STATE(4568),
    [sym_map_type] = STATE(4568),
    [sym_union_type] = STATE(4568),
    [sym_bit_set_type] = STATE(4568),
    [sym_matrix_type] = STATE(4568),
    [sym_field_type] = STATE(4568),
    [sym_tuple_type] = STATE(4568),
    [sym_struct_type] = STATE(4568),
    [sym_enum_type] = STATE(4568),
    [sym_bit_field_type] = STATE(4568),
    [sym_constant_type] = STATE(4568),
    [sym_specialized_type] = STATE(4568),
    [sym__procedure_type] = STATE(4568),
    [sym_distinct_type] = STATE(4568),
    [sym_empty_type] = STATE(4568),
    [sym_polymorphic_type] = STATE(4568),
    [sym_conditional_type] = STATE(4568),
    [ts_builtin_sym_end] = ACTIONS(893),
    [sym_identifier] = ACTIONS(2654),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(2656),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_struct] = ACTIONS(2658),
    [anon_sym_enum] = ACTIONS(2660),
    [anon_sym_union] = ACTIONS(2662),
    [anon_sym_bit_field] = ACTIONS(2664),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_LPAREN] = ACTIONS(2727),
    [anon_sym_DOLLAR] = ACTIONS(2670),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_case] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(2672),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(2730),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(2678),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(2733),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2684),
    [anon_sym_map] = ACTIONS(2686),
    [anon_sym_bit_set] = ACTIONS(2688),
    [anon_sym_matrix] = ACTIONS(2690),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_tag] = ACTIONS(2692),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(893),
    [sym_block_comment] = ACTIONS(3),
  },
  [278] = {
    [sym_procedure] = STATE(4572),
    [sym_type] = STATE(4556),
    [sym_pointer_type] = STATE(4568),
    [sym_variadic_type] = STATE(4568),
    [sym_array_type] = STATE(4568),
    [sym_map_type] = STATE(4568),
    [sym_union_type] = STATE(4568),
    [sym_bit_set_type] = STATE(4568),
    [sym_matrix_type] = STATE(4568),
    [sym_field_type] = STATE(4568),
    [sym_tuple_type] = STATE(4568),
    [sym_struct_type] = STATE(4568),
    [sym_enum_type] = STATE(4568),
    [sym_bit_field_type] = STATE(4568),
    [sym_constant_type] = STATE(4568),
    [sym_specialized_type] = STATE(4568),
    [sym__procedure_type] = STATE(4568),
    [sym_distinct_type] = STATE(4568),
    [sym_empty_type] = STATE(4568),
    [sym_polymorphic_type] = STATE(4568),
    [sym_conditional_type] = STATE(4568),
    [ts_builtin_sym_end] = ACTIONS(767),
    [sym_identifier] = ACTIONS(2654),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(2656),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_struct] = ACTIONS(2658),
    [anon_sym_enum] = ACTIONS(2660),
    [anon_sym_union] = ACTIONS(2662),
    [anon_sym_bit_field] = ACTIONS(2664),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(2736),
    [anon_sym_DOLLAR] = ACTIONS(2670),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_case] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(2672),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(2739),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(2678),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(2742),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2684),
    [anon_sym_map] = ACTIONS(2686),
    [anon_sym_bit_set] = ACTIONS(2688),
    [anon_sym_matrix] = ACTIONS(2690),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_tag] = ACTIONS(2692),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(767),
    [sym_block_comment] = ACTIONS(3),
  },
  [279] = {
    [sym_procedure] = STATE(4572),
    [sym_type] = STATE(4516),
    [sym_pointer_type] = STATE(4568),
    [sym_variadic_type] = STATE(4568),
    [sym_array_type] = STATE(4568),
    [sym_map_type] = STATE(4568),
    [sym_union_type] = STATE(4568),
    [sym_bit_set_type] = STATE(4568),
    [sym_matrix_type] = STATE(4568),
    [sym_field_type] = STATE(4568),
    [sym_tuple_type] = STATE(4568),
    [sym_struct_type] = STATE(4568),
    [sym_enum_type] = STATE(4568),
    [sym_bit_field_type] = STATE(4568),
    [sym_constant_type] = STATE(4568),
    [sym_specialized_type] = STATE(4568),
    [sym__procedure_type] = STATE(4568),
    [sym_distinct_type] = STATE(4568),
    [sym_empty_type] = STATE(4568),
    [sym_polymorphic_type] = STATE(4568),
    [sym_conditional_type] = STATE(4568),
    [ts_builtin_sym_end] = ACTIONS(855),
    [sym_identifier] = ACTIONS(2654),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(2656),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_struct] = ACTIONS(2658),
    [anon_sym_enum] = ACTIONS(2660),
    [anon_sym_union] = ACTIONS(2662),
    [anon_sym_bit_field] = ACTIONS(2664),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(2745),
    [anon_sym_DOLLAR] = ACTIONS(2670),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_SEMI] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(2672),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(2748),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(2678),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(2751),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2684),
    [anon_sym_map] = ACTIONS(2686),
    [anon_sym_bit_set] = ACTIONS(2688),
    [anon_sym_matrix] = ACTIONS(2690),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_tag] = ACTIONS(2692),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(855),
    [sym__backslash] = ACTIONS(3),
    [sym__nl_comma] = ACTIONS(855),
    [sym_block_comment] = ACTIONS(3),
  },
  [280] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3108),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(2754),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_proc] = ACTIONS(2758),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_where] = ACTIONS(812),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_LPAREN] = ACTIONS(1774),
    [anon_sym_RPAREN] = ACTIONS(809),
    [anon_sym_DOLLAR] = ACTIONS(2760),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_when] = ACTIONS(812),
    [anon_sym_in] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(809),
    [anon_sym_or_else] = ACTIONS(812),
    [anon_sym_AMP_AMP] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(809),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(2762),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(812),
    [anon_sym_DOT_DOT] = ACTIONS(2766),
    [anon_sym_or_return] = ACTIONS(812),
    [anon_sym_or_continue] = ACTIONS(812),
    [anon_sym_or_break] = ACTIONS(812),
    [anon_sym_CARET] = ACTIONS(2768),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(2772),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(2774),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_uninitialized] = ACTIONS(809),
    [sym_tag] = ACTIONS(2776),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [281] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3046),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(2780),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_proc] = ACTIONS(2758),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_where] = ACTIONS(911),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_LPAREN] = ACTIONS(1894),
    [anon_sym_RPAREN] = ACTIONS(909),
    [anon_sym_DOLLAR] = ACTIONS(2760),
    [anon_sym_if] = ACTIONS(911),
    [anon_sym_when] = ACTIONS(911),
    [anon_sym_in] = ACTIONS(911),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(909),
    [anon_sym_or_else] = ACTIONS(911),
    [anon_sym_AMP_AMP] = ACTIONS(909),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(909),
    [anon_sym_LT_LT] = ACTIONS(909),
    [anon_sym_GT_GT] = ACTIONS(909),
    [anon_sym_STAR] = ACTIONS(909),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(2783),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(911),
    [anon_sym_DOT_DOT] = ACTIONS(2766),
    [anon_sym_or_return] = ACTIONS(911),
    [anon_sym_or_continue] = ACTIONS(911),
    [anon_sym_or_break] = ACTIONS(911),
    [anon_sym_CARET] = ACTIONS(2786),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(2772),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(2774),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_uninitialized] = ACTIONS(909),
    [sym_tag] = ACTIONS(2789),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [282] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3165),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(2792),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_proc] = ACTIONS(2758),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_where] = ACTIONS(773),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(1870),
    [anon_sym_RPAREN] = ACTIONS(767),
    [anon_sym_DOLLAR] = ACTIONS(2760),
    [anon_sym_if] = ACTIONS(773),
    [anon_sym_when] = ACTIONS(773),
    [anon_sym_in] = ACTIONS(773),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(767),
    [anon_sym_or_else] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(767),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(2795),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(773),
    [anon_sym_DOT_DOT] = ACTIONS(2766),
    [anon_sym_or_return] = ACTIONS(773),
    [anon_sym_or_continue] = ACTIONS(773),
    [anon_sym_or_break] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(2798),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(2772),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(2774),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_uninitialized] = ACTIONS(767),
    [sym_tag] = ACTIONS(2801),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [283] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3051),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(2804),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_proc] = ACTIONS(2758),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_where] = ACTIONS(874),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_LPAREN] = ACTIONS(1842),
    [anon_sym_RPAREN] = ACTIONS(871),
    [anon_sym_DOLLAR] = ACTIONS(2760),
    [anon_sym_if] = ACTIONS(874),
    [anon_sym_when] = ACTIONS(874),
    [anon_sym_in] = ACTIONS(874),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(871),
    [anon_sym_or_else] = ACTIONS(874),
    [anon_sym_AMP_AMP] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(871),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(2808),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(874),
    [anon_sym_DOT_DOT] = ACTIONS(2766),
    [anon_sym_or_return] = ACTIONS(874),
    [anon_sym_or_continue] = ACTIONS(874),
    [anon_sym_or_break] = ACTIONS(874),
    [anon_sym_CARET] = ACTIONS(2812),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(2772),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(2774),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_uninitialized] = ACTIONS(871),
    [sym_tag] = ACTIONS(2816),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [284] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3078),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(2820),
    [anon_sym_LBRACE] = ACTIONS(833),
    [anon_sym_COMMA] = ACTIONS(833),
    [anon_sym_proc] = ACTIONS(2758),
    [anon_sym_DASH_GT] = ACTIONS(833),
    [anon_sym_where] = ACTIONS(836),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(836),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_LPAREN] = ACTIONS(1744),
    [anon_sym_RPAREN] = ACTIONS(833),
    [anon_sym_DOLLAR] = ACTIONS(2760),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_when] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(833),
    [anon_sym_PLUS] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(836),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(833),
    [anon_sym_or_else] = ACTIONS(836),
    [anon_sym_AMP_AMP] = ACTIONS(833),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_GT_EQ] = ACTIONS(833),
    [anon_sym_LT_EQ] = ACTIONS(833),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(833),
    [anon_sym_BANG_EQ] = ACTIONS(833),
    [anon_sym_TILDE_EQ] = ACTIONS(833),
    [anon_sym_AMP_TILDE] = ACTIONS(833),
    [anon_sym_LT_LT] = ACTIONS(833),
    [anon_sym_GT_GT] = ACTIONS(833),
    [anon_sym_STAR] = ACTIONS(833),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(836),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(833),
    [anon_sym_DOT] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(2824),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(833),
    [anon_sym_DOT_DOT_LT] = ACTIONS(833),
    [anon_sym_not_in] = ACTIONS(836),
    [anon_sym_DOT_DOT] = ACTIONS(2766),
    [anon_sym_or_return] = ACTIONS(836),
    [anon_sym_or_continue] = ACTIONS(836),
    [anon_sym_or_break] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(2828),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(2772),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(2774),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_uninitialized] = ACTIONS(833),
    [sym_tag] = ACTIONS(2832),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [285] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3043),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(2836),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_proc] = ACTIONS(2758),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_where] = ACTIONS(895),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_RPAREN] = ACTIONS(893),
    [anon_sym_DOLLAR] = ACTIONS(2760),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_when] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(893),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_or_else] = ACTIONS(895),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(893),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(893),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(2839),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(895),
    [anon_sym_DOT_DOT] = ACTIONS(2766),
    [anon_sym_or_return] = ACTIONS(895),
    [anon_sym_or_continue] = ACTIONS(895),
    [anon_sym_or_break] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(2842),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(2772),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(2774),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_uninitialized] = ACTIONS(893),
    [sym_tag] = ACTIONS(2845),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [286] = {
    [sym_procedure] = STATE(3117),
    [sym_type] = STATE(3017),
    [sym_pointer_type] = STATE(3122),
    [sym_variadic_type] = STATE(3122),
    [sym_array_type] = STATE(3122),
    [sym_map_type] = STATE(3122),
    [sym_union_type] = STATE(3122),
    [sym_bit_set_type] = STATE(3122),
    [sym_matrix_type] = STATE(3122),
    [sym_field_type] = STATE(3122),
    [sym_tuple_type] = STATE(3122),
    [sym_struct_type] = STATE(3122),
    [sym_enum_type] = STATE(3122),
    [sym_bit_field_type] = STATE(3122),
    [sym_constant_type] = STATE(3122),
    [sym_specialized_type] = STATE(3122),
    [sym__procedure_type] = STATE(3122),
    [sym_distinct_type] = STATE(3122),
    [sym_empty_type] = STATE(3122),
    [sym_polymorphic_type] = STATE(3122),
    [sym_conditional_type] = STATE(3122),
    [sym_identifier] = ACTIONS(2848),
    [anon_sym_LBRACE] = ACTIONS(855),
    [anon_sym_COMMA] = ACTIONS(855),
    [anon_sym_proc] = ACTIONS(2758),
    [anon_sym_DASH_GT] = ACTIONS(855),
    [anon_sym_where] = ACTIONS(857),
    [anon_sym_struct] = ACTIONS(1736),
    [anon_sym_enum] = ACTIONS(1738),
    [anon_sym_EQ] = ACTIONS(857),
    [anon_sym_union] = ACTIONS(1740),
    [anon_sym_bit_field] = ACTIONS(1742),
    [anon_sym_PIPE] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(1882),
    [anon_sym_RPAREN] = ACTIONS(855),
    [anon_sym_DOLLAR] = ACTIONS(2760),
    [anon_sym_if] = ACTIONS(857),
    [anon_sym_when] = ACTIONS(857),
    [anon_sym_in] = ACTIONS(857),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(857),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(1750),
    [anon_sym_AMP] = ACTIONS(857),
    [anon_sym_PIPE_PIPE] = ACTIONS(855),
    [anon_sym_or_else] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(855),
    [anon_sym_LT] = ACTIONS(857),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_TILDE_EQ] = ACTIONS(855),
    [anon_sym_AMP_TILDE] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(855),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_SLASH] = ACTIONS(857),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(855),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_LBRACK] = ACTIONS(2851),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(855),
    [anon_sym_not_in] = ACTIONS(857),
    [anon_sym_DOT_DOT] = ACTIONS(2766),
    [anon_sym_or_return] = ACTIONS(857),
    [anon_sym_or_continue] = ACTIONS(857),
    [anon_sym_or_break] = ACTIONS(857),
    [anon_sym_CARET] = ACTIONS(2854),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1762),
    [anon_sym_map] = ACTIONS(2772),
    [anon_sym_bit_set] = ACTIONS(1766),
    [anon_sym_matrix] = ACTIONS(2774),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_uninitialized] = ACTIONS(855),
    [sym_tag] = ACTIONS(2857),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [287] = {
    [sym_block] = STATE(7128),
    [sym_attributes] = STATE(1513),
    [sym_attribute] = STATE(6180),
    [sym_assignment_statement] = STATE(9116),
    [sym_update_statement] = STATE(9116),
    [sym__for_in_expression] = STATE(7907),
    [sym_var_declaration] = STATE(9116),
    [sym_expression] = STATE(2820),
    [sym__expression_no_tag] = STATE(2756),
    [sym_unary_expression] = STATE(2756),
    [sym_binary_expression] = STATE(2756),
    [sym_ternary_expression] = STATE(2756),
    [sym_call_expression] = STATE(2756),
    [sym_selector_call_expression] = STATE(2756),
    [sym_member_expression] = STATE(2756),
    [sym_index_expression] = STATE(2756),
    [sym_slice_expression] = STATE(2756),
    [sym_range_expression] = STATE(2756),
    [sym_cast_expression] = STATE(2756),
    [sym_in_expression] = STATE(2756),
    [sym_variadic_expression] = STATE(2756),
    [sym_parenthesized_expression] = STATE(2756),
    [sym_or_return_expression] = STATE(2756),
    [sym_or_continue_expression] = STATE(2756),
    [sym_or_break_expression] = STATE(2756),
    [sym_address] = STATE(2756),
    [sym_map_type] = STATE(2756),
    [sym_matrix_type] = STATE(2756),
    [sym_distinct_type] = STATE(2756),
    [sym_literal] = STATE(2756),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(2860),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_SEMI] = ACTIONS(2862),
    [anon_sym_do] = ACTIONS(2864),
    [anon_sym_in] = ACTIONS(2866),
    [anon_sym_QMARK] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [288] = {
    [sym_block] = STATE(7128),
    [sym_attributes] = STATE(1513),
    [sym_attribute] = STATE(6180),
    [sym_assignment_statement] = STATE(9469),
    [sym_update_statement] = STATE(9469),
    [sym__for_in_expression] = STATE(8448),
    [sym_var_declaration] = STATE(9469),
    [sym_expression] = STATE(2919),
    [sym__expression_no_tag] = STATE(2756),
    [sym_unary_expression] = STATE(2756),
    [sym_binary_expression] = STATE(2756),
    [sym_ternary_expression] = STATE(2756),
    [sym_call_expression] = STATE(2756),
    [sym_selector_call_expression] = STATE(2756),
    [sym_member_expression] = STATE(2756),
    [sym_index_expression] = STATE(2756),
    [sym_slice_expression] = STATE(2756),
    [sym_range_expression] = STATE(2756),
    [sym_cast_expression] = STATE(2756),
    [sym_in_expression] = STATE(2756),
    [sym_variadic_expression] = STATE(2756),
    [sym_parenthesized_expression] = STATE(2756),
    [sym_or_return_expression] = STATE(2756),
    [sym_or_continue_expression] = STATE(2756),
    [sym_or_break_expression] = STATE(2756),
    [sym_address] = STATE(2756),
    [sym_map_type] = STATE(2756),
    [sym_matrix_type] = STATE(2756),
    [sym_distinct_type] = STATE(2756),
    [sym_literal] = STATE(2756),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(2860),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_SEMI] = ACTIONS(2874),
    [anon_sym_do] = ACTIONS(2876),
    [anon_sym_in] = ACTIONS(2866),
    [anon_sym_QMARK] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [289] = {
    [sym_procedure] = STATE(7208),
    [sym_expression] = STATE(4958),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_pointer_type] = STATE(7007),
    [sym_array_type] = STATE(7007),
    [sym_map_type] = STATE(4697),
    [sym_bit_set_type] = STATE(7007),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(2878),
    [anon_sym_struct] = ACTIONS(2880),
    [anon_sym_enum] = ACTIONS(2882),
    [anon_sym_union] = ACTIONS(2884),
    [anon_sym_bit_field] = ACTIONS(2886),
    [anon_sym_POUNDtype] = ACTIONS(621),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(2888),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_CARET] = ACTIONS(2892),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(617),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(2894),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [290] = {
    [sym_procedure] = STATE(7168),
    [sym_expression] = STATE(4962),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_pointer_type] = STATE(7024),
    [sym_array_type] = STATE(7024),
    [sym_map_type] = STATE(4697),
    [sym_bit_set_type] = STATE(7024),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(2896),
    [anon_sym_struct] = ACTIONS(2898),
    [anon_sym_enum] = ACTIONS(2900),
    [anon_sym_union] = ACTIONS(2902),
    [anon_sym_bit_field] = ACTIONS(2904),
    [anon_sym_POUNDtype] = ACTIONS(2906),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(2888),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_CARET] = ACTIONS(2892),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(617),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(2908),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [291] = {
    [sym_block] = STATE(7112),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(7858),
    [sym__simple_assignment_statement] = STATE(7858),
    [sym_expression] = STATE(2956),
    [sym__expression_no_tag] = STATE(2756),
    [sym_unary_expression] = STATE(2756),
    [sym_binary_expression] = STATE(2756),
    [sym_ternary_expression] = STATE(2756),
    [sym_call_expression] = STATE(2756),
    [sym_selector_call_expression] = STATE(2756),
    [sym_member_expression] = STATE(2756),
    [sym_index_expression] = STATE(2756),
    [sym_slice_expression] = STATE(2756),
    [sym_range_expression] = STATE(2756),
    [sym_cast_expression] = STATE(2756),
    [sym_in_expression] = STATE(2756),
    [sym_variadic_expression] = STATE(2756),
    [sym_parenthesized_expression] = STATE(2756),
    [sym_or_return_expression] = STATE(2756),
    [sym_or_continue_expression] = STATE(2756),
    [sym_or_break_expression] = STATE(2756),
    [sym_address] = STATE(2756),
    [sym_map_type] = STATE(2756),
    [sym_matrix_type] = STATE(2756),
    [sym_distinct_type] = STATE(2756),
    [sym_literal] = STATE(2756),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(2860),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_SEMI] = ACTIONS(2910),
    [anon_sym_do] = ACTIONS(2912),
    [anon_sym_QMARK] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [292] = {
    [sym_procedure] = STATE(4572),
    [sym_expression] = STATE(4965),
    [sym__expression_no_tag] = STATE(4543),
    [sym_unary_expression] = STATE(4543),
    [sym_binary_expression] = STATE(4543),
    [sym_ternary_expression] = STATE(4543),
    [sym_call_expression] = STATE(4543),
    [sym_selector_call_expression] = STATE(4543),
    [sym_member_expression] = STATE(4543),
    [sym_index_expression] = STATE(4543),
    [sym_slice_expression] = STATE(4543),
    [sym_range_expression] = STATE(4543),
    [sym_cast_expression] = STATE(4543),
    [sym_in_expression] = STATE(4543),
    [sym_variadic_expression] = STATE(4543),
    [sym_parenthesized_expression] = STATE(4543),
    [sym_or_return_expression] = STATE(4543),
    [sym_or_continue_expression] = STATE(4543),
    [sym_or_break_expression] = STATE(4543),
    [sym_address] = STATE(4543),
    [sym_map_type] = STATE(4543),
    [sym_matrix_type] = STATE(4543),
    [sym__procedure_type] = STATE(6994),
    [sym_distinct_type] = STATE(4543),
    [sym_literal] = STATE(4543),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [ts_builtin_sym_end] = ACTIONS(2914),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(2914),
    [anon_sym_proc] = ACTIONS(723),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_SEMI] = ACTIONS(2914),
    [anon_sym_else] = ACTIONS(2916),
    [anon_sym_case] = ACTIONS(2916),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(2914),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [293] = {
    [sym_procedure] = STATE(4572),
    [sym_expression] = STATE(4965),
    [sym__expression_no_tag] = STATE(4543),
    [sym_unary_expression] = STATE(4543),
    [sym_binary_expression] = STATE(4543),
    [sym_ternary_expression] = STATE(4543),
    [sym_call_expression] = STATE(4543),
    [sym_selector_call_expression] = STATE(4543),
    [sym_member_expression] = STATE(4543),
    [sym_index_expression] = STATE(4543),
    [sym_slice_expression] = STATE(4543),
    [sym_range_expression] = STATE(4543),
    [sym_cast_expression] = STATE(4543),
    [sym_in_expression] = STATE(4543),
    [sym_variadic_expression] = STATE(4543),
    [sym_parenthesized_expression] = STATE(4543),
    [sym_or_return_expression] = STATE(4543),
    [sym_or_continue_expression] = STATE(4543),
    [sym_or_break_expression] = STATE(4543),
    [sym_address] = STATE(4543),
    [sym_map_type] = STATE(4543),
    [sym_matrix_type] = STATE(4543),
    [sym__procedure_type] = STATE(6994),
    [sym_distinct_type] = STATE(4543),
    [sym_literal] = STATE(4543),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [ts_builtin_sym_end] = ACTIONS(2920),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(2920),
    [anon_sym_proc] = ACTIONS(723),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_SEMI] = ACTIONS(2920),
    [anon_sym_else] = ACTIONS(2922),
    [anon_sym_case] = ACTIONS(2922),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(2920),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [294] = {
    [sym_procedure] = STATE(7638),
    [sym_expression] = STATE(5961),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7693),
    [sym_array_type] = STATE(7693),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7688),
    [sym__procedure_type] = STATE(8952),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2924),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [295] = {
    [sym_procedure] = STATE(7651),
    [sym_expression] = STATE(5943),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7585),
    [sym_array_type] = STATE(7585),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7665),
    [sym__procedure_type] = STATE(8952),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2936),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [296] = {
    [sym_procedure] = STATE(7560),
    [sym_expression] = STATE(5946),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7735),
    [sym_array_type] = STATE(7735),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7650),
    [sym__procedure_type] = STATE(9269),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2938),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [297] = {
    [sym_procedure] = STATE(4572),
    [sym_expression] = STATE(4965),
    [sym__expression_no_tag] = STATE(4543),
    [sym_unary_expression] = STATE(4543),
    [sym_binary_expression] = STATE(4543),
    [sym_ternary_expression] = STATE(4543),
    [sym_call_expression] = STATE(4543),
    [sym_selector_call_expression] = STATE(4543),
    [sym_member_expression] = STATE(4543),
    [sym_index_expression] = STATE(4543),
    [sym_slice_expression] = STATE(4543),
    [sym_range_expression] = STATE(4543),
    [sym_cast_expression] = STATE(4543),
    [sym_in_expression] = STATE(4543),
    [sym_variadic_expression] = STATE(4543),
    [sym_parenthesized_expression] = STATE(4543),
    [sym_or_return_expression] = STATE(4543),
    [sym_or_continue_expression] = STATE(4543),
    [sym_or_break_expression] = STATE(4543),
    [sym_address] = STATE(4543),
    [sym_map_type] = STATE(4543),
    [sym_matrix_type] = STATE(4543),
    [sym__procedure_type] = STATE(6994),
    [sym_distinct_type] = STATE(4543),
    [sym_literal] = STATE(4543),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [ts_builtin_sym_end] = ACTIONS(2940),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(2940),
    [anon_sym_proc] = ACTIONS(723),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_SEMI] = ACTIONS(2940),
    [anon_sym_else] = ACTIONS(2942),
    [anon_sym_case] = ACTIONS(2942),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(2940),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [298] = {
    [sym_procedure] = STATE(7733),
    [sym_expression] = STATE(5939),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7646),
    [sym_array_type] = STATE(7646),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7603),
    [sym__procedure_type] = STATE(9344),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2944),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [299] = {
    [sym_procedure] = STATE(4572),
    [sym_expression] = STATE(4899),
    [sym__expression_no_tag] = STATE(4543),
    [sym_unary_expression] = STATE(4543),
    [sym_binary_expression] = STATE(4543),
    [sym_ternary_expression] = STATE(4543),
    [sym_call_expression] = STATE(4543),
    [sym_selector_call_expression] = STATE(4543),
    [sym_member_expression] = STATE(4543),
    [sym_index_expression] = STATE(4543),
    [sym_slice_expression] = STATE(4543),
    [sym_range_expression] = STATE(4543),
    [sym_cast_expression] = STATE(4543),
    [sym_in_expression] = STATE(4543),
    [sym_variadic_expression] = STATE(4543),
    [sym_parenthesized_expression] = STATE(4543),
    [sym_or_return_expression] = STATE(4543),
    [sym_or_continue_expression] = STATE(4543),
    [sym_or_break_expression] = STATE(4543),
    [sym_address] = STATE(4543),
    [sym_map_type] = STATE(4543),
    [sym_matrix_type] = STATE(4543),
    [sym__procedure_type] = STATE(6958),
    [sym_distinct_type] = STATE(4543),
    [sym_literal] = STATE(4543),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [ts_builtin_sym_end] = ACTIONS(2946),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(2946),
    [anon_sym_proc] = ACTIONS(723),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_SEMI] = ACTIONS(2946),
    [anon_sym_else] = ACTIONS(2948),
    [anon_sym_case] = ACTIONS(2948),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(2950),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(2946),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [300] = {
    [sym_block] = STATE(7112),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(8453),
    [sym__simple_assignment_statement] = STATE(8453),
    [sym_expression] = STATE(2967),
    [sym__expression_no_tag] = STATE(2756),
    [sym_unary_expression] = STATE(2756),
    [sym_binary_expression] = STATE(2756),
    [sym_ternary_expression] = STATE(2756),
    [sym_call_expression] = STATE(2756),
    [sym_selector_call_expression] = STATE(2756),
    [sym_member_expression] = STATE(2756),
    [sym_index_expression] = STATE(2756),
    [sym_slice_expression] = STATE(2756),
    [sym_range_expression] = STATE(2756),
    [sym_cast_expression] = STATE(2756),
    [sym_in_expression] = STATE(2756),
    [sym_variadic_expression] = STATE(2756),
    [sym_parenthesized_expression] = STATE(2756),
    [sym_or_return_expression] = STATE(2756),
    [sym_or_continue_expression] = STATE(2756),
    [sym_or_break_expression] = STATE(2756),
    [sym_address] = STATE(2756),
    [sym_map_type] = STATE(2756),
    [sym_matrix_type] = STATE(2756),
    [sym_distinct_type] = STATE(2756),
    [sym_literal] = STATE(2756),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(2860),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_SEMI] = ACTIONS(2952),
    [anon_sym_do] = ACTIONS(2954),
    [anon_sym_QMARK] = ACTIONS(2868),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [301] = {
    [sym_procedure] = STATE(7634),
    [sym_expression] = STATE(5913),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7533),
    [sym_array_type] = STATE(7533),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7728),
    [sym__procedure_type] = STATE(9174),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2956),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [302] = {
    [sym_procedure] = STATE(7661),
    [sym_expression] = STATE(5964),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7700),
    [sym_array_type] = STATE(7700),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7736),
    [sym__procedure_type] = STATE(9603),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2958),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [303] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2960),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [304] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2962),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [305] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2964),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [306] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2966),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [307] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2968),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [308] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2970),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [309] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2972),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [310] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2974),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [311] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2976),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [312] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2978),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [313] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2980),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [314] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2982),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [315] = {
    [sym_procedure] = STATE(7688),
    [sym_expression] = STATE(5923),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7688),
    [sym_array_type] = STATE(7688),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7688),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2924),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [316] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2984),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [317] = {
    [sym_procedure] = STATE(7551),
    [sym_expression] = STATE(5941),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7551),
    [sym_array_type] = STATE(7551),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7551),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2986),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [318] = {
    [sym_procedure] = STATE(7707),
    [sym_expression] = STATE(5945),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7707),
    [sym_array_type] = STATE(7707),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7707),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(2988),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2990),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [319] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2992),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [320] = {
    [sym_procedure] = STATE(7604),
    [sym_expression] = STATE(5937),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7604),
    [sym_array_type] = STATE(7604),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7604),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(2994),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2996),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [321] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2998),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [322] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3000),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [323] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3002),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [324] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3004),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [325] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3006),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [326] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3008),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [327] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3010),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [328] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3012),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [329] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3014),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [330] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3016),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [331] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3018),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [332] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3020),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [333] = {
    [sym_procedure] = STATE(7736),
    [sym_expression] = STATE(5935),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7736),
    [sym_array_type] = STATE(7736),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7736),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2958),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [334] = {
    [sym_procedure] = STATE(7604),
    [sym_expression] = STATE(5937),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7604),
    [sym_array_type] = STATE(7604),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7604),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3022),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [335] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3024),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [336] = {
    [sym_procedure] = STATE(7709),
    [sym_expression] = STATE(5960),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7709),
    [sym_array_type] = STATE(7709),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7709),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(3026),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3028),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [337] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3030),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [338] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3032),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [339] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3034),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [340] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3036),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [341] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3038),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [342] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3040),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [343] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3042),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [344] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3044),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [345] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3046),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [346] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3048),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [347] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3050),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [348] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3052),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [349] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3054),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [350] = {
    [sym_procedure] = STATE(7665),
    [sym_expression] = STATE(5956),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7665),
    [sym_array_type] = STATE(7665),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7665),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2936),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [351] = {
    [sym_procedure] = STATE(7707),
    [sym_expression] = STATE(5945),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7707),
    [sym_array_type] = STATE(7707),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7707),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3056),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [352] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3058),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [353] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3060),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [354] = {
    [sym_procedure] = STATE(7730),
    [sym_expression] = STATE(5959),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7730),
    [sym_array_type] = STATE(7730),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7730),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(3062),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3064),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [355] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3066),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [356] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3068),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [357] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3070),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [358] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3072),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [359] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3074),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [360] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3076),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [361] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3078),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [362] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3080),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [363] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3082),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [364] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3084),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [365] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3086),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [366] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3088),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [367] = {
    [sym_procedure] = STATE(7650),
    [sym_expression] = STATE(5953),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7650),
    [sym_array_type] = STATE(7650),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7650),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2938),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [368] = {
    [sym_procedure] = STATE(7709),
    [sym_expression] = STATE(5960),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7709),
    [sym_array_type] = STATE(7709),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7709),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3090),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [369] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3092),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [370] = {
    [sym_procedure] = STATE(7551),
    [sym_expression] = STATE(5941),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7551),
    [sym_array_type] = STATE(7551),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7551),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(2994),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3094),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [371] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3096),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [372] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3098),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [373] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3100),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [374] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3102),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [375] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3104),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [376] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3106),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [377] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3108),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [378] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3110),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [379] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3112),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [380] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3114),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [381] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3116),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [382] = {
    [sym_procedure] = STATE(7640),
    [sym_expression] = STATE(5947),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7640),
    [sym_array_type] = STATE(7640),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7640),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3118),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [383] = {
    [sym_procedure] = STATE(7589),
    [sym_expression] = STATE(5926),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7589),
    [sym_array_type] = STATE(7589),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7589),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3120),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [384] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3122),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [385] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3124),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [386] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3126),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [387] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3128),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [388] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3130),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [389] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3132),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [390] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3134),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [391] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3136),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [392] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3138),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [393] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3140),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [394] = {
    [sym_procedure] = STATE(7708),
    [sym_expression] = STATE(5934),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7708),
    [sym_array_type] = STATE(7708),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7708),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3142),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [395] = {
    [sym_procedure] = STATE(7734),
    [sym_expression] = STATE(5965),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7734),
    [sym_array_type] = STATE(7734),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7734),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3144),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [396] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3146),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [397] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3148),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [398] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3150),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [399] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3152),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [400] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3154),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [401] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3156),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [402] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3158),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [403] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3160),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [404] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3162),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [405] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3164),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [406] = {
    [sym_procedure] = STATE(7674),
    [sym_expression] = STATE(5906),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7674),
    [sym_array_type] = STATE(7674),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7674),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2956),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [407] = {
    [sym_procedure] = STATE(7576),
    [sym_expression] = STATE(5949),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7576),
    [sym_array_type] = STATE(7576),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7576),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3166),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [408] = {
    [sym_procedure] = STATE(7659),
    [sym_expression] = STATE(5938),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7659),
    [sym_array_type] = STATE(7659),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7659),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3168),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [409] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3170),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [410] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3172),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [411] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3174),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [412] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3176),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [413] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3178),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [414] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3180),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [415] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3182),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [416] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3184),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [417] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3186),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [418] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3188),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [419] = {
    [sym_procedure] = STATE(7652),
    [sym_expression] = STATE(5929),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7652),
    [sym_array_type] = STATE(7652),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7652),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3190),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [420] = {
    [sym_procedure] = STATE(7586),
    [sym_expression] = STATE(5915),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7586),
    [sym_array_type] = STATE(7586),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7586),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3192),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [421] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3194),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [422] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3196),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [423] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3198),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [424] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3200),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [425] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3202),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [426] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3204),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [427] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3206),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [428] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3208),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [429] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3210),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [430] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3212),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [431] = {
    [sym_procedure] = STATE(7636),
    [sym_expression] = STATE(5950),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7636),
    [sym_array_type] = STATE(7636),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7636),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3214),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [432] = {
    [sym_procedure] = STATE(7655),
    [sym_expression] = STATE(5931),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7655),
    [sym_array_type] = STATE(7655),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7655),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3216),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [433] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3218),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [434] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3220),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [435] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3222),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [436] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3224),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [437] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3226),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [438] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3228),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [439] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3230),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [440] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3232),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [441] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3234),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [442] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3236),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [443] = {
    [sym_procedure] = STATE(7731),
    [sym_expression] = STATE(5917),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7731),
    [sym_array_type] = STATE(7731),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7731),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3238),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [444] = {
    [sym_procedure] = STATE(7727),
    [sym_expression] = STATE(5919),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7727),
    [sym_array_type] = STATE(7727),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7727),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3240),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [445] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3242),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [446] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3244),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [447] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3246),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [448] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3248),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [449] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3250),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [450] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3252),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [451] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3254),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [452] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3256),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [453] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3258),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [454] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3260),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [455] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3262),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [456] = {
    [sym_procedure] = STATE(7679),
    [sym_expression] = STATE(5966),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7679),
    [sym_array_type] = STATE(7679),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7679),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3264),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [457] = {
    [sym_procedure] = STATE(7698),
    [sym_expression] = STATE(5954),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7698),
    [sym_array_type] = STATE(7698),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7698),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3266),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [458] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3268),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [459] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3270),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [460] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [461] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3274),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [462] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3276),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [463] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3278),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [464] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3280),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [465] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3282),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [466] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3284),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [467] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3286),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [468] = {
    [sym_procedure] = STATE(7728),
    [sym_expression] = STATE(5932),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7728),
    [sym_array_type] = STATE(7728),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7728),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2956),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [469] = {
    [sym_procedure] = STATE(7603),
    [sym_expression] = STATE(5908),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7603),
    [sym_array_type] = STATE(7603),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7603),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2944),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [470] = {
    [sym_procedure] = STATE(7570),
    [sym_expression] = STATE(5940),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7570),
    [sym_array_type] = STATE(7570),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7570),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2958),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [471] = {
    [sym_procedure] = STATE(7542),
    [sym_expression] = STATE(5936),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7542),
    [sym_array_type] = STATE(7542),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7542),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2936),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [472] = {
    [sym_procedure] = STATE(7610),
    [sym_expression] = STATE(5958),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7610),
    [sym_array_type] = STATE(7610),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7610),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3288),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [473] = {
    [sym_block] = STATE(7140),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(7936),
    [sym__simple_assignment_statement] = STATE(7936),
    [sym_expression] = STATE(3575),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(3290),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_do] = ACTIONS(3292),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [474] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3300),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [475] = {
    [sym_block] = STATE(7142),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(7944),
    [sym__simple_assignment_statement] = STATE(7944),
    [sym_expression] = STATE(3575),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(3290),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_do] = ACTIONS(3302),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [476] = {
    [sym_block] = STATE(7145),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(7973),
    [sym__simple_assignment_statement] = STATE(7973),
    [sym_expression] = STATE(3575),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(3290),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_do] = ACTIONS(3304),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [477] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3306),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [478] = {
    [sym_block] = STATE(7173),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(7990),
    [sym__simple_assignment_statement] = STATE(7990),
    [sym_expression] = STATE(3575),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(3290),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_do] = ACTIONS(3308),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [479] = {
    [sym_procedure] = STATE(7620),
    [sym_expression] = STATE(5909),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7620),
    [sym_array_type] = STATE(7620),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7620),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(2944),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [480] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3310),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [481] = {
    [sym_procedure] = STATE(7730),
    [sym_expression] = STATE(5959),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7730),
    [sym_array_type] = STATE(7730),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7730),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3312),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [482] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3314),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [483] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3316),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [484] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3318),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [485] = {
    [sym_block] = STATE(7145),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(8459),
    [sym__simple_assignment_statement] = STATE(8459),
    [sym_expression] = STATE(3575),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(3290),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_do] = ACTIONS(3320),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [486] = {
    [sym_block] = STATE(7173),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(8462),
    [sym__simple_assignment_statement] = STATE(8462),
    [sym_expression] = STATE(3575),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(3290),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_do] = ACTIONS(3322),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [487] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3324),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [488] = {
    [sym_block] = STATE(7140),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(8465),
    [sym__simple_assignment_statement] = STATE(8465),
    [sym_expression] = STATE(3575),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(3290),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_do] = ACTIONS(3326),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [489] = {
    [sym_block] = STATE(7142),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(8466),
    [sym__simple_assignment_statement] = STATE(8466),
    [sym_expression] = STATE(3575),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(3290),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_do] = ACTIONS(3328),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [490] = {
    [sym_block] = STATE(7289),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(8470),
    [sym__simple_assignment_statement] = STATE(8470),
    [sym_expression] = STATE(3575),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(3290),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_do] = ACTIONS(3330),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [491] = {
    [sym_procedure] = STATE(7610),
    [sym_expression] = STATE(5958),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7610),
    [sym_array_type] = STATE(7610),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(7610),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(3332),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3334),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [492] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3336),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [493] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_RPAREN] = ACTIONS(3338),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [494] = {
    [sym_attributes] = STATE(1513),
    [sym_attribute] = STATE(6180),
    [sym_assignment_statement] = STATE(9536),
    [sym_update_statement] = STATE(9536),
    [sym_var_declaration] = STATE(9536),
    [sym_expression] = STATE(3005),
    [sym__expression_no_tag] = STATE(2788),
    [sym_unary_expression] = STATE(2788),
    [sym_binary_expression] = STATE(2788),
    [sym_ternary_expression] = STATE(2788),
    [sym_call_expression] = STATE(2788),
    [sym_selector_call_expression] = STATE(2788),
    [sym_member_expression] = STATE(2788),
    [sym_index_expression] = STATE(2788),
    [sym_slice_expression] = STATE(2788),
    [sym_range_expression] = STATE(2788),
    [sym_cast_expression] = STATE(2788),
    [sym_in_expression] = STATE(2788),
    [sym_variadic_expression] = STATE(2788),
    [sym_parenthesized_expression] = STATE(2788),
    [sym_or_return_expression] = STATE(2788),
    [sym_or_continue_expression] = STATE(2788),
    [sym_or_break_expression] = STATE(2788),
    [sym_address] = STATE(2788),
    [sym_map_type] = STATE(2788),
    [sym_matrix_type] = STATE(2788),
    [sym_distinct_type] = STATE(2788),
    [sym_literal] = STATE(2788),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_SEMI] = ACTIONS(3340),
    [anon_sym_QMARK] = ACTIONS(3342),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(3348),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [495] = {
    [sym_attributes] = STATE(1513),
    [sym_attribute] = STATE(6180),
    [sym_assignment_statement] = STATE(9224),
    [sym_update_statement] = STATE(9224),
    [sym_var_declaration] = STATE(9224),
    [sym_expression] = STATE(2965),
    [sym__expression_no_tag] = STATE(2788),
    [sym_unary_expression] = STATE(2788),
    [sym_binary_expression] = STATE(2788),
    [sym_ternary_expression] = STATE(2788),
    [sym_call_expression] = STATE(2788),
    [sym_selector_call_expression] = STATE(2788),
    [sym_member_expression] = STATE(2788),
    [sym_index_expression] = STATE(2788),
    [sym_slice_expression] = STATE(2788),
    [sym_range_expression] = STATE(2788),
    [sym_cast_expression] = STATE(2788),
    [sym_in_expression] = STATE(2788),
    [sym_variadic_expression] = STATE(2788),
    [sym_parenthesized_expression] = STATE(2788),
    [sym_or_return_expression] = STATE(2788),
    [sym_or_continue_expression] = STATE(2788),
    [sym_or_break_expression] = STATE(2788),
    [sym_address] = STATE(2788),
    [sym_map_type] = STATE(2788),
    [sym_matrix_type] = STATE(2788),
    [sym_distinct_type] = STATE(2788),
    [sym_literal] = STATE(2788),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_SEMI] = ACTIONS(3350),
    [anon_sym_QMARK] = ACTIONS(3342),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(3352),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [496] = {
    [sym_block] = STATE(7289),
    [sym_attributes] = STATE(1914),
    [sym_attribute] = STATE(6180),
    [sym_update_statement] = STATE(8316),
    [sym__simple_assignment_statement] = STATE(8316),
    [sym_expression] = STATE(3575),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(3290),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_do] = ACTIONS(3354),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [497] = {
    [sym_procedure] = STATE(8611),
    [sym_expression] = STATE(6105),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8611),
    [sym_array_type] = STATE(8611),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_struct_type] = STATE(8611),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_struct] = ACTIONS(2286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [498] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6444),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9174),
    [sym_array_type] = STATE(9174),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9174),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [499] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6220),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9572),
    [sym_array_type] = STATE(9572),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9572),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [500] = {
    [sym_attributes] = STATE(1559),
    [sym_attribute] = STATE(6180),
    [sym_assignment_statement] = STATE(7950),
    [sym_expression] = STATE(5787),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(3356),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_in] = ACTIONS(3358),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [501] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6500),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8952),
    [sym_array_type] = STATE(8952),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(8952),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [502] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6549),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9603),
    [sym_array_type] = STATE(9603),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9603),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [503] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6395),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9070),
    [sym_array_type] = STATE(9070),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9070),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [504] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6544),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9269),
    [sym_array_type] = STATE(9269),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9269),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [505] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6499),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9155),
    [sym_array_type] = STATE(9155),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9155),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [506] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6308),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9095),
    [sym_array_type] = STATE(9095),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9095),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [507] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6314),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9203),
    [sym_array_type] = STATE(9203),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9203),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [508] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6459),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9178),
    [sym_array_type] = STATE(9178),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9178),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [509] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6222),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9277),
    [sym_array_type] = STATE(9277),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9277),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [510] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6308),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9376),
    [sym_array_type] = STATE(9376),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9376),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [511] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6548),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9314),
    [sym_array_type] = STATE(9314),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9314),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [512] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6533),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9393),
    [sym_array_type] = STATE(9393),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9393),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [513] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6444),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9206),
    [sym_array_type] = STATE(9206),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9206),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [514] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6220),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9344),
    [sym_array_type] = STATE(9344),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9344),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [515] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6395),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8939),
    [sym_array_type] = STATE(8939),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(8939),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [516] = {
    [sym_attributes] = STATE(1724),
    [sym_attribute] = STATE(6180),
    [sym_assignment_statement] = STATE(9187),
    [sym_expression] = STATE(4991),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_SEMI] = ACTIONS(3362),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [517] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6549),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(9290),
    [sym_array_type] = STATE(9290),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(9290),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [518] = {
    [sym_expression] = STATE(4958),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_pointer_type] = STATE(7007),
    [sym_array_type] = STATE(7007),
    [sym_map_type] = STATE(4697),
    [sym_bit_set_type] = STATE(7007),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_POUNDtype] = ACTIONS(621),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(2888),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_CARET] = ACTIONS(2892),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(617),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(3364),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [519] = {
    [sym_procedure] = STATE(7067),
    [sym_expression] = STATE(4983),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(3366),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_SEMI] = ACTIONS(3366),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3366),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [520] = {
    [sym_block] = STATE(1568),
    [sym_where_clause] = STATE(720),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3380),
    [sym_tag] = ACTIONS(3382),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [521] = {
    [sym_block] = STATE(1568),
    [sym_where_clause] = STATE(720),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3380),
    [sym_tag] = ACTIONS(3382),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [522] = {
    [sym_block] = STATE(2356),
    [sym_where_clause] = STATE(810),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3390),
    [sym_tag] = ACTIONS(3392),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [523] = {
    [sym_block] = STATE(2342),
    [sym_where_clause] = STATE(807),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3394),
    [sym_tag] = ACTIONS(3396),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [524] = {
    [sym_block] = STATE(2356),
    [sym_where_clause] = STATE(810),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3390),
    [sym_tag] = ACTIONS(3392),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [525] = {
    [sym_block] = STATE(2356),
    [sym_where_clause] = STATE(810),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3390),
    [sym_tag] = ACTIONS(3398),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [526] = {
    [sym_block] = STATE(2357),
    [sym_where_clause] = STATE(811),
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(3404),
    [sym_tag] = ACTIONS(3406),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [527] = {
    [aux_sym_field_type_repeat1] = STATE(527),
    [ts_builtin_sym_end] = ACTIONS(3408),
    [anon_sym_LBRACE] = ACTIONS(3408),
    [anon_sym_RBRACE] = ACTIONS(3408),
    [anon_sym_COMMA] = ACTIONS(3408),
    [anon_sym_COLON_COLON] = ACTIONS(3408),
    [anon_sym_DASH_GT] = ACTIONS(3408),
    [anon_sym_where] = ACTIONS(3408),
    [anon_sym_EQ] = ACTIONS(3410),
    [anon_sym_COLON] = ACTIONS(3410),
    [anon_sym_PIPE] = ACTIONS(3410),
    [anon_sym_COLON_EQ] = ACTIONS(3408),
    [anon_sym_LPAREN] = ACTIONS(3408),
    [anon_sym_PLUS_EQ] = ACTIONS(3408),
    [anon_sym_DASH_EQ] = ACTIONS(3408),
    [anon_sym_STAR_EQ] = ACTIONS(3408),
    [anon_sym_SLASH_EQ] = ACTIONS(3408),
    [anon_sym_PERCENT_EQ] = ACTIONS(3408),
    [anon_sym_AMP_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_CARET_EQ] = ACTIONS(3408),
    [anon_sym_LT_LT_EQ] = ACTIONS(3408),
    [anon_sym_GT_GT_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_if] = ACTIONS(3408),
    [anon_sym_SEMI] = ACTIONS(3408),
    [anon_sym_else] = ACTIONS(3408),
    [anon_sym_when] = ACTIONS(3408),
    [anon_sym_in] = ACTIONS(3408),
    [anon_sym_case] = ACTIONS(3408),
    [anon_sym_QMARK] = ACTIONS(3408),
    [anon_sym_PLUS] = ACTIONS(3410),
    [anon_sym_DASH] = ACTIONS(3410),
    [anon_sym_TILDE] = ACTIONS(3410),
    [anon_sym_AMP] = ACTIONS(3410),
    [anon_sym_PIPE_PIPE] = ACTIONS(3410),
    [anon_sym_or_else] = ACTIONS(3408),
    [anon_sym_AMP_AMP] = ACTIONS(3410),
    [anon_sym_GT] = ACTIONS(3410),
    [anon_sym_GT_EQ] = ACTIONS(3408),
    [anon_sym_LT_EQ] = ACTIONS(3408),
    [anon_sym_LT] = ACTIONS(3410),
    [anon_sym_EQ_EQ] = ACTIONS(3408),
    [anon_sym_BANG_EQ] = ACTIONS(3408),
    [anon_sym_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE] = ACTIONS(3410),
    [anon_sym_LT_LT] = ACTIONS(3410),
    [anon_sym_GT_GT] = ACTIONS(3410),
    [anon_sym_STAR] = ACTIONS(3410),
    [anon_sym_SLASH] = ACTIONS(3410),
    [anon_sym_PERCENT] = ACTIONS(3410),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3408),
    [anon_sym_DOT] = ACTIONS(3410),
    [anon_sym_LBRACK] = ACTIONS(3408),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3408),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3408),
    [anon_sym_not_in] = ACTIONS(3408),
    [anon_sym_or_return] = ACTIONS(3408),
    [anon_sym_or_continue] = ACTIONS(3408),
    [anon_sym_or_break] = ACTIONS(3408),
    [anon_sym_CARET] = ACTIONS(3410),
    [anon_sym_DOT2] = ACTIONS(3412),
    [sym_uninitialized] = ACTIONS(3408),
    [sym_tag] = ACTIONS(3408),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3408),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [528] = {
    [sym_procedure] = STATE(7067),
    [sym_expression] = STATE(4983),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(3415),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_SEMI] = ACTIONS(3415),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3415),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [529] = {
    [sym_expression] = STATE(4955),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_pointer_type] = STATE(7014),
    [sym_array_type] = STATE(7014),
    [sym_map_type] = STATE(4697),
    [sym_bit_set_type] = STATE(7014),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_POUNDtype] = ACTIONS(601),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(2888),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_CARET] = ACTIONS(2892),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(617),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(3417),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [530] = {
    [sym_expression] = STATE(5150),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_pointer_type] = STATE(7075),
    [sym_array_type] = STATE(7075),
    [sym_map_type] = STATE(4697),
    [sym_bit_set_type] = STATE(7075),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_POUNDtype] = ACTIONS(3419),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(2888),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_CARET] = ACTIONS(2892),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(617),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(619),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [531] = {
    [sym_block] = STATE(1587),
    [sym_where_clause] = STATE(774),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3421),
    [sym_tag] = ACTIONS(3423),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [532] = {
    [sym_block] = STATE(1558),
    [sym_where_clause] = STATE(716),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3429),
    [sym_tag] = ACTIONS(3431),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [533] = {
    [aux_sym_field_type_repeat1] = STATE(527),
    [ts_builtin_sym_end] = ACTIONS(3433),
    [anon_sym_LBRACE] = ACTIONS(3433),
    [anon_sym_RBRACE] = ACTIONS(3433),
    [anon_sym_COMMA] = ACTIONS(3433),
    [anon_sym_COLON_COLON] = ACTIONS(3433),
    [anon_sym_DASH_GT] = ACTIONS(3433),
    [anon_sym_where] = ACTIONS(3433),
    [anon_sym_EQ] = ACTIONS(3435),
    [anon_sym_COLON] = ACTIONS(3435),
    [anon_sym_PIPE] = ACTIONS(3435),
    [anon_sym_COLON_EQ] = ACTIONS(3433),
    [anon_sym_LPAREN] = ACTIONS(3433),
    [anon_sym_PLUS_EQ] = ACTIONS(3433),
    [anon_sym_DASH_EQ] = ACTIONS(3433),
    [anon_sym_STAR_EQ] = ACTIONS(3433),
    [anon_sym_SLASH_EQ] = ACTIONS(3433),
    [anon_sym_PERCENT_EQ] = ACTIONS(3433),
    [anon_sym_AMP_EQ] = ACTIONS(3433),
    [anon_sym_PIPE_EQ] = ACTIONS(3433),
    [anon_sym_CARET_EQ] = ACTIONS(3433),
    [anon_sym_LT_LT_EQ] = ACTIONS(3433),
    [anon_sym_GT_GT_EQ] = ACTIONS(3433),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3433),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3433),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3433),
    [anon_sym_if] = ACTIONS(3433),
    [anon_sym_SEMI] = ACTIONS(3433),
    [anon_sym_else] = ACTIONS(3433),
    [anon_sym_when] = ACTIONS(3433),
    [anon_sym_in] = ACTIONS(3433),
    [anon_sym_case] = ACTIONS(3433),
    [anon_sym_QMARK] = ACTIONS(3433),
    [anon_sym_PLUS] = ACTIONS(3435),
    [anon_sym_DASH] = ACTIONS(3435),
    [anon_sym_TILDE] = ACTIONS(3435),
    [anon_sym_AMP] = ACTIONS(3435),
    [anon_sym_PIPE_PIPE] = ACTIONS(3435),
    [anon_sym_or_else] = ACTIONS(3433),
    [anon_sym_AMP_AMP] = ACTIONS(3435),
    [anon_sym_GT] = ACTIONS(3435),
    [anon_sym_GT_EQ] = ACTIONS(3433),
    [anon_sym_LT_EQ] = ACTIONS(3433),
    [anon_sym_LT] = ACTIONS(3435),
    [anon_sym_EQ_EQ] = ACTIONS(3433),
    [anon_sym_BANG_EQ] = ACTIONS(3433),
    [anon_sym_TILDE_EQ] = ACTIONS(3433),
    [anon_sym_AMP_TILDE] = ACTIONS(3435),
    [anon_sym_LT_LT] = ACTIONS(3435),
    [anon_sym_GT_GT] = ACTIONS(3435),
    [anon_sym_STAR] = ACTIONS(3435),
    [anon_sym_SLASH] = ACTIONS(3435),
    [anon_sym_PERCENT] = ACTIONS(3435),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3433),
    [anon_sym_DOT] = ACTIONS(3435),
    [anon_sym_LBRACK] = ACTIONS(3433),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3433),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3433),
    [anon_sym_not_in] = ACTIONS(3433),
    [anon_sym_or_return] = ACTIONS(3433),
    [anon_sym_or_continue] = ACTIONS(3433),
    [anon_sym_or_break] = ACTIONS(3433),
    [anon_sym_CARET] = ACTIONS(3435),
    [anon_sym_DOT2] = ACTIONS(3437),
    [sym_uninitialized] = ACTIONS(3433),
    [sym_tag] = ACTIONS(3433),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3433),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [534] = {
    [sym_block] = STATE(781),
    [sym_where_clause] = STATE(665),
    [ts_builtin_sym_end] = ACTIONS(3439),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3439),
    [anon_sym_COMMA] = ACTIONS(3439),
    [anon_sym_COLON_COLON] = ACTIONS(3439),
    [anon_sym_DASH_GT] = ACTIONS(3443),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3445),
    [anon_sym_COLON] = ACTIONS(3445),
    [anon_sym_PIPE] = ACTIONS(3445),
    [anon_sym_COLON_EQ] = ACTIONS(3439),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_PLUS_EQ] = ACTIONS(3439),
    [anon_sym_DASH_EQ] = ACTIONS(3439),
    [anon_sym_STAR_EQ] = ACTIONS(3439),
    [anon_sym_SLASH_EQ] = ACTIONS(3439),
    [anon_sym_PERCENT_EQ] = ACTIONS(3439),
    [anon_sym_AMP_EQ] = ACTIONS(3439),
    [anon_sym_PIPE_EQ] = ACTIONS(3439),
    [anon_sym_CARET_EQ] = ACTIONS(3439),
    [anon_sym_LT_LT_EQ] = ACTIONS(3439),
    [anon_sym_GT_GT_EQ] = ACTIONS(3439),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3439),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3439),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3439),
    [anon_sym_if] = ACTIONS(3439),
    [anon_sym_SEMI] = ACTIONS(3439),
    [anon_sym_else] = ACTIONS(3439),
    [anon_sym_when] = ACTIONS(3439),
    [anon_sym_in] = ACTIONS(3439),
    [anon_sym_case] = ACTIONS(3439),
    [anon_sym_QMARK] = ACTIONS(3439),
    [anon_sym_PLUS] = ACTIONS(3445),
    [anon_sym_DASH] = ACTIONS(3445),
    [anon_sym_TILDE] = ACTIONS(3445),
    [anon_sym_AMP] = ACTIONS(3445),
    [anon_sym_PIPE_PIPE] = ACTIONS(3445),
    [anon_sym_or_else] = ACTIONS(3439),
    [anon_sym_AMP_AMP] = ACTIONS(3445),
    [anon_sym_GT] = ACTIONS(3445),
    [anon_sym_GT_EQ] = ACTIONS(3439),
    [anon_sym_LT_EQ] = ACTIONS(3439),
    [anon_sym_LT] = ACTIONS(3445),
    [anon_sym_EQ_EQ] = ACTIONS(3439),
    [anon_sym_BANG_EQ] = ACTIONS(3439),
    [anon_sym_TILDE_EQ] = ACTIONS(3439),
    [anon_sym_AMP_TILDE] = ACTIONS(3445),
    [anon_sym_LT_LT] = ACTIONS(3445),
    [anon_sym_GT_GT] = ACTIONS(3445),
    [anon_sym_STAR] = ACTIONS(3445),
    [anon_sym_SLASH] = ACTIONS(3445),
    [anon_sym_PERCENT] = ACTIONS(3445),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3439),
    [anon_sym_DOT] = ACTIONS(3445),
    [anon_sym_LBRACK] = ACTIONS(3439),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3439),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3439),
    [anon_sym_not_in] = ACTIONS(3439),
    [anon_sym_or_return] = ACTIONS(3439),
    [anon_sym_or_continue] = ACTIONS(3439),
    [anon_sym_or_break] = ACTIONS(3439),
    [anon_sym_CARET] = ACTIONS(3445),
    [sym_uninitialized] = ACTIONS(3447),
    [sym_tag] = ACTIONS(3449),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3439),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [535] = {
    [sym_block] = STATE(786),
    [sym_where_clause] = STATE(667),
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3453),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(3457),
    [sym_tag] = ACTIONS(3459),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [536] = {
    [sym_switch_case] = STATE(7540),
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8077),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [aux_sym_switch_statement_repeat1] = STATE(7540),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(3461),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_case] = ACTIONS(3463),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [537] = {
    [sym_block] = STATE(790),
    [sym_where_clause] = STATE(669),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3465),
    [sym_tag] = ACTIONS(3467),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [538] = {
    [sym_block] = STATE(2326),
    [sym_where_clause] = STATE(776),
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3469),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(3471),
    [sym_tag] = ACTIONS(3473),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [539] = {
    [sym_switch_case] = STATE(7579),
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8077),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [aux_sym_switch_statement_repeat1] = STATE(7579),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(3475),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_case] = ACTIONS(3463),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [540] = {
    [sym_block] = STATE(793),
    [sym_where_clause] = STATE(671),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3477),
    [sym_tag] = ACTIONS(3479),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [541] = {
    [sym_block] = STATE(793),
    [sym_where_clause] = STATE(671),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3477),
    [sym_tag] = ACTIONS(3479),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [542] = {
    [sym_block] = STATE(1558),
    [sym_where_clause] = STATE(716),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3429),
    [sym_tag] = ACTIONS(3431),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [543] = {
    [sym_block] = STATE(2342),
    [sym_where_clause] = STATE(807),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3394),
    [sym_tag] = ACTIONS(3396),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [544] = {
    [aux_sym_field_type_repeat1] = STATE(533),
    [ts_builtin_sym_end] = ACTIONS(3481),
    [anon_sym_LBRACE] = ACTIONS(3481),
    [anon_sym_RBRACE] = ACTIONS(3481),
    [anon_sym_COMMA] = ACTIONS(3481),
    [anon_sym_COLON_COLON] = ACTIONS(3481),
    [anon_sym_DASH_GT] = ACTIONS(3481),
    [anon_sym_where] = ACTIONS(3481),
    [anon_sym_EQ] = ACTIONS(3483),
    [anon_sym_COLON] = ACTIONS(3485),
    [anon_sym_PIPE] = ACTIONS(3483),
    [anon_sym_COLON_EQ] = ACTIONS(3481),
    [anon_sym_LPAREN] = ACTIONS(3481),
    [anon_sym_PLUS_EQ] = ACTIONS(3481),
    [anon_sym_DASH_EQ] = ACTIONS(3481),
    [anon_sym_STAR_EQ] = ACTIONS(3481),
    [anon_sym_SLASH_EQ] = ACTIONS(3481),
    [anon_sym_PERCENT_EQ] = ACTIONS(3481),
    [anon_sym_AMP_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_CARET_EQ] = ACTIONS(3481),
    [anon_sym_LT_LT_EQ] = ACTIONS(3481),
    [anon_sym_GT_GT_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(3481),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_else] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_in] = ACTIONS(3481),
    [anon_sym_case] = ACTIONS(3481),
    [anon_sym_QMARK] = ACTIONS(3481),
    [anon_sym_PLUS] = ACTIONS(3483),
    [anon_sym_DASH] = ACTIONS(3483),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_AMP] = ACTIONS(3483),
    [anon_sym_PIPE_PIPE] = ACTIONS(3483),
    [anon_sym_or_else] = ACTIONS(3481),
    [anon_sym_AMP_AMP] = ACTIONS(3483),
    [anon_sym_GT] = ACTIONS(3483),
    [anon_sym_GT_EQ] = ACTIONS(3481),
    [anon_sym_LT_EQ] = ACTIONS(3481),
    [anon_sym_LT] = ACTIONS(3483),
    [anon_sym_EQ_EQ] = ACTIONS(3481),
    [anon_sym_BANG_EQ] = ACTIONS(3481),
    [anon_sym_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE] = ACTIONS(3483),
    [anon_sym_LT_LT] = ACTIONS(3483),
    [anon_sym_GT_GT] = ACTIONS(3483),
    [anon_sym_STAR] = ACTIONS(3483),
    [anon_sym_SLASH] = ACTIONS(3483),
    [anon_sym_PERCENT] = ACTIONS(3483),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3481),
    [anon_sym_DOT] = ACTIONS(3483),
    [anon_sym_LBRACK] = ACTIONS(3481),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3481),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3481),
    [anon_sym_not_in] = ACTIONS(3481),
    [anon_sym_or_return] = ACTIONS(3481),
    [anon_sym_or_continue] = ACTIONS(3481),
    [anon_sym_or_break] = ACTIONS(3481),
    [anon_sym_CARET] = ACTIONS(3483),
    [anon_sym_DOT2] = ACTIONS(3437),
    [sym_uninitialized] = ACTIONS(3481),
    [sym_tag] = ACTIONS(3481),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3481),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [545] = {
    [sym_block] = STATE(2342),
    [sym_where_clause] = STATE(807),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3394),
    [sym_tag] = ACTIONS(3487),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [546] = {
    [sym_switch_case] = STATE(7605),
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8077),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [aux_sym_switch_statement_repeat1] = STATE(7605),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(3489),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_case] = ACTIONS(3463),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [547] = {
    [sym_block] = STATE(793),
    [sym_where_clause] = STATE(671),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3477),
    [sym_tag] = ACTIONS(3491),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [548] = {
    [sym_block] = STATE(794),
    [sym_where_clause] = STATE(675),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3493),
    [sym_tag] = ACTIONS(3495),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [549] = {
    [sym_block] = STATE(794),
    [sym_where_clause] = STATE(675),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3493),
    [sym_tag] = ACTIONS(3495),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [550] = {
    [sym_block] = STATE(794),
    [sym_where_clause] = STATE(675),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3493),
    [sym_tag] = ACTIONS(3497),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [551] = {
    [sym_block] = STATE(2305),
    [sym_where_clause] = STATE(729),
    [ts_builtin_sym_end] = ACTIONS(3439),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3439),
    [anon_sym_COMMA] = ACTIONS(3439),
    [anon_sym_COLON_COLON] = ACTIONS(3439),
    [anon_sym_DASH_GT] = ACTIONS(3499),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3445),
    [anon_sym_COLON] = ACTIONS(3445),
    [anon_sym_PIPE] = ACTIONS(3445),
    [anon_sym_COLON_EQ] = ACTIONS(3439),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_PLUS_EQ] = ACTIONS(3439),
    [anon_sym_DASH_EQ] = ACTIONS(3439),
    [anon_sym_STAR_EQ] = ACTIONS(3439),
    [anon_sym_SLASH_EQ] = ACTIONS(3439),
    [anon_sym_PERCENT_EQ] = ACTIONS(3439),
    [anon_sym_AMP_EQ] = ACTIONS(3439),
    [anon_sym_PIPE_EQ] = ACTIONS(3439),
    [anon_sym_CARET_EQ] = ACTIONS(3439),
    [anon_sym_LT_LT_EQ] = ACTIONS(3439),
    [anon_sym_GT_GT_EQ] = ACTIONS(3439),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3439),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3439),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3439),
    [anon_sym_if] = ACTIONS(3439),
    [anon_sym_SEMI] = ACTIONS(3439),
    [anon_sym_else] = ACTIONS(3439),
    [anon_sym_when] = ACTIONS(3439),
    [anon_sym_in] = ACTIONS(3439),
    [anon_sym_case] = ACTIONS(3439),
    [anon_sym_QMARK] = ACTIONS(3439),
    [anon_sym_PLUS] = ACTIONS(3445),
    [anon_sym_DASH] = ACTIONS(3445),
    [anon_sym_TILDE] = ACTIONS(3445),
    [anon_sym_AMP] = ACTIONS(3445),
    [anon_sym_PIPE_PIPE] = ACTIONS(3445),
    [anon_sym_or_else] = ACTIONS(3439),
    [anon_sym_AMP_AMP] = ACTIONS(3445),
    [anon_sym_GT] = ACTIONS(3445),
    [anon_sym_GT_EQ] = ACTIONS(3439),
    [anon_sym_LT_EQ] = ACTIONS(3439),
    [anon_sym_LT] = ACTIONS(3445),
    [anon_sym_EQ_EQ] = ACTIONS(3439),
    [anon_sym_BANG_EQ] = ACTIONS(3439),
    [anon_sym_TILDE_EQ] = ACTIONS(3439),
    [anon_sym_AMP_TILDE] = ACTIONS(3445),
    [anon_sym_LT_LT] = ACTIONS(3445),
    [anon_sym_GT_GT] = ACTIONS(3445),
    [anon_sym_STAR] = ACTIONS(3445),
    [anon_sym_SLASH] = ACTIONS(3445),
    [anon_sym_PERCENT] = ACTIONS(3445),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3439),
    [anon_sym_DOT] = ACTIONS(3445),
    [anon_sym_LBRACK] = ACTIONS(3439),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3439),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3439),
    [anon_sym_not_in] = ACTIONS(3439),
    [anon_sym_or_return] = ACTIONS(3439),
    [anon_sym_or_continue] = ACTIONS(3439),
    [anon_sym_or_break] = ACTIONS(3439),
    [anon_sym_CARET] = ACTIONS(3445),
    [sym_uninitialized] = ACTIONS(3501),
    [sym_tag] = ACTIONS(3503),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3439),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [552] = {
    [sym_block] = STATE(796),
    [sym_where_clause] = STATE(683),
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(3505),
    [sym_tag] = ACTIONS(3507),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [553] = {
    [sym_procedure] = STATE(7067),
    [sym_expression] = STATE(4983),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(3509),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_SEMI] = ACTIONS(3509),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3509),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [554] = {
    [sym_procedure] = STATE(7067),
    [sym_expression] = STATE(4983),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [ts_builtin_sym_end] = ACTIONS(3511),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_SEMI] = ACTIONS(3511),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3511),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [555] = {
    [sym_attributes] = STATE(1559),
    [sym_attribute] = STATE(6180),
    [sym_assignment_statement] = STATE(7903),
    [sym_expression] = STATE(5753),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [aux_sym_attributes_repeat1] = STATE(6180),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_AT] = ACTIONS(21),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [556] = {
    [sym_block] = STATE(1587),
    [sym_where_clause] = STATE(774),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3421),
    [sym_tag] = ACTIONS(3423),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [557] = {
    [sym_block] = STATE(2341),
    [sym_where_clause] = STATE(795),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3513),
    [sym_tag] = ACTIONS(3515),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [558] = {
    [sym_block] = STATE(2341),
    [sym_where_clause] = STATE(795),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3513),
    [sym_tag] = ACTIONS(3515),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [559] = {
    [sym_block] = STATE(1568),
    [sym_where_clause] = STATE(720),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3380),
    [sym_tag] = ACTIONS(3517),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [560] = {
    [sym_block] = STATE(1587),
    [sym_where_clause] = STATE(774),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3421),
    [sym_tag] = ACTIONS(3519),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [561] = {
    [aux_sym_field_type_repeat1] = STATE(533),
    [ts_builtin_sym_end] = ACTIONS(3481),
    [anon_sym_LBRACE] = ACTIONS(3481),
    [anon_sym_RBRACE] = ACTIONS(3481),
    [anon_sym_COMMA] = ACTIONS(3481),
    [anon_sym_COLON_COLON] = ACTIONS(3481),
    [anon_sym_DASH_GT] = ACTIONS(3481),
    [anon_sym_where] = ACTIONS(3481),
    [anon_sym_EQ] = ACTIONS(3483),
    [anon_sym_COLON] = ACTIONS(3483),
    [anon_sym_PIPE] = ACTIONS(3483),
    [anon_sym_COLON_EQ] = ACTIONS(3481),
    [anon_sym_LPAREN] = ACTIONS(3481),
    [anon_sym_PLUS_EQ] = ACTIONS(3481),
    [anon_sym_DASH_EQ] = ACTIONS(3481),
    [anon_sym_STAR_EQ] = ACTIONS(3481),
    [anon_sym_SLASH_EQ] = ACTIONS(3481),
    [anon_sym_PERCENT_EQ] = ACTIONS(3481),
    [anon_sym_AMP_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_CARET_EQ] = ACTIONS(3481),
    [anon_sym_LT_LT_EQ] = ACTIONS(3481),
    [anon_sym_GT_GT_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(3481),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_else] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_in] = ACTIONS(3481),
    [anon_sym_case] = ACTIONS(3481),
    [anon_sym_QMARK] = ACTIONS(3481),
    [anon_sym_PLUS] = ACTIONS(3483),
    [anon_sym_DASH] = ACTIONS(3483),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_AMP] = ACTIONS(3483),
    [anon_sym_PIPE_PIPE] = ACTIONS(3483),
    [anon_sym_or_else] = ACTIONS(3481),
    [anon_sym_AMP_AMP] = ACTIONS(3483),
    [anon_sym_GT] = ACTIONS(3483),
    [anon_sym_GT_EQ] = ACTIONS(3481),
    [anon_sym_LT_EQ] = ACTIONS(3481),
    [anon_sym_LT] = ACTIONS(3483),
    [anon_sym_EQ_EQ] = ACTIONS(3481),
    [anon_sym_BANG_EQ] = ACTIONS(3481),
    [anon_sym_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE] = ACTIONS(3483),
    [anon_sym_LT_LT] = ACTIONS(3483),
    [anon_sym_GT_GT] = ACTIONS(3483),
    [anon_sym_STAR] = ACTIONS(3483),
    [anon_sym_SLASH] = ACTIONS(3483),
    [anon_sym_PERCENT] = ACTIONS(3483),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3481),
    [anon_sym_DOT] = ACTIONS(3483),
    [anon_sym_LBRACK] = ACTIONS(3481),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3481),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3481),
    [anon_sym_not_in] = ACTIONS(3481),
    [anon_sym_or_return] = ACTIONS(3481),
    [anon_sym_or_continue] = ACTIONS(3481),
    [anon_sym_or_break] = ACTIONS(3481),
    [anon_sym_CARET] = ACTIONS(3483),
    [anon_sym_DOT2] = ACTIONS(3437),
    [sym_uninitialized] = ACTIONS(3481),
    [sym_tag] = ACTIONS(3481),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3481),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [562] = {
    [sym_block] = STATE(1594),
    [sym_where_clause] = STATE(775),
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(3521),
    [sym_tag] = ACTIONS(3523),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [563] = {
    [sym_block] = STATE(1530),
    [sym_where_clause] = STATE(707),
    [ts_builtin_sym_end] = ACTIONS(3439),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3439),
    [anon_sym_COMMA] = ACTIONS(3439),
    [anon_sym_COLON_COLON] = ACTIONS(3439),
    [anon_sym_DASH_GT] = ACTIONS(3525),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3445),
    [anon_sym_COLON] = ACTIONS(3445),
    [anon_sym_PIPE] = ACTIONS(3445),
    [anon_sym_COLON_EQ] = ACTIONS(3439),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_PLUS_EQ] = ACTIONS(3439),
    [anon_sym_DASH_EQ] = ACTIONS(3439),
    [anon_sym_STAR_EQ] = ACTIONS(3439),
    [anon_sym_SLASH_EQ] = ACTIONS(3439),
    [anon_sym_PERCENT_EQ] = ACTIONS(3439),
    [anon_sym_AMP_EQ] = ACTIONS(3439),
    [anon_sym_PIPE_EQ] = ACTIONS(3439),
    [anon_sym_CARET_EQ] = ACTIONS(3439),
    [anon_sym_LT_LT_EQ] = ACTIONS(3439),
    [anon_sym_GT_GT_EQ] = ACTIONS(3439),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3439),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3439),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3439),
    [anon_sym_if] = ACTIONS(3439),
    [anon_sym_SEMI] = ACTIONS(3439),
    [anon_sym_else] = ACTIONS(3439),
    [anon_sym_when] = ACTIONS(3439),
    [anon_sym_in] = ACTIONS(3439),
    [anon_sym_case] = ACTIONS(3439),
    [anon_sym_QMARK] = ACTIONS(3439),
    [anon_sym_PLUS] = ACTIONS(3445),
    [anon_sym_DASH] = ACTIONS(3445),
    [anon_sym_TILDE] = ACTIONS(3445),
    [anon_sym_AMP] = ACTIONS(3445),
    [anon_sym_PIPE_PIPE] = ACTIONS(3445),
    [anon_sym_or_else] = ACTIONS(3439),
    [anon_sym_AMP_AMP] = ACTIONS(3445),
    [anon_sym_GT] = ACTIONS(3445),
    [anon_sym_GT_EQ] = ACTIONS(3439),
    [anon_sym_LT_EQ] = ACTIONS(3439),
    [anon_sym_LT] = ACTIONS(3445),
    [anon_sym_EQ_EQ] = ACTIONS(3439),
    [anon_sym_BANG_EQ] = ACTIONS(3439),
    [anon_sym_TILDE_EQ] = ACTIONS(3439),
    [anon_sym_AMP_TILDE] = ACTIONS(3445),
    [anon_sym_LT_LT] = ACTIONS(3445),
    [anon_sym_GT_GT] = ACTIONS(3445),
    [anon_sym_STAR] = ACTIONS(3445),
    [anon_sym_SLASH] = ACTIONS(3445),
    [anon_sym_PERCENT] = ACTIONS(3445),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3439),
    [anon_sym_DOT] = ACTIONS(3445),
    [anon_sym_LBRACK] = ACTIONS(3439),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3439),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3439),
    [anon_sym_not_in] = ACTIONS(3439),
    [anon_sym_or_return] = ACTIONS(3439),
    [anon_sym_or_continue] = ACTIONS(3439),
    [anon_sym_or_break] = ACTIONS(3439),
    [anon_sym_CARET] = ACTIONS(3445),
    [sym_uninitialized] = ACTIONS(3527),
    [sym_tag] = ACTIONS(3529),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3439),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [564] = {
    [sym_block] = STATE(1551),
    [sym_where_clause] = STATE(710),
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3531),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(3533),
    [sym_tag] = ACTIONS(3535),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [565] = {
    [sym_block] = STATE(790),
    [sym_where_clause] = STATE(669),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3372),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3465),
    [sym_tag] = ACTIONS(3467),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [566] = {
    [sym_expression] = STATE(6475),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3537),
    [anon_sym_QMARK] = ACTIONS(3539),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3541),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3543),
    [anon_sym_dynamic] = ACTIONS(3545),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [567] = {
    [aux_sym_struct_type_repeat2] = STATE(584),
    [ts_builtin_sym_end] = ACTIONS(3547),
    [anon_sym_LBRACE] = ACTIONS(3547),
    [anon_sym_RBRACE] = ACTIONS(3547),
    [anon_sym_COMMA] = ACTIONS(3547),
    [anon_sym_COLON_COLON] = ACTIONS(3547),
    [anon_sym_DASH_GT] = ACTIONS(3547),
    [anon_sym_where] = ACTIONS(3547),
    [anon_sym_EQ] = ACTIONS(3549),
    [anon_sym_COLON] = ACTIONS(3549),
    [anon_sym_PIPE] = ACTIONS(3549),
    [anon_sym_COLON_EQ] = ACTIONS(3547),
    [anon_sym_LPAREN] = ACTIONS(3547),
    [anon_sym_PLUS_EQ] = ACTIONS(3547),
    [anon_sym_DASH_EQ] = ACTIONS(3547),
    [anon_sym_STAR_EQ] = ACTIONS(3547),
    [anon_sym_SLASH_EQ] = ACTIONS(3547),
    [anon_sym_PERCENT_EQ] = ACTIONS(3547),
    [anon_sym_AMP_EQ] = ACTIONS(3547),
    [anon_sym_PIPE_EQ] = ACTIONS(3547),
    [anon_sym_CARET_EQ] = ACTIONS(3547),
    [anon_sym_LT_LT_EQ] = ACTIONS(3547),
    [anon_sym_GT_GT_EQ] = ACTIONS(3547),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3547),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3547),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3547),
    [anon_sym_if] = ACTIONS(3547),
    [anon_sym_SEMI] = ACTIONS(3547),
    [anon_sym_else] = ACTIONS(3547),
    [anon_sym_when] = ACTIONS(3547),
    [anon_sym_in] = ACTIONS(3547),
    [anon_sym_case] = ACTIONS(3547),
    [anon_sym_QMARK] = ACTIONS(3547),
    [anon_sym_PLUS] = ACTIONS(3549),
    [anon_sym_DASH] = ACTIONS(3549),
    [anon_sym_TILDE] = ACTIONS(3549),
    [anon_sym_AMP] = ACTIONS(3549),
    [anon_sym_PIPE_PIPE] = ACTIONS(3549),
    [anon_sym_or_else] = ACTIONS(3547),
    [anon_sym_AMP_AMP] = ACTIONS(3549),
    [anon_sym_GT] = ACTIONS(3549),
    [anon_sym_GT_EQ] = ACTIONS(3547),
    [anon_sym_LT_EQ] = ACTIONS(3547),
    [anon_sym_LT] = ACTIONS(3549),
    [anon_sym_EQ_EQ] = ACTIONS(3547),
    [anon_sym_BANG_EQ] = ACTIONS(3547),
    [anon_sym_TILDE_EQ] = ACTIONS(3547),
    [anon_sym_AMP_TILDE] = ACTIONS(3549),
    [anon_sym_LT_LT] = ACTIONS(3549),
    [anon_sym_GT_GT] = ACTIONS(3549),
    [anon_sym_STAR] = ACTIONS(3549),
    [anon_sym_SLASH] = ACTIONS(3549),
    [anon_sym_PERCENT] = ACTIONS(3549),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3547),
    [anon_sym_DOT] = ACTIONS(3549),
    [anon_sym_LBRACK] = ACTIONS(3547),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3547),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3547),
    [anon_sym_not_in] = ACTIONS(3547),
    [anon_sym_or_return] = ACTIONS(3547),
    [anon_sym_or_continue] = ACTIONS(3547),
    [anon_sym_or_break] = ACTIONS(3547),
    [anon_sym_CARET] = ACTIONS(3549),
    [sym_uninitialized] = ACTIONS(3547),
    [sym_tag] = ACTIONS(3547),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3547),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [568] = {
    [sym_expression] = STATE(6415),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3551),
    [anon_sym_QMARK] = ACTIONS(3553),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3555),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3557),
    [anon_sym_dynamic] = ACTIONS(3559),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [569] = {
    [sym_expression] = STATE(6580),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3561),
    [anon_sym_QMARK] = ACTIONS(3563),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3565),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3567),
    [anon_sym_dynamic] = ACTIONS(3569),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [570] = {
    [sym_expression] = STATE(6436),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3571),
    [anon_sym_QMARK] = ACTIONS(3573),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3575),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3577),
    [anon_sym_dynamic] = ACTIONS(3579),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [571] = {
    [sym_expression] = STATE(6561),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3581),
    [anon_sym_QMARK] = ACTIONS(3583),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3585),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3587),
    [anon_sym_dynamic] = ACTIONS(3589),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [572] = {
    [sym_expression] = STATE(6429),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3591),
    [anon_sym_QMARK] = ACTIONS(3593),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3595),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3597),
    [anon_sym_dynamic] = ACTIONS(3599),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [573] = {
    [sym_expression] = STATE(6592),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3601),
    [anon_sym_QMARK] = ACTIONS(3603),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3605),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3607),
    [anon_sym_dynamic] = ACTIONS(3609),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [574] = {
    [sym_expression] = STATE(6384),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3611),
    [anon_sym_QMARK] = ACTIONS(3613),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3615),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3617),
    [anon_sym_dynamic] = ACTIONS(3619),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [575] = {
    [sym_expression] = STATE(6413),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3621),
    [anon_sym_QMARK] = ACTIONS(3623),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3625),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3627),
    [anon_sym_dynamic] = ACTIONS(3629),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [576] = {
    [sym_expression] = STATE(6517),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3631),
    [anon_sym_QMARK] = ACTIONS(3633),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3635),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3637),
    [anon_sym_dynamic] = ACTIONS(3639),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [577] = {
    [sym_expression] = STATE(6573),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3641),
    [anon_sym_QMARK] = ACTIONS(3643),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3645),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3647),
    [anon_sym_dynamic] = ACTIONS(3649),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [578] = {
    [sym_expression] = STATE(6547),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3651),
    [anon_sym_QMARK] = ACTIONS(3653),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3655),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3657),
    [anon_sym_dynamic] = ACTIONS(3659),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [579] = {
    [sym_expression] = STATE(6056),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(7995),
    [sym_array_type] = STATE(7995),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(3661),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [580] = {
    [sym_expression] = STATE(6552),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3611),
    [anon_sym_QMARK] = ACTIONS(3663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3665),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3667),
    [anon_sym_dynamic] = ACTIONS(3669),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [581] = {
    [sym_expression] = STATE(6226),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3671),
    [anon_sym_QMARK] = ACTIONS(3673),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3675),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3677),
    [anon_sym_dynamic] = ACTIONS(3679),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [582] = {
    [sym_expression] = STATE(6399),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3681),
    [anon_sym_QMARK] = ACTIONS(3683),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3685),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3687),
    [anon_sym_dynamic] = ACTIONS(3689),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [583] = {
    [sym_expression] = STATE(6420),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3691),
    [anon_sym_QMARK] = ACTIONS(3693),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3695),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3697),
    [anon_sym_dynamic] = ACTIONS(3699),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [584] = {
    [aux_sym_struct_type_repeat2] = STATE(584),
    [ts_builtin_sym_end] = ACTIONS(3701),
    [anon_sym_LBRACE] = ACTIONS(3703),
    [anon_sym_RBRACE] = ACTIONS(3701),
    [anon_sym_COMMA] = ACTIONS(3701),
    [anon_sym_COLON_COLON] = ACTIONS(3701),
    [anon_sym_DASH_GT] = ACTIONS(3701),
    [anon_sym_where] = ACTIONS(3701),
    [anon_sym_EQ] = ACTIONS(3706),
    [anon_sym_COLON] = ACTIONS(3706),
    [anon_sym_PIPE] = ACTIONS(3706),
    [anon_sym_COLON_EQ] = ACTIONS(3701),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_PLUS_EQ] = ACTIONS(3701),
    [anon_sym_DASH_EQ] = ACTIONS(3701),
    [anon_sym_STAR_EQ] = ACTIONS(3701),
    [anon_sym_SLASH_EQ] = ACTIONS(3701),
    [anon_sym_PERCENT_EQ] = ACTIONS(3701),
    [anon_sym_AMP_EQ] = ACTIONS(3701),
    [anon_sym_PIPE_EQ] = ACTIONS(3701),
    [anon_sym_CARET_EQ] = ACTIONS(3701),
    [anon_sym_LT_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT_GT_EQ] = ACTIONS(3701),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3701),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3701),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3701),
    [anon_sym_if] = ACTIONS(3701),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_else] = ACTIONS(3701),
    [anon_sym_when] = ACTIONS(3701),
    [anon_sym_in] = ACTIONS(3701),
    [anon_sym_case] = ACTIONS(3701),
    [anon_sym_QMARK] = ACTIONS(3701),
    [anon_sym_PLUS] = ACTIONS(3706),
    [anon_sym_DASH] = ACTIONS(3706),
    [anon_sym_TILDE] = ACTIONS(3706),
    [anon_sym_AMP] = ACTIONS(3706),
    [anon_sym_PIPE_PIPE] = ACTIONS(3706),
    [anon_sym_or_else] = ACTIONS(3701),
    [anon_sym_AMP_AMP] = ACTIONS(3706),
    [anon_sym_GT] = ACTIONS(3706),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_LT] = ACTIONS(3706),
    [anon_sym_EQ_EQ] = ACTIONS(3701),
    [anon_sym_BANG_EQ] = ACTIONS(3701),
    [anon_sym_TILDE_EQ] = ACTIONS(3701),
    [anon_sym_AMP_TILDE] = ACTIONS(3706),
    [anon_sym_LT_LT] = ACTIONS(3706),
    [anon_sym_GT_GT] = ACTIONS(3706),
    [anon_sym_STAR] = ACTIONS(3706),
    [anon_sym_SLASH] = ACTIONS(3706),
    [anon_sym_PERCENT] = ACTIONS(3706),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(3706),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3701),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3701),
    [anon_sym_not_in] = ACTIONS(3701),
    [anon_sym_or_return] = ACTIONS(3701),
    [anon_sym_or_continue] = ACTIONS(3701),
    [anon_sym_or_break] = ACTIONS(3701),
    [anon_sym_CARET] = ACTIONS(3706),
    [sym_uninitialized] = ACTIONS(3701),
    [sym_tag] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3701),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [585] = {
    [sym_expression] = STATE(6416),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3708),
    [anon_sym_QMARK] = ACTIONS(3710),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3712),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3714),
    [anon_sym_dynamic] = ACTIONS(3716),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [586] = {
    [sym_expression] = STATE(6221),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3718),
    [anon_sym_QMARK] = ACTIONS(3720),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3722),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3724),
    [anon_sym_dynamic] = ACTIONS(3726),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [587] = {
    [sym_expression] = STATE(6272),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3728),
    [anon_sym_QMARK] = ACTIONS(3730),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3732),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3734),
    [anon_sym_dynamic] = ACTIONS(3736),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [588] = {
    [sym_expression] = STATE(6332),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3738),
    [anon_sym_QMARK] = ACTIONS(3740),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3742),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3744),
    [anon_sym_dynamic] = ACTIONS(3746),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [589] = {
    [sym_expression] = STATE(6455),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3748),
    [anon_sym_QMARK] = ACTIONS(3750),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3752),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3754),
    [anon_sym_dynamic] = ACTIONS(3756),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [590] = {
    [sym_expression] = STATE(6218),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3758),
    [anon_sym_QMARK] = ACTIONS(3760),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3762),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3764),
    [anon_sym_dynamic] = ACTIONS(3766),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [591] = {
    [sym_expression] = STATE(6287),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3768),
    [anon_sym_QMARK] = ACTIONS(3770),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3772),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3774),
    [anon_sym_dynamic] = ACTIONS(3776),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [592] = {
    [sym_expression] = STATE(6453),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3778),
    [anon_sym_QMARK] = ACTIONS(3780),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3782),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3784),
    [anon_sym_dynamic] = ACTIONS(3786),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [593] = {
    [sym_expression] = STATE(6479),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3788),
    [anon_sym_QMARK] = ACTIONS(3790),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3792),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3794),
    [anon_sym_dynamic] = ACTIONS(3796),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [594] = {
    [sym_expression] = STATE(6483),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3798),
    [anon_sym_QMARK] = ACTIONS(3800),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3802),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3804),
    [anon_sym_dynamic] = ACTIONS(3806),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [595] = {
    [sym_expression] = STATE(6325),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3808),
    [anon_sym_QMARK] = ACTIONS(3810),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3812),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3814),
    [anon_sym_dynamic] = ACTIONS(3816),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [596] = {
    [sym_expression] = STATE(6350),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3818),
    [anon_sym_QMARK] = ACTIONS(3820),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3822),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3824),
    [anon_sym_dynamic] = ACTIONS(3826),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [597] = {
    [sym_expression] = STATE(6243),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3828),
    [anon_sym_QMARK] = ACTIONS(3830),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3832),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3834),
    [anon_sym_dynamic] = ACTIONS(3836),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [598] = {
    [sym_expression] = STATE(6307),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3838),
    [anon_sym_QMARK] = ACTIONS(3840),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3842),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3844),
    [anon_sym_dynamic] = ACTIONS(3846),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [599] = {
    [sym_expression] = STATE(6591),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3848),
    [anon_sym_QMARK] = ACTIONS(3850),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3852),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3854),
    [anon_sym_dynamic] = ACTIONS(3856),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [600] = {
    [sym_expression] = STATE(6575),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3858),
    [anon_sym_QMARK] = ACTIONS(3860),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3862),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3864),
    [anon_sym_dynamic] = ACTIONS(3866),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [601] = {
    [sym_expression] = STATE(6219),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3868),
    [anon_sym_QMARK] = ACTIONS(3870),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3872),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3874),
    [anon_sym_dynamic] = ACTIONS(3876),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [602] = {
    [ts_builtin_sym_end] = ACTIONS(69),
    [sym_identifier] = ACTIONS(3878),
    [anon_sym_LBRACE] = ACTIONS(69),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_where] = ACTIONS(73),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_LPAREN] = ACTIONS(3880),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(73),
    [anon_sym_when] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [sym_uninitialized] = ACTIONS(69),
    [sym_tag] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [603] = {
    [sym_expression] = STATE(6553),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3882),
    [anon_sym_QMARK] = ACTIONS(3884),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3886),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3888),
    [anon_sym_dynamic] = ACTIONS(3890),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [604] = {
    [sym_expression] = STATE(6364),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3892),
    [anon_sym_QMARK] = ACTIONS(3894),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3896),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3898),
    [anon_sym_dynamic] = ACTIONS(3900),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [605] = {
    [sym_expression] = STATE(6230),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3902),
    [anon_sym_QMARK] = ACTIONS(3904),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3906),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3908),
    [anon_sym_dynamic] = ACTIONS(3910),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [606] = {
    [aux_sym_field_identifier_repeat1] = STATE(7617),
    [ts_builtin_sym_end] = ACTIONS(3912),
    [anon_sym_LBRACE] = ACTIONS(3914),
    [anon_sym_RBRACE] = ACTIONS(3912),
    [anon_sym_COMMA] = ACTIONS(3912),
    [anon_sym_COLON_COLON] = ACTIONS(3912),
    [anon_sym_DASH_GT] = ACTIONS(3912),
    [anon_sym_where] = ACTIONS(3912),
    [anon_sym_EQ] = ACTIONS(3917),
    [anon_sym_COLON] = ACTIONS(3917),
    [anon_sym_PIPE] = ACTIONS(3917),
    [anon_sym_COLON_EQ] = ACTIONS(3912),
    [anon_sym_LPAREN] = ACTIONS(3919),
    [anon_sym_PLUS_EQ] = ACTIONS(3912),
    [anon_sym_DASH_EQ] = ACTIONS(3912),
    [anon_sym_STAR_EQ] = ACTIONS(3912),
    [anon_sym_SLASH_EQ] = ACTIONS(3912),
    [anon_sym_PERCENT_EQ] = ACTIONS(3912),
    [anon_sym_AMP_EQ] = ACTIONS(3912),
    [anon_sym_PIPE_EQ] = ACTIONS(3912),
    [anon_sym_CARET_EQ] = ACTIONS(3912),
    [anon_sym_LT_LT_EQ] = ACTIONS(3912),
    [anon_sym_GT_GT_EQ] = ACTIONS(3912),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3912),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3912),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3912),
    [anon_sym_if] = ACTIONS(3912),
    [anon_sym_SEMI] = ACTIONS(3912),
    [anon_sym_else] = ACTIONS(3912),
    [anon_sym_when] = ACTIONS(3912),
    [anon_sym_in] = ACTIONS(3912),
    [anon_sym_case] = ACTIONS(3912),
    [anon_sym_QMARK] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3917),
    [anon_sym_DASH] = ACTIONS(3917),
    [anon_sym_TILDE] = ACTIONS(3917),
    [anon_sym_AMP] = ACTIONS(3917),
    [anon_sym_PIPE_PIPE] = ACTIONS(3917),
    [anon_sym_or_else] = ACTIONS(3912),
    [anon_sym_AMP_AMP] = ACTIONS(3917),
    [anon_sym_GT] = ACTIONS(3917),
    [anon_sym_GT_EQ] = ACTIONS(3912),
    [anon_sym_LT_EQ] = ACTIONS(3912),
    [anon_sym_LT] = ACTIONS(3917),
    [anon_sym_EQ_EQ] = ACTIONS(3912),
    [anon_sym_BANG_EQ] = ACTIONS(3912),
    [anon_sym_TILDE_EQ] = ACTIONS(3912),
    [anon_sym_AMP_TILDE] = ACTIONS(3917),
    [anon_sym_LT_LT] = ACTIONS(3917),
    [anon_sym_GT_GT] = ACTIONS(3917),
    [anon_sym_STAR] = ACTIONS(3917),
    [anon_sym_SLASH] = ACTIONS(3917),
    [anon_sym_PERCENT] = ACTIONS(3917),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3912),
    [anon_sym_DOT] = ACTIONS(3917),
    [anon_sym_LBRACK] = ACTIONS(3912),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3912),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3912),
    [anon_sym_not_in] = ACTIONS(3912),
    [anon_sym_or_return] = ACTIONS(3912),
    [anon_sym_or_continue] = ACTIONS(3912),
    [anon_sym_or_break] = ACTIONS(3912),
    [anon_sym_CARET] = ACTIONS(3917),
    [sym_uninitialized] = ACTIONS(3912),
    [sym_tag] = ACTIONS(3912),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3912),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [607] = {
    [sym_expression] = STATE(6418),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3922),
    [anon_sym_QMARK] = ACTIONS(3924),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3926),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3928),
    [anon_sym_dynamic] = ACTIONS(3930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [608] = {
    [sym_expression] = STATE(6509),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3932),
    [anon_sym_QMARK] = ACTIONS(3934),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3936),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3938),
    [anon_sym_dynamic] = ACTIONS(3940),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [609] = {
    [sym_expression] = STATE(6432),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3942),
    [anon_sym_QMARK] = ACTIONS(3944),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3946),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3948),
    [anon_sym_dynamic] = ACTIONS(3950),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [610] = {
    [sym_expression] = STATE(6473),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3952),
    [anon_sym_QMARK] = ACTIONS(3954),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3956),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3958),
    [anon_sym_dynamic] = ACTIONS(3960),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [611] = {
    [sym_expression] = STATE(6427),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3962),
    [anon_sym_QMARK] = ACTIONS(3964),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3966),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3968),
    [anon_sym_dynamic] = ACTIONS(3970),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [612] = {
    [sym_expression] = STATE(6485),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3972),
    [anon_sym_QMARK] = ACTIONS(3974),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3976),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3978),
    [anon_sym_dynamic] = ACTIONS(3980),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [613] = {
    [sym_expression] = STATE(6534),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3982),
    [anon_sym_QMARK] = ACTIONS(3984),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3986),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3988),
    [anon_sym_dynamic] = ACTIONS(3990),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [614] = {
    [sym_expression] = STATE(6541),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(3992),
    [anon_sym_QMARK] = ACTIONS(3994),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(3996),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3998),
    [anon_sym_dynamic] = ACTIONS(4000),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [615] = {
    [sym_expression] = STATE(6555),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4002),
    [anon_sym_QMARK] = ACTIONS(4004),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4006),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4008),
    [anon_sym_dynamic] = ACTIONS(4010),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [616] = {
    [sym_expression] = STATE(6443),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4012),
    [anon_sym_QMARK] = ACTIONS(4014),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4016),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4018),
    [anon_sym_dynamic] = ACTIONS(4020),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [617] = {
    [sym_expression] = STATE(6609),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4022),
    [anon_sym_QMARK] = ACTIONS(4024),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4026),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4028),
    [anon_sym_dynamic] = ACTIONS(4030),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [618] = {
    [sym_expression] = STATE(6227),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4032),
    [anon_sym_QMARK] = ACTIONS(4034),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4036),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4038),
    [anon_sym_dynamic] = ACTIONS(4040),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [619] = {
    [sym_expression] = STATE(6605),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4042),
    [anon_sym_QMARK] = ACTIONS(4044),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4046),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4048),
    [anon_sym_dynamic] = ACTIONS(4050),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [620] = {
    [sym_expression] = STATE(6248),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4052),
    [anon_sym_QMARK] = ACTIONS(4054),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4056),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4058),
    [anon_sym_dynamic] = ACTIONS(4060),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [621] = {
    [sym_expression] = STATE(6310),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4062),
    [anon_sym_QMARK] = ACTIONS(4064),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4066),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4068),
    [anon_sym_dynamic] = ACTIONS(4070),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [622] = {
    [sym_expression] = STATE(6234),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4072),
    [anon_sym_QMARK] = ACTIONS(4074),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4076),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4078),
    [anon_sym_dynamic] = ACTIONS(4080),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [623] = {
    [sym_expression] = STATE(6343),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4082),
    [anon_sym_QMARK] = ACTIONS(4084),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4086),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4088),
    [anon_sym_dynamic] = ACTIONS(4090),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [624] = {
    [sym_expression] = STATE(6369),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4092),
    [anon_sym_QMARK] = ACTIONS(4094),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4096),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4098),
    [anon_sym_dynamic] = ACTIONS(4100),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [625] = {
    [sym_expression] = STATE(6334),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4102),
    [anon_sym_QMARK] = ACTIONS(4104),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4106),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4108),
    [anon_sym_dynamic] = ACTIONS(4110),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [626] = {
    [sym_expression] = STATE(6381),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4112),
    [anon_sym_QMARK] = ACTIONS(4114),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4116),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4118),
    [anon_sym_dynamic] = ACTIONS(4120),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [627] = {
    [sym_expression] = STATE(6403),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4126),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4128),
    [anon_sym_dynamic] = ACTIONS(4130),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [628] = {
    [sym_expression] = STATE(6377),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4132),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4136),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_dynamic] = ACTIONS(4140),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [629] = {
    [sym_expression] = STATE(6414),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4142),
    [anon_sym_QMARK] = ACTIONS(4144),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4146),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4148),
    [anon_sym_dynamic] = ACTIONS(4150),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [630] = {
    [sym_expression] = STATE(6437),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4152),
    [anon_sym_QMARK] = ACTIONS(4154),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4156),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4158),
    [anon_sym_dynamic] = ACTIONS(4160),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [631] = {
    [sym_expression] = STATE(6412),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4162),
    [anon_sym_QMARK] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4166),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4168),
    [anon_sym_dynamic] = ACTIONS(4170),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [632] = {
    [sym_expression] = STATE(6446),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4172),
    [anon_sym_QMARK] = ACTIONS(4174),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4176),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4178),
    [anon_sym_dynamic] = ACTIONS(4180),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [633] = {
    [sym_expression] = STATE(6458),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4182),
    [anon_sym_QMARK] = ACTIONS(4184),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4186),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_dynamic] = ACTIONS(4190),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [634] = {
    [sym_expression] = STATE(6293),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4192),
    [anon_sym_QMARK] = ACTIONS(4194),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4196),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4198),
    [anon_sym_dynamic] = ACTIONS(4200),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [635] = {
    [sym_expression] = STATE(6469),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4202),
    [anon_sym_QMARK] = ACTIONS(4204),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4206),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4208),
    [anon_sym_dynamic] = ACTIONS(4210),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [636] = {
    [sym_expression] = STATE(6497),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4212),
    [anon_sym_QMARK] = ACTIONS(4214),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4216),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4218),
    [anon_sym_dynamic] = ACTIONS(4220),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [637] = {
    [sym_expression] = STATE(6461),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4222),
    [anon_sym_QMARK] = ACTIONS(4224),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4226),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4228),
    [anon_sym_dynamic] = ACTIONS(4230),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [638] = {
    [sym_expression] = STATE(6511),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4232),
    [anon_sym_QMARK] = ACTIONS(4234),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4236),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4238),
    [anon_sym_dynamic] = ACTIONS(4240),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [639] = {
    [sym_expression] = STATE(6550),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4242),
    [anon_sym_QMARK] = ACTIONS(4244),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4246),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4248),
    [anon_sym_dynamic] = ACTIONS(4250),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [640] = {
    [sym_expression] = STATE(6506),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4252),
    [anon_sym_QMARK] = ACTIONS(4254),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4256),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4258),
    [anon_sym_dynamic] = ACTIONS(4260),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [641] = {
    [sym_expression] = STATE(6564),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4262),
    [anon_sym_QMARK] = ACTIONS(4264),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4266),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4268),
    [anon_sym_dynamic] = ACTIONS(4270),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [642] = {
    [sym_expression] = STATE(6406),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4272),
    [anon_sym_QMARK] = ACTIONS(4274),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4276),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4278),
    [anon_sym_dynamic] = ACTIONS(4280),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [643] = {
    [sym_expression] = STATE(6557),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4282),
    [anon_sym_QMARK] = ACTIONS(4284),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4286),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4288),
    [anon_sym_dynamic] = ACTIONS(4290),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [644] = {
    [sym_expression] = STATE(6470),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4292),
    [anon_sym_QMARK] = ACTIONS(4294),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4296),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4298),
    [anon_sym_dynamic] = ACTIONS(4300),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [645] = {
    [sym_expression] = STATE(6582),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4302),
    [anon_sym_QMARK] = ACTIONS(4304),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4306),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4308),
    [anon_sym_dynamic] = ACTIONS(4310),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [646] = {
    [sym_expression] = STATE(6435),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4312),
    [anon_sym_QMARK] = ACTIONS(4314),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4316),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4318),
    [anon_sym_dynamic] = ACTIONS(4320),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [647] = {
    [sym_expression] = STATE(6494),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4322),
    [anon_sym_QMARK] = ACTIONS(4324),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4326),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4328),
    [anon_sym_dynamic] = ACTIONS(4330),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [648] = {
    [sym_expression] = STATE(6393),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4332),
    [anon_sym_QMARK] = ACTIONS(4334),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4336),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4338),
    [anon_sym_dynamic] = ACTIONS(4340),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [649] = {
    [sym_expression] = STATE(6462),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4342),
    [anon_sym_QMARK] = ACTIONS(4344),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4346),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4348),
    [anon_sym_dynamic] = ACTIONS(4350),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [650] = {
    [sym_expression] = STATE(6478),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4352),
    [anon_sym_QMARK] = ACTIONS(4354),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4356),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4358),
    [anon_sym_dynamic] = ACTIONS(4360),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [651] = {
    [sym_expression] = STATE(6239),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4362),
    [anon_sym_QMARK] = ACTIONS(4364),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4366),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4368),
    [anon_sym_dynamic] = ACTIONS(4370),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [652] = {
    [sym_expression] = STATE(6270),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4372),
    [anon_sym_QMARK] = ACTIONS(4374),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4376),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4378),
    [anon_sym_dynamic] = ACTIONS(4380),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [653] = {
    [sym_expression] = STATE(6315),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4382),
    [anon_sym_QMARK] = ACTIONS(4384),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4386),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4388),
    [anon_sym_dynamic] = ACTIONS(4390),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [654] = {
    [sym_expression] = STATE(6467),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4392),
    [anon_sym_QMARK] = ACTIONS(4394),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4396),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4398),
    [anon_sym_dynamic] = ACTIONS(4400),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [655] = {
    [sym_expression] = STATE(6362),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4402),
    [anon_sym_QMARK] = ACTIONS(4404),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4406),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4408),
    [anon_sym_dynamic] = ACTIONS(4410),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [656] = {
    [sym_expression] = STATE(6529),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4412),
    [anon_sym_QMARK] = ACTIONS(4414),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4416),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4418),
    [anon_sym_dynamic] = ACTIONS(4420),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [657] = {
    [sym_expression] = STATE(6538),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4412),
    [anon_sym_QMARK] = ACTIONS(4422),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4424),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4426),
    [anon_sym_dynamic] = ACTIONS(4428),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [658] = {
    [sym_expression] = STATE(6578),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4430),
    [anon_sym_QMARK] = ACTIONS(4432),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4434),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4436),
    [anon_sym_dynamic] = ACTIONS(4438),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [659] = {
    [sym_expression] = STATE(6602),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4440),
    [anon_sym_QMARK] = ACTIONS(4442),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4444),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4446),
    [anon_sym_dynamic] = ACTIONS(4448),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [660] = {
    [ts_builtin_sym_end] = ACTIONS(4450),
    [sym_identifier] = ACTIONS(4452),
    [anon_sym_LBRACE] = ACTIONS(4450),
    [anon_sym_RBRACE] = ACTIONS(4450),
    [anon_sym_COMMA] = ACTIONS(4450),
    [anon_sym_COLON_COLON] = ACTIONS(4450),
    [anon_sym_DASH_GT] = ACTIONS(4450),
    [anon_sym_where] = ACTIONS(4454),
    [anon_sym_EQ] = ACTIONS(4454),
    [anon_sym_COLON] = ACTIONS(4454),
    [anon_sym_PIPE] = ACTIONS(4454),
    [anon_sym_COLON_EQ] = ACTIONS(4450),
    [anon_sym_LPAREN] = ACTIONS(4450),
    [anon_sym_PLUS_EQ] = ACTIONS(4450),
    [anon_sym_DASH_EQ] = ACTIONS(4450),
    [anon_sym_STAR_EQ] = ACTIONS(4450),
    [anon_sym_SLASH_EQ] = ACTIONS(4450),
    [anon_sym_PERCENT_EQ] = ACTIONS(4450),
    [anon_sym_AMP_EQ] = ACTIONS(4450),
    [anon_sym_PIPE_EQ] = ACTIONS(4450),
    [anon_sym_CARET_EQ] = ACTIONS(4450),
    [anon_sym_LT_LT_EQ] = ACTIONS(4450),
    [anon_sym_GT_GT_EQ] = ACTIONS(4450),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4450),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4450),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4450),
    [anon_sym_if] = ACTIONS(4454),
    [anon_sym_SEMI] = ACTIONS(4450),
    [anon_sym_else] = ACTIONS(4454),
    [anon_sym_when] = ACTIONS(4454),
    [anon_sym_in] = ACTIONS(4454),
    [anon_sym_case] = ACTIONS(4454),
    [anon_sym_QMARK] = ACTIONS(4450),
    [anon_sym_PLUS] = ACTIONS(4454),
    [anon_sym_DASH] = ACTIONS(4454),
    [anon_sym_TILDE] = ACTIONS(4454),
    [anon_sym_AMP] = ACTIONS(4454),
    [anon_sym_PIPE_PIPE] = ACTIONS(4454),
    [anon_sym_or_else] = ACTIONS(4454),
    [anon_sym_AMP_AMP] = ACTIONS(4454),
    [anon_sym_GT] = ACTIONS(4454),
    [anon_sym_GT_EQ] = ACTIONS(4450),
    [anon_sym_LT_EQ] = ACTIONS(4450),
    [anon_sym_LT] = ACTIONS(4454),
    [anon_sym_EQ_EQ] = ACTIONS(4450),
    [anon_sym_BANG_EQ] = ACTIONS(4450),
    [anon_sym_TILDE_EQ] = ACTIONS(4450),
    [anon_sym_AMP_TILDE] = ACTIONS(4454),
    [anon_sym_LT_LT] = ACTIONS(4454),
    [anon_sym_GT_GT] = ACTIONS(4454),
    [anon_sym_STAR] = ACTIONS(4454),
    [anon_sym_SLASH] = ACTIONS(4454),
    [anon_sym_PERCENT] = ACTIONS(4454),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4450),
    [anon_sym_DOT] = ACTIONS(4454),
    [anon_sym_LBRACK] = ACTIONS(4450),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4450),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4450),
    [anon_sym_not_in] = ACTIONS(4454),
    [anon_sym_or_return] = ACTIONS(4454),
    [anon_sym_or_continue] = ACTIONS(4454),
    [anon_sym_or_break] = ACTIONS(4454),
    [anon_sym_CARET] = ACTIONS(4454),
    [sym_uninitialized] = ACTIONS(4450),
    [sym_tag] = ACTIONS(4450),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4450),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [661] = {
    [aux_sym_where_clause_repeat1] = STATE(664),
    [ts_builtin_sym_end] = ACTIONS(4456),
    [anon_sym_LBRACE] = ACTIONS(4456),
    [anon_sym_RBRACE] = ACTIONS(4456),
    [anon_sym_COMMA] = ACTIONS(4458),
    [anon_sym_COLON_COLON] = ACTIONS(4456),
    [anon_sym_DASH_GT] = ACTIONS(4456),
    [anon_sym_where] = ACTIONS(4456),
    [anon_sym_EQ] = ACTIONS(4460),
    [anon_sym_COLON] = ACTIONS(4460),
    [anon_sym_PIPE] = ACTIONS(4460),
    [anon_sym_COLON_EQ] = ACTIONS(4456),
    [anon_sym_LPAREN] = ACTIONS(4456),
    [anon_sym_PLUS_EQ] = ACTIONS(4456),
    [anon_sym_DASH_EQ] = ACTIONS(4456),
    [anon_sym_STAR_EQ] = ACTIONS(4456),
    [anon_sym_SLASH_EQ] = ACTIONS(4456),
    [anon_sym_PERCENT_EQ] = ACTIONS(4456),
    [anon_sym_AMP_EQ] = ACTIONS(4456),
    [anon_sym_PIPE_EQ] = ACTIONS(4456),
    [anon_sym_CARET_EQ] = ACTIONS(4456),
    [anon_sym_LT_LT_EQ] = ACTIONS(4456),
    [anon_sym_GT_GT_EQ] = ACTIONS(4456),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4456),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4456),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4456),
    [anon_sym_if] = ACTIONS(4456),
    [anon_sym_SEMI] = ACTIONS(4456),
    [anon_sym_else] = ACTIONS(4456),
    [anon_sym_when] = ACTIONS(4456),
    [anon_sym_in] = ACTIONS(4456),
    [anon_sym_case] = ACTIONS(4456),
    [anon_sym_QMARK] = ACTIONS(4456),
    [anon_sym_PLUS] = ACTIONS(4460),
    [anon_sym_DASH] = ACTIONS(4460),
    [anon_sym_TILDE] = ACTIONS(4460),
    [anon_sym_AMP] = ACTIONS(4460),
    [anon_sym_PIPE_PIPE] = ACTIONS(4460),
    [anon_sym_or_else] = ACTIONS(4456),
    [anon_sym_AMP_AMP] = ACTIONS(4460),
    [anon_sym_GT] = ACTIONS(4460),
    [anon_sym_GT_EQ] = ACTIONS(4456),
    [anon_sym_LT_EQ] = ACTIONS(4456),
    [anon_sym_LT] = ACTIONS(4460),
    [anon_sym_EQ_EQ] = ACTIONS(4456),
    [anon_sym_BANG_EQ] = ACTIONS(4456),
    [anon_sym_TILDE_EQ] = ACTIONS(4456),
    [anon_sym_AMP_TILDE] = ACTIONS(4460),
    [anon_sym_LT_LT] = ACTIONS(4460),
    [anon_sym_GT_GT] = ACTIONS(4460),
    [anon_sym_STAR] = ACTIONS(4460),
    [anon_sym_SLASH] = ACTIONS(4460),
    [anon_sym_PERCENT] = ACTIONS(4460),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4456),
    [anon_sym_DOT] = ACTIONS(4460),
    [anon_sym_LBRACK] = ACTIONS(4456),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4456),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4456),
    [anon_sym_not_in] = ACTIONS(4456),
    [anon_sym_or_return] = ACTIONS(4456),
    [anon_sym_or_continue] = ACTIONS(4456),
    [anon_sym_or_break] = ACTIONS(4456),
    [anon_sym_CARET] = ACTIONS(4460),
    [sym_uninitialized] = ACTIONS(4456),
    [sym_tag] = ACTIONS(4456),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4456),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [662] = {
    [aux_sym_struct_type_repeat2] = STATE(584),
    [ts_builtin_sym_end] = ACTIONS(4462),
    [anon_sym_LBRACE] = ACTIONS(4462),
    [anon_sym_RBRACE] = ACTIONS(4462),
    [anon_sym_COMMA] = ACTIONS(4462),
    [anon_sym_COLON_COLON] = ACTIONS(4462),
    [anon_sym_DASH_GT] = ACTIONS(4462),
    [anon_sym_where] = ACTIONS(4462),
    [anon_sym_EQ] = ACTIONS(4464),
    [anon_sym_COLON] = ACTIONS(4464),
    [anon_sym_PIPE] = ACTIONS(4464),
    [anon_sym_COLON_EQ] = ACTIONS(4462),
    [anon_sym_LPAREN] = ACTIONS(4462),
    [anon_sym_PLUS_EQ] = ACTIONS(4462),
    [anon_sym_DASH_EQ] = ACTIONS(4462),
    [anon_sym_STAR_EQ] = ACTIONS(4462),
    [anon_sym_SLASH_EQ] = ACTIONS(4462),
    [anon_sym_PERCENT_EQ] = ACTIONS(4462),
    [anon_sym_AMP_EQ] = ACTIONS(4462),
    [anon_sym_PIPE_EQ] = ACTIONS(4462),
    [anon_sym_CARET_EQ] = ACTIONS(4462),
    [anon_sym_LT_LT_EQ] = ACTIONS(4462),
    [anon_sym_GT_GT_EQ] = ACTIONS(4462),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4462),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4462),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4462),
    [anon_sym_if] = ACTIONS(4462),
    [anon_sym_SEMI] = ACTIONS(4462),
    [anon_sym_else] = ACTIONS(4462),
    [anon_sym_when] = ACTIONS(4462),
    [anon_sym_in] = ACTIONS(4462),
    [anon_sym_case] = ACTIONS(4462),
    [anon_sym_QMARK] = ACTIONS(4462),
    [anon_sym_PLUS] = ACTIONS(4464),
    [anon_sym_DASH] = ACTIONS(4464),
    [anon_sym_TILDE] = ACTIONS(4464),
    [anon_sym_AMP] = ACTIONS(4464),
    [anon_sym_PIPE_PIPE] = ACTIONS(4464),
    [anon_sym_or_else] = ACTIONS(4462),
    [anon_sym_AMP_AMP] = ACTIONS(4464),
    [anon_sym_GT] = ACTIONS(4464),
    [anon_sym_GT_EQ] = ACTIONS(4462),
    [anon_sym_LT_EQ] = ACTIONS(4462),
    [anon_sym_LT] = ACTIONS(4464),
    [anon_sym_EQ_EQ] = ACTIONS(4462),
    [anon_sym_BANG_EQ] = ACTIONS(4462),
    [anon_sym_TILDE_EQ] = ACTIONS(4462),
    [anon_sym_AMP_TILDE] = ACTIONS(4464),
    [anon_sym_LT_LT] = ACTIONS(4464),
    [anon_sym_GT_GT] = ACTIONS(4464),
    [anon_sym_STAR] = ACTIONS(4464),
    [anon_sym_SLASH] = ACTIONS(4464),
    [anon_sym_PERCENT] = ACTIONS(4464),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4462),
    [anon_sym_DOT] = ACTIONS(4464),
    [anon_sym_LBRACK] = ACTIONS(4462),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4462),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4462),
    [anon_sym_not_in] = ACTIONS(4462),
    [anon_sym_or_return] = ACTIONS(4462),
    [anon_sym_or_continue] = ACTIONS(4462),
    [anon_sym_or_break] = ACTIONS(4462),
    [anon_sym_CARET] = ACTIONS(4464),
    [sym_uninitialized] = ACTIONS(4462),
    [sym_tag] = ACTIONS(4462),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4462),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [663] = {
    [sym_block] = STATE(786),
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3451),
    [anon_sym_where] = ACTIONS(3451),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(3457),
    [sym_tag] = ACTIONS(3451),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [664] = {
    [aux_sym_where_clause_repeat1] = STATE(664),
    [ts_builtin_sym_end] = ACTIONS(4466),
    [anon_sym_LBRACE] = ACTIONS(4466),
    [anon_sym_RBRACE] = ACTIONS(4466),
    [anon_sym_COMMA] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(4466),
    [anon_sym_DASH_GT] = ACTIONS(4466),
    [anon_sym_where] = ACTIONS(4466),
    [anon_sym_EQ] = ACTIONS(4471),
    [anon_sym_COLON] = ACTIONS(4471),
    [anon_sym_PIPE] = ACTIONS(4471),
    [anon_sym_COLON_EQ] = ACTIONS(4466),
    [anon_sym_LPAREN] = ACTIONS(4466),
    [anon_sym_PLUS_EQ] = ACTIONS(4466),
    [anon_sym_DASH_EQ] = ACTIONS(4466),
    [anon_sym_STAR_EQ] = ACTIONS(4466),
    [anon_sym_SLASH_EQ] = ACTIONS(4466),
    [anon_sym_PERCENT_EQ] = ACTIONS(4466),
    [anon_sym_AMP_EQ] = ACTIONS(4466),
    [anon_sym_PIPE_EQ] = ACTIONS(4466),
    [anon_sym_CARET_EQ] = ACTIONS(4466),
    [anon_sym_LT_LT_EQ] = ACTIONS(4466),
    [anon_sym_GT_GT_EQ] = ACTIONS(4466),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4466),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4466),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4466),
    [anon_sym_if] = ACTIONS(4466),
    [anon_sym_SEMI] = ACTIONS(4466),
    [anon_sym_else] = ACTIONS(4466),
    [anon_sym_when] = ACTIONS(4466),
    [anon_sym_in] = ACTIONS(4466),
    [anon_sym_case] = ACTIONS(4466),
    [anon_sym_QMARK] = ACTIONS(4466),
    [anon_sym_PLUS] = ACTIONS(4471),
    [anon_sym_DASH] = ACTIONS(4471),
    [anon_sym_TILDE] = ACTIONS(4471),
    [anon_sym_AMP] = ACTIONS(4471),
    [anon_sym_PIPE_PIPE] = ACTIONS(4471),
    [anon_sym_or_else] = ACTIONS(4466),
    [anon_sym_AMP_AMP] = ACTIONS(4471),
    [anon_sym_GT] = ACTIONS(4471),
    [anon_sym_GT_EQ] = ACTIONS(4466),
    [anon_sym_LT_EQ] = ACTIONS(4466),
    [anon_sym_LT] = ACTIONS(4471),
    [anon_sym_EQ_EQ] = ACTIONS(4466),
    [anon_sym_BANG_EQ] = ACTIONS(4466),
    [anon_sym_TILDE_EQ] = ACTIONS(4466),
    [anon_sym_AMP_TILDE] = ACTIONS(4471),
    [anon_sym_LT_LT] = ACTIONS(4471),
    [anon_sym_GT_GT] = ACTIONS(4471),
    [anon_sym_STAR] = ACTIONS(4471),
    [anon_sym_SLASH] = ACTIONS(4471),
    [anon_sym_PERCENT] = ACTIONS(4471),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4466),
    [anon_sym_DOT] = ACTIONS(4471),
    [anon_sym_LBRACK] = ACTIONS(4466),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4466),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4466),
    [anon_sym_not_in] = ACTIONS(4466),
    [anon_sym_or_return] = ACTIONS(4466),
    [anon_sym_or_continue] = ACTIONS(4466),
    [anon_sym_or_break] = ACTIONS(4466),
    [anon_sym_CARET] = ACTIONS(4471),
    [sym_uninitialized] = ACTIONS(4466),
    [sym_tag] = ACTIONS(4466),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4466),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [665] = {
    [sym_block] = STATE(786),
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3451),
    [anon_sym_where] = ACTIONS(3451),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(3457),
    [sym_tag] = ACTIONS(3459),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [666] = {
    [sym_block] = STATE(790),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3425),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3465),
    [sym_tag] = ACTIONS(3425),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [667] = {
    [sym_block] = STATE(790),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3425),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3465),
    [sym_tag] = ACTIONS(4473),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [668] = {
    [sym_block] = STATE(793),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3368),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3477),
    [sym_tag] = ACTIONS(3368),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [669] = {
    [sym_block] = STATE(793),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3368),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3477),
    [sym_tag] = ACTIONS(3491),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [670] = {
    [aux_sym_struct_type_repeat2] = STATE(584),
    [ts_builtin_sym_end] = ACTIONS(4475),
    [anon_sym_LBRACE] = ACTIONS(4475),
    [anon_sym_RBRACE] = ACTIONS(4475),
    [anon_sym_COMMA] = ACTIONS(4475),
    [anon_sym_COLON_COLON] = ACTIONS(4475),
    [anon_sym_DASH_GT] = ACTIONS(4475),
    [anon_sym_where] = ACTIONS(4475),
    [anon_sym_EQ] = ACTIONS(4477),
    [anon_sym_COLON] = ACTIONS(4477),
    [anon_sym_PIPE] = ACTIONS(4477),
    [anon_sym_COLON_EQ] = ACTIONS(4475),
    [anon_sym_LPAREN] = ACTIONS(4475),
    [anon_sym_PLUS_EQ] = ACTIONS(4475),
    [anon_sym_DASH_EQ] = ACTIONS(4475),
    [anon_sym_STAR_EQ] = ACTIONS(4475),
    [anon_sym_SLASH_EQ] = ACTIONS(4475),
    [anon_sym_PERCENT_EQ] = ACTIONS(4475),
    [anon_sym_AMP_EQ] = ACTIONS(4475),
    [anon_sym_PIPE_EQ] = ACTIONS(4475),
    [anon_sym_CARET_EQ] = ACTIONS(4475),
    [anon_sym_LT_LT_EQ] = ACTIONS(4475),
    [anon_sym_GT_GT_EQ] = ACTIONS(4475),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4475),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4475),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4475),
    [anon_sym_if] = ACTIONS(4475),
    [anon_sym_SEMI] = ACTIONS(4475),
    [anon_sym_else] = ACTIONS(4475),
    [anon_sym_when] = ACTIONS(4475),
    [anon_sym_in] = ACTIONS(4475),
    [anon_sym_case] = ACTIONS(4475),
    [anon_sym_QMARK] = ACTIONS(4475),
    [anon_sym_PLUS] = ACTIONS(4477),
    [anon_sym_DASH] = ACTIONS(4477),
    [anon_sym_TILDE] = ACTIONS(4477),
    [anon_sym_AMP] = ACTIONS(4477),
    [anon_sym_PIPE_PIPE] = ACTIONS(4477),
    [anon_sym_or_else] = ACTIONS(4475),
    [anon_sym_AMP_AMP] = ACTIONS(4477),
    [anon_sym_GT] = ACTIONS(4477),
    [anon_sym_GT_EQ] = ACTIONS(4475),
    [anon_sym_LT_EQ] = ACTIONS(4475),
    [anon_sym_LT] = ACTIONS(4477),
    [anon_sym_EQ_EQ] = ACTIONS(4475),
    [anon_sym_BANG_EQ] = ACTIONS(4475),
    [anon_sym_TILDE_EQ] = ACTIONS(4475),
    [anon_sym_AMP_TILDE] = ACTIONS(4477),
    [anon_sym_LT_LT] = ACTIONS(4477),
    [anon_sym_GT_GT] = ACTIONS(4477),
    [anon_sym_STAR] = ACTIONS(4477),
    [anon_sym_SLASH] = ACTIONS(4477),
    [anon_sym_PERCENT] = ACTIONS(4477),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4475),
    [anon_sym_DOT] = ACTIONS(4477),
    [anon_sym_LBRACK] = ACTIONS(4475),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4475),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4475),
    [anon_sym_not_in] = ACTIONS(4475),
    [anon_sym_or_return] = ACTIONS(4475),
    [anon_sym_or_continue] = ACTIONS(4475),
    [anon_sym_or_break] = ACTIONS(4475),
    [anon_sym_CARET] = ACTIONS(4477),
    [sym_uninitialized] = ACTIONS(4475),
    [sym_tag] = ACTIONS(4475),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4475),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [671] = {
    [sym_block] = STATE(794),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3384),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3493),
    [sym_tag] = ACTIONS(3497),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [672] = {
    [sym_block] = STATE(794),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3384),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3493),
    [sym_tag] = ACTIONS(3384),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [673] = {
    [aux_sym_where_clause_repeat1] = STATE(661),
    [ts_builtin_sym_end] = ACTIONS(4479),
    [anon_sym_LBRACE] = ACTIONS(4479),
    [anon_sym_RBRACE] = ACTIONS(4479),
    [anon_sym_COMMA] = ACTIONS(4458),
    [anon_sym_COLON_COLON] = ACTIONS(4479),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4479),
    [anon_sym_EQ] = ACTIONS(4483),
    [anon_sym_COLON] = ACTIONS(4483),
    [anon_sym_PIPE] = ACTIONS(4485),
    [anon_sym_COLON_EQ] = ACTIONS(4479),
    [anon_sym_LPAREN] = ACTIONS(4479),
    [anon_sym_PLUS_EQ] = ACTIONS(4479),
    [anon_sym_DASH_EQ] = ACTIONS(4479),
    [anon_sym_STAR_EQ] = ACTIONS(4479),
    [anon_sym_SLASH_EQ] = ACTIONS(4479),
    [anon_sym_PERCENT_EQ] = ACTIONS(4479),
    [anon_sym_AMP_EQ] = ACTIONS(4479),
    [anon_sym_PIPE_EQ] = ACTIONS(4479),
    [anon_sym_CARET_EQ] = ACTIONS(4479),
    [anon_sym_LT_LT_EQ] = ACTIONS(4479),
    [anon_sym_GT_GT_EQ] = ACTIONS(4479),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4479),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4479),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4479),
    [anon_sym_if] = ACTIONS(4479),
    [anon_sym_SEMI] = ACTIONS(4479),
    [anon_sym_else] = ACTIONS(4479),
    [anon_sym_when] = ACTIONS(4479),
    [anon_sym_in] = ACTIONS(4479),
    [anon_sym_case] = ACTIONS(4479),
    [anon_sym_QMARK] = ACTIONS(4479),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4493),
    [anon_sym_or_else] = ACTIONS(4495),
    [anon_sym_AMP_AMP] = ACTIONS(4497),
    [anon_sym_GT] = ACTIONS(4499),
    [anon_sym_GT_EQ] = ACTIONS(4501),
    [anon_sym_LT_EQ] = ACTIONS(4501),
    [anon_sym_LT] = ACTIONS(4499),
    [anon_sym_EQ_EQ] = ACTIONS(4503),
    [anon_sym_BANG_EQ] = ACTIONS(4503),
    [anon_sym_TILDE_EQ] = ACTIONS(4503),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4479),
    [anon_sym_or_return] = ACTIONS(4519),
    [anon_sym_or_continue] = ACTIONS(4521),
    [anon_sym_or_break] = ACTIONS(4523),
    [anon_sym_CARET] = ACTIONS(4525),
    [sym_uninitialized] = ACTIONS(4479),
    [sym_tag] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4479),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [674] = {
    [ts_builtin_sym_end] = ACTIONS(3408),
    [anon_sym_LBRACE] = ACTIONS(3408),
    [anon_sym_RBRACE] = ACTIONS(3408),
    [anon_sym_COMMA] = ACTIONS(3408),
    [anon_sym_COLON_COLON] = ACTIONS(3408),
    [anon_sym_DASH_GT] = ACTIONS(3408),
    [anon_sym_where] = ACTIONS(3408),
    [anon_sym_EQ] = ACTIONS(3410),
    [anon_sym_COLON] = ACTIONS(3410),
    [anon_sym_PIPE] = ACTIONS(3410),
    [anon_sym_COLON_EQ] = ACTIONS(3408),
    [anon_sym_LPAREN] = ACTIONS(3408),
    [anon_sym_PLUS_EQ] = ACTIONS(3408),
    [anon_sym_DASH_EQ] = ACTIONS(3408),
    [anon_sym_STAR_EQ] = ACTIONS(3408),
    [anon_sym_SLASH_EQ] = ACTIONS(3408),
    [anon_sym_PERCENT_EQ] = ACTIONS(3408),
    [anon_sym_AMP_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_CARET_EQ] = ACTIONS(3408),
    [anon_sym_LT_LT_EQ] = ACTIONS(3408),
    [anon_sym_GT_GT_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_if] = ACTIONS(3408),
    [anon_sym_SEMI] = ACTIONS(3408),
    [anon_sym_else] = ACTIONS(3408),
    [anon_sym_when] = ACTIONS(3408),
    [anon_sym_in] = ACTIONS(3408),
    [anon_sym_case] = ACTIONS(3408),
    [anon_sym_QMARK] = ACTIONS(3408),
    [anon_sym_PLUS] = ACTIONS(3410),
    [anon_sym_DASH] = ACTIONS(3410),
    [anon_sym_TILDE] = ACTIONS(3410),
    [anon_sym_AMP] = ACTIONS(3410),
    [anon_sym_PIPE_PIPE] = ACTIONS(3410),
    [anon_sym_or_else] = ACTIONS(3408),
    [anon_sym_AMP_AMP] = ACTIONS(3410),
    [anon_sym_GT] = ACTIONS(3410),
    [anon_sym_GT_EQ] = ACTIONS(3408),
    [anon_sym_LT_EQ] = ACTIONS(3408),
    [anon_sym_LT] = ACTIONS(3410),
    [anon_sym_EQ_EQ] = ACTIONS(3408),
    [anon_sym_BANG_EQ] = ACTIONS(3408),
    [anon_sym_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE] = ACTIONS(3410),
    [anon_sym_LT_LT] = ACTIONS(3410),
    [anon_sym_GT_GT] = ACTIONS(3410),
    [anon_sym_STAR] = ACTIONS(3410),
    [anon_sym_SLASH] = ACTIONS(3410),
    [anon_sym_PERCENT] = ACTIONS(3410),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3408),
    [anon_sym_DOT] = ACTIONS(3410),
    [anon_sym_LBRACK] = ACTIONS(3408),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3408),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3408),
    [anon_sym_not_in] = ACTIONS(3408),
    [anon_sym_or_return] = ACTIONS(3408),
    [anon_sym_or_continue] = ACTIONS(3408),
    [anon_sym_or_break] = ACTIONS(3408),
    [anon_sym_CARET] = ACTIONS(3410),
    [anon_sym_DOT2] = ACTIONS(3410),
    [sym_uninitialized] = ACTIONS(3408),
    [sym_tag] = ACTIONS(3408),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3408),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [675] = {
    [sym_block] = STATE(796),
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_where] = ACTIONS(3400),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(3505),
    [sym_tag] = ACTIONS(3507),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [676] = {
    [sym_expression] = STATE(6231),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4527),
    [anon_sym_QMARK] = ACTIONS(4529),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4531),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4533),
    [anon_sym_dynamic] = ACTIONS(4535),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [677] = {
    [sym_expression] = STATE(6524),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4537),
    [anon_sym_QMARK] = ACTIONS(4539),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4541),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4543),
    [anon_sym_dynamic] = ACTIONS(4545),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [678] = {
    [sym_expression] = STATE(6326),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4547),
    [anon_sym_QMARK] = ACTIONS(4549),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4551),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4553),
    [anon_sym_dynamic] = ACTIONS(4555),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [679] = {
    [sym_expression] = STATE(6430),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4557),
    [anon_sym_QMARK] = ACTIONS(4559),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4561),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4563),
    [anon_sym_dynamic] = ACTIONS(4565),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [680] = {
    [sym_expression] = STATE(6450),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4567),
    [anon_sym_QMARK] = ACTIONS(4569),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4571),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4573),
    [anon_sym_dynamic] = ACTIONS(4575),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [681] = {
    [sym_block] = STATE(796),
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_where] = ACTIONS(3400),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(3505),
    [sym_tag] = ACTIONS(3400),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [682] = {
    [sym_block] = STATE(798),
    [ts_builtin_sym_end] = ACTIONS(4577),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(4577),
    [anon_sym_COMMA] = ACTIONS(4577),
    [anon_sym_COLON_COLON] = ACTIONS(4577),
    [anon_sym_DASH_GT] = ACTIONS(4577),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_EQ] = ACTIONS(4579),
    [anon_sym_COLON] = ACTIONS(4579),
    [anon_sym_PIPE] = ACTIONS(4579),
    [anon_sym_COLON_EQ] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4577),
    [anon_sym_PLUS_EQ] = ACTIONS(4577),
    [anon_sym_DASH_EQ] = ACTIONS(4577),
    [anon_sym_STAR_EQ] = ACTIONS(4577),
    [anon_sym_SLASH_EQ] = ACTIONS(4577),
    [anon_sym_PERCENT_EQ] = ACTIONS(4577),
    [anon_sym_AMP_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_CARET_EQ] = ACTIONS(4577),
    [anon_sym_LT_LT_EQ] = ACTIONS(4577),
    [anon_sym_GT_GT_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_when] = ACTIONS(4577),
    [anon_sym_in] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [anon_sym_TILDE] = ACTIONS(4579),
    [anon_sym_AMP] = ACTIONS(4579),
    [anon_sym_PIPE_PIPE] = ACTIONS(4579),
    [anon_sym_or_else] = ACTIONS(4577),
    [anon_sym_AMP_AMP] = ACTIONS(4579),
    [anon_sym_GT] = ACTIONS(4579),
    [anon_sym_GT_EQ] = ACTIONS(4577),
    [anon_sym_LT_EQ] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4579),
    [anon_sym_EQ_EQ] = ACTIONS(4577),
    [anon_sym_BANG_EQ] = ACTIONS(4577),
    [anon_sym_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE] = ACTIONS(4579),
    [anon_sym_LT_LT] = ACTIONS(4579),
    [anon_sym_GT_GT] = ACTIONS(4579),
    [anon_sym_STAR] = ACTIONS(4579),
    [anon_sym_SLASH] = ACTIONS(4579),
    [anon_sym_PERCENT] = ACTIONS(4579),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4577),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4577),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4577),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4577),
    [anon_sym_not_in] = ACTIONS(4577),
    [anon_sym_or_return] = ACTIONS(4577),
    [anon_sym_or_continue] = ACTIONS(4577),
    [anon_sym_or_break] = ACTIONS(4577),
    [anon_sym_CARET] = ACTIONS(4579),
    [sym_uninitialized] = ACTIONS(4581),
    [sym_tag] = ACTIONS(4577),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4577),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [683] = {
    [sym_block] = STATE(798),
    [ts_builtin_sym_end] = ACTIONS(4577),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(4577),
    [anon_sym_COMMA] = ACTIONS(4577),
    [anon_sym_COLON_COLON] = ACTIONS(4577),
    [anon_sym_DASH_GT] = ACTIONS(4577),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_EQ] = ACTIONS(4579),
    [anon_sym_COLON] = ACTIONS(4579),
    [anon_sym_PIPE] = ACTIONS(4579),
    [anon_sym_COLON_EQ] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4577),
    [anon_sym_PLUS_EQ] = ACTIONS(4577),
    [anon_sym_DASH_EQ] = ACTIONS(4577),
    [anon_sym_STAR_EQ] = ACTIONS(4577),
    [anon_sym_SLASH_EQ] = ACTIONS(4577),
    [anon_sym_PERCENT_EQ] = ACTIONS(4577),
    [anon_sym_AMP_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_CARET_EQ] = ACTIONS(4577),
    [anon_sym_LT_LT_EQ] = ACTIONS(4577),
    [anon_sym_GT_GT_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_when] = ACTIONS(4577),
    [anon_sym_in] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [anon_sym_TILDE] = ACTIONS(4579),
    [anon_sym_AMP] = ACTIONS(4579),
    [anon_sym_PIPE_PIPE] = ACTIONS(4579),
    [anon_sym_or_else] = ACTIONS(4577),
    [anon_sym_AMP_AMP] = ACTIONS(4579),
    [anon_sym_GT] = ACTIONS(4579),
    [anon_sym_GT_EQ] = ACTIONS(4577),
    [anon_sym_LT_EQ] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4579),
    [anon_sym_EQ_EQ] = ACTIONS(4577),
    [anon_sym_BANG_EQ] = ACTIONS(4577),
    [anon_sym_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE] = ACTIONS(4579),
    [anon_sym_LT_LT] = ACTIONS(4579),
    [anon_sym_GT_GT] = ACTIONS(4579),
    [anon_sym_STAR] = ACTIONS(4579),
    [anon_sym_SLASH] = ACTIONS(4579),
    [anon_sym_PERCENT] = ACTIONS(4579),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4577),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4577),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4577),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4577),
    [anon_sym_not_in] = ACTIONS(4577),
    [anon_sym_or_return] = ACTIONS(4577),
    [anon_sym_or_continue] = ACTIONS(4577),
    [anon_sym_or_break] = ACTIONS(4577),
    [anon_sym_CARET] = ACTIONS(4579),
    [sym_uninitialized] = ACTIONS(4581),
    [sym_tag] = ACTIONS(4583),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4577),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [684] = {
    [sym_block] = STATE(799),
    [ts_builtin_sym_end] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_COLON_COLON] = ACTIONS(4585),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_where] = ACTIONS(4585),
    [anon_sym_EQ] = ACTIONS(4587),
    [anon_sym_COLON] = ACTIONS(4587),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_COLON_EQ] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_PLUS_EQ] = ACTIONS(4585),
    [anon_sym_DASH_EQ] = ACTIONS(4585),
    [anon_sym_STAR_EQ] = ACTIONS(4585),
    [anon_sym_SLASH_EQ] = ACTIONS(4585),
    [anon_sym_PERCENT_EQ] = ACTIONS(4585),
    [anon_sym_AMP_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_CARET_EQ] = ACTIONS(4585),
    [anon_sym_LT_LT_EQ] = ACTIONS(4585),
    [anon_sym_GT_GT_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_if] = ACTIONS(4585),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_else] = ACTIONS(4585),
    [anon_sym_when] = ACTIONS(4585),
    [anon_sym_in] = ACTIONS(4585),
    [anon_sym_case] = ACTIONS(4585),
    [anon_sym_QMARK] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_TILDE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_PIPE_PIPE] = ACTIONS(4587),
    [anon_sym_or_else] = ACTIONS(4585),
    [anon_sym_AMP_AMP] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4587),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4587),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4587),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4585),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4585),
    [anon_sym_not_in] = ACTIONS(4585),
    [anon_sym_or_return] = ACTIONS(4585),
    [anon_sym_or_continue] = ACTIONS(4585),
    [anon_sym_or_break] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4587),
    [sym_uninitialized] = ACTIONS(4589),
    [sym_tag] = ACTIONS(4585),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4585),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [685] = {
    [sym_expression] = STATE(6593),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4591),
    [anon_sym_QMARK] = ACTIONS(4593),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4595),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4597),
    [anon_sym_dynamic] = ACTIONS(4599),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [686] = {
    [sym_expression] = STATE(6250),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4601),
    [anon_sym_QMARK] = ACTIONS(4603),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4605),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4607),
    [anon_sym_dynamic] = ACTIONS(4609),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [687] = {
    [sym_expression] = STATE(6264),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4611),
    [anon_sym_QMARK] = ACTIONS(4613),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4615),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4617),
    [anon_sym_dynamic] = ACTIONS(4619),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [688] = {
    [sym_expression] = STATE(6597),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(4621),
    [anon_sym_QMARK] = ACTIONS(4623),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4625),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4627),
    [anon_sym_dynamic] = ACTIONS(4629),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [689] = {
    [ts_builtin_sym_end] = ACTIONS(4631),
    [anon_sym_LBRACE] = ACTIONS(4631),
    [anon_sym_RBRACE] = ACTIONS(4631),
    [anon_sym_COMMA] = ACTIONS(4631),
    [anon_sym_COLON_COLON] = ACTIONS(4631),
    [anon_sym_DASH_GT] = ACTIONS(4631),
    [anon_sym_where] = ACTIONS(4631),
    [anon_sym_EQ] = ACTIONS(4633),
    [anon_sym_COLON] = ACTIONS(4633),
    [anon_sym_PIPE] = ACTIONS(4633),
    [anon_sym_COLON_EQ] = ACTIONS(4631),
    [anon_sym_LPAREN] = ACTIONS(4631),
    [anon_sym_PLUS_EQ] = ACTIONS(4631),
    [anon_sym_DASH_EQ] = ACTIONS(4631),
    [anon_sym_STAR_EQ] = ACTIONS(4631),
    [anon_sym_SLASH_EQ] = ACTIONS(4631),
    [anon_sym_PERCENT_EQ] = ACTIONS(4631),
    [anon_sym_AMP_EQ] = ACTIONS(4631),
    [anon_sym_PIPE_EQ] = ACTIONS(4631),
    [anon_sym_CARET_EQ] = ACTIONS(4631),
    [anon_sym_LT_LT_EQ] = ACTIONS(4631),
    [anon_sym_GT_GT_EQ] = ACTIONS(4631),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4631),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4631),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4631),
    [anon_sym_if] = ACTIONS(4631),
    [anon_sym_SEMI] = ACTIONS(4631),
    [anon_sym_else] = ACTIONS(4631),
    [anon_sym_when] = ACTIONS(4631),
    [anon_sym_in] = ACTIONS(4631),
    [anon_sym_case] = ACTIONS(4631),
    [anon_sym_QMARK] = ACTIONS(4631),
    [anon_sym_PLUS] = ACTIONS(4633),
    [anon_sym_DASH] = ACTIONS(4633),
    [anon_sym_TILDE] = ACTIONS(4633),
    [anon_sym_AMP] = ACTIONS(4633),
    [anon_sym_PIPE_PIPE] = ACTIONS(4633),
    [anon_sym_or_else] = ACTIONS(4631),
    [anon_sym_AMP_AMP] = ACTIONS(4633),
    [anon_sym_GT] = ACTIONS(4633),
    [anon_sym_GT_EQ] = ACTIONS(4631),
    [anon_sym_LT_EQ] = ACTIONS(4631),
    [anon_sym_LT] = ACTIONS(4633),
    [anon_sym_EQ_EQ] = ACTIONS(4631),
    [anon_sym_BANG_EQ] = ACTIONS(4631),
    [anon_sym_TILDE_EQ] = ACTIONS(4631),
    [anon_sym_AMP_TILDE] = ACTIONS(4633),
    [anon_sym_LT_LT] = ACTIONS(4633),
    [anon_sym_GT_GT] = ACTIONS(4633),
    [anon_sym_STAR] = ACTIONS(4633),
    [anon_sym_SLASH] = ACTIONS(4633),
    [anon_sym_PERCENT] = ACTIONS(4633),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4631),
    [anon_sym_DOT] = ACTIONS(4633),
    [anon_sym_LBRACK] = ACTIONS(4631),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4631),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4631),
    [anon_sym_not_in] = ACTIONS(4631),
    [anon_sym_or_return] = ACTIONS(4631),
    [anon_sym_or_continue] = ACTIONS(4631),
    [anon_sym_or_break] = ACTIONS(4631),
    [anon_sym_CARET] = ACTIONS(4633),
    [sym_uninitialized] = ACTIONS(4631),
    [sym_tag] = ACTIONS(4631),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4631),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [690] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4637),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4637),
    [anon_sym_DASH] = ACTIONS(4637),
    [anon_sym_TILDE] = ACTIONS(4637),
    [anon_sym_AMP] = ACTIONS(4637),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4637),
    [anon_sym_GT] = ACTIONS(4637),
    [anon_sym_GT_EQ] = ACTIONS(4635),
    [anon_sym_LT_EQ] = ACTIONS(4635),
    [anon_sym_LT] = ACTIONS(4637),
    [anon_sym_EQ_EQ] = ACTIONS(4635),
    [anon_sym_BANG_EQ] = ACTIONS(4635),
    [anon_sym_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE] = ACTIONS(4637),
    [anon_sym_LT_LT] = ACTIONS(4637),
    [anon_sym_GT_GT] = ACTIONS(4637),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [691] = {
    [ts_builtin_sym_end] = ACTIONS(4639),
    [anon_sym_LBRACE] = ACTIONS(4639),
    [anon_sym_RBRACE] = ACTIONS(4639),
    [anon_sym_COMMA] = ACTIONS(4639),
    [anon_sym_COLON_COLON] = ACTIONS(4639),
    [anon_sym_DASH_GT] = ACTIONS(4639),
    [anon_sym_where] = ACTIONS(4639),
    [anon_sym_EQ] = ACTIONS(4641),
    [anon_sym_COLON] = ACTIONS(4641),
    [anon_sym_PIPE] = ACTIONS(4641),
    [anon_sym_COLON_EQ] = ACTIONS(4639),
    [anon_sym_LPAREN] = ACTIONS(4639),
    [anon_sym_PLUS_EQ] = ACTIONS(4639),
    [anon_sym_DASH_EQ] = ACTIONS(4639),
    [anon_sym_STAR_EQ] = ACTIONS(4639),
    [anon_sym_SLASH_EQ] = ACTIONS(4639),
    [anon_sym_PERCENT_EQ] = ACTIONS(4639),
    [anon_sym_AMP_EQ] = ACTIONS(4639),
    [anon_sym_PIPE_EQ] = ACTIONS(4639),
    [anon_sym_CARET_EQ] = ACTIONS(4639),
    [anon_sym_LT_LT_EQ] = ACTIONS(4639),
    [anon_sym_GT_GT_EQ] = ACTIONS(4639),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4639),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4639),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4639),
    [anon_sym_if] = ACTIONS(4639),
    [anon_sym_SEMI] = ACTIONS(4639),
    [anon_sym_else] = ACTIONS(4639),
    [anon_sym_when] = ACTIONS(4639),
    [anon_sym_in] = ACTIONS(4639),
    [anon_sym_case] = ACTIONS(4639),
    [anon_sym_QMARK] = ACTIONS(4639),
    [anon_sym_PLUS] = ACTIONS(4641),
    [anon_sym_DASH] = ACTIONS(4641),
    [anon_sym_TILDE] = ACTIONS(4641),
    [anon_sym_AMP] = ACTIONS(4641),
    [anon_sym_PIPE_PIPE] = ACTIONS(4641),
    [anon_sym_or_else] = ACTIONS(4639),
    [anon_sym_AMP_AMP] = ACTIONS(4641),
    [anon_sym_GT] = ACTIONS(4641),
    [anon_sym_GT_EQ] = ACTIONS(4639),
    [anon_sym_LT_EQ] = ACTIONS(4639),
    [anon_sym_LT] = ACTIONS(4641),
    [anon_sym_EQ_EQ] = ACTIONS(4639),
    [anon_sym_BANG_EQ] = ACTIONS(4639),
    [anon_sym_TILDE_EQ] = ACTIONS(4639),
    [anon_sym_AMP_TILDE] = ACTIONS(4641),
    [anon_sym_LT_LT] = ACTIONS(4641),
    [anon_sym_GT_GT] = ACTIONS(4641),
    [anon_sym_STAR] = ACTIONS(4641),
    [anon_sym_SLASH] = ACTIONS(4641),
    [anon_sym_PERCENT] = ACTIONS(4641),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4639),
    [anon_sym_DOT] = ACTIONS(4641),
    [anon_sym_LBRACK] = ACTIONS(4639),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4639),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4639),
    [anon_sym_not_in] = ACTIONS(4639),
    [anon_sym_or_return] = ACTIONS(4639),
    [anon_sym_or_continue] = ACTIONS(4639),
    [anon_sym_or_break] = ACTIONS(4639),
    [anon_sym_CARET] = ACTIONS(4641),
    [sym_uninitialized] = ACTIONS(4639),
    [sym_tag] = ACTIONS(4639),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4639),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [692] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4637),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4637),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4637),
    [anon_sym_GT] = ACTIONS(4637),
    [anon_sym_GT_EQ] = ACTIONS(4635),
    [anon_sym_LT_EQ] = ACTIONS(4635),
    [anon_sym_LT] = ACTIONS(4637),
    [anon_sym_EQ_EQ] = ACTIONS(4635),
    [anon_sym_BANG_EQ] = ACTIONS(4635),
    [anon_sym_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [693] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4637),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4637),
    [anon_sym_AMP] = ACTIONS(4637),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4637),
    [anon_sym_GT] = ACTIONS(4637),
    [anon_sym_GT_EQ] = ACTIONS(4635),
    [anon_sym_LT_EQ] = ACTIONS(4635),
    [anon_sym_LT] = ACTIONS(4637),
    [anon_sym_EQ_EQ] = ACTIONS(4635),
    [anon_sym_BANG_EQ] = ACTIONS(4635),
    [anon_sym_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [694] = {
    [ts_builtin_sym_end] = ACTIONS(4643),
    [anon_sym_LBRACE] = ACTIONS(4643),
    [anon_sym_RBRACE] = ACTIONS(4643),
    [anon_sym_COMMA] = ACTIONS(4643),
    [anon_sym_COLON_COLON] = ACTIONS(4643),
    [anon_sym_DASH_GT] = ACTIONS(4643),
    [anon_sym_where] = ACTIONS(4643),
    [anon_sym_EQ] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4645),
    [anon_sym_PIPE] = ACTIONS(4645),
    [anon_sym_COLON_EQ] = ACTIONS(4643),
    [anon_sym_LPAREN] = ACTIONS(4643),
    [anon_sym_PLUS_EQ] = ACTIONS(4643),
    [anon_sym_DASH_EQ] = ACTIONS(4643),
    [anon_sym_STAR_EQ] = ACTIONS(4643),
    [anon_sym_SLASH_EQ] = ACTIONS(4643),
    [anon_sym_PERCENT_EQ] = ACTIONS(4643),
    [anon_sym_AMP_EQ] = ACTIONS(4643),
    [anon_sym_PIPE_EQ] = ACTIONS(4643),
    [anon_sym_CARET_EQ] = ACTIONS(4643),
    [anon_sym_LT_LT_EQ] = ACTIONS(4643),
    [anon_sym_GT_GT_EQ] = ACTIONS(4643),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4643),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4643),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4643),
    [anon_sym_if] = ACTIONS(4643),
    [anon_sym_SEMI] = ACTIONS(4643),
    [anon_sym_else] = ACTIONS(4643),
    [anon_sym_when] = ACTIONS(4643),
    [anon_sym_in] = ACTIONS(4643),
    [anon_sym_case] = ACTIONS(4643),
    [anon_sym_QMARK] = ACTIONS(4643),
    [anon_sym_PLUS] = ACTIONS(4645),
    [anon_sym_DASH] = ACTIONS(4645),
    [anon_sym_TILDE] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_PIPE_PIPE] = ACTIONS(4645),
    [anon_sym_or_else] = ACTIONS(4643),
    [anon_sym_AMP_AMP] = ACTIONS(4645),
    [anon_sym_GT] = ACTIONS(4645),
    [anon_sym_GT_EQ] = ACTIONS(4643),
    [anon_sym_LT_EQ] = ACTIONS(4643),
    [anon_sym_LT] = ACTIONS(4645),
    [anon_sym_EQ_EQ] = ACTIONS(4643),
    [anon_sym_BANG_EQ] = ACTIONS(4643),
    [anon_sym_TILDE_EQ] = ACTIONS(4643),
    [anon_sym_AMP_TILDE] = ACTIONS(4645),
    [anon_sym_LT_LT] = ACTIONS(4645),
    [anon_sym_GT_GT] = ACTIONS(4645),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_SLASH] = ACTIONS(4645),
    [anon_sym_PERCENT] = ACTIONS(4645),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4643),
    [anon_sym_DOT] = ACTIONS(4645),
    [anon_sym_LBRACK] = ACTIONS(4643),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4643),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4643),
    [anon_sym_not_in] = ACTIONS(4643),
    [anon_sym_or_return] = ACTIONS(4643),
    [anon_sym_or_continue] = ACTIONS(4643),
    [anon_sym_or_break] = ACTIONS(4643),
    [anon_sym_CARET] = ACTIONS(4645),
    [sym_uninitialized] = ACTIONS(4643),
    [sym_tag] = ACTIONS(4643),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4643),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [695] = {
    [ts_builtin_sym_end] = ACTIONS(4647),
    [anon_sym_LBRACE] = ACTIONS(4647),
    [anon_sym_RBRACE] = ACTIONS(4647),
    [anon_sym_COMMA] = ACTIONS(4647),
    [anon_sym_COLON_COLON] = ACTIONS(4647),
    [anon_sym_DASH_GT] = ACTIONS(4647),
    [anon_sym_where] = ACTIONS(4647),
    [anon_sym_EQ] = ACTIONS(4649),
    [anon_sym_COLON] = ACTIONS(4649),
    [anon_sym_PIPE] = ACTIONS(4649),
    [anon_sym_COLON_EQ] = ACTIONS(4647),
    [anon_sym_LPAREN] = ACTIONS(4647),
    [anon_sym_PLUS_EQ] = ACTIONS(4647),
    [anon_sym_DASH_EQ] = ACTIONS(4647),
    [anon_sym_STAR_EQ] = ACTIONS(4647),
    [anon_sym_SLASH_EQ] = ACTIONS(4647),
    [anon_sym_PERCENT_EQ] = ACTIONS(4647),
    [anon_sym_AMP_EQ] = ACTIONS(4647),
    [anon_sym_PIPE_EQ] = ACTIONS(4647),
    [anon_sym_CARET_EQ] = ACTIONS(4647),
    [anon_sym_LT_LT_EQ] = ACTIONS(4647),
    [anon_sym_GT_GT_EQ] = ACTIONS(4647),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4647),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4647),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4647),
    [anon_sym_if] = ACTIONS(4647),
    [anon_sym_SEMI] = ACTIONS(4647),
    [anon_sym_else] = ACTIONS(4647),
    [anon_sym_when] = ACTIONS(4647),
    [anon_sym_in] = ACTIONS(4647),
    [anon_sym_case] = ACTIONS(4647),
    [anon_sym_QMARK] = ACTIONS(4647),
    [anon_sym_PLUS] = ACTIONS(4649),
    [anon_sym_DASH] = ACTIONS(4649),
    [anon_sym_TILDE] = ACTIONS(4649),
    [anon_sym_AMP] = ACTIONS(4649),
    [anon_sym_PIPE_PIPE] = ACTIONS(4649),
    [anon_sym_or_else] = ACTIONS(4647),
    [anon_sym_AMP_AMP] = ACTIONS(4649),
    [anon_sym_GT] = ACTIONS(4649),
    [anon_sym_GT_EQ] = ACTIONS(4647),
    [anon_sym_LT_EQ] = ACTIONS(4647),
    [anon_sym_LT] = ACTIONS(4649),
    [anon_sym_EQ_EQ] = ACTIONS(4647),
    [anon_sym_BANG_EQ] = ACTIONS(4647),
    [anon_sym_TILDE_EQ] = ACTIONS(4647),
    [anon_sym_AMP_TILDE] = ACTIONS(4649),
    [anon_sym_LT_LT] = ACTIONS(4649),
    [anon_sym_GT_GT] = ACTIONS(4649),
    [anon_sym_STAR] = ACTIONS(4649),
    [anon_sym_SLASH] = ACTIONS(4649),
    [anon_sym_PERCENT] = ACTIONS(4649),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4647),
    [anon_sym_DOT] = ACTIONS(4649),
    [anon_sym_LBRACK] = ACTIONS(4647),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4647),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4647),
    [anon_sym_not_in] = ACTIONS(4647),
    [anon_sym_or_return] = ACTIONS(4647),
    [anon_sym_or_continue] = ACTIONS(4647),
    [anon_sym_or_break] = ACTIONS(4647),
    [anon_sym_CARET] = ACTIONS(4649),
    [sym_uninitialized] = ACTIONS(4647),
    [sym_tag] = ACTIONS(4647),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4647),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [696] = {
    [ts_builtin_sym_end] = ACTIONS(4651),
    [anon_sym_LBRACE] = ACTIONS(4651),
    [anon_sym_RBRACE] = ACTIONS(4651),
    [anon_sym_COMMA] = ACTIONS(4651),
    [anon_sym_COLON_COLON] = ACTIONS(4651),
    [anon_sym_DASH_GT] = ACTIONS(4651),
    [anon_sym_where] = ACTIONS(4651),
    [anon_sym_EQ] = ACTIONS(4653),
    [anon_sym_COLON] = ACTIONS(4653),
    [anon_sym_PIPE] = ACTIONS(4653),
    [anon_sym_COLON_EQ] = ACTIONS(4651),
    [anon_sym_LPAREN] = ACTIONS(4651),
    [anon_sym_PLUS_EQ] = ACTIONS(4651),
    [anon_sym_DASH_EQ] = ACTIONS(4651),
    [anon_sym_STAR_EQ] = ACTIONS(4651),
    [anon_sym_SLASH_EQ] = ACTIONS(4651),
    [anon_sym_PERCENT_EQ] = ACTIONS(4651),
    [anon_sym_AMP_EQ] = ACTIONS(4651),
    [anon_sym_PIPE_EQ] = ACTIONS(4651),
    [anon_sym_CARET_EQ] = ACTIONS(4651),
    [anon_sym_LT_LT_EQ] = ACTIONS(4651),
    [anon_sym_GT_GT_EQ] = ACTIONS(4651),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4651),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4651),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4651),
    [anon_sym_if] = ACTIONS(4651),
    [anon_sym_SEMI] = ACTIONS(4651),
    [anon_sym_else] = ACTIONS(4651),
    [anon_sym_when] = ACTIONS(4651),
    [anon_sym_in] = ACTIONS(4651),
    [anon_sym_case] = ACTIONS(4651),
    [anon_sym_QMARK] = ACTIONS(4651),
    [anon_sym_PLUS] = ACTIONS(4653),
    [anon_sym_DASH] = ACTIONS(4653),
    [anon_sym_TILDE] = ACTIONS(4653),
    [anon_sym_AMP] = ACTIONS(4653),
    [anon_sym_PIPE_PIPE] = ACTIONS(4653),
    [anon_sym_or_else] = ACTIONS(4651),
    [anon_sym_AMP_AMP] = ACTIONS(4653),
    [anon_sym_GT] = ACTIONS(4653),
    [anon_sym_GT_EQ] = ACTIONS(4651),
    [anon_sym_LT_EQ] = ACTIONS(4651),
    [anon_sym_LT] = ACTIONS(4653),
    [anon_sym_EQ_EQ] = ACTIONS(4651),
    [anon_sym_BANG_EQ] = ACTIONS(4651),
    [anon_sym_TILDE_EQ] = ACTIONS(4651),
    [anon_sym_AMP_TILDE] = ACTIONS(4653),
    [anon_sym_LT_LT] = ACTIONS(4653),
    [anon_sym_GT_GT] = ACTIONS(4653),
    [anon_sym_STAR] = ACTIONS(4653),
    [anon_sym_SLASH] = ACTIONS(4653),
    [anon_sym_PERCENT] = ACTIONS(4653),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4651),
    [anon_sym_DOT] = ACTIONS(4653),
    [anon_sym_LBRACK] = ACTIONS(4651),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4651),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4651),
    [anon_sym_not_in] = ACTIONS(4651),
    [anon_sym_or_return] = ACTIONS(4651),
    [anon_sym_or_continue] = ACTIONS(4651),
    [anon_sym_or_break] = ACTIONS(4651),
    [anon_sym_CARET] = ACTIONS(4653),
    [sym_uninitialized] = ACTIONS(4651),
    [sym_tag] = ACTIONS(4651),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4651),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [697] = {
    [ts_builtin_sym_end] = ACTIONS(4655),
    [anon_sym_LBRACE] = ACTIONS(4655),
    [anon_sym_RBRACE] = ACTIONS(4655),
    [anon_sym_COMMA] = ACTIONS(4655),
    [anon_sym_COLON_COLON] = ACTIONS(4655),
    [anon_sym_DASH_GT] = ACTIONS(4655),
    [anon_sym_where] = ACTIONS(4655),
    [anon_sym_EQ] = ACTIONS(4657),
    [anon_sym_COLON] = ACTIONS(4657),
    [anon_sym_PIPE] = ACTIONS(4657),
    [anon_sym_COLON_EQ] = ACTIONS(4655),
    [anon_sym_LPAREN] = ACTIONS(4655),
    [anon_sym_PLUS_EQ] = ACTIONS(4655),
    [anon_sym_DASH_EQ] = ACTIONS(4655),
    [anon_sym_STAR_EQ] = ACTIONS(4655),
    [anon_sym_SLASH_EQ] = ACTIONS(4655),
    [anon_sym_PERCENT_EQ] = ACTIONS(4655),
    [anon_sym_AMP_EQ] = ACTIONS(4655),
    [anon_sym_PIPE_EQ] = ACTIONS(4655),
    [anon_sym_CARET_EQ] = ACTIONS(4655),
    [anon_sym_LT_LT_EQ] = ACTIONS(4655),
    [anon_sym_GT_GT_EQ] = ACTIONS(4655),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4655),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4655),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4655),
    [anon_sym_if] = ACTIONS(4655),
    [anon_sym_SEMI] = ACTIONS(4655),
    [anon_sym_else] = ACTIONS(4655),
    [anon_sym_when] = ACTIONS(4655),
    [anon_sym_in] = ACTIONS(4655),
    [anon_sym_case] = ACTIONS(4655),
    [anon_sym_QMARK] = ACTIONS(4655),
    [anon_sym_PLUS] = ACTIONS(4657),
    [anon_sym_DASH] = ACTIONS(4657),
    [anon_sym_TILDE] = ACTIONS(4657),
    [anon_sym_AMP] = ACTIONS(4657),
    [anon_sym_PIPE_PIPE] = ACTIONS(4657),
    [anon_sym_or_else] = ACTIONS(4655),
    [anon_sym_AMP_AMP] = ACTIONS(4657),
    [anon_sym_GT] = ACTIONS(4657),
    [anon_sym_GT_EQ] = ACTIONS(4655),
    [anon_sym_LT_EQ] = ACTIONS(4655),
    [anon_sym_LT] = ACTIONS(4657),
    [anon_sym_EQ_EQ] = ACTIONS(4655),
    [anon_sym_BANG_EQ] = ACTIONS(4655),
    [anon_sym_TILDE_EQ] = ACTIONS(4655),
    [anon_sym_AMP_TILDE] = ACTIONS(4657),
    [anon_sym_LT_LT] = ACTIONS(4657),
    [anon_sym_GT_GT] = ACTIONS(4657),
    [anon_sym_STAR] = ACTIONS(4657),
    [anon_sym_SLASH] = ACTIONS(4657),
    [anon_sym_PERCENT] = ACTIONS(4657),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4655),
    [anon_sym_DOT] = ACTIONS(4657),
    [anon_sym_LBRACK] = ACTIONS(4655),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4655),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4655),
    [anon_sym_not_in] = ACTIONS(4655),
    [anon_sym_or_return] = ACTIONS(4655),
    [anon_sym_or_continue] = ACTIONS(4655),
    [anon_sym_or_break] = ACTIONS(4655),
    [anon_sym_CARET] = ACTIONS(4657),
    [sym_uninitialized] = ACTIONS(4655),
    [sym_tag] = ACTIONS(4655),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4655),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [698] = {
    [ts_builtin_sym_end] = ACTIONS(4659),
    [anon_sym_LBRACE] = ACTIONS(4659),
    [anon_sym_RBRACE] = ACTIONS(4659),
    [anon_sym_COMMA] = ACTIONS(4659),
    [anon_sym_COLON_COLON] = ACTIONS(4659),
    [anon_sym_DASH_GT] = ACTIONS(4659),
    [anon_sym_where] = ACTIONS(4659),
    [anon_sym_EQ] = ACTIONS(4661),
    [anon_sym_COLON] = ACTIONS(4661),
    [anon_sym_PIPE] = ACTIONS(4661),
    [anon_sym_COLON_EQ] = ACTIONS(4659),
    [anon_sym_LPAREN] = ACTIONS(4659),
    [anon_sym_PLUS_EQ] = ACTIONS(4659),
    [anon_sym_DASH_EQ] = ACTIONS(4659),
    [anon_sym_STAR_EQ] = ACTIONS(4659),
    [anon_sym_SLASH_EQ] = ACTIONS(4659),
    [anon_sym_PERCENT_EQ] = ACTIONS(4659),
    [anon_sym_AMP_EQ] = ACTIONS(4659),
    [anon_sym_PIPE_EQ] = ACTIONS(4659),
    [anon_sym_CARET_EQ] = ACTIONS(4659),
    [anon_sym_LT_LT_EQ] = ACTIONS(4659),
    [anon_sym_GT_GT_EQ] = ACTIONS(4659),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4659),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4659),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4659),
    [anon_sym_if] = ACTIONS(4659),
    [anon_sym_SEMI] = ACTIONS(4659),
    [anon_sym_else] = ACTIONS(4659),
    [anon_sym_when] = ACTIONS(4659),
    [anon_sym_in] = ACTIONS(4659),
    [anon_sym_case] = ACTIONS(4659),
    [anon_sym_QMARK] = ACTIONS(4659),
    [anon_sym_PLUS] = ACTIONS(4661),
    [anon_sym_DASH] = ACTIONS(4661),
    [anon_sym_TILDE] = ACTIONS(4661),
    [anon_sym_AMP] = ACTIONS(4661),
    [anon_sym_PIPE_PIPE] = ACTIONS(4661),
    [anon_sym_or_else] = ACTIONS(4659),
    [anon_sym_AMP_AMP] = ACTIONS(4661),
    [anon_sym_GT] = ACTIONS(4661),
    [anon_sym_GT_EQ] = ACTIONS(4659),
    [anon_sym_LT_EQ] = ACTIONS(4659),
    [anon_sym_LT] = ACTIONS(4661),
    [anon_sym_EQ_EQ] = ACTIONS(4659),
    [anon_sym_BANG_EQ] = ACTIONS(4659),
    [anon_sym_TILDE_EQ] = ACTIONS(4659),
    [anon_sym_AMP_TILDE] = ACTIONS(4661),
    [anon_sym_LT_LT] = ACTIONS(4661),
    [anon_sym_GT_GT] = ACTIONS(4661),
    [anon_sym_STAR] = ACTIONS(4661),
    [anon_sym_SLASH] = ACTIONS(4661),
    [anon_sym_PERCENT] = ACTIONS(4661),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4659),
    [anon_sym_DOT] = ACTIONS(4661),
    [anon_sym_LBRACK] = ACTIONS(4659),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4659),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4659),
    [anon_sym_not_in] = ACTIONS(4659),
    [anon_sym_or_return] = ACTIONS(4659),
    [anon_sym_or_continue] = ACTIONS(4659),
    [anon_sym_or_break] = ACTIONS(4659),
    [anon_sym_CARET] = ACTIONS(4661),
    [sym_uninitialized] = ACTIONS(4659),
    [sym_tag] = ACTIONS(4659),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4659),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [699] = {
    [ts_builtin_sym_end] = ACTIONS(4663),
    [anon_sym_LBRACE] = ACTIONS(4663),
    [anon_sym_RBRACE] = ACTIONS(4663),
    [anon_sym_COMMA] = ACTIONS(4663),
    [anon_sym_COLON_COLON] = ACTIONS(4663),
    [anon_sym_DASH_GT] = ACTIONS(4663),
    [anon_sym_where] = ACTIONS(4663),
    [anon_sym_EQ] = ACTIONS(4665),
    [anon_sym_COLON] = ACTIONS(4665),
    [anon_sym_PIPE] = ACTIONS(4665),
    [anon_sym_COLON_EQ] = ACTIONS(4663),
    [anon_sym_LPAREN] = ACTIONS(4663),
    [anon_sym_PLUS_EQ] = ACTIONS(4663),
    [anon_sym_DASH_EQ] = ACTIONS(4663),
    [anon_sym_STAR_EQ] = ACTIONS(4663),
    [anon_sym_SLASH_EQ] = ACTIONS(4663),
    [anon_sym_PERCENT_EQ] = ACTIONS(4663),
    [anon_sym_AMP_EQ] = ACTIONS(4663),
    [anon_sym_PIPE_EQ] = ACTIONS(4663),
    [anon_sym_CARET_EQ] = ACTIONS(4663),
    [anon_sym_LT_LT_EQ] = ACTIONS(4663),
    [anon_sym_GT_GT_EQ] = ACTIONS(4663),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4663),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4663),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4663),
    [anon_sym_if] = ACTIONS(4663),
    [anon_sym_SEMI] = ACTIONS(4663),
    [anon_sym_else] = ACTIONS(4663),
    [anon_sym_when] = ACTIONS(4663),
    [anon_sym_in] = ACTIONS(4663),
    [anon_sym_case] = ACTIONS(4663),
    [anon_sym_QMARK] = ACTIONS(4663),
    [anon_sym_PLUS] = ACTIONS(4665),
    [anon_sym_DASH] = ACTIONS(4665),
    [anon_sym_TILDE] = ACTIONS(4665),
    [anon_sym_AMP] = ACTIONS(4665),
    [anon_sym_PIPE_PIPE] = ACTIONS(4665),
    [anon_sym_or_else] = ACTIONS(4663),
    [anon_sym_AMP_AMP] = ACTIONS(4665),
    [anon_sym_GT] = ACTIONS(4665),
    [anon_sym_GT_EQ] = ACTIONS(4663),
    [anon_sym_LT_EQ] = ACTIONS(4663),
    [anon_sym_LT] = ACTIONS(4665),
    [anon_sym_EQ_EQ] = ACTIONS(4663),
    [anon_sym_BANG_EQ] = ACTIONS(4663),
    [anon_sym_TILDE_EQ] = ACTIONS(4663),
    [anon_sym_AMP_TILDE] = ACTIONS(4665),
    [anon_sym_LT_LT] = ACTIONS(4665),
    [anon_sym_GT_GT] = ACTIONS(4665),
    [anon_sym_STAR] = ACTIONS(4665),
    [anon_sym_SLASH] = ACTIONS(4665),
    [anon_sym_PERCENT] = ACTIONS(4665),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4663),
    [anon_sym_DOT] = ACTIONS(4665),
    [anon_sym_LBRACK] = ACTIONS(4663),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4663),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4663),
    [anon_sym_not_in] = ACTIONS(4663),
    [anon_sym_or_return] = ACTIONS(4663),
    [anon_sym_or_continue] = ACTIONS(4663),
    [anon_sym_or_break] = ACTIONS(4663),
    [anon_sym_CARET] = ACTIONS(4665),
    [sym_uninitialized] = ACTIONS(4663),
    [sym_tag] = ACTIONS(4663),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4663),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [700] = {
    [ts_builtin_sym_end] = ACTIONS(4667),
    [anon_sym_LBRACE] = ACTIONS(4667),
    [anon_sym_RBRACE] = ACTIONS(4667),
    [anon_sym_COMMA] = ACTIONS(4667),
    [anon_sym_COLON_COLON] = ACTIONS(4667),
    [anon_sym_DASH_GT] = ACTIONS(4667),
    [anon_sym_where] = ACTIONS(4667),
    [anon_sym_EQ] = ACTIONS(4669),
    [anon_sym_COLON] = ACTIONS(4669),
    [anon_sym_PIPE] = ACTIONS(4669),
    [anon_sym_COLON_EQ] = ACTIONS(4667),
    [anon_sym_LPAREN] = ACTIONS(4667),
    [anon_sym_PLUS_EQ] = ACTIONS(4667),
    [anon_sym_DASH_EQ] = ACTIONS(4667),
    [anon_sym_STAR_EQ] = ACTIONS(4667),
    [anon_sym_SLASH_EQ] = ACTIONS(4667),
    [anon_sym_PERCENT_EQ] = ACTIONS(4667),
    [anon_sym_AMP_EQ] = ACTIONS(4667),
    [anon_sym_PIPE_EQ] = ACTIONS(4667),
    [anon_sym_CARET_EQ] = ACTIONS(4667),
    [anon_sym_LT_LT_EQ] = ACTIONS(4667),
    [anon_sym_GT_GT_EQ] = ACTIONS(4667),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4667),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4667),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4667),
    [anon_sym_if] = ACTIONS(4667),
    [anon_sym_SEMI] = ACTIONS(4667),
    [anon_sym_else] = ACTIONS(4667),
    [anon_sym_when] = ACTIONS(4667),
    [anon_sym_in] = ACTIONS(4667),
    [anon_sym_case] = ACTIONS(4667),
    [anon_sym_QMARK] = ACTIONS(4667),
    [anon_sym_PLUS] = ACTIONS(4669),
    [anon_sym_DASH] = ACTIONS(4669),
    [anon_sym_TILDE] = ACTIONS(4669),
    [anon_sym_AMP] = ACTIONS(4669),
    [anon_sym_PIPE_PIPE] = ACTIONS(4669),
    [anon_sym_or_else] = ACTIONS(4667),
    [anon_sym_AMP_AMP] = ACTIONS(4669),
    [anon_sym_GT] = ACTIONS(4669),
    [anon_sym_GT_EQ] = ACTIONS(4667),
    [anon_sym_LT_EQ] = ACTIONS(4667),
    [anon_sym_LT] = ACTIONS(4669),
    [anon_sym_EQ_EQ] = ACTIONS(4667),
    [anon_sym_BANG_EQ] = ACTIONS(4667),
    [anon_sym_TILDE_EQ] = ACTIONS(4667),
    [anon_sym_AMP_TILDE] = ACTIONS(4669),
    [anon_sym_LT_LT] = ACTIONS(4669),
    [anon_sym_GT_GT] = ACTIONS(4669),
    [anon_sym_STAR] = ACTIONS(4669),
    [anon_sym_SLASH] = ACTIONS(4669),
    [anon_sym_PERCENT] = ACTIONS(4669),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4667),
    [anon_sym_DOT] = ACTIONS(4669),
    [anon_sym_LBRACK] = ACTIONS(4667),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4667),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4667),
    [anon_sym_not_in] = ACTIONS(4667),
    [anon_sym_or_return] = ACTIONS(4667),
    [anon_sym_or_continue] = ACTIONS(4667),
    [anon_sym_or_break] = ACTIONS(4667),
    [anon_sym_CARET] = ACTIONS(4669),
    [sym_uninitialized] = ACTIONS(4667),
    [sym_tag] = ACTIONS(4667),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4667),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [701] = {
    [ts_builtin_sym_end] = ACTIONS(4671),
    [anon_sym_LBRACE] = ACTIONS(4671),
    [anon_sym_RBRACE] = ACTIONS(4671),
    [anon_sym_COMMA] = ACTIONS(4671),
    [anon_sym_COLON_COLON] = ACTIONS(4671),
    [anon_sym_DASH_GT] = ACTIONS(4671),
    [anon_sym_where] = ACTIONS(4671),
    [anon_sym_EQ] = ACTIONS(4673),
    [anon_sym_COLON] = ACTIONS(4673),
    [anon_sym_PIPE] = ACTIONS(4673),
    [anon_sym_COLON_EQ] = ACTIONS(4671),
    [anon_sym_LPAREN] = ACTIONS(4671),
    [anon_sym_PLUS_EQ] = ACTIONS(4671),
    [anon_sym_DASH_EQ] = ACTIONS(4671),
    [anon_sym_STAR_EQ] = ACTIONS(4671),
    [anon_sym_SLASH_EQ] = ACTIONS(4671),
    [anon_sym_PERCENT_EQ] = ACTIONS(4671),
    [anon_sym_AMP_EQ] = ACTIONS(4671),
    [anon_sym_PIPE_EQ] = ACTIONS(4671),
    [anon_sym_CARET_EQ] = ACTIONS(4671),
    [anon_sym_LT_LT_EQ] = ACTIONS(4671),
    [anon_sym_GT_GT_EQ] = ACTIONS(4671),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4671),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4671),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4671),
    [anon_sym_if] = ACTIONS(4671),
    [anon_sym_SEMI] = ACTIONS(4671),
    [anon_sym_else] = ACTIONS(4671),
    [anon_sym_when] = ACTIONS(4671),
    [anon_sym_in] = ACTIONS(4671),
    [anon_sym_case] = ACTIONS(4671),
    [anon_sym_QMARK] = ACTIONS(4671),
    [anon_sym_PLUS] = ACTIONS(4673),
    [anon_sym_DASH] = ACTIONS(4673),
    [anon_sym_TILDE] = ACTIONS(4673),
    [anon_sym_AMP] = ACTIONS(4673),
    [anon_sym_PIPE_PIPE] = ACTIONS(4673),
    [anon_sym_or_else] = ACTIONS(4671),
    [anon_sym_AMP_AMP] = ACTIONS(4673),
    [anon_sym_GT] = ACTIONS(4673),
    [anon_sym_GT_EQ] = ACTIONS(4671),
    [anon_sym_LT_EQ] = ACTIONS(4671),
    [anon_sym_LT] = ACTIONS(4673),
    [anon_sym_EQ_EQ] = ACTIONS(4671),
    [anon_sym_BANG_EQ] = ACTIONS(4671),
    [anon_sym_TILDE_EQ] = ACTIONS(4671),
    [anon_sym_AMP_TILDE] = ACTIONS(4673),
    [anon_sym_LT_LT] = ACTIONS(4673),
    [anon_sym_GT_GT] = ACTIONS(4673),
    [anon_sym_STAR] = ACTIONS(4673),
    [anon_sym_SLASH] = ACTIONS(4673),
    [anon_sym_PERCENT] = ACTIONS(4673),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4671),
    [anon_sym_DOT] = ACTIONS(4673),
    [anon_sym_LBRACK] = ACTIONS(4671),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4671),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4671),
    [anon_sym_not_in] = ACTIONS(4671),
    [anon_sym_or_return] = ACTIONS(4671),
    [anon_sym_or_continue] = ACTIONS(4671),
    [anon_sym_or_break] = ACTIONS(4671),
    [anon_sym_CARET] = ACTIONS(4673),
    [sym_uninitialized] = ACTIONS(4671),
    [sym_tag] = ACTIONS(4671),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4671),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [702] = {
    [ts_builtin_sym_end] = ACTIONS(4675),
    [anon_sym_LBRACE] = ACTIONS(4675),
    [anon_sym_RBRACE] = ACTIONS(4675),
    [anon_sym_COMMA] = ACTIONS(4675),
    [anon_sym_COLON_COLON] = ACTIONS(4675),
    [anon_sym_DASH_GT] = ACTIONS(4675),
    [anon_sym_where] = ACTIONS(4675),
    [anon_sym_EQ] = ACTIONS(4677),
    [anon_sym_COLON] = ACTIONS(4677),
    [anon_sym_PIPE] = ACTIONS(4677),
    [anon_sym_COLON_EQ] = ACTIONS(4675),
    [anon_sym_LPAREN] = ACTIONS(4675),
    [anon_sym_PLUS_EQ] = ACTIONS(4675),
    [anon_sym_DASH_EQ] = ACTIONS(4675),
    [anon_sym_STAR_EQ] = ACTIONS(4675),
    [anon_sym_SLASH_EQ] = ACTIONS(4675),
    [anon_sym_PERCENT_EQ] = ACTIONS(4675),
    [anon_sym_AMP_EQ] = ACTIONS(4675),
    [anon_sym_PIPE_EQ] = ACTIONS(4675),
    [anon_sym_CARET_EQ] = ACTIONS(4675),
    [anon_sym_LT_LT_EQ] = ACTIONS(4675),
    [anon_sym_GT_GT_EQ] = ACTIONS(4675),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4675),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4675),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4675),
    [anon_sym_if] = ACTIONS(4675),
    [anon_sym_SEMI] = ACTIONS(4675),
    [anon_sym_else] = ACTIONS(4675),
    [anon_sym_when] = ACTIONS(4675),
    [anon_sym_in] = ACTIONS(4675),
    [anon_sym_case] = ACTIONS(4675),
    [anon_sym_QMARK] = ACTIONS(4675),
    [anon_sym_PLUS] = ACTIONS(4677),
    [anon_sym_DASH] = ACTIONS(4677),
    [anon_sym_TILDE] = ACTIONS(4677),
    [anon_sym_AMP] = ACTIONS(4677),
    [anon_sym_PIPE_PIPE] = ACTIONS(4677),
    [anon_sym_or_else] = ACTIONS(4675),
    [anon_sym_AMP_AMP] = ACTIONS(4677),
    [anon_sym_GT] = ACTIONS(4677),
    [anon_sym_GT_EQ] = ACTIONS(4675),
    [anon_sym_LT_EQ] = ACTIONS(4675),
    [anon_sym_LT] = ACTIONS(4677),
    [anon_sym_EQ_EQ] = ACTIONS(4675),
    [anon_sym_BANG_EQ] = ACTIONS(4675),
    [anon_sym_TILDE_EQ] = ACTIONS(4675),
    [anon_sym_AMP_TILDE] = ACTIONS(4677),
    [anon_sym_LT_LT] = ACTIONS(4677),
    [anon_sym_GT_GT] = ACTIONS(4677),
    [anon_sym_STAR] = ACTIONS(4677),
    [anon_sym_SLASH] = ACTIONS(4677),
    [anon_sym_PERCENT] = ACTIONS(4677),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4675),
    [anon_sym_DOT] = ACTIONS(4677),
    [anon_sym_LBRACK] = ACTIONS(4675),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4675),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4675),
    [anon_sym_not_in] = ACTIONS(4675),
    [anon_sym_or_return] = ACTIONS(4675),
    [anon_sym_or_continue] = ACTIONS(4675),
    [anon_sym_or_break] = ACTIONS(4675),
    [anon_sym_CARET] = ACTIONS(4677),
    [sym_uninitialized] = ACTIONS(4675),
    [sym_tag] = ACTIONS(4675),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4675),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [703] = {
    [ts_builtin_sym_end] = ACTIONS(4679),
    [anon_sym_LBRACE] = ACTIONS(4679),
    [anon_sym_RBRACE] = ACTIONS(4679),
    [anon_sym_COMMA] = ACTIONS(4679),
    [anon_sym_COLON_COLON] = ACTIONS(4679),
    [anon_sym_DASH_GT] = ACTIONS(4679),
    [anon_sym_where] = ACTIONS(4679),
    [anon_sym_EQ] = ACTIONS(4681),
    [anon_sym_COLON] = ACTIONS(4681),
    [anon_sym_PIPE] = ACTIONS(4681),
    [anon_sym_COLON_EQ] = ACTIONS(4679),
    [anon_sym_LPAREN] = ACTIONS(4679),
    [anon_sym_PLUS_EQ] = ACTIONS(4679),
    [anon_sym_DASH_EQ] = ACTIONS(4679),
    [anon_sym_STAR_EQ] = ACTIONS(4679),
    [anon_sym_SLASH_EQ] = ACTIONS(4679),
    [anon_sym_PERCENT_EQ] = ACTIONS(4679),
    [anon_sym_AMP_EQ] = ACTIONS(4679),
    [anon_sym_PIPE_EQ] = ACTIONS(4679),
    [anon_sym_CARET_EQ] = ACTIONS(4679),
    [anon_sym_LT_LT_EQ] = ACTIONS(4679),
    [anon_sym_GT_GT_EQ] = ACTIONS(4679),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4679),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4679),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4679),
    [anon_sym_if] = ACTIONS(4679),
    [anon_sym_SEMI] = ACTIONS(4679),
    [anon_sym_else] = ACTIONS(4679),
    [anon_sym_when] = ACTIONS(4679),
    [anon_sym_in] = ACTIONS(4679),
    [anon_sym_case] = ACTIONS(4679),
    [anon_sym_QMARK] = ACTIONS(4679),
    [anon_sym_PLUS] = ACTIONS(4681),
    [anon_sym_DASH] = ACTIONS(4681),
    [anon_sym_TILDE] = ACTIONS(4681),
    [anon_sym_AMP] = ACTIONS(4681),
    [anon_sym_PIPE_PIPE] = ACTIONS(4681),
    [anon_sym_or_else] = ACTIONS(4679),
    [anon_sym_AMP_AMP] = ACTIONS(4681),
    [anon_sym_GT] = ACTIONS(4681),
    [anon_sym_GT_EQ] = ACTIONS(4679),
    [anon_sym_LT_EQ] = ACTIONS(4679),
    [anon_sym_LT] = ACTIONS(4681),
    [anon_sym_EQ_EQ] = ACTIONS(4679),
    [anon_sym_BANG_EQ] = ACTIONS(4679),
    [anon_sym_TILDE_EQ] = ACTIONS(4679),
    [anon_sym_AMP_TILDE] = ACTIONS(4681),
    [anon_sym_LT_LT] = ACTIONS(4681),
    [anon_sym_GT_GT] = ACTIONS(4681),
    [anon_sym_STAR] = ACTIONS(4681),
    [anon_sym_SLASH] = ACTIONS(4681),
    [anon_sym_PERCENT] = ACTIONS(4681),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4679),
    [anon_sym_DOT] = ACTIONS(4681),
    [anon_sym_LBRACK] = ACTIONS(4679),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4679),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4679),
    [anon_sym_not_in] = ACTIONS(4679),
    [anon_sym_or_return] = ACTIONS(4679),
    [anon_sym_or_continue] = ACTIONS(4679),
    [anon_sym_or_break] = ACTIONS(4679),
    [anon_sym_CARET] = ACTIONS(4681),
    [sym_uninitialized] = ACTIONS(4679),
    [sym_tag] = ACTIONS(4679),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4679),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [704] = {
    [ts_builtin_sym_end] = ACTIONS(4683),
    [anon_sym_LBRACE] = ACTIONS(4683),
    [anon_sym_RBRACE] = ACTIONS(4683),
    [anon_sym_COMMA] = ACTIONS(4683),
    [anon_sym_COLON_COLON] = ACTIONS(4683),
    [anon_sym_DASH_GT] = ACTIONS(4683),
    [anon_sym_where] = ACTIONS(4683),
    [anon_sym_EQ] = ACTIONS(4685),
    [anon_sym_COLON] = ACTIONS(4685),
    [anon_sym_PIPE] = ACTIONS(4685),
    [anon_sym_COLON_EQ] = ACTIONS(4683),
    [anon_sym_LPAREN] = ACTIONS(4683),
    [anon_sym_PLUS_EQ] = ACTIONS(4683),
    [anon_sym_DASH_EQ] = ACTIONS(4683),
    [anon_sym_STAR_EQ] = ACTIONS(4683),
    [anon_sym_SLASH_EQ] = ACTIONS(4683),
    [anon_sym_PERCENT_EQ] = ACTIONS(4683),
    [anon_sym_AMP_EQ] = ACTIONS(4683),
    [anon_sym_PIPE_EQ] = ACTIONS(4683),
    [anon_sym_CARET_EQ] = ACTIONS(4683),
    [anon_sym_LT_LT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4683),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4683),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4683),
    [anon_sym_if] = ACTIONS(4683),
    [anon_sym_SEMI] = ACTIONS(4683),
    [anon_sym_else] = ACTIONS(4683),
    [anon_sym_when] = ACTIONS(4683),
    [anon_sym_in] = ACTIONS(4683),
    [anon_sym_case] = ACTIONS(4683),
    [anon_sym_QMARK] = ACTIONS(4683),
    [anon_sym_PLUS] = ACTIONS(4685),
    [anon_sym_DASH] = ACTIONS(4685),
    [anon_sym_TILDE] = ACTIONS(4685),
    [anon_sym_AMP] = ACTIONS(4685),
    [anon_sym_PIPE_PIPE] = ACTIONS(4685),
    [anon_sym_or_else] = ACTIONS(4683),
    [anon_sym_AMP_AMP] = ACTIONS(4685),
    [anon_sym_GT] = ACTIONS(4685),
    [anon_sym_GT_EQ] = ACTIONS(4683),
    [anon_sym_LT_EQ] = ACTIONS(4683),
    [anon_sym_LT] = ACTIONS(4685),
    [anon_sym_EQ_EQ] = ACTIONS(4683),
    [anon_sym_BANG_EQ] = ACTIONS(4683),
    [anon_sym_TILDE_EQ] = ACTIONS(4683),
    [anon_sym_AMP_TILDE] = ACTIONS(4685),
    [anon_sym_LT_LT] = ACTIONS(4685),
    [anon_sym_GT_GT] = ACTIONS(4685),
    [anon_sym_STAR] = ACTIONS(4685),
    [anon_sym_SLASH] = ACTIONS(4685),
    [anon_sym_PERCENT] = ACTIONS(4685),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4683),
    [anon_sym_DOT] = ACTIONS(4685),
    [anon_sym_LBRACK] = ACTIONS(4683),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4683),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4683),
    [anon_sym_not_in] = ACTIONS(4683),
    [anon_sym_or_return] = ACTIONS(4683),
    [anon_sym_or_continue] = ACTIONS(4683),
    [anon_sym_or_break] = ACTIONS(4683),
    [anon_sym_CARET] = ACTIONS(4685),
    [sym_uninitialized] = ACTIONS(4683),
    [sym_tag] = ACTIONS(4683),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4683),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [705] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4485),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4497),
    [anon_sym_GT] = ACTIONS(4499),
    [anon_sym_GT_EQ] = ACTIONS(4501),
    [anon_sym_LT_EQ] = ACTIONS(4501),
    [anon_sym_LT] = ACTIONS(4499),
    [anon_sym_EQ_EQ] = ACTIONS(4503),
    [anon_sym_BANG_EQ] = ACTIONS(4503),
    [anon_sym_TILDE_EQ] = ACTIONS(4503),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [706] = {
    [ts_builtin_sym_end] = ACTIONS(909),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_where] = ACTIONS(909),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(909),
    [anon_sym_PLUS_EQ] = ACTIONS(909),
    [anon_sym_DASH_EQ] = ACTIONS(909),
    [anon_sym_STAR_EQ] = ACTIONS(909),
    [anon_sym_SLASH_EQ] = ACTIONS(909),
    [anon_sym_PERCENT_EQ] = ACTIONS(909),
    [anon_sym_AMP_EQ] = ACTIONS(909),
    [anon_sym_PIPE_EQ] = ACTIONS(909),
    [anon_sym_CARET_EQ] = ACTIONS(909),
    [anon_sym_LT_LT_EQ] = ACTIONS(909),
    [anon_sym_GT_GT_EQ] = ACTIONS(909),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(909),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(909),
    [anon_sym_if] = ACTIONS(909),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(909),
    [anon_sym_when] = ACTIONS(909),
    [anon_sym_in] = ACTIONS(909),
    [anon_sym_case] = ACTIONS(909),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(911),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(911),
    [anon_sym_or_else] = ACTIONS(909),
    [anon_sym_AMP_AMP] = ACTIONS(911),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(911),
    [anon_sym_LT_LT] = ACTIONS(911),
    [anon_sym_GT_GT] = ACTIONS(911),
    [anon_sym_STAR] = ACTIONS(911),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(909),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(909),
    [anon_sym_or_return] = ACTIONS(909),
    [anon_sym_or_continue] = ACTIONS(909),
    [anon_sym_or_break] = ACTIONS(909),
    [anon_sym_CARET] = ACTIONS(911),
    [sym_uninitialized] = ACTIONS(909),
    [sym_tag] = ACTIONS(909),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [707] = {
    [sym_block] = STATE(1551),
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3451),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(3533),
    [sym_tag] = ACTIONS(3535),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [708] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4485),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4637),
    [anon_sym_GT] = ACTIONS(4499),
    [anon_sym_GT_EQ] = ACTIONS(4501),
    [anon_sym_LT_EQ] = ACTIONS(4501),
    [anon_sym_LT] = ACTIONS(4499),
    [anon_sym_EQ_EQ] = ACTIONS(4503),
    [anon_sym_BANG_EQ] = ACTIONS(4503),
    [anon_sym_TILDE_EQ] = ACTIONS(4503),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [709] = {
    [ts_builtin_sym_end] = ACTIONS(767),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_where] = ACTIONS(767),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(767),
    [anon_sym_PLUS_EQ] = ACTIONS(767),
    [anon_sym_DASH_EQ] = ACTIONS(767),
    [anon_sym_STAR_EQ] = ACTIONS(767),
    [anon_sym_SLASH_EQ] = ACTIONS(767),
    [anon_sym_PERCENT_EQ] = ACTIONS(767),
    [anon_sym_AMP_EQ] = ACTIONS(767),
    [anon_sym_PIPE_EQ] = ACTIONS(767),
    [anon_sym_CARET_EQ] = ACTIONS(767),
    [anon_sym_LT_LT_EQ] = ACTIONS(767),
    [anon_sym_GT_GT_EQ] = ACTIONS(767),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(767),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(767),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(767),
    [anon_sym_when] = ACTIONS(767),
    [anon_sym_in] = ACTIONS(767),
    [anon_sym_case] = ACTIONS(767),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_or_else] = ACTIONS(767),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(773),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(773),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(767),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(767),
    [anon_sym_or_return] = ACTIONS(767),
    [anon_sym_or_continue] = ACTIONS(767),
    [anon_sym_or_break] = ACTIONS(767),
    [anon_sym_CARET] = ACTIONS(773),
    [sym_uninitialized] = ACTIONS(767),
    [sym_tag] = ACTIONS(767),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [710] = {
    [sym_block] = STATE(1558),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3429),
    [sym_tag] = ACTIONS(4687),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [711] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4485),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4637),
    [anon_sym_GT] = ACTIONS(4637),
    [anon_sym_GT_EQ] = ACTIONS(4635),
    [anon_sym_LT_EQ] = ACTIONS(4635),
    [anon_sym_LT] = ACTIONS(4637),
    [anon_sym_EQ_EQ] = ACTIONS(4503),
    [anon_sym_BANG_EQ] = ACTIONS(4503),
    [anon_sym_TILDE_EQ] = ACTIONS(4503),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [712] = {
    [ts_builtin_sym_end] = ACTIONS(4689),
    [anon_sym_LBRACE] = ACTIONS(4689),
    [anon_sym_RBRACE] = ACTIONS(4689),
    [anon_sym_COMMA] = ACTIONS(4689),
    [anon_sym_COLON_COLON] = ACTIONS(4689),
    [anon_sym_DASH_GT] = ACTIONS(4689),
    [anon_sym_where] = ACTIONS(4689),
    [anon_sym_EQ] = ACTIONS(4691),
    [anon_sym_COLON] = ACTIONS(4691),
    [anon_sym_PIPE] = ACTIONS(4691),
    [anon_sym_COLON_EQ] = ACTIONS(4689),
    [anon_sym_LPAREN] = ACTIONS(4689),
    [anon_sym_PLUS_EQ] = ACTIONS(4689),
    [anon_sym_DASH_EQ] = ACTIONS(4689),
    [anon_sym_STAR_EQ] = ACTIONS(4689),
    [anon_sym_SLASH_EQ] = ACTIONS(4689),
    [anon_sym_PERCENT_EQ] = ACTIONS(4689),
    [anon_sym_AMP_EQ] = ACTIONS(4689),
    [anon_sym_PIPE_EQ] = ACTIONS(4689),
    [anon_sym_CARET_EQ] = ACTIONS(4689),
    [anon_sym_LT_LT_EQ] = ACTIONS(4689),
    [anon_sym_GT_GT_EQ] = ACTIONS(4689),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4689),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4689),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4689),
    [anon_sym_if] = ACTIONS(4689),
    [anon_sym_SEMI] = ACTIONS(4689),
    [anon_sym_else] = ACTIONS(4689),
    [anon_sym_when] = ACTIONS(4689),
    [anon_sym_in] = ACTIONS(4689),
    [anon_sym_case] = ACTIONS(4689),
    [anon_sym_QMARK] = ACTIONS(4689),
    [anon_sym_PLUS] = ACTIONS(4691),
    [anon_sym_DASH] = ACTIONS(4691),
    [anon_sym_TILDE] = ACTIONS(4691),
    [anon_sym_AMP] = ACTIONS(4691),
    [anon_sym_PIPE_PIPE] = ACTIONS(4691),
    [anon_sym_or_else] = ACTIONS(4689),
    [anon_sym_AMP_AMP] = ACTIONS(4691),
    [anon_sym_GT] = ACTIONS(4691),
    [anon_sym_GT_EQ] = ACTIONS(4689),
    [anon_sym_LT_EQ] = ACTIONS(4689),
    [anon_sym_LT] = ACTIONS(4691),
    [anon_sym_EQ_EQ] = ACTIONS(4689),
    [anon_sym_BANG_EQ] = ACTIONS(4689),
    [anon_sym_TILDE_EQ] = ACTIONS(4689),
    [anon_sym_AMP_TILDE] = ACTIONS(4691),
    [anon_sym_LT_LT] = ACTIONS(4691),
    [anon_sym_GT_GT] = ACTIONS(4691),
    [anon_sym_STAR] = ACTIONS(4691),
    [anon_sym_SLASH] = ACTIONS(4691),
    [anon_sym_PERCENT] = ACTIONS(4691),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4689),
    [anon_sym_DOT] = ACTIONS(4691),
    [anon_sym_LBRACK] = ACTIONS(4689),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4689),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4689),
    [anon_sym_not_in] = ACTIONS(4689),
    [anon_sym_or_return] = ACTIONS(4689),
    [anon_sym_or_continue] = ACTIONS(4689),
    [anon_sym_or_break] = ACTIONS(4689),
    [anon_sym_CARET] = ACTIONS(4691),
    [sym_uninitialized] = ACTIONS(4689),
    [sym_tag] = ACTIONS(4689),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4689),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [713] = {
    [ts_builtin_sym_end] = ACTIONS(4693),
    [anon_sym_LBRACE] = ACTIONS(4693),
    [anon_sym_RBRACE] = ACTIONS(4693),
    [anon_sym_COMMA] = ACTIONS(4693),
    [anon_sym_COLON_COLON] = ACTIONS(4693),
    [anon_sym_DASH_GT] = ACTIONS(4693),
    [anon_sym_where] = ACTIONS(4693),
    [anon_sym_EQ] = ACTIONS(4695),
    [anon_sym_COLON] = ACTIONS(4695),
    [anon_sym_PIPE] = ACTIONS(4695),
    [anon_sym_COLON_EQ] = ACTIONS(4693),
    [anon_sym_LPAREN] = ACTIONS(4693),
    [anon_sym_PLUS_EQ] = ACTIONS(4693),
    [anon_sym_DASH_EQ] = ACTIONS(4693),
    [anon_sym_STAR_EQ] = ACTIONS(4693),
    [anon_sym_SLASH_EQ] = ACTIONS(4693),
    [anon_sym_PERCENT_EQ] = ACTIONS(4693),
    [anon_sym_AMP_EQ] = ACTIONS(4693),
    [anon_sym_PIPE_EQ] = ACTIONS(4693),
    [anon_sym_CARET_EQ] = ACTIONS(4693),
    [anon_sym_LT_LT_EQ] = ACTIONS(4693),
    [anon_sym_GT_GT_EQ] = ACTIONS(4693),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4693),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4693),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4693),
    [anon_sym_if] = ACTIONS(4697),
    [anon_sym_SEMI] = ACTIONS(4693),
    [anon_sym_else] = ACTIONS(4693),
    [anon_sym_when] = ACTIONS(4697),
    [anon_sym_in] = ACTIONS(4693),
    [anon_sym_case] = ACTIONS(4693),
    [anon_sym_QMARK] = ACTIONS(4699),
    [anon_sym_PLUS] = ACTIONS(4695),
    [anon_sym_DASH] = ACTIONS(4695),
    [anon_sym_TILDE] = ACTIONS(4695),
    [anon_sym_AMP] = ACTIONS(4695),
    [anon_sym_PIPE_PIPE] = ACTIONS(4695),
    [anon_sym_or_else] = ACTIONS(4693),
    [anon_sym_AMP_AMP] = ACTIONS(4695),
    [anon_sym_GT] = ACTIONS(4695),
    [anon_sym_GT_EQ] = ACTIONS(4693),
    [anon_sym_LT_EQ] = ACTIONS(4693),
    [anon_sym_LT] = ACTIONS(4695),
    [anon_sym_EQ_EQ] = ACTIONS(4693),
    [anon_sym_BANG_EQ] = ACTIONS(4693),
    [anon_sym_TILDE_EQ] = ACTIONS(4693),
    [anon_sym_AMP_TILDE] = ACTIONS(4695),
    [anon_sym_LT_LT] = ACTIONS(4695),
    [anon_sym_GT_GT] = ACTIONS(4695),
    [anon_sym_STAR] = ACTIONS(4695),
    [anon_sym_SLASH] = ACTIONS(4695),
    [anon_sym_PERCENT] = ACTIONS(4695),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4693),
    [anon_sym_DOT] = ACTIONS(4695),
    [anon_sym_LBRACK] = ACTIONS(4693),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4693),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4693),
    [anon_sym_not_in] = ACTIONS(4693),
    [anon_sym_or_return] = ACTIONS(4693),
    [anon_sym_or_continue] = ACTIONS(4693),
    [anon_sym_or_break] = ACTIONS(4693),
    [anon_sym_CARET] = ACTIONS(4695),
    [sym_uninitialized] = ACTIONS(4693),
    [sym_tag] = ACTIONS(4693),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4693),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [714] = {
    [ts_builtin_sym_end] = ACTIONS(4701),
    [anon_sym_LBRACE] = ACTIONS(4701),
    [anon_sym_RBRACE] = ACTIONS(4701),
    [anon_sym_COMMA] = ACTIONS(4701),
    [anon_sym_COLON_COLON] = ACTIONS(4701),
    [anon_sym_DASH_GT] = ACTIONS(4701),
    [anon_sym_where] = ACTIONS(4701),
    [anon_sym_EQ] = ACTIONS(4703),
    [anon_sym_COLON] = ACTIONS(4703),
    [anon_sym_PIPE] = ACTIONS(4703),
    [anon_sym_COLON_EQ] = ACTIONS(4701),
    [anon_sym_LPAREN] = ACTIONS(4701),
    [anon_sym_PLUS_EQ] = ACTIONS(4701),
    [anon_sym_DASH_EQ] = ACTIONS(4701),
    [anon_sym_STAR_EQ] = ACTIONS(4701),
    [anon_sym_SLASH_EQ] = ACTIONS(4701),
    [anon_sym_PERCENT_EQ] = ACTIONS(4701),
    [anon_sym_AMP_EQ] = ACTIONS(4701),
    [anon_sym_PIPE_EQ] = ACTIONS(4701),
    [anon_sym_CARET_EQ] = ACTIONS(4701),
    [anon_sym_LT_LT_EQ] = ACTIONS(4701),
    [anon_sym_GT_GT_EQ] = ACTIONS(4701),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4701),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4701),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4701),
    [anon_sym_if] = ACTIONS(4701),
    [anon_sym_SEMI] = ACTIONS(4701),
    [anon_sym_else] = ACTIONS(4701),
    [anon_sym_when] = ACTIONS(4701),
    [anon_sym_in] = ACTIONS(4701),
    [anon_sym_case] = ACTIONS(4701),
    [anon_sym_QMARK] = ACTIONS(4701),
    [anon_sym_PLUS] = ACTIONS(4703),
    [anon_sym_DASH] = ACTIONS(4703),
    [anon_sym_TILDE] = ACTIONS(4703),
    [anon_sym_AMP] = ACTIONS(4703),
    [anon_sym_PIPE_PIPE] = ACTIONS(4703),
    [anon_sym_or_else] = ACTIONS(4701),
    [anon_sym_AMP_AMP] = ACTIONS(4703),
    [anon_sym_GT] = ACTIONS(4703),
    [anon_sym_GT_EQ] = ACTIONS(4701),
    [anon_sym_LT_EQ] = ACTIONS(4701),
    [anon_sym_LT] = ACTIONS(4703),
    [anon_sym_EQ_EQ] = ACTIONS(4701),
    [anon_sym_BANG_EQ] = ACTIONS(4701),
    [anon_sym_TILDE_EQ] = ACTIONS(4701),
    [anon_sym_AMP_TILDE] = ACTIONS(4703),
    [anon_sym_LT_LT] = ACTIONS(4703),
    [anon_sym_GT_GT] = ACTIONS(4703),
    [anon_sym_STAR] = ACTIONS(4703),
    [anon_sym_SLASH] = ACTIONS(4703),
    [anon_sym_PERCENT] = ACTIONS(4703),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4701),
    [anon_sym_DOT] = ACTIONS(4703),
    [anon_sym_LBRACK] = ACTIONS(4701),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4701),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4701),
    [anon_sym_not_in] = ACTIONS(4701),
    [anon_sym_or_return] = ACTIONS(4701),
    [anon_sym_or_continue] = ACTIONS(4701),
    [anon_sym_or_break] = ACTIONS(4701),
    [anon_sym_CARET] = ACTIONS(4703),
    [sym_uninitialized] = ACTIONS(4701),
    [sym_tag] = ACTIONS(4701),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4701),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [715] = {
    [ts_builtin_sym_end] = ACTIONS(4705),
    [anon_sym_LBRACE] = ACTIONS(4705),
    [anon_sym_RBRACE] = ACTIONS(4705),
    [anon_sym_COMMA] = ACTIONS(4705),
    [anon_sym_COLON_COLON] = ACTIONS(4705),
    [anon_sym_DASH_GT] = ACTIONS(4705),
    [anon_sym_where] = ACTIONS(4705),
    [anon_sym_EQ] = ACTIONS(4707),
    [anon_sym_COLON] = ACTIONS(4707),
    [anon_sym_PIPE] = ACTIONS(4707),
    [anon_sym_COLON_EQ] = ACTIONS(4705),
    [anon_sym_LPAREN] = ACTIONS(4705),
    [anon_sym_PLUS_EQ] = ACTIONS(4705),
    [anon_sym_DASH_EQ] = ACTIONS(4705),
    [anon_sym_STAR_EQ] = ACTIONS(4705),
    [anon_sym_SLASH_EQ] = ACTIONS(4705),
    [anon_sym_PERCENT_EQ] = ACTIONS(4705),
    [anon_sym_AMP_EQ] = ACTIONS(4705),
    [anon_sym_PIPE_EQ] = ACTIONS(4705),
    [anon_sym_CARET_EQ] = ACTIONS(4705),
    [anon_sym_LT_LT_EQ] = ACTIONS(4705),
    [anon_sym_GT_GT_EQ] = ACTIONS(4705),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4705),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4705),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4705),
    [anon_sym_if] = ACTIONS(4705),
    [anon_sym_SEMI] = ACTIONS(4705),
    [anon_sym_else] = ACTIONS(4705),
    [anon_sym_when] = ACTIONS(4705),
    [anon_sym_in] = ACTIONS(4705),
    [anon_sym_case] = ACTIONS(4705),
    [anon_sym_QMARK] = ACTIONS(4705),
    [anon_sym_PLUS] = ACTIONS(4707),
    [anon_sym_DASH] = ACTIONS(4707),
    [anon_sym_TILDE] = ACTIONS(4707),
    [anon_sym_AMP] = ACTIONS(4707),
    [anon_sym_PIPE_PIPE] = ACTIONS(4707),
    [anon_sym_or_else] = ACTIONS(4705),
    [anon_sym_AMP_AMP] = ACTIONS(4707),
    [anon_sym_GT] = ACTIONS(4707),
    [anon_sym_GT_EQ] = ACTIONS(4705),
    [anon_sym_LT_EQ] = ACTIONS(4705),
    [anon_sym_LT] = ACTIONS(4707),
    [anon_sym_EQ_EQ] = ACTIONS(4705),
    [anon_sym_BANG_EQ] = ACTIONS(4705),
    [anon_sym_TILDE_EQ] = ACTIONS(4705),
    [anon_sym_AMP_TILDE] = ACTIONS(4707),
    [anon_sym_LT_LT] = ACTIONS(4707),
    [anon_sym_GT_GT] = ACTIONS(4707),
    [anon_sym_STAR] = ACTIONS(4707),
    [anon_sym_SLASH] = ACTIONS(4707),
    [anon_sym_PERCENT] = ACTIONS(4707),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4705),
    [anon_sym_DOT] = ACTIONS(4707),
    [anon_sym_LBRACK] = ACTIONS(4705),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4705),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4705),
    [anon_sym_not_in] = ACTIONS(4705),
    [anon_sym_or_return] = ACTIONS(4705),
    [anon_sym_or_continue] = ACTIONS(4705),
    [anon_sym_or_break] = ACTIONS(4705),
    [anon_sym_CARET] = ACTIONS(4707),
    [sym_uninitialized] = ACTIONS(4705),
    [sym_tag] = ACTIONS(4705),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4705),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [716] = {
    [sym_block] = STATE(1568),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3380),
    [sym_tag] = ACTIONS(3517),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [717] = {
    [ts_builtin_sym_end] = ACTIONS(4709),
    [anon_sym_LBRACE] = ACTIONS(4709),
    [anon_sym_RBRACE] = ACTIONS(4709),
    [anon_sym_COMMA] = ACTIONS(4709),
    [anon_sym_COLON_COLON] = ACTIONS(4709),
    [anon_sym_DASH_GT] = ACTIONS(4709),
    [anon_sym_where] = ACTIONS(4709),
    [anon_sym_EQ] = ACTIONS(4711),
    [anon_sym_COLON] = ACTIONS(4711),
    [anon_sym_PIPE] = ACTIONS(4711),
    [anon_sym_COLON_EQ] = ACTIONS(4709),
    [anon_sym_LPAREN] = ACTIONS(4709),
    [anon_sym_PLUS_EQ] = ACTIONS(4709),
    [anon_sym_DASH_EQ] = ACTIONS(4709),
    [anon_sym_STAR_EQ] = ACTIONS(4709),
    [anon_sym_SLASH_EQ] = ACTIONS(4709),
    [anon_sym_PERCENT_EQ] = ACTIONS(4709),
    [anon_sym_AMP_EQ] = ACTIONS(4709),
    [anon_sym_PIPE_EQ] = ACTIONS(4709),
    [anon_sym_CARET_EQ] = ACTIONS(4709),
    [anon_sym_LT_LT_EQ] = ACTIONS(4709),
    [anon_sym_GT_GT_EQ] = ACTIONS(4709),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4709),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4709),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4709),
    [anon_sym_if] = ACTIONS(4709),
    [anon_sym_SEMI] = ACTIONS(4709),
    [anon_sym_else] = ACTIONS(4709),
    [anon_sym_when] = ACTIONS(4709),
    [anon_sym_in] = ACTIONS(4709),
    [anon_sym_case] = ACTIONS(4709),
    [anon_sym_QMARK] = ACTIONS(4709),
    [anon_sym_PLUS] = ACTIONS(4711),
    [anon_sym_DASH] = ACTIONS(4711),
    [anon_sym_TILDE] = ACTIONS(4711),
    [anon_sym_AMP] = ACTIONS(4711),
    [anon_sym_PIPE_PIPE] = ACTIONS(4711),
    [anon_sym_or_else] = ACTIONS(4709),
    [anon_sym_AMP_AMP] = ACTIONS(4711),
    [anon_sym_GT] = ACTIONS(4711),
    [anon_sym_GT_EQ] = ACTIONS(4709),
    [anon_sym_LT_EQ] = ACTIONS(4709),
    [anon_sym_LT] = ACTIONS(4711),
    [anon_sym_EQ_EQ] = ACTIONS(4709),
    [anon_sym_BANG_EQ] = ACTIONS(4709),
    [anon_sym_TILDE_EQ] = ACTIONS(4709),
    [anon_sym_AMP_TILDE] = ACTIONS(4711),
    [anon_sym_LT_LT] = ACTIONS(4711),
    [anon_sym_GT_GT] = ACTIONS(4711),
    [anon_sym_STAR] = ACTIONS(4711),
    [anon_sym_SLASH] = ACTIONS(4711),
    [anon_sym_PERCENT] = ACTIONS(4711),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4709),
    [anon_sym_DOT] = ACTIONS(4711),
    [anon_sym_LBRACK] = ACTIONS(4709),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4709),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4709),
    [anon_sym_not_in] = ACTIONS(4709),
    [anon_sym_or_return] = ACTIONS(4709),
    [anon_sym_or_continue] = ACTIONS(4709),
    [anon_sym_or_break] = ACTIONS(4709),
    [anon_sym_CARET] = ACTIONS(4711),
    [sym_uninitialized] = ACTIONS(4709),
    [sym_tag] = ACTIONS(4709),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4709),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [718] = {
    [ts_builtin_sym_end] = ACTIONS(4713),
    [anon_sym_LBRACE] = ACTIONS(4713),
    [anon_sym_RBRACE] = ACTIONS(4713),
    [anon_sym_COMMA] = ACTIONS(4713),
    [anon_sym_COLON_COLON] = ACTIONS(4713),
    [anon_sym_DASH_GT] = ACTIONS(4713),
    [anon_sym_where] = ACTIONS(4713),
    [anon_sym_EQ] = ACTIONS(4715),
    [anon_sym_COLON] = ACTIONS(4715),
    [anon_sym_PIPE] = ACTIONS(4715),
    [anon_sym_COLON_EQ] = ACTIONS(4713),
    [anon_sym_LPAREN] = ACTIONS(4713),
    [anon_sym_PLUS_EQ] = ACTIONS(4713),
    [anon_sym_DASH_EQ] = ACTIONS(4713),
    [anon_sym_STAR_EQ] = ACTIONS(4713),
    [anon_sym_SLASH_EQ] = ACTIONS(4713),
    [anon_sym_PERCENT_EQ] = ACTIONS(4713),
    [anon_sym_AMP_EQ] = ACTIONS(4713),
    [anon_sym_PIPE_EQ] = ACTIONS(4713),
    [anon_sym_CARET_EQ] = ACTIONS(4713),
    [anon_sym_LT_LT_EQ] = ACTIONS(4713),
    [anon_sym_GT_GT_EQ] = ACTIONS(4713),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4713),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4713),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4713),
    [anon_sym_if] = ACTIONS(4713),
    [anon_sym_SEMI] = ACTIONS(4713),
    [anon_sym_else] = ACTIONS(4713),
    [anon_sym_when] = ACTIONS(4713),
    [anon_sym_in] = ACTIONS(4713),
    [anon_sym_case] = ACTIONS(4713),
    [anon_sym_QMARK] = ACTIONS(4713),
    [anon_sym_PLUS] = ACTIONS(4715),
    [anon_sym_DASH] = ACTIONS(4715),
    [anon_sym_TILDE] = ACTIONS(4715),
    [anon_sym_AMP] = ACTIONS(4715),
    [anon_sym_PIPE_PIPE] = ACTIONS(4715),
    [anon_sym_or_else] = ACTIONS(4713),
    [anon_sym_AMP_AMP] = ACTIONS(4715),
    [anon_sym_GT] = ACTIONS(4715),
    [anon_sym_GT_EQ] = ACTIONS(4713),
    [anon_sym_LT_EQ] = ACTIONS(4713),
    [anon_sym_LT] = ACTIONS(4715),
    [anon_sym_EQ_EQ] = ACTIONS(4713),
    [anon_sym_BANG_EQ] = ACTIONS(4713),
    [anon_sym_TILDE_EQ] = ACTIONS(4713),
    [anon_sym_AMP_TILDE] = ACTIONS(4715),
    [anon_sym_LT_LT] = ACTIONS(4715),
    [anon_sym_GT_GT] = ACTIONS(4715),
    [anon_sym_STAR] = ACTIONS(4715),
    [anon_sym_SLASH] = ACTIONS(4715),
    [anon_sym_PERCENT] = ACTIONS(4715),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4713),
    [anon_sym_DOT] = ACTIONS(4715),
    [anon_sym_LBRACK] = ACTIONS(4713),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4713),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4713),
    [anon_sym_not_in] = ACTIONS(4713),
    [anon_sym_or_return] = ACTIONS(4713),
    [anon_sym_or_continue] = ACTIONS(4713),
    [anon_sym_or_break] = ACTIONS(4713),
    [anon_sym_CARET] = ACTIONS(4715),
    [sym_uninitialized] = ACTIONS(4713),
    [sym_tag] = ACTIONS(4713),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4713),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [719] = {
    [ts_builtin_sym_end] = ACTIONS(4717),
    [anon_sym_LBRACE] = ACTIONS(4717),
    [anon_sym_RBRACE] = ACTIONS(4717),
    [anon_sym_COMMA] = ACTIONS(4717),
    [anon_sym_COLON_COLON] = ACTIONS(4717),
    [anon_sym_DASH_GT] = ACTIONS(4717),
    [anon_sym_where] = ACTIONS(4717),
    [anon_sym_EQ] = ACTIONS(4719),
    [anon_sym_COLON] = ACTIONS(4719),
    [anon_sym_PIPE] = ACTIONS(4719),
    [anon_sym_COLON_EQ] = ACTIONS(4717),
    [anon_sym_LPAREN] = ACTIONS(4717),
    [anon_sym_PLUS_EQ] = ACTIONS(4717),
    [anon_sym_DASH_EQ] = ACTIONS(4717),
    [anon_sym_STAR_EQ] = ACTIONS(4717),
    [anon_sym_SLASH_EQ] = ACTIONS(4717),
    [anon_sym_PERCENT_EQ] = ACTIONS(4717),
    [anon_sym_AMP_EQ] = ACTIONS(4717),
    [anon_sym_PIPE_EQ] = ACTIONS(4717),
    [anon_sym_CARET_EQ] = ACTIONS(4717),
    [anon_sym_LT_LT_EQ] = ACTIONS(4717),
    [anon_sym_GT_GT_EQ] = ACTIONS(4717),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4717),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4717),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4717),
    [anon_sym_if] = ACTIONS(4717),
    [anon_sym_SEMI] = ACTIONS(4717),
    [anon_sym_else] = ACTIONS(4717),
    [anon_sym_when] = ACTIONS(4717),
    [anon_sym_in] = ACTIONS(4717),
    [anon_sym_case] = ACTIONS(4717),
    [anon_sym_QMARK] = ACTIONS(4717),
    [anon_sym_PLUS] = ACTIONS(4719),
    [anon_sym_DASH] = ACTIONS(4719),
    [anon_sym_TILDE] = ACTIONS(4719),
    [anon_sym_AMP] = ACTIONS(4719),
    [anon_sym_PIPE_PIPE] = ACTIONS(4719),
    [anon_sym_or_else] = ACTIONS(4717),
    [anon_sym_AMP_AMP] = ACTIONS(4719),
    [anon_sym_GT] = ACTIONS(4719),
    [anon_sym_GT_EQ] = ACTIONS(4717),
    [anon_sym_LT_EQ] = ACTIONS(4717),
    [anon_sym_LT] = ACTIONS(4719),
    [anon_sym_EQ_EQ] = ACTIONS(4717),
    [anon_sym_BANG_EQ] = ACTIONS(4717),
    [anon_sym_TILDE_EQ] = ACTIONS(4717),
    [anon_sym_AMP_TILDE] = ACTIONS(4719),
    [anon_sym_LT_LT] = ACTIONS(4719),
    [anon_sym_GT_GT] = ACTIONS(4719),
    [anon_sym_STAR] = ACTIONS(4719),
    [anon_sym_SLASH] = ACTIONS(4719),
    [anon_sym_PERCENT] = ACTIONS(4719),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4717),
    [anon_sym_DOT] = ACTIONS(4719),
    [anon_sym_LBRACK] = ACTIONS(4717),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4717),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4717),
    [anon_sym_not_in] = ACTIONS(4717),
    [anon_sym_or_return] = ACTIONS(4717),
    [anon_sym_or_continue] = ACTIONS(4717),
    [anon_sym_or_break] = ACTIONS(4717),
    [anon_sym_CARET] = ACTIONS(4719),
    [sym_uninitialized] = ACTIONS(4717),
    [sym_tag] = ACTIONS(4717),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4717),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [720] = {
    [sym_block] = STATE(1587),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3421),
    [sym_tag] = ACTIONS(3519),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [721] = {
    [ts_builtin_sym_end] = ACTIONS(4721),
    [anon_sym_LBRACE] = ACTIONS(4721),
    [anon_sym_RBRACE] = ACTIONS(4721),
    [anon_sym_COMMA] = ACTIONS(4721),
    [anon_sym_COLON_COLON] = ACTIONS(4721),
    [anon_sym_DASH_GT] = ACTIONS(4721),
    [anon_sym_where] = ACTIONS(4721),
    [anon_sym_EQ] = ACTIONS(4723),
    [anon_sym_COLON] = ACTIONS(4723),
    [anon_sym_PIPE] = ACTIONS(4723),
    [anon_sym_COLON_EQ] = ACTIONS(4721),
    [anon_sym_LPAREN] = ACTIONS(4721),
    [anon_sym_PLUS_EQ] = ACTIONS(4721),
    [anon_sym_DASH_EQ] = ACTIONS(4721),
    [anon_sym_STAR_EQ] = ACTIONS(4721),
    [anon_sym_SLASH_EQ] = ACTIONS(4721),
    [anon_sym_PERCENT_EQ] = ACTIONS(4721),
    [anon_sym_AMP_EQ] = ACTIONS(4721),
    [anon_sym_PIPE_EQ] = ACTIONS(4721),
    [anon_sym_CARET_EQ] = ACTIONS(4721),
    [anon_sym_LT_LT_EQ] = ACTIONS(4721),
    [anon_sym_GT_GT_EQ] = ACTIONS(4721),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4721),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4721),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4721),
    [anon_sym_if] = ACTIONS(4721),
    [anon_sym_SEMI] = ACTIONS(4721),
    [anon_sym_else] = ACTIONS(4721),
    [anon_sym_when] = ACTIONS(4721),
    [anon_sym_in] = ACTIONS(4721),
    [anon_sym_case] = ACTIONS(4721),
    [anon_sym_QMARK] = ACTIONS(4721),
    [anon_sym_PLUS] = ACTIONS(4723),
    [anon_sym_DASH] = ACTIONS(4723),
    [anon_sym_TILDE] = ACTIONS(4723),
    [anon_sym_AMP] = ACTIONS(4723),
    [anon_sym_PIPE_PIPE] = ACTIONS(4723),
    [anon_sym_or_else] = ACTIONS(4721),
    [anon_sym_AMP_AMP] = ACTIONS(4723),
    [anon_sym_GT] = ACTIONS(4723),
    [anon_sym_GT_EQ] = ACTIONS(4721),
    [anon_sym_LT_EQ] = ACTIONS(4721),
    [anon_sym_LT] = ACTIONS(4723),
    [anon_sym_EQ_EQ] = ACTIONS(4721),
    [anon_sym_BANG_EQ] = ACTIONS(4721),
    [anon_sym_TILDE_EQ] = ACTIONS(4721),
    [anon_sym_AMP_TILDE] = ACTIONS(4723),
    [anon_sym_LT_LT] = ACTIONS(4723),
    [anon_sym_GT_GT] = ACTIONS(4723),
    [anon_sym_STAR] = ACTIONS(4723),
    [anon_sym_SLASH] = ACTIONS(4723),
    [anon_sym_PERCENT] = ACTIONS(4723),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4721),
    [anon_sym_DOT] = ACTIONS(4723),
    [anon_sym_LBRACK] = ACTIONS(4721),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4721),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4721),
    [anon_sym_not_in] = ACTIONS(4721),
    [anon_sym_or_return] = ACTIONS(4721),
    [anon_sym_or_continue] = ACTIONS(4721),
    [anon_sym_or_break] = ACTIONS(4721),
    [anon_sym_CARET] = ACTIONS(4723),
    [sym_uninitialized] = ACTIONS(4721),
    [sym_tag] = ACTIONS(4721),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4721),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [722] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4485),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4637),
    [anon_sym_GT] = ACTIONS(4637),
    [anon_sym_GT_EQ] = ACTIONS(4635),
    [anon_sym_LT_EQ] = ACTIONS(4635),
    [anon_sym_LT] = ACTIONS(4637),
    [anon_sym_EQ_EQ] = ACTIONS(4635),
    [anon_sym_BANG_EQ] = ACTIONS(4635),
    [anon_sym_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [723] = {
    [ts_builtin_sym_end] = ACTIONS(4725),
    [anon_sym_LBRACE] = ACTIONS(4725),
    [anon_sym_RBRACE] = ACTIONS(4725),
    [anon_sym_COMMA] = ACTIONS(4725),
    [anon_sym_COLON_COLON] = ACTIONS(4725),
    [anon_sym_DASH_GT] = ACTIONS(4725),
    [anon_sym_where] = ACTIONS(4725),
    [anon_sym_EQ] = ACTIONS(4727),
    [anon_sym_COLON] = ACTIONS(4727),
    [anon_sym_PIPE] = ACTIONS(4727),
    [anon_sym_COLON_EQ] = ACTIONS(4725),
    [anon_sym_LPAREN] = ACTIONS(4725),
    [anon_sym_PLUS_EQ] = ACTIONS(4725),
    [anon_sym_DASH_EQ] = ACTIONS(4725),
    [anon_sym_STAR_EQ] = ACTIONS(4725),
    [anon_sym_SLASH_EQ] = ACTIONS(4725),
    [anon_sym_PERCENT_EQ] = ACTIONS(4725),
    [anon_sym_AMP_EQ] = ACTIONS(4725),
    [anon_sym_PIPE_EQ] = ACTIONS(4725),
    [anon_sym_CARET_EQ] = ACTIONS(4725),
    [anon_sym_LT_LT_EQ] = ACTIONS(4725),
    [anon_sym_GT_GT_EQ] = ACTIONS(4725),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4725),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4725),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4725),
    [anon_sym_if] = ACTIONS(4725),
    [anon_sym_SEMI] = ACTIONS(4725),
    [anon_sym_else] = ACTIONS(4725),
    [anon_sym_when] = ACTIONS(4725),
    [anon_sym_in] = ACTIONS(4725),
    [anon_sym_case] = ACTIONS(4725),
    [anon_sym_QMARK] = ACTIONS(4725),
    [anon_sym_PLUS] = ACTIONS(4727),
    [anon_sym_DASH] = ACTIONS(4727),
    [anon_sym_TILDE] = ACTIONS(4727),
    [anon_sym_AMP] = ACTIONS(4727),
    [anon_sym_PIPE_PIPE] = ACTIONS(4727),
    [anon_sym_or_else] = ACTIONS(4725),
    [anon_sym_AMP_AMP] = ACTIONS(4727),
    [anon_sym_GT] = ACTIONS(4727),
    [anon_sym_GT_EQ] = ACTIONS(4725),
    [anon_sym_LT_EQ] = ACTIONS(4725),
    [anon_sym_LT] = ACTIONS(4727),
    [anon_sym_EQ_EQ] = ACTIONS(4725),
    [anon_sym_BANG_EQ] = ACTIONS(4725),
    [anon_sym_TILDE_EQ] = ACTIONS(4725),
    [anon_sym_AMP_TILDE] = ACTIONS(4727),
    [anon_sym_LT_LT] = ACTIONS(4727),
    [anon_sym_GT_GT] = ACTIONS(4727),
    [anon_sym_STAR] = ACTIONS(4727),
    [anon_sym_SLASH] = ACTIONS(4727),
    [anon_sym_PERCENT] = ACTIONS(4727),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4725),
    [anon_sym_DOT] = ACTIONS(4727),
    [anon_sym_LBRACK] = ACTIONS(4725),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4725),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4725),
    [anon_sym_not_in] = ACTIONS(4725),
    [anon_sym_or_return] = ACTIONS(4725),
    [anon_sym_or_continue] = ACTIONS(4725),
    [anon_sym_or_break] = ACTIONS(4725),
    [anon_sym_CARET] = ACTIONS(4727),
    [sym_uninitialized] = ACTIONS(4725),
    [sym_tag] = ACTIONS(4725),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4725),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [724] = {
    [sym_procedure] = STATE(7386),
    [sym_expression] = STATE(5803),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym__procedure_type] = STATE(8648),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(4729),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [725] = {
    [ts_builtin_sym_end] = ACTIONS(4731),
    [anon_sym_LBRACE] = ACTIONS(4731),
    [anon_sym_RBRACE] = ACTIONS(4731),
    [anon_sym_COMMA] = ACTIONS(4731),
    [anon_sym_COLON_COLON] = ACTIONS(4731),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4731),
    [anon_sym_EQ] = ACTIONS(4733),
    [anon_sym_COLON] = ACTIONS(4733),
    [anon_sym_PIPE] = ACTIONS(4733),
    [anon_sym_COLON_EQ] = ACTIONS(4731),
    [anon_sym_LPAREN] = ACTIONS(4731),
    [anon_sym_PLUS_EQ] = ACTIONS(4731),
    [anon_sym_DASH_EQ] = ACTIONS(4731),
    [anon_sym_STAR_EQ] = ACTIONS(4731),
    [anon_sym_SLASH_EQ] = ACTIONS(4731),
    [anon_sym_PERCENT_EQ] = ACTIONS(4731),
    [anon_sym_AMP_EQ] = ACTIONS(4731),
    [anon_sym_PIPE_EQ] = ACTIONS(4731),
    [anon_sym_CARET_EQ] = ACTIONS(4731),
    [anon_sym_LT_LT_EQ] = ACTIONS(4731),
    [anon_sym_GT_GT_EQ] = ACTIONS(4731),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4731),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4731),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4731),
    [anon_sym_if] = ACTIONS(4731),
    [anon_sym_SEMI] = ACTIONS(4731),
    [anon_sym_else] = ACTIONS(4731),
    [anon_sym_when] = ACTIONS(4731),
    [anon_sym_in] = ACTIONS(4731),
    [anon_sym_case] = ACTIONS(4731),
    [anon_sym_QMARK] = ACTIONS(4731),
    [anon_sym_PLUS] = ACTIONS(4733),
    [anon_sym_DASH] = ACTIONS(4733),
    [anon_sym_TILDE] = ACTIONS(4733),
    [anon_sym_AMP] = ACTIONS(4733),
    [anon_sym_PIPE_PIPE] = ACTIONS(4733),
    [anon_sym_or_else] = ACTIONS(4731),
    [anon_sym_AMP_AMP] = ACTIONS(4733),
    [anon_sym_GT] = ACTIONS(4733),
    [anon_sym_GT_EQ] = ACTIONS(4731),
    [anon_sym_LT_EQ] = ACTIONS(4731),
    [anon_sym_LT] = ACTIONS(4733),
    [anon_sym_EQ_EQ] = ACTIONS(4731),
    [anon_sym_BANG_EQ] = ACTIONS(4731),
    [anon_sym_TILDE_EQ] = ACTIONS(4731),
    [anon_sym_AMP_TILDE] = ACTIONS(4733),
    [anon_sym_LT_LT] = ACTIONS(4733),
    [anon_sym_GT_GT] = ACTIONS(4733),
    [anon_sym_STAR] = ACTIONS(4733),
    [anon_sym_SLASH] = ACTIONS(4733),
    [anon_sym_PERCENT] = ACTIONS(4733),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4731),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4731),
    [anon_sym_or_return] = ACTIONS(4731),
    [anon_sym_or_continue] = ACTIONS(4731),
    [anon_sym_or_break] = ACTIONS(4731),
    [anon_sym_CARET] = ACTIONS(4733),
    [sym_uninitialized] = ACTIONS(4731),
    [sym_tag] = ACTIONS(4731),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4731),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [726] = {
    [ts_builtin_sym_end] = ACTIONS(4735),
    [anon_sym_LBRACE] = ACTIONS(4735),
    [anon_sym_RBRACE] = ACTIONS(4735),
    [anon_sym_COMMA] = ACTIONS(4735),
    [anon_sym_COLON_COLON] = ACTIONS(4735),
    [anon_sym_DASH_GT] = ACTIONS(4735),
    [anon_sym_where] = ACTIONS(4735),
    [anon_sym_EQ] = ACTIONS(4737),
    [anon_sym_COLON] = ACTIONS(4737),
    [anon_sym_PIPE] = ACTIONS(4737),
    [anon_sym_COLON_EQ] = ACTIONS(4735),
    [anon_sym_LPAREN] = ACTIONS(4735),
    [anon_sym_PLUS_EQ] = ACTIONS(4735),
    [anon_sym_DASH_EQ] = ACTIONS(4735),
    [anon_sym_STAR_EQ] = ACTIONS(4735),
    [anon_sym_SLASH_EQ] = ACTIONS(4735),
    [anon_sym_PERCENT_EQ] = ACTIONS(4735),
    [anon_sym_AMP_EQ] = ACTIONS(4735),
    [anon_sym_PIPE_EQ] = ACTIONS(4735),
    [anon_sym_CARET_EQ] = ACTIONS(4735),
    [anon_sym_LT_LT_EQ] = ACTIONS(4735),
    [anon_sym_GT_GT_EQ] = ACTIONS(4735),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4735),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4735),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4735),
    [anon_sym_if] = ACTIONS(4735),
    [anon_sym_SEMI] = ACTIONS(4735),
    [anon_sym_else] = ACTIONS(4735),
    [anon_sym_when] = ACTIONS(4735),
    [anon_sym_in] = ACTIONS(4735),
    [anon_sym_case] = ACTIONS(4735),
    [anon_sym_QMARK] = ACTIONS(4735),
    [anon_sym_PLUS] = ACTIONS(4737),
    [anon_sym_DASH] = ACTIONS(4737),
    [anon_sym_TILDE] = ACTIONS(4737),
    [anon_sym_AMP] = ACTIONS(4737),
    [anon_sym_PIPE_PIPE] = ACTIONS(4737),
    [anon_sym_or_else] = ACTIONS(4735),
    [anon_sym_AMP_AMP] = ACTIONS(4737),
    [anon_sym_GT] = ACTIONS(4737),
    [anon_sym_GT_EQ] = ACTIONS(4735),
    [anon_sym_LT_EQ] = ACTIONS(4735),
    [anon_sym_LT] = ACTIONS(4737),
    [anon_sym_EQ_EQ] = ACTIONS(4735),
    [anon_sym_BANG_EQ] = ACTIONS(4735),
    [anon_sym_TILDE_EQ] = ACTIONS(4735),
    [anon_sym_AMP_TILDE] = ACTIONS(4737),
    [anon_sym_LT_LT] = ACTIONS(4737),
    [anon_sym_GT_GT] = ACTIONS(4737),
    [anon_sym_STAR] = ACTIONS(4737),
    [anon_sym_SLASH] = ACTIONS(4737),
    [anon_sym_PERCENT] = ACTIONS(4737),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4735),
    [anon_sym_DOT] = ACTIONS(4737),
    [anon_sym_LBRACK] = ACTIONS(4735),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4735),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4735),
    [anon_sym_not_in] = ACTIONS(4735),
    [anon_sym_or_return] = ACTIONS(4735),
    [anon_sym_or_continue] = ACTIONS(4735),
    [anon_sym_or_break] = ACTIONS(4735),
    [anon_sym_CARET] = ACTIONS(4737),
    [sym_uninitialized] = ACTIONS(4735),
    [sym_tag] = ACTIONS(4735),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4735),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [727] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4637),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4637),
    [anon_sym_AMP] = ACTIONS(4637),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4637),
    [anon_sym_GT] = ACTIONS(4637),
    [anon_sym_GT_EQ] = ACTIONS(4635),
    [anon_sym_LT_EQ] = ACTIONS(4635),
    [anon_sym_LT] = ACTIONS(4637),
    [anon_sym_EQ_EQ] = ACTIONS(4635),
    [anon_sym_BANG_EQ] = ACTIONS(4635),
    [anon_sym_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE] = ACTIONS(4637),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [728] = {
    [ts_builtin_sym_end] = ACTIONS(4739),
    [anon_sym_LBRACE] = ACTIONS(4739),
    [anon_sym_RBRACE] = ACTIONS(4739),
    [anon_sym_COMMA] = ACTIONS(4739),
    [anon_sym_COLON_COLON] = ACTIONS(4739),
    [anon_sym_DASH_GT] = ACTIONS(4739),
    [anon_sym_where] = ACTIONS(4739),
    [anon_sym_EQ] = ACTIONS(4741),
    [anon_sym_COLON] = ACTIONS(4741),
    [anon_sym_PIPE] = ACTIONS(4741),
    [anon_sym_COLON_EQ] = ACTIONS(4739),
    [anon_sym_LPAREN] = ACTIONS(4739),
    [anon_sym_PLUS_EQ] = ACTIONS(4739),
    [anon_sym_DASH_EQ] = ACTIONS(4739),
    [anon_sym_STAR_EQ] = ACTIONS(4739),
    [anon_sym_SLASH_EQ] = ACTIONS(4739),
    [anon_sym_PERCENT_EQ] = ACTIONS(4739),
    [anon_sym_AMP_EQ] = ACTIONS(4739),
    [anon_sym_PIPE_EQ] = ACTIONS(4739),
    [anon_sym_CARET_EQ] = ACTIONS(4739),
    [anon_sym_LT_LT_EQ] = ACTIONS(4739),
    [anon_sym_GT_GT_EQ] = ACTIONS(4739),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4739),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4739),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4739),
    [anon_sym_if] = ACTIONS(4739),
    [anon_sym_SEMI] = ACTIONS(4739),
    [anon_sym_else] = ACTIONS(4739),
    [anon_sym_when] = ACTIONS(4739),
    [anon_sym_in] = ACTIONS(4739),
    [anon_sym_case] = ACTIONS(4739),
    [anon_sym_QMARK] = ACTIONS(4739),
    [anon_sym_PLUS] = ACTIONS(4741),
    [anon_sym_DASH] = ACTIONS(4741),
    [anon_sym_TILDE] = ACTIONS(4741),
    [anon_sym_AMP] = ACTIONS(4741),
    [anon_sym_PIPE_PIPE] = ACTIONS(4741),
    [anon_sym_or_else] = ACTIONS(4739),
    [anon_sym_AMP_AMP] = ACTIONS(4741),
    [anon_sym_GT] = ACTIONS(4741),
    [anon_sym_GT_EQ] = ACTIONS(4739),
    [anon_sym_LT_EQ] = ACTIONS(4739),
    [anon_sym_LT] = ACTIONS(4741),
    [anon_sym_EQ_EQ] = ACTIONS(4739),
    [anon_sym_BANG_EQ] = ACTIONS(4739),
    [anon_sym_TILDE_EQ] = ACTIONS(4739),
    [anon_sym_AMP_TILDE] = ACTIONS(4741),
    [anon_sym_LT_LT] = ACTIONS(4741),
    [anon_sym_GT_GT] = ACTIONS(4741),
    [anon_sym_STAR] = ACTIONS(4741),
    [anon_sym_SLASH] = ACTIONS(4741),
    [anon_sym_PERCENT] = ACTIONS(4741),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4739),
    [anon_sym_DOT] = ACTIONS(4741),
    [anon_sym_LBRACK] = ACTIONS(4739),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4739),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4739),
    [anon_sym_not_in] = ACTIONS(4739),
    [anon_sym_or_return] = ACTIONS(4739),
    [anon_sym_or_continue] = ACTIONS(4739),
    [anon_sym_or_break] = ACTIONS(4739),
    [anon_sym_CARET] = ACTIONS(4741),
    [sym_uninitialized] = ACTIONS(4739),
    [sym_tag] = ACTIONS(4739),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4739),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [729] = {
    [sym_block] = STATE(2326),
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3451),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(3471),
    [sym_tag] = ACTIONS(3473),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [730] = {
    [ts_builtin_sym_end] = ACTIONS(4743),
    [anon_sym_LBRACE] = ACTIONS(4743),
    [anon_sym_RBRACE] = ACTIONS(4743),
    [anon_sym_COMMA] = ACTIONS(4743),
    [anon_sym_COLON_COLON] = ACTIONS(4743),
    [anon_sym_DASH_GT] = ACTIONS(4743),
    [anon_sym_where] = ACTIONS(4743),
    [anon_sym_EQ] = ACTIONS(4745),
    [anon_sym_COLON] = ACTIONS(4745),
    [anon_sym_PIPE] = ACTIONS(4745),
    [anon_sym_COLON_EQ] = ACTIONS(4743),
    [anon_sym_LPAREN] = ACTIONS(4743),
    [anon_sym_PLUS_EQ] = ACTIONS(4743),
    [anon_sym_DASH_EQ] = ACTIONS(4743),
    [anon_sym_STAR_EQ] = ACTIONS(4743),
    [anon_sym_SLASH_EQ] = ACTIONS(4743),
    [anon_sym_PERCENT_EQ] = ACTIONS(4743),
    [anon_sym_AMP_EQ] = ACTIONS(4743),
    [anon_sym_PIPE_EQ] = ACTIONS(4743),
    [anon_sym_CARET_EQ] = ACTIONS(4743),
    [anon_sym_LT_LT_EQ] = ACTIONS(4743),
    [anon_sym_GT_GT_EQ] = ACTIONS(4743),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4743),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4743),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4743),
    [anon_sym_if] = ACTIONS(4743),
    [anon_sym_SEMI] = ACTIONS(4743),
    [anon_sym_else] = ACTIONS(4743),
    [anon_sym_when] = ACTIONS(4743),
    [anon_sym_in] = ACTIONS(4743),
    [anon_sym_case] = ACTIONS(4743),
    [anon_sym_QMARK] = ACTIONS(4743),
    [anon_sym_PLUS] = ACTIONS(4745),
    [anon_sym_DASH] = ACTIONS(4745),
    [anon_sym_TILDE] = ACTIONS(4745),
    [anon_sym_AMP] = ACTIONS(4745),
    [anon_sym_PIPE_PIPE] = ACTIONS(4745),
    [anon_sym_or_else] = ACTIONS(4743),
    [anon_sym_AMP_AMP] = ACTIONS(4745),
    [anon_sym_GT] = ACTIONS(4745),
    [anon_sym_GT_EQ] = ACTIONS(4743),
    [anon_sym_LT_EQ] = ACTIONS(4743),
    [anon_sym_LT] = ACTIONS(4745),
    [anon_sym_EQ_EQ] = ACTIONS(4743),
    [anon_sym_BANG_EQ] = ACTIONS(4743),
    [anon_sym_TILDE_EQ] = ACTIONS(4743),
    [anon_sym_AMP_TILDE] = ACTIONS(4745),
    [anon_sym_LT_LT] = ACTIONS(4745),
    [anon_sym_GT_GT] = ACTIONS(4745),
    [anon_sym_STAR] = ACTIONS(4745),
    [anon_sym_SLASH] = ACTIONS(4745),
    [anon_sym_PERCENT] = ACTIONS(4745),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4743),
    [anon_sym_DOT] = ACTIONS(4745),
    [anon_sym_LBRACK] = ACTIONS(4743),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4743),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4743),
    [anon_sym_not_in] = ACTIONS(4743),
    [anon_sym_or_return] = ACTIONS(4743),
    [anon_sym_or_continue] = ACTIONS(4743),
    [anon_sym_or_break] = ACTIONS(4743),
    [anon_sym_CARET] = ACTIONS(4745),
    [sym_uninitialized] = ACTIONS(4743),
    [sym_tag] = ACTIONS(4743),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4743),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [731] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4637),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4637),
    [anon_sym_AMP] = ACTIONS(4637),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4637),
    [anon_sym_GT] = ACTIONS(4637),
    [anon_sym_GT_EQ] = ACTIONS(4635),
    [anon_sym_LT_EQ] = ACTIONS(4635),
    [anon_sym_LT] = ACTIONS(4637),
    [anon_sym_EQ_EQ] = ACTIONS(4635),
    [anon_sym_BANG_EQ] = ACTIONS(4635),
    [anon_sym_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE] = ACTIONS(4637),
    [anon_sym_LT_LT] = ACTIONS(4637),
    [anon_sym_GT_GT] = ACTIONS(4637),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [732] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4637),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4637),
    [anon_sym_DASH] = ACTIONS(4637),
    [anon_sym_TILDE] = ACTIONS(4637),
    [anon_sym_AMP] = ACTIONS(4637),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4637),
    [anon_sym_GT] = ACTIONS(4637),
    [anon_sym_GT_EQ] = ACTIONS(4635),
    [anon_sym_LT_EQ] = ACTIONS(4635),
    [anon_sym_LT] = ACTIONS(4637),
    [anon_sym_EQ_EQ] = ACTIONS(4635),
    [anon_sym_BANG_EQ] = ACTIONS(4635),
    [anon_sym_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE] = ACTIONS(4637),
    [anon_sym_LT_LT] = ACTIONS(4637),
    [anon_sym_GT_GT] = ACTIONS(4637),
    [anon_sym_STAR] = ACTIONS(4637),
    [anon_sym_SLASH] = ACTIONS(4637),
    [anon_sym_PERCENT] = ACTIONS(4637),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4635),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [733] = {
    [ts_builtin_sym_end] = ACTIONS(4747),
    [anon_sym_LBRACE] = ACTIONS(4747),
    [anon_sym_RBRACE] = ACTIONS(4747),
    [anon_sym_COMMA] = ACTIONS(4747),
    [anon_sym_COLON_COLON] = ACTIONS(4747),
    [anon_sym_DASH_GT] = ACTIONS(4747),
    [anon_sym_where] = ACTIONS(4747),
    [anon_sym_EQ] = ACTIONS(4749),
    [anon_sym_COLON] = ACTIONS(4749),
    [anon_sym_PIPE] = ACTIONS(4749),
    [anon_sym_COLON_EQ] = ACTIONS(4747),
    [anon_sym_LPAREN] = ACTIONS(4747),
    [anon_sym_PLUS_EQ] = ACTIONS(4747),
    [anon_sym_DASH_EQ] = ACTIONS(4747),
    [anon_sym_STAR_EQ] = ACTIONS(4747),
    [anon_sym_SLASH_EQ] = ACTIONS(4747),
    [anon_sym_PERCENT_EQ] = ACTIONS(4747),
    [anon_sym_AMP_EQ] = ACTIONS(4747),
    [anon_sym_PIPE_EQ] = ACTIONS(4747),
    [anon_sym_CARET_EQ] = ACTIONS(4747),
    [anon_sym_LT_LT_EQ] = ACTIONS(4747),
    [anon_sym_GT_GT_EQ] = ACTIONS(4747),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4747),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4747),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4747),
    [anon_sym_if] = ACTIONS(4747),
    [anon_sym_SEMI] = ACTIONS(4747),
    [anon_sym_else] = ACTIONS(4747),
    [anon_sym_when] = ACTIONS(4747),
    [anon_sym_in] = ACTIONS(4747),
    [anon_sym_case] = ACTIONS(4747),
    [anon_sym_QMARK] = ACTIONS(4747),
    [anon_sym_PLUS] = ACTIONS(4749),
    [anon_sym_DASH] = ACTIONS(4749),
    [anon_sym_TILDE] = ACTIONS(4749),
    [anon_sym_AMP] = ACTIONS(4749),
    [anon_sym_PIPE_PIPE] = ACTIONS(4749),
    [anon_sym_or_else] = ACTIONS(4747),
    [anon_sym_AMP_AMP] = ACTIONS(4749),
    [anon_sym_GT] = ACTIONS(4749),
    [anon_sym_GT_EQ] = ACTIONS(4747),
    [anon_sym_LT_EQ] = ACTIONS(4747),
    [anon_sym_LT] = ACTIONS(4749),
    [anon_sym_EQ_EQ] = ACTIONS(4747),
    [anon_sym_BANG_EQ] = ACTIONS(4747),
    [anon_sym_TILDE_EQ] = ACTIONS(4747),
    [anon_sym_AMP_TILDE] = ACTIONS(4749),
    [anon_sym_LT_LT] = ACTIONS(4749),
    [anon_sym_GT_GT] = ACTIONS(4749),
    [anon_sym_STAR] = ACTIONS(4749),
    [anon_sym_SLASH] = ACTIONS(4749),
    [anon_sym_PERCENT] = ACTIONS(4749),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4747),
    [anon_sym_DOT] = ACTIONS(4749),
    [anon_sym_LBRACK] = ACTIONS(4747),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4747),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4747),
    [anon_sym_not_in] = ACTIONS(4747),
    [anon_sym_or_return] = ACTIONS(4747),
    [anon_sym_or_continue] = ACTIONS(4747),
    [anon_sym_or_break] = ACTIONS(4747),
    [anon_sym_CARET] = ACTIONS(4749),
    [sym_uninitialized] = ACTIONS(4747),
    [sym_tag] = ACTIONS(4747),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4747),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [734] = {
    [ts_builtin_sym_end] = ACTIONS(4751),
    [anon_sym_LBRACE] = ACTIONS(4751),
    [anon_sym_RBRACE] = ACTIONS(4751),
    [anon_sym_COMMA] = ACTIONS(4751),
    [anon_sym_COLON_COLON] = ACTIONS(4751),
    [anon_sym_DASH_GT] = ACTIONS(4751),
    [anon_sym_where] = ACTIONS(4751),
    [anon_sym_EQ] = ACTIONS(4753),
    [anon_sym_COLON] = ACTIONS(4753),
    [anon_sym_PIPE] = ACTIONS(4753),
    [anon_sym_COLON_EQ] = ACTIONS(4751),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(4751),
    [anon_sym_DASH_EQ] = ACTIONS(4751),
    [anon_sym_STAR_EQ] = ACTIONS(4751),
    [anon_sym_SLASH_EQ] = ACTIONS(4751),
    [anon_sym_PERCENT_EQ] = ACTIONS(4751),
    [anon_sym_AMP_EQ] = ACTIONS(4751),
    [anon_sym_PIPE_EQ] = ACTIONS(4751),
    [anon_sym_CARET_EQ] = ACTIONS(4751),
    [anon_sym_LT_LT_EQ] = ACTIONS(4751),
    [anon_sym_GT_GT_EQ] = ACTIONS(4751),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4751),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4751),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4751),
    [anon_sym_if] = ACTIONS(4751),
    [anon_sym_SEMI] = ACTIONS(4751),
    [anon_sym_else] = ACTIONS(4751),
    [anon_sym_when] = ACTIONS(4751),
    [anon_sym_in] = ACTIONS(4751),
    [anon_sym_case] = ACTIONS(4751),
    [anon_sym_QMARK] = ACTIONS(4751),
    [anon_sym_PLUS] = ACTIONS(4753),
    [anon_sym_DASH] = ACTIONS(4753),
    [anon_sym_TILDE] = ACTIONS(4753),
    [anon_sym_AMP] = ACTIONS(4753),
    [anon_sym_PIPE_PIPE] = ACTIONS(4753),
    [anon_sym_or_else] = ACTIONS(4751),
    [anon_sym_AMP_AMP] = ACTIONS(4753),
    [anon_sym_GT] = ACTIONS(4753),
    [anon_sym_GT_EQ] = ACTIONS(4751),
    [anon_sym_LT_EQ] = ACTIONS(4751),
    [anon_sym_LT] = ACTIONS(4753),
    [anon_sym_EQ_EQ] = ACTIONS(4751),
    [anon_sym_BANG_EQ] = ACTIONS(4751),
    [anon_sym_TILDE_EQ] = ACTIONS(4751),
    [anon_sym_AMP_TILDE] = ACTIONS(4753),
    [anon_sym_LT_LT] = ACTIONS(4753),
    [anon_sym_GT_GT] = ACTIONS(4753),
    [anon_sym_STAR] = ACTIONS(4753),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(4753),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4751),
    [anon_sym_DOT] = ACTIONS(4753),
    [anon_sym_LBRACK] = ACTIONS(4751),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4751),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4751),
    [anon_sym_not_in] = ACTIONS(4751),
    [anon_sym_or_return] = ACTIONS(4751),
    [anon_sym_or_continue] = ACTIONS(4751),
    [anon_sym_or_break] = ACTIONS(4751),
    [anon_sym_CARET] = ACTIONS(4753),
    [sym_uninitialized] = ACTIONS(4751),
    [sym_tag] = ACTIONS(4751),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4751),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [735] = {
    [ts_builtin_sym_end] = ACTIONS(69),
    [anon_sym_LBRACE] = ACTIONS(69),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_where] = ACTIONS(69),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_LPAREN] = ACTIONS(3880),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(69),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(69),
    [anon_sym_when] = ACTIONS(69),
    [anon_sym_in] = ACTIONS(69),
    [anon_sym_case] = ACTIONS(69),
    [anon_sym_QMARK] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_not_in] = ACTIONS(69),
    [anon_sym_or_return] = ACTIONS(69),
    [anon_sym_or_continue] = ACTIONS(69),
    [anon_sym_or_break] = ACTIONS(69),
    [anon_sym_CARET] = ACTIONS(73),
    [sym_uninitialized] = ACTIONS(69),
    [sym_tag] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [736] = {
    [ts_builtin_sym_end] = ACTIONS(4755),
    [anon_sym_LBRACE] = ACTIONS(4755),
    [anon_sym_RBRACE] = ACTIONS(4755),
    [anon_sym_COMMA] = ACTIONS(4755),
    [anon_sym_COLON_COLON] = ACTIONS(4755),
    [anon_sym_DASH_GT] = ACTIONS(4755),
    [anon_sym_where] = ACTIONS(4755),
    [anon_sym_EQ] = ACTIONS(4757),
    [anon_sym_COLON] = ACTIONS(4757),
    [anon_sym_PIPE] = ACTIONS(4757),
    [anon_sym_COLON_EQ] = ACTIONS(4755),
    [anon_sym_LPAREN] = ACTIONS(4755),
    [anon_sym_PLUS_EQ] = ACTIONS(4755),
    [anon_sym_DASH_EQ] = ACTIONS(4755),
    [anon_sym_STAR_EQ] = ACTIONS(4755),
    [anon_sym_SLASH_EQ] = ACTIONS(4755),
    [anon_sym_PERCENT_EQ] = ACTIONS(4755),
    [anon_sym_AMP_EQ] = ACTIONS(4755),
    [anon_sym_PIPE_EQ] = ACTIONS(4755),
    [anon_sym_CARET_EQ] = ACTIONS(4755),
    [anon_sym_LT_LT_EQ] = ACTIONS(4755),
    [anon_sym_GT_GT_EQ] = ACTIONS(4755),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4755),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4755),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4755),
    [anon_sym_if] = ACTIONS(4755),
    [anon_sym_SEMI] = ACTIONS(4755),
    [anon_sym_else] = ACTIONS(4755),
    [anon_sym_when] = ACTIONS(4755),
    [anon_sym_in] = ACTIONS(4755),
    [anon_sym_case] = ACTIONS(4755),
    [anon_sym_QMARK] = ACTIONS(4755),
    [anon_sym_PLUS] = ACTIONS(4757),
    [anon_sym_DASH] = ACTIONS(4757),
    [anon_sym_TILDE] = ACTIONS(4757),
    [anon_sym_AMP] = ACTIONS(4757),
    [anon_sym_PIPE_PIPE] = ACTIONS(4757),
    [anon_sym_or_else] = ACTIONS(4755),
    [anon_sym_AMP_AMP] = ACTIONS(4757),
    [anon_sym_GT] = ACTIONS(4757),
    [anon_sym_GT_EQ] = ACTIONS(4755),
    [anon_sym_LT_EQ] = ACTIONS(4755),
    [anon_sym_LT] = ACTIONS(4757),
    [anon_sym_EQ_EQ] = ACTIONS(4755),
    [anon_sym_BANG_EQ] = ACTIONS(4755),
    [anon_sym_TILDE_EQ] = ACTIONS(4755),
    [anon_sym_AMP_TILDE] = ACTIONS(4757),
    [anon_sym_LT_LT] = ACTIONS(4757),
    [anon_sym_GT_GT] = ACTIONS(4757),
    [anon_sym_STAR] = ACTIONS(4757),
    [anon_sym_SLASH] = ACTIONS(4757),
    [anon_sym_PERCENT] = ACTIONS(4757),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4755),
    [anon_sym_DOT] = ACTIONS(4757),
    [anon_sym_LBRACK] = ACTIONS(4755),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4755),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4755),
    [anon_sym_not_in] = ACTIONS(4755),
    [anon_sym_or_return] = ACTIONS(4755),
    [anon_sym_or_continue] = ACTIONS(4755),
    [anon_sym_or_break] = ACTIONS(4755),
    [anon_sym_CARET] = ACTIONS(4757),
    [sym_uninitialized] = ACTIONS(4755),
    [sym_tag] = ACTIONS(4755),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4755),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [737] = {
    [ts_builtin_sym_end] = ACTIONS(4759),
    [anon_sym_LBRACE] = ACTIONS(4759),
    [anon_sym_RBRACE] = ACTIONS(4759),
    [anon_sym_COMMA] = ACTIONS(4759),
    [anon_sym_COLON_COLON] = ACTIONS(4759),
    [anon_sym_DASH_GT] = ACTIONS(4759),
    [anon_sym_where] = ACTIONS(4759),
    [anon_sym_EQ] = ACTIONS(4761),
    [anon_sym_COLON] = ACTIONS(4761),
    [anon_sym_PIPE] = ACTIONS(4761),
    [anon_sym_COLON_EQ] = ACTIONS(4759),
    [anon_sym_LPAREN] = ACTIONS(4759),
    [anon_sym_PLUS_EQ] = ACTIONS(4759),
    [anon_sym_DASH_EQ] = ACTIONS(4759),
    [anon_sym_STAR_EQ] = ACTIONS(4759),
    [anon_sym_SLASH_EQ] = ACTIONS(4759),
    [anon_sym_PERCENT_EQ] = ACTIONS(4759),
    [anon_sym_AMP_EQ] = ACTIONS(4759),
    [anon_sym_PIPE_EQ] = ACTIONS(4759),
    [anon_sym_CARET_EQ] = ACTIONS(4759),
    [anon_sym_LT_LT_EQ] = ACTIONS(4759),
    [anon_sym_GT_GT_EQ] = ACTIONS(4759),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4759),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4759),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4759),
    [anon_sym_if] = ACTIONS(4759),
    [anon_sym_SEMI] = ACTIONS(4759),
    [anon_sym_else] = ACTIONS(4759),
    [anon_sym_when] = ACTIONS(4759),
    [anon_sym_in] = ACTIONS(4759),
    [anon_sym_case] = ACTIONS(4759),
    [anon_sym_QMARK] = ACTIONS(4759),
    [anon_sym_PLUS] = ACTIONS(4761),
    [anon_sym_DASH] = ACTIONS(4761),
    [anon_sym_TILDE] = ACTIONS(4761),
    [anon_sym_AMP] = ACTIONS(4761),
    [anon_sym_PIPE_PIPE] = ACTIONS(4761),
    [anon_sym_or_else] = ACTIONS(4759),
    [anon_sym_AMP_AMP] = ACTIONS(4761),
    [anon_sym_GT] = ACTIONS(4761),
    [anon_sym_GT_EQ] = ACTIONS(4759),
    [anon_sym_LT_EQ] = ACTIONS(4759),
    [anon_sym_LT] = ACTIONS(4761),
    [anon_sym_EQ_EQ] = ACTIONS(4759),
    [anon_sym_BANG_EQ] = ACTIONS(4759),
    [anon_sym_TILDE_EQ] = ACTIONS(4759),
    [anon_sym_AMP_TILDE] = ACTIONS(4761),
    [anon_sym_LT_LT] = ACTIONS(4761),
    [anon_sym_GT_GT] = ACTIONS(4761),
    [anon_sym_STAR] = ACTIONS(4761),
    [anon_sym_SLASH] = ACTIONS(4761),
    [anon_sym_PERCENT] = ACTIONS(4761),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4759),
    [anon_sym_DOT] = ACTIONS(4761),
    [anon_sym_LBRACK] = ACTIONS(4759),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4759),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4759),
    [anon_sym_not_in] = ACTIONS(4759),
    [anon_sym_or_return] = ACTIONS(4759),
    [anon_sym_or_continue] = ACTIONS(4759),
    [anon_sym_or_break] = ACTIONS(4759),
    [anon_sym_CARET] = ACTIONS(4761),
    [sym_uninitialized] = ACTIONS(4759),
    [sym_tag] = ACTIONS(4759),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4759),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [738] = {
    [ts_builtin_sym_end] = ACTIONS(4763),
    [anon_sym_LBRACE] = ACTIONS(4763),
    [anon_sym_RBRACE] = ACTIONS(4763),
    [anon_sym_COMMA] = ACTIONS(4763),
    [anon_sym_COLON_COLON] = ACTIONS(4763),
    [anon_sym_DASH_GT] = ACTIONS(4763),
    [anon_sym_where] = ACTIONS(4763),
    [anon_sym_EQ] = ACTIONS(4765),
    [anon_sym_COLON] = ACTIONS(4765),
    [anon_sym_PIPE] = ACTIONS(4765),
    [anon_sym_COLON_EQ] = ACTIONS(4763),
    [anon_sym_LPAREN] = ACTIONS(4763),
    [anon_sym_PLUS_EQ] = ACTIONS(4763),
    [anon_sym_DASH_EQ] = ACTIONS(4763),
    [anon_sym_STAR_EQ] = ACTIONS(4763),
    [anon_sym_SLASH_EQ] = ACTIONS(4763),
    [anon_sym_PERCENT_EQ] = ACTIONS(4763),
    [anon_sym_AMP_EQ] = ACTIONS(4763),
    [anon_sym_PIPE_EQ] = ACTIONS(4763),
    [anon_sym_CARET_EQ] = ACTIONS(4763),
    [anon_sym_LT_LT_EQ] = ACTIONS(4763),
    [anon_sym_GT_GT_EQ] = ACTIONS(4763),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4763),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4763),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4763),
    [anon_sym_if] = ACTIONS(4763),
    [anon_sym_SEMI] = ACTIONS(4763),
    [anon_sym_else] = ACTIONS(4763),
    [anon_sym_when] = ACTIONS(4763),
    [anon_sym_in] = ACTIONS(4763),
    [anon_sym_case] = ACTIONS(4763),
    [anon_sym_QMARK] = ACTIONS(4763),
    [anon_sym_PLUS] = ACTIONS(4765),
    [anon_sym_DASH] = ACTIONS(4765),
    [anon_sym_TILDE] = ACTIONS(4765),
    [anon_sym_AMP] = ACTIONS(4765),
    [anon_sym_PIPE_PIPE] = ACTIONS(4765),
    [anon_sym_or_else] = ACTIONS(4763),
    [anon_sym_AMP_AMP] = ACTIONS(4765),
    [anon_sym_GT] = ACTIONS(4765),
    [anon_sym_GT_EQ] = ACTIONS(4763),
    [anon_sym_LT_EQ] = ACTIONS(4763),
    [anon_sym_LT] = ACTIONS(4765),
    [anon_sym_EQ_EQ] = ACTIONS(4763),
    [anon_sym_BANG_EQ] = ACTIONS(4763),
    [anon_sym_TILDE_EQ] = ACTIONS(4763),
    [anon_sym_AMP_TILDE] = ACTIONS(4765),
    [anon_sym_LT_LT] = ACTIONS(4765),
    [anon_sym_GT_GT] = ACTIONS(4765),
    [anon_sym_STAR] = ACTIONS(4765),
    [anon_sym_SLASH] = ACTIONS(4765),
    [anon_sym_PERCENT] = ACTIONS(4765),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4763),
    [anon_sym_DOT] = ACTIONS(4765),
    [anon_sym_LBRACK] = ACTIONS(4763),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4763),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4763),
    [anon_sym_not_in] = ACTIONS(4763),
    [anon_sym_or_return] = ACTIONS(4763),
    [anon_sym_or_continue] = ACTIONS(4763),
    [anon_sym_or_break] = ACTIONS(4763),
    [anon_sym_CARET] = ACTIONS(4765),
    [sym_uninitialized] = ACTIONS(4763),
    [sym_tag] = ACTIONS(4763),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4763),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [739] = {
    [sym_block] = STATE(7170),
    [sym_expression] = STATE(5948),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(4767),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_SEMI] = ACTIONS(4769),
    [anon_sym_do] = ACTIONS(4771),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [740] = {
    [ts_builtin_sym_end] = ACTIONS(4773),
    [anon_sym_LBRACE] = ACTIONS(4773),
    [anon_sym_RBRACE] = ACTIONS(4773),
    [anon_sym_COMMA] = ACTIONS(4773),
    [anon_sym_COLON_COLON] = ACTIONS(4773),
    [anon_sym_DASH_GT] = ACTIONS(4773),
    [anon_sym_where] = ACTIONS(4773),
    [anon_sym_EQ] = ACTIONS(4775),
    [anon_sym_COLON] = ACTIONS(4775),
    [anon_sym_PIPE] = ACTIONS(4775),
    [anon_sym_COLON_EQ] = ACTIONS(4773),
    [anon_sym_LPAREN] = ACTIONS(4773),
    [anon_sym_PLUS_EQ] = ACTIONS(4773),
    [anon_sym_DASH_EQ] = ACTIONS(4773),
    [anon_sym_STAR_EQ] = ACTIONS(4773),
    [anon_sym_SLASH_EQ] = ACTIONS(4773),
    [anon_sym_PERCENT_EQ] = ACTIONS(4773),
    [anon_sym_AMP_EQ] = ACTIONS(4773),
    [anon_sym_PIPE_EQ] = ACTIONS(4773),
    [anon_sym_CARET_EQ] = ACTIONS(4773),
    [anon_sym_LT_LT_EQ] = ACTIONS(4773),
    [anon_sym_GT_GT_EQ] = ACTIONS(4773),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4773),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4773),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4773),
    [anon_sym_if] = ACTIONS(4773),
    [anon_sym_SEMI] = ACTIONS(4773),
    [anon_sym_else] = ACTIONS(4773),
    [anon_sym_when] = ACTIONS(4773),
    [anon_sym_in] = ACTIONS(4773),
    [anon_sym_case] = ACTIONS(4773),
    [anon_sym_QMARK] = ACTIONS(4773),
    [anon_sym_PLUS] = ACTIONS(4775),
    [anon_sym_DASH] = ACTIONS(4775),
    [anon_sym_TILDE] = ACTIONS(4775),
    [anon_sym_AMP] = ACTIONS(4775),
    [anon_sym_PIPE_PIPE] = ACTIONS(4775),
    [anon_sym_or_else] = ACTIONS(4773),
    [anon_sym_AMP_AMP] = ACTIONS(4775),
    [anon_sym_GT] = ACTIONS(4775),
    [anon_sym_GT_EQ] = ACTIONS(4773),
    [anon_sym_LT_EQ] = ACTIONS(4773),
    [anon_sym_LT] = ACTIONS(4775),
    [anon_sym_EQ_EQ] = ACTIONS(4773),
    [anon_sym_BANG_EQ] = ACTIONS(4773),
    [anon_sym_TILDE_EQ] = ACTIONS(4773),
    [anon_sym_AMP_TILDE] = ACTIONS(4775),
    [anon_sym_LT_LT] = ACTIONS(4775),
    [anon_sym_GT_GT] = ACTIONS(4775),
    [anon_sym_STAR] = ACTIONS(4775),
    [anon_sym_SLASH] = ACTIONS(4775),
    [anon_sym_PERCENT] = ACTIONS(4775),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4773),
    [anon_sym_DOT] = ACTIONS(4775),
    [anon_sym_LBRACK] = ACTIONS(4773),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4773),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4773),
    [anon_sym_not_in] = ACTIONS(4773),
    [anon_sym_or_return] = ACTIONS(4773),
    [anon_sym_or_continue] = ACTIONS(4773),
    [anon_sym_or_break] = ACTIONS(4773),
    [anon_sym_CARET] = ACTIONS(4775),
    [sym_uninitialized] = ACTIONS(4773),
    [sym_tag] = ACTIONS(4773),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4773),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [741] = {
    [sym_expression] = STATE(5507),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_foreign] = ACTIONS(4777),
    [anon_sym_import] = ACTIONS(4779),
    [anon_sym_using] = ACTIONS(4781),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(4785),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [742] = {
    [ts_builtin_sym_end] = ACTIONS(4787),
    [anon_sym_LBRACE] = ACTIONS(4787),
    [anon_sym_RBRACE] = ACTIONS(4787),
    [anon_sym_COMMA] = ACTIONS(4787),
    [anon_sym_COLON_COLON] = ACTIONS(4787),
    [anon_sym_DASH_GT] = ACTIONS(4787),
    [anon_sym_where] = ACTIONS(4787),
    [anon_sym_EQ] = ACTIONS(4789),
    [anon_sym_COLON] = ACTIONS(4789),
    [anon_sym_PIPE] = ACTIONS(4789),
    [anon_sym_COLON_EQ] = ACTIONS(4787),
    [anon_sym_LPAREN] = ACTIONS(4787),
    [anon_sym_PLUS_EQ] = ACTIONS(4787),
    [anon_sym_DASH_EQ] = ACTIONS(4787),
    [anon_sym_STAR_EQ] = ACTIONS(4787),
    [anon_sym_SLASH_EQ] = ACTIONS(4787),
    [anon_sym_PERCENT_EQ] = ACTIONS(4787),
    [anon_sym_AMP_EQ] = ACTIONS(4787),
    [anon_sym_PIPE_EQ] = ACTIONS(4787),
    [anon_sym_CARET_EQ] = ACTIONS(4787),
    [anon_sym_LT_LT_EQ] = ACTIONS(4787),
    [anon_sym_GT_GT_EQ] = ACTIONS(4787),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4787),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4787),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4787),
    [anon_sym_if] = ACTIONS(4787),
    [anon_sym_SEMI] = ACTIONS(4787),
    [anon_sym_else] = ACTIONS(4787),
    [anon_sym_when] = ACTIONS(4787),
    [anon_sym_in] = ACTIONS(4787),
    [anon_sym_case] = ACTIONS(4787),
    [anon_sym_QMARK] = ACTIONS(4787),
    [anon_sym_PLUS] = ACTIONS(4789),
    [anon_sym_DASH] = ACTIONS(4789),
    [anon_sym_TILDE] = ACTIONS(4789),
    [anon_sym_AMP] = ACTIONS(4789),
    [anon_sym_PIPE_PIPE] = ACTIONS(4789),
    [anon_sym_or_else] = ACTIONS(4787),
    [anon_sym_AMP_AMP] = ACTIONS(4789),
    [anon_sym_GT] = ACTIONS(4789),
    [anon_sym_GT_EQ] = ACTIONS(4787),
    [anon_sym_LT_EQ] = ACTIONS(4787),
    [anon_sym_LT] = ACTIONS(4789),
    [anon_sym_EQ_EQ] = ACTIONS(4787),
    [anon_sym_BANG_EQ] = ACTIONS(4787),
    [anon_sym_TILDE_EQ] = ACTIONS(4787),
    [anon_sym_AMP_TILDE] = ACTIONS(4789),
    [anon_sym_LT_LT] = ACTIONS(4789),
    [anon_sym_GT_GT] = ACTIONS(4789),
    [anon_sym_STAR] = ACTIONS(4789),
    [anon_sym_SLASH] = ACTIONS(4789),
    [anon_sym_PERCENT] = ACTIONS(4789),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4787),
    [anon_sym_DOT] = ACTIONS(4789),
    [anon_sym_LBRACK] = ACTIONS(4787),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4787),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4787),
    [anon_sym_not_in] = ACTIONS(4787),
    [anon_sym_or_return] = ACTIONS(4787),
    [anon_sym_or_continue] = ACTIONS(4787),
    [anon_sym_or_break] = ACTIONS(4787),
    [anon_sym_CARET] = ACTIONS(4789),
    [sym_uninitialized] = ACTIONS(4787),
    [sym_tag] = ACTIONS(4787),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4787),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [743] = {
    [sym_procedure] = STATE(4572),
    [sym_expression] = STATE(4965),
    [sym__expression_no_tag] = STATE(4543),
    [sym_unary_expression] = STATE(4543),
    [sym_binary_expression] = STATE(4543),
    [sym_ternary_expression] = STATE(4543),
    [sym_call_expression] = STATE(4543),
    [sym_selector_call_expression] = STATE(4543),
    [sym_member_expression] = STATE(4543),
    [sym_index_expression] = STATE(4543),
    [sym_slice_expression] = STATE(4543),
    [sym_range_expression] = STATE(4543),
    [sym_cast_expression] = STATE(4543),
    [sym_in_expression] = STATE(4543),
    [sym_variadic_expression] = STATE(4543),
    [sym_parenthesized_expression] = STATE(4543),
    [sym_or_return_expression] = STATE(4543),
    [sym_or_continue_expression] = STATE(4543),
    [sym_or_break_expression] = STATE(4543),
    [sym_address] = STATE(4543),
    [sym_map_type] = STATE(4543),
    [sym_matrix_type] = STATE(4543),
    [sym__procedure_type] = STATE(6994),
    [sym_distinct_type] = STATE(4543),
    [sym_literal] = STATE(4543),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_proc] = ACTIONS(723),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [744] = {
    [ts_builtin_sym_end] = ACTIONS(4791),
    [anon_sym_LBRACE] = ACTIONS(4791),
    [anon_sym_RBRACE] = ACTIONS(4791),
    [anon_sym_COMMA] = ACTIONS(4791),
    [anon_sym_COLON_COLON] = ACTIONS(4791),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4791),
    [anon_sym_EQ] = ACTIONS(4793),
    [anon_sym_COLON] = ACTIONS(4793),
    [anon_sym_PIPE] = ACTIONS(4485),
    [anon_sym_COLON_EQ] = ACTIONS(4791),
    [anon_sym_LPAREN] = ACTIONS(4791),
    [anon_sym_PLUS_EQ] = ACTIONS(4791),
    [anon_sym_DASH_EQ] = ACTIONS(4791),
    [anon_sym_STAR_EQ] = ACTIONS(4791),
    [anon_sym_SLASH_EQ] = ACTIONS(4791),
    [anon_sym_PERCENT_EQ] = ACTIONS(4791),
    [anon_sym_AMP_EQ] = ACTIONS(4791),
    [anon_sym_PIPE_EQ] = ACTIONS(4791),
    [anon_sym_CARET_EQ] = ACTIONS(4791),
    [anon_sym_LT_LT_EQ] = ACTIONS(4791),
    [anon_sym_GT_GT_EQ] = ACTIONS(4791),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4791),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4791),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4791),
    [anon_sym_if] = ACTIONS(4791),
    [anon_sym_SEMI] = ACTIONS(4791),
    [anon_sym_else] = ACTIONS(4791),
    [anon_sym_when] = ACTIONS(4791),
    [anon_sym_in] = ACTIONS(4791),
    [anon_sym_case] = ACTIONS(4791),
    [anon_sym_QMARK] = ACTIONS(4791),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4493),
    [anon_sym_or_else] = ACTIONS(4495),
    [anon_sym_AMP_AMP] = ACTIONS(4497),
    [anon_sym_GT] = ACTIONS(4499),
    [anon_sym_GT_EQ] = ACTIONS(4501),
    [anon_sym_LT_EQ] = ACTIONS(4501),
    [anon_sym_LT] = ACTIONS(4499),
    [anon_sym_EQ_EQ] = ACTIONS(4503),
    [anon_sym_BANG_EQ] = ACTIONS(4503),
    [anon_sym_TILDE_EQ] = ACTIONS(4503),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4791),
    [anon_sym_or_return] = ACTIONS(4519),
    [anon_sym_or_continue] = ACTIONS(4521),
    [anon_sym_or_break] = ACTIONS(4523),
    [anon_sym_CARET] = ACTIONS(4525),
    [sym_uninitialized] = ACTIONS(4791),
    [sym_tag] = ACTIONS(4791),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4791),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [745] = {
    [ts_builtin_sym_end] = ACTIONS(4795),
    [anon_sym_LBRACE] = ACTIONS(4795),
    [anon_sym_RBRACE] = ACTIONS(4795),
    [anon_sym_COMMA] = ACTIONS(4795),
    [anon_sym_COLON_COLON] = ACTIONS(4795),
    [anon_sym_DASH_GT] = ACTIONS(4795),
    [anon_sym_where] = ACTIONS(4795),
    [anon_sym_EQ] = ACTIONS(4797),
    [anon_sym_COLON] = ACTIONS(4797),
    [anon_sym_PIPE] = ACTIONS(4797),
    [anon_sym_COLON_EQ] = ACTIONS(4795),
    [anon_sym_LPAREN] = ACTIONS(4795),
    [anon_sym_PLUS_EQ] = ACTIONS(4795),
    [anon_sym_DASH_EQ] = ACTIONS(4795),
    [anon_sym_STAR_EQ] = ACTIONS(4795),
    [anon_sym_SLASH_EQ] = ACTIONS(4795),
    [anon_sym_PERCENT_EQ] = ACTIONS(4795),
    [anon_sym_AMP_EQ] = ACTIONS(4795),
    [anon_sym_PIPE_EQ] = ACTIONS(4795),
    [anon_sym_CARET_EQ] = ACTIONS(4795),
    [anon_sym_LT_LT_EQ] = ACTIONS(4795),
    [anon_sym_GT_GT_EQ] = ACTIONS(4795),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4795),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4795),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4795),
    [anon_sym_if] = ACTIONS(4795),
    [anon_sym_SEMI] = ACTIONS(4795),
    [anon_sym_else] = ACTIONS(4795),
    [anon_sym_when] = ACTIONS(4795),
    [anon_sym_in] = ACTIONS(4795),
    [anon_sym_case] = ACTIONS(4795),
    [anon_sym_QMARK] = ACTIONS(4795),
    [anon_sym_PLUS] = ACTIONS(4797),
    [anon_sym_DASH] = ACTIONS(4797),
    [anon_sym_TILDE] = ACTIONS(4797),
    [anon_sym_AMP] = ACTIONS(4797),
    [anon_sym_PIPE_PIPE] = ACTIONS(4797),
    [anon_sym_or_else] = ACTIONS(4795),
    [anon_sym_AMP_AMP] = ACTIONS(4797),
    [anon_sym_GT] = ACTIONS(4797),
    [anon_sym_GT_EQ] = ACTIONS(4795),
    [anon_sym_LT_EQ] = ACTIONS(4795),
    [anon_sym_LT] = ACTIONS(4797),
    [anon_sym_EQ_EQ] = ACTIONS(4795),
    [anon_sym_BANG_EQ] = ACTIONS(4795),
    [anon_sym_TILDE_EQ] = ACTIONS(4795),
    [anon_sym_AMP_TILDE] = ACTIONS(4797),
    [anon_sym_LT_LT] = ACTIONS(4797),
    [anon_sym_GT_GT] = ACTIONS(4797),
    [anon_sym_STAR] = ACTIONS(4797),
    [anon_sym_SLASH] = ACTIONS(4797),
    [anon_sym_PERCENT] = ACTIONS(4797),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4795),
    [anon_sym_DOT] = ACTIONS(4797),
    [anon_sym_LBRACK] = ACTIONS(4795),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4795),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4795),
    [anon_sym_not_in] = ACTIONS(4795),
    [anon_sym_or_return] = ACTIONS(4795),
    [anon_sym_or_continue] = ACTIONS(4795),
    [anon_sym_or_break] = ACTIONS(4795),
    [anon_sym_CARET] = ACTIONS(4797),
    [sym_uninitialized] = ACTIONS(4795),
    [sym_tag] = ACTIONS(4795),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4795),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [746] = {
    [ts_builtin_sym_end] = ACTIONS(4799),
    [anon_sym_LBRACE] = ACTIONS(4799),
    [anon_sym_RBRACE] = ACTIONS(4799),
    [anon_sym_COMMA] = ACTIONS(4799),
    [anon_sym_COLON_COLON] = ACTIONS(4799),
    [anon_sym_DASH_GT] = ACTIONS(4799),
    [anon_sym_where] = ACTIONS(4799),
    [anon_sym_EQ] = ACTIONS(4801),
    [anon_sym_COLON] = ACTIONS(4801),
    [anon_sym_PIPE] = ACTIONS(4801),
    [anon_sym_COLON_EQ] = ACTIONS(4799),
    [anon_sym_LPAREN] = ACTIONS(4799),
    [anon_sym_PLUS_EQ] = ACTIONS(4799),
    [anon_sym_DASH_EQ] = ACTIONS(4799),
    [anon_sym_STAR_EQ] = ACTIONS(4799),
    [anon_sym_SLASH_EQ] = ACTIONS(4799),
    [anon_sym_PERCENT_EQ] = ACTIONS(4799),
    [anon_sym_AMP_EQ] = ACTIONS(4799),
    [anon_sym_PIPE_EQ] = ACTIONS(4799),
    [anon_sym_CARET_EQ] = ACTIONS(4799),
    [anon_sym_LT_LT_EQ] = ACTIONS(4799),
    [anon_sym_GT_GT_EQ] = ACTIONS(4799),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4799),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4799),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4799),
    [anon_sym_if] = ACTIONS(4799),
    [anon_sym_SEMI] = ACTIONS(4799),
    [anon_sym_else] = ACTIONS(4799),
    [anon_sym_when] = ACTIONS(4799),
    [anon_sym_in] = ACTIONS(4799),
    [anon_sym_case] = ACTIONS(4799),
    [anon_sym_QMARK] = ACTIONS(4799),
    [anon_sym_PLUS] = ACTIONS(4801),
    [anon_sym_DASH] = ACTIONS(4801),
    [anon_sym_TILDE] = ACTIONS(4801),
    [anon_sym_AMP] = ACTIONS(4801),
    [anon_sym_PIPE_PIPE] = ACTIONS(4801),
    [anon_sym_or_else] = ACTIONS(4799),
    [anon_sym_AMP_AMP] = ACTIONS(4801),
    [anon_sym_GT] = ACTIONS(4801),
    [anon_sym_GT_EQ] = ACTIONS(4799),
    [anon_sym_LT_EQ] = ACTIONS(4799),
    [anon_sym_LT] = ACTIONS(4801),
    [anon_sym_EQ_EQ] = ACTIONS(4799),
    [anon_sym_BANG_EQ] = ACTIONS(4799),
    [anon_sym_TILDE_EQ] = ACTIONS(4799),
    [anon_sym_AMP_TILDE] = ACTIONS(4801),
    [anon_sym_LT_LT] = ACTIONS(4801),
    [anon_sym_GT_GT] = ACTIONS(4801),
    [anon_sym_STAR] = ACTIONS(4801),
    [anon_sym_SLASH] = ACTIONS(4801),
    [anon_sym_PERCENT] = ACTIONS(4801),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4799),
    [anon_sym_DOT] = ACTIONS(4801),
    [anon_sym_LBRACK] = ACTIONS(4799),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4799),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4799),
    [anon_sym_not_in] = ACTIONS(4799),
    [anon_sym_or_return] = ACTIONS(4799),
    [anon_sym_or_continue] = ACTIONS(4799),
    [anon_sym_or_break] = ACTIONS(4799),
    [anon_sym_CARET] = ACTIONS(4801),
    [sym_uninitialized] = ACTIONS(4799),
    [sym_tag] = ACTIONS(4799),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4799),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [747] = {
    [ts_builtin_sym_end] = ACTIONS(4803),
    [anon_sym_LBRACE] = ACTIONS(4803),
    [anon_sym_RBRACE] = ACTIONS(4803),
    [anon_sym_COMMA] = ACTIONS(4803),
    [anon_sym_COLON_COLON] = ACTIONS(4803),
    [anon_sym_DASH_GT] = ACTIONS(4803),
    [anon_sym_where] = ACTIONS(4803),
    [anon_sym_EQ] = ACTIONS(4805),
    [anon_sym_COLON] = ACTIONS(4805),
    [anon_sym_PIPE] = ACTIONS(4805),
    [anon_sym_COLON_EQ] = ACTIONS(4803),
    [anon_sym_LPAREN] = ACTIONS(4803),
    [anon_sym_PLUS_EQ] = ACTIONS(4803),
    [anon_sym_DASH_EQ] = ACTIONS(4803),
    [anon_sym_STAR_EQ] = ACTIONS(4803),
    [anon_sym_SLASH_EQ] = ACTIONS(4803),
    [anon_sym_PERCENT_EQ] = ACTIONS(4803),
    [anon_sym_AMP_EQ] = ACTIONS(4803),
    [anon_sym_PIPE_EQ] = ACTIONS(4803),
    [anon_sym_CARET_EQ] = ACTIONS(4803),
    [anon_sym_LT_LT_EQ] = ACTIONS(4803),
    [anon_sym_GT_GT_EQ] = ACTIONS(4803),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4803),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4803),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4803),
    [anon_sym_if] = ACTIONS(4803),
    [anon_sym_SEMI] = ACTIONS(4803),
    [anon_sym_else] = ACTIONS(4803),
    [anon_sym_when] = ACTIONS(4803),
    [anon_sym_in] = ACTIONS(4803),
    [anon_sym_case] = ACTIONS(4803),
    [anon_sym_QMARK] = ACTIONS(4803),
    [anon_sym_PLUS] = ACTIONS(4805),
    [anon_sym_DASH] = ACTIONS(4805),
    [anon_sym_TILDE] = ACTIONS(4805),
    [anon_sym_AMP] = ACTIONS(4805),
    [anon_sym_PIPE_PIPE] = ACTIONS(4805),
    [anon_sym_or_else] = ACTIONS(4803),
    [anon_sym_AMP_AMP] = ACTIONS(4805),
    [anon_sym_GT] = ACTIONS(4805),
    [anon_sym_GT_EQ] = ACTIONS(4803),
    [anon_sym_LT_EQ] = ACTIONS(4803),
    [anon_sym_LT] = ACTIONS(4805),
    [anon_sym_EQ_EQ] = ACTIONS(4803),
    [anon_sym_BANG_EQ] = ACTIONS(4803),
    [anon_sym_TILDE_EQ] = ACTIONS(4803),
    [anon_sym_AMP_TILDE] = ACTIONS(4805),
    [anon_sym_LT_LT] = ACTIONS(4805),
    [anon_sym_GT_GT] = ACTIONS(4805),
    [anon_sym_STAR] = ACTIONS(4805),
    [anon_sym_SLASH] = ACTIONS(4805),
    [anon_sym_PERCENT] = ACTIONS(4805),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4803),
    [anon_sym_DOT] = ACTIONS(4805),
    [anon_sym_LBRACK] = ACTIONS(4803),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4803),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4803),
    [anon_sym_not_in] = ACTIONS(4803),
    [anon_sym_or_return] = ACTIONS(4803),
    [anon_sym_or_continue] = ACTIONS(4803),
    [anon_sym_or_break] = ACTIONS(4803),
    [anon_sym_CARET] = ACTIONS(4805),
    [sym_uninitialized] = ACTIONS(4803),
    [sym_tag] = ACTIONS(4803),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4803),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [748] = {
    [ts_builtin_sym_end] = ACTIONS(4807),
    [anon_sym_LBRACE] = ACTIONS(4807),
    [anon_sym_RBRACE] = ACTIONS(4807),
    [anon_sym_COMMA] = ACTIONS(4807),
    [anon_sym_COLON_COLON] = ACTIONS(4807),
    [anon_sym_DASH_GT] = ACTIONS(4807),
    [anon_sym_where] = ACTIONS(4807),
    [anon_sym_EQ] = ACTIONS(4809),
    [anon_sym_COLON] = ACTIONS(4809),
    [anon_sym_PIPE] = ACTIONS(4809),
    [anon_sym_COLON_EQ] = ACTIONS(4807),
    [anon_sym_LPAREN] = ACTIONS(4807),
    [anon_sym_PLUS_EQ] = ACTIONS(4807),
    [anon_sym_DASH_EQ] = ACTIONS(4807),
    [anon_sym_STAR_EQ] = ACTIONS(4807),
    [anon_sym_SLASH_EQ] = ACTIONS(4807),
    [anon_sym_PERCENT_EQ] = ACTIONS(4807),
    [anon_sym_AMP_EQ] = ACTIONS(4807),
    [anon_sym_PIPE_EQ] = ACTIONS(4807),
    [anon_sym_CARET_EQ] = ACTIONS(4807),
    [anon_sym_LT_LT_EQ] = ACTIONS(4807),
    [anon_sym_GT_GT_EQ] = ACTIONS(4807),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4807),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4807),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4807),
    [anon_sym_if] = ACTIONS(4807),
    [anon_sym_SEMI] = ACTIONS(4807),
    [anon_sym_else] = ACTIONS(4807),
    [anon_sym_when] = ACTIONS(4807),
    [anon_sym_in] = ACTIONS(4807),
    [anon_sym_case] = ACTIONS(4807),
    [anon_sym_QMARK] = ACTIONS(4807),
    [anon_sym_PLUS] = ACTIONS(4809),
    [anon_sym_DASH] = ACTIONS(4809),
    [anon_sym_TILDE] = ACTIONS(4809),
    [anon_sym_AMP] = ACTIONS(4809),
    [anon_sym_PIPE_PIPE] = ACTIONS(4809),
    [anon_sym_or_else] = ACTIONS(4807),
    [anon_sym_AMP_AMP] = ACTIONS(4809),
    [anon_sym_GT] = ACTIONS(4809),
    [anon_sym_GT_EQ] = ACTIONS(4807),
    [anon_sym_LT_EQ] = ACTIONS(4807),
    [anon_sym_LT] = ACTIONS(4809),
    [anon_sym_EQ_EQ] = ACTIONS(4807),
    [anon_sym_BANG_EQ] = ACTIONS(4807),
    [anon_sym_TILDE_EQ] = ACTIONS(4807),
    [anon_sym_AMP_TILDE] = ACTIONS(4809),
    [anon_sym_LT_LT] = ACTIONS(4809),
    [anon_sym_GT_GT] = ACTIONS(4809),
    [anon_sym_STAR] = ACTIONS(4809),
    [anon_sym_SLASH] = ACTIONS(4809),
    [anon_sym_PERCENT] = ACTIONS(4809),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4807),
    [anon_sym_DOT] = ACTIONS(4809),
    [anon_sym_LBRACK] = ACTIONS(4807),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4807),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4807),
    [anon_sym_not_in] = ACTIONS(4807),
    [anon_sym_or_return] = ACTIONS(4807),
    [anon_sym_or_continue] = ACTIONS(4807),
    [anon_sym_or_break] = ACTIONS(4807),
    [anon_sym_CARET] = ACTIONS(4809),
    [sym_uninitialized] = ACTIONS(4807),
    [sym_tag] = ACTIONS(4807),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4807),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [749] = {
    [ts_builtin_sym_end] = ACTIONS(4811),
    [anon_sym_LBRACE] = ACTIONS(4811),
    [anon_sym_RBRACE] = ACTIONS(4811),
    [anon_sym_COMMA] = ACTIONS(4811),
    [anon_sym_COLON_COLON] = ACTIONS(4811),
    [anon_sym_DASH_GT] = ACTIONS(4811),
    [anon_sym_where] = ACTIONS(4811),
    [anon_sym_EQ] = ACTIONS(4813),
    [anon_sym_COLON] = ACTIONS(4813),
    [anon_sym_PIPE] = ACTIONS(4813),
    [anon_sym_COLON_EQ] = ACTIONS(4811),
    [anon_sym_LPAREN] = ACTIONS(4811),
    [anon_sym_PLUS_EQ] = ACTIONS(4811),
    [anon_sym_DASH_EQ] = ACTIONS(4811),
    [anon_sym_STAR_EQ] = ACTIONS(4811),
    [anon_sym_SLASH_EQ] = ACTIONS(4811),
    [anon_sym_PERCENT_EQ] = ACTIONS(4811),
    [anon_sym_AMP_EQ] = ACTIONS(4811),
    [anon_sym_PIPE_EQ] = ACTIONS(4811),
    [anon_sym_CARET_EQ] = ACTIONS(4811),
    [anon_sym_LT_LT_EQ] = ACTIONS(4811),
    [anon_sym_GT_GT_EQ] = ACTIONS(4811),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4811),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4811),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4811),
    [anon_sym_if] = ACTIONS(4811),
    [anon_sym_SEMI] = ACTIONS(4811),
    [anon_sym_else] = ACTIONS(4811),
    [anon_sym_when] = ACTIONS(4811),
    [anon_sym_in] = ACTIONS(4811),
    [anon_sym_case] = ACTIONS(4811),
    [anon_sym_QMARK] = ACTIONS(4811),
    [anon_sym_PLUS] = ACTIONS(4813),
    [anon_sym_DASH] = ACTIONS(4813),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_AMP] = ACTIONS(4813),
    [anon_sym_PIPE_PIPE] = ACTIONS(4813),
    [anon_sym_or_else] = ACTIONS(4811),
    [anon_sym_AMP_AMP] = ACTIONS(4813),
    [anon_sym_GT] = ACTIONS(4813),
    [anon_sym_GT_EQ] = ACTIONS(4811),
    [anon_sym_LT_EQ] = ACTIONS(4811),
    [anon_sym_LT] = ACTIONS(4813),
    [anon_sym_EQ_EQ] = ACTIONS(4811),
    [anon_sym_BANG_EQ] = ACTIONS(4811),
    [anon_sym_TILDE_EQ] = ACTIONS(4811),
    [anon_sym_AMP_TILDE] = ACTIONS(4813),
    [anon_sym_LT_LT] = ACTIONS(4813),
    [anon_sym_GT_GT] = ACTIONS(4813),
    [anon_sym_STAR] = ACTIONS(4813),
    [anon_sym_SLASH] = ACTIONS(4813),
    [anon_sym_PERCENT] = ACTIONS(4813),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4811),
    [anon_sym_DOT] = ACTIONS(4813),
    [anon_sym_LBRACK] = ACTIONS(4811),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4811),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4811),
    [anon_sym_not_in] = ACTIONS(4811),
    [anon_sym_or_return] = ACTIONS(4811),
    [anon_sym_or_continue] = ACTIONS(4811),
    [anon_sym_or_break] = ACTIONS(4811),
    [anon_sym_CARET] = ACTIONS(4813),
    [sym_uninitialized] = ACTIONS(4811),
    [sym_tag] = ACTIONS(4811),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4811),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [750] = {
    [ts_builtin_sym_end] = ACTIONS(4815),
    [anon_sym_LBRACE] = ACTIONS(4815),
    [anon_sym_RBRACE] = ACTIONS(4815),
    [anon_sym_COMMA] = ACTIONS(4815),
    [anon_sym_COLON_COLON] = ACTIONS(4815),
    [anon_sym_DASH_GT] = ACTIONS(4815),
    [anon_sym_where] = ACTIONS(4815),
    [anon_sym_EQ] = ACTIONS(4817),
    [anon_sym_COLON] = ACTIONS(4817),
    [anon_sym_PIPE] = ACTIONS(4817),
    [anon_sym_COLON_EQ] = ACTIONS(4815),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PLUS_EQ] = ACTIONS(4815),
    [anon_sym_DASH_EQ] = ACTIONS(4815),
    [anon_sym_STAR_EQ] = ACTIONS(4815),
    [anon_sym_SLASH_EQ] = ACTIONS(4815),
    [anon_sym_PERCENT_EQ] = ACTIONS(4815),
    [anon_sym_AMP_EQ] = ACTIONS(4815),
    [anon_sym_PIPE_EQ] = ACTIONS(4815),
    [anon_sym_CARET_EQ] = ACTIONS(4815),
    [anon_sym_LT_LT_EQ] = ACTIONS(4815),
    [anon_sym_GT_GT_EQ] = ACTIONS(4815),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4815),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4815),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4815),
    [anon_sym_if] = ACTIONS(4815),
    [anon_sym_SEMI] = ACTIONS(4815),
    [anon_sym_else] = ACTIONS(4815),
    [anon_sym_when] = ACTIONS(4815),
    [anon_sym_in] = ACTIONS(4815),
    [anon_sym_case] = ACTIONS(4815),
    [anon_sym_QMARK] = ACTIONS(4815),
    [anon_sym_PLUS] = ACTIONS(4817),
    [anon_sym_DASH] = ACTIONS(4817),
    [anon_sym_TILDE] = ACTIONS(4817),
    [anon_sym_AMP] = ACTIONS(4817),
    [anon_sym_PIPE_PIPE] = ACTIONS(4817),
    [anon_sym_or_else] = ACTIONS(4815),
    [anon_sym_AMP_AMP] = ACTIONS(4817),
    [anon_sym_GT] = ACTIONS(4817),
    [anon_sym_GT_EQ] = ACTIONS(4815),
    [anon_sym_LT_EQ] = ACTIONS(4815),
    [anon_sym_LT] = ACTIONS(4817),
    [anon_sym_EQ_EQ] = ACTIONS(4815),
    [anon_sym_BANG_EQ] = ACTIONS(4815),
    [anon_sym_TILDE_EQ] = ACTIONS(4815),
    [anon_sym_AMP_TILDE] = ACTIONS(4817),
    [anon_sym_LT_LT] = ACTIONS(4817),
    [anon_sym_GT_GT] = ACTIONS(4817),
    [anon_sym_STAR] = ACTIONS(4817),
    [anon_sym_SLASH] = ACTIONS(4817),
    [anon_sym_PERCENT] = ACTIONS(4817),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4815),
    [anon_sym_DOT] = ACTIONS(4817),
    [anon_sym_LBRACK] = ACTIONS(4815),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4815),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4815),
    [anon_sym_not_in] = ACTIONS(4815),
    [anon_sym_or_return] = ACTIONS(4815),
    [anon_sym_or_continue] = ACTIONS(4815),
    [anon_sym_or_break] = ACTIONS(4815),
    [anon_sym_CARET] = ACTIONS(4817),
    [sym_uninitialized] = ACTIONS(4815),
    [sym_tag] = ACTIONS(4815),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4815),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [751] = {
    [ts_builtin_sym_end] = ACTIONS(4819),
    [anon_sym_LBRACE] = ACTIONS(4819),
    [anon_sym_RBRACE] = ACTIONS(4819),
    [anon_sym_COMMA] = ACTIONS(4819),
    [anon_sym_COLON_COLON] = ACTIONS(4819),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4819),
    [anon_sym_EQ] = ACTIONS(4821),
    [anon_sym_COLON] = ACTIONS(4821),
    [anon_sym_PIPE] = ACTIONS(4821),
    [anon_sym_COLON_EQ] = ACTIONS(4819),
    [anon_sym_LPAREN] = ACTIONS(4819),
    [anon_sym_PLUS_EQ] = ACTIONS(4819),
    [anon_sym_DASH_EQ] = ACTIONS(4819),
    [anon_sym_STAR_EQ] = ACTIONS(4819),
    [anon_sym_SLASH_EQ] = ACTIONS(4819),
    [anon_sym_PERCENT_EQ] = ACTIONS(4819),
    [anon_sym_AMP_EQ] = ACTIONS(4819),
    [anon_sym_PIPE_EQ] = ACTIONS(4819),
    [anon_sym_CARET_EQ] = ACTIONS(4819),
    [anon_sym_LT_LT_EQ] = ACTIONS(4819),
    [anon_sym_GT_GT_EQ] = ACTIONS(4819),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4819),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4819),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4819),
    [anon_sym_if] = ACTIONS(4819),
    [anon_sym_SEMI] = ACTIONS(4819),
    [anon_sym_else] = ACTIONS(4819),
    [anon_sym_when] = ACTIONS(4819),
    [anon_sym_in] = ACTIONS(4819),
    [anon_sym_case] = ACTIONS(4819),
    [anon_sym_QMARK] = ACTIONS(4819),
    [anon_sym_PLUS] = ACTIONS(4821),
    [anon_sym_DASH] = ACTIONS(4821),
    [anon_sym_TILDE] = ACTIONS(4821),
    [anon_sym_AMP] = ACTIONS(4821),
    [anon_sym_PIPE_PIPE] = ACTIONS(4821),
    [anon_sym_or_else] = ACTIONS(4819),
    [anon_sym_AMP_AMP] = ACTIONS(4821),
    [anon_sym_GT] = ACTIONS(4821),
    [anon_sym_GT_EQ] = ACTIONS(4819),
    [anon_sym_LT_EQ] = ACTIONS(4819),
    [anon_sym_LT] = ACTIONS(4821),
    [anon_sym_EQ_EQ] = ACTIONS(4819),
    [anon_sym_BANG_EQ] = ACTIONS(4819),
    [anon_sym_TILDE_EQ] = ACTIONS(4819),
    [anon_sym_AMP_TILDE] = ACTIONS(4821),
    [anon_sym_LT_LT] = ACTIONS(4821),
    [anon_sym_GT_GT] = ACTIONS(4821),
    [anon_sym_STAR] = ACTIONS(4821),
    [anon_sym_SLASH] = ACTIONS(4821),
    [anon_sym_PERCENT] = ACTIONS(4821),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4819),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4819),
    [anon_sym_or_return] = ACTIONS(4819),
    [anon_sym_or_continue] = ACTIONS(4819),
    [anon_sym_or_break] = ACTIONS(4819),
    [anon_sym_CARET] = ACTIONS(4821),
    [sym_uninitialized] = ACTIONS(4819),
    [sym_tag] = ACTIONS(4819),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4819),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [752] = {
    [ts_builtin_sym_end] = ACTIONS(207),
    [anon_sym_LBRACE] = ACTIONS(207),
    [anon_sym_RBRACE] = ACTIONS(207),
    [anon_sym_COMMA] = ACTIONS(207),
    [anon_sym_COLON_COLON] = ACTIONS(207),
    [anon_sym_DASH_GT] = ACTIONS(207),
    [anon_sym_where] = ACTIONS(207),
    [anon_sym_EQ] = ACTIONS(209),
    [anon_sym_COLON] = ACTIONS(209),
    [anon_sym_PIPE] = ACTIONS(209),
    [anon_sym_COLON_EQ] = ACTIONS(207),
    [anon_sym_LPAREN] = ACTIONS(207),
    [anon_sym_PLUS_EQ] = ACTIONS(207),
    [anon_sym_DASH_EQ] = ACTIONS(207),
    [anon_sym_STAR_EQ] = ACTIONS(207),
    [anon_sym_SLASH_EQ] = ACTIONS(207),
    [anon_sym_PERCENT_EQ] = ACTIONS(207),
    [anon_sym_AMP_EQ] = ACTIONS(207),
    [anon_sym_PIPE_EQ] = ACTIONS(207),
    [anon_sym_CARET_EQ] = ACTIONS(207),
    [anon_sym_LT_LT_EQ] = ACTIONS(207),
    [anon_sym_GT_GT_EQ] = ACTIONS(207),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(207),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(207),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(207),
    [anon_sym_if] = ACTIONS(207),
    [anon_sym_SEMI] = ACTIONS(207),
    [anon_sym_else] = ACTIONS(207),
    [anon_sym_when] = ACTIONS(207),
    [anon_sym_in] = ACTIONS(207),
    [anon_sym_case] = ACTIONS(207),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_PLUS] = ACTIONS(209),
    [anon_sym_DASH] = ACTIONS(209),
    [anon_sym_TILDE] = ACTIONS(209),
    [anon_sym_AMP] = ACTIONS(209),
    [anon_sym_PIPE_PIPE] = ACTIONS(209),
    [anon_sym_or_else] = ACTIONS(207),
    [anon_sym_AMP_AMP] = ACTIONS(209),
    [anon_sym_GT] = ACTIONS(209),
    [anon_sym_GT_EQ] = ACTIONS(207),
    [anon_sym_LT_EQ] = ACTIONS(207),
    [anon_sym_LT] = ACTIONS(209),
    [anon_sym_EQ_EQ] = ACTIONS(207),
    [anon_sym_BANG_EQ] = ACTIONS(207),
    [anon_sym_TILDE_EQ] = ACTIONS(207),
    [anon_sym_AMP_TILDE] = ACTIONS(209),
    [anon_sym_LT_LT] = ACTIONS(209),
    [anon_sym_GT_GT] = ACTIONS(209),
    [anon_sym_STAR] = ACTIONS(209),
    [anon_sym_SLASH] = ACTIONS(209),
    [anon_sym_PERCENT] = ACTIONS(209),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(207),
    [anon_sym_DOT] = ACTIONS(209),
    [anon_sym_LBRACK] = ACTIONS(207),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(207),
    [anon_sym_DOT_DOT_LT] = ACTIONS(207),
    [anon_sym_not_in] = ACTIONS(207),
    [anon_sym_or_return] = ACTIONS(207),
    [anon_sym_or_continue] = ACTIONS(207),
    [anon_sym_or_break] = ACTIONS(207),
    [anon_sym_CARET] = ACTIONS(209),
    [sym_uninitialized] = ACTIONS(207),
    [sym_tag] = ACTIONS(207),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(207),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [753] = {
    [ts_builtin_sym_end] = ACTIONS(4823),
    [anon_sym_LBRACE] = ACTIONS(4823),
    [anon_sym_RBRACE] = ACTIONS(4823),
    [anon_sym_COMMA] = ACTIONS(4823),
    [anon_sym_COLON_COLON] = ACTIONS(4823),
    [anon_sym_DASH_GT] = ACTIONS(4823),
    [anon_sym_where] = ACTIONS(4823),
    [anon_sym_EQ] = ACTIONS(4825),
    [anon_sym_COLON] = ACTIONS(4825),
    [anon_sym_PIPE] = ACTIONS(4825),
    [anon_sym_COLON_EQ] = ACTIONS(4823),
    [anon_sym_LPAREN] = ACTIONS(4823),
    [anon_sym_PLUS_EQ] = ACTIONS(4823),
    [anon_sym_DASH_EQ] = ACTIONS(4823),
    [anon_sym_STAR_EQ] = ACTIONS(4823),
    [anon_sym_SLASH_EQ] = ACTIONS(4823),
    [anon_sym_PERCENT_EQ] = ACTIONS(4823),
    [anon_sym_AMP_EQ] = ACTIONS(4823),
    [anon_sym_PIPE_EQ] = ACTIONS(4823),
    [anon_sym_CARET_EQ] = ACTIONS(4823),
    [anon_sym_LT_LT_EQ] = ACTIONS(4823),
    [anon_sym_GT_GT_EQ] = ACTIONS(4823),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4823),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4823),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4823),
    [anon_sym_if] = ACTIONS(4823),
    [anon_sym_SEMI] = ACTIONS(4823),
    [anon_sym_else] = ACTIONS(4823),
    [anon_sym_when] = ACTIONS(4823),
    [anon_sym_in] = ACTIONS(4823),
    [anon_sym_case] = ACTIONS(4823),
    [anon_sym_QMARK] = ACTIONS(4823),
    [anon_sym_PLUS] = ACTIONS(4825),
    [anon_sym_DASH] = ACTIONS(4825),
    [anon_sym_TILDE] = ACTIONS(4825),
    [anon_sym_AMP] = ACTIONS(4825),
    [anon_sym_PIPE_PIPE] = ACTIONS(4825),
    [anon_sym_or_else] = ACTIONS(4823),
    [anon_sym_AMP_AMP] = ACTIONS(4825),
    [anon_sym_GT] = ACTIONS(4825),
    [anon_sym_GT_EQ] = ACTIONS(4823),
    [anon_sym_LT_EQ] = ACTIONS(4823),
    [anon_sym_LT] = ACTIONS(4825),
    [anon_sym_EQ_EQ] = ACTIONS(4823),
    [anon_sym_BANG_EQ] = ACTIONS(4823),
    [anon_sym_TILDE_EQ] = ACTIONS(4823),
    [anon_sym_AMP_TILDE] = ACTIONS(4825),
    [anon_sym_LT_LT] = ACTIONS(4825),
    [anon_sym_GT_GT] = ACTIONS(4825),
    [anon_sym_STAR] = ACTIONS(4825),
    [anon_sym_SLASH] = ACTIONS(4825),
    [anon_sym_PERCENT] = ACTIONS(4825),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4823),
    [anon_sym_DOT] = ACTIONS(4825),
    [anon_sym_LBRACK] = ACTIONS(4823),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4823),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4823),
    [anon_sym_not_in] = ACTIONS(4823),
    [anon_sym_or_return] = ACTIONS(4823),
    [anon_sym_or_continue] = ACTIONS(4823),
    [anon_sym_or_break] = ACTIONS(4823),
    [anon_sym_CARET] = ACTIONS(4825),
    [sym_uninitialized] = ACTIONS(4823),
    [sym_tag] = ACTIONS(4823),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4823),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [754] = {
    [ts_builtin_sym_end] = ACTIONS(4827),
    [anon_sym_LBRACE] = ACTIONS(4827),
    [anon_sym_RBRACE] = ACTIONS(4827),
    [anon_sym_COMMA] = ACTIONS(4827),
    [anon_sym_COLON_COLON] = ACTIONS(4827),
    [anon_sym_DASH_GT] = ACTIONS(4827),
    [anon_sym_where] = ACTIONS(4827),
    [anon_sym_EQ] = ACTIONS(4829),
    [anon_sym_COLON] = ACTIONS(4829),
    [anon_sym_PIPE] = ACTIONS(4829),
    [anon_sym_COLON_EQ] = ACTIONS(4827),
    [anon_sym_LPAREN] = ACTIONS(4827),
    [anon_sym_PLUS_EQ] = ACTIONS(4827),
    [anon_sym_DASH_EQ] = ACTIONS(4827),
    [anon_sym_STAR_EQ] = ACTIONS(4827),
    [anon_sym_SLASH_EQ] = ACTIONS(4827),
    [anon_sym_PERCENT_EQ] = ACTIONS(4827),
    [anon_sym_AMP_EQ] = ACTIONS(4827),
    [anon_sym_PIPE_EQ] = ACTIONS(4827),
    [anon_sym_CARET_EQ] = ACTIONS(4827),
    [anon_sym_LT_LT_EQ] = ACTIONS(4827),
    [anon_sym_GT_GT_EQ] = ACTIONS(4827),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4827),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4827),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4827),
    [anon_sym_if] = ACTIONS(4827),
    [anon_sym_SEMI] = ACTIONS(4827),
    [anon_sym_else] = ACTIONS(4827),
    [anon_sym_when] = ACTIONS(4827),
    [anon_sym_in] = ACTIONS(4827),
    [anon_sym_case] = ACTIONS(4827),
    [anon_sym_QMARK] = ACTIONS(4827),
    [anon_sym_PLUS] = ACTIONS(4829),
    [anon_sym_DASH] = ACTIONS(4829),
    [anon_sym_TILDE] = ACTIONS(4829),
    [anon_sym_AMP] = ACTIONS(4829),
    [anon_sym_PIPE_PIPE] = ACTIONS(4829),
    [anon_sym_or_else] = ACTIONS(4827),
    [anon_sym_AMP_AMP] = ACTIONS(4829),
    [anon_sym_GT] = ACTIONS(4829),
    [anon_sym_GT_EQ] = ACTIONS(4827),
    [anon_sym_LT_EQ] = ACTIONS(4827),
    [anon_sym_LT] = ACTIONS(4829),
    [anon_sym_EQ_EQ] = ACTIONS(4827),
    [anon_sym_BANG_EQ] = ACTIONS(4827),
    [anon_sym_TILDE_EQ] = ACTIONS(4827),
    [anon_sym_AMP_TILDE] = ACTIONS(4829),
    [anon_sym_LT_LT] = ACTIONS(4829),
    [anon_sym_GT_GT] = ACTIONS(4829),
    [anon_sym_STAR] = ACTIONS(4829),
    [anon_sym_SLASH] = ACTIONS(4829),
    [anon_sym_PERCENT] = ACTIONS(4829),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4827),
    [anon_sym_DOT] = ACTIONS(4829),
    [anon_sym_LBRACK] = ACTIONS(4827),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4827),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4827),
    [anon_sym_not_in] = ACTIONS(4827),
    [anon_sym_or_return] = ACTIONS(4827),
    [anon_sym_or_continue] = ACTIONS(4827),
    [anon_sym_or_break] = ACTIONS(4827),
    [anon_sym_CARET] = ACTIONS(4829),
    [sym_uninitialized] = ACTIONS(4827),
    [sym_tag] = ACTIONS(4827),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4827),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [755] = {
    [ts_builtin_sym_end] = ACTIONS(4831),
    [anon_sym_LBRACE] = ACTIONS(4831),
    [anon_sym_RBRACE] = ACTIONS(4831),
    [anon_sym_COMMA] = ACTIONS(4831),
    [anon_sym_COLON_COLON] = ACTIONS(4831),
    [anon_sym_DASH_GT] = ACTIONS(4831),
    [anon_sym_where] = ACTIONS(4831),
    [anon_sym_EQ] = ACTIONS(4833),
    [anon_sym_COLON] = ACTIONS(4833),
    [anon_sym_PIPE] = ACTIONS(4833),
    [anon_sym_COLON_EQ] = ACTIONS(4831),
    [anon_sym_LPAREN] = ACTIONS(4831),
    [anon_sym_PLUS_EQ] = ACTIONS(4831),
    [anon_sym_DASH_EQ] = ACTIONS(4831),
    [anon_sym_STAR_EQ] = ACTIONS(4831),
    [anon_sym_SLASH_EQ] = ACTIONS(4831),
    [anon_sym_PERCENT_EQ] = ACTIONS(4831),
    [anon_sym_AMP_EQ] = ACTIONS(4831),
    [anon_sym_PIPE_EQ] = ACTIONS(4831),
    [anon_sym_CARET_EQ] = ACTIONS(4831),
    [anon_sym_LT_LT_EQ] = ACTIONS(4831),
    [anon_sym_GT_GT_EQ] = ACTIONS(4831),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4831),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4831),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4831),
    [anon_sym_if] = ACTIONS(4831),
    [anon_sym_SEMI] = ACTIONS(4831),
    [anon_sym_else] = ACTIONS(4831),
    [anon_sym_when] = ACTIONS(4831),
    [anon_sym_in] = ACTIONS(4831),
    [anon_sym_case] = ACTIONS(4831),
    [anon_sym_QMARK] = ACTIONS(4831),
    [anon_sym_PLUS] = ACTIONS(4833),
    [anon_sym_DASH] = ACTIONS(4833),
    [anon_sym_TILDE] = ACTIONS(4833),
    [anon_sym_AMP] = ACTIONS(4833),
    [anon_sym_PIPE_PIPE] = ACTIONS(4833),
    [anon_sym_or_else] = ACTIONS(4831),
    [anon_sym_AMP_AMP] = ACTIONS(4833),
    [anon_sym_GT] = ACTIONS(4833),
    [anon_sym_GT_EQ] = ACTIONS(4831),
    [anon_sym_LT_EQ] = ACTIONS(4831),
    [anon_sym_LT] = ACTIONS(4833),
    [anon_sym_EQ_EQ] = ACTIONS(4831),
    [anon_sym_BANG_EQ] = ACTIONS(4831),
    [anon_sym_TILDE_EQ] = ACTIONS(4831),
    [anon_sym_AMP_TILDE] = ACTIONS(4833),
    [anon_sym_LT_LT] = ACTIONS(4833),
    [anon_sym_GT_GT] = ACTIONS(4833),
    [anon_sym_STAR] = ACTIONS(4833),
    [anon_sym_SLASH] = ACTIONS(4833),
    [anon_sym_PERCENT] = ACTIONS(4833),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4831),
    [anon_sym_DOT] = ACTIONS(4833),
    [anon_sym_LBRACK] = ACTIONS(4831),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4831),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4831),
    [anon_sym_not_in] = ACTIONS(4831),
    [anon_sym_or_return] = ACTIONS(4831),
    [anon_sym_or_continue] = ACTIONS(4831),
    [anon_sym_or_break] = ACTIONS(4831),
    [anon_sym_CARET] = ACTIONS(4833),
    [sym_uninitialized] = ACTIONS(4831),
    [sym_tag] = ACTIONS(4831),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4831),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [756] = {
    [ts_builtin_sym_end] = ACTIONS(4835),
    [anon_sym_LBRACE] = ACTIONS(4835),
    [anon_sym_RBRACE] = ACTIONS(4835),
    [anon_sym_COMMA] = ACTIONS(4835),
    [anon_sym_COLON_COLON] = ACTIONS(4835),
    [anon_sym_DASH_GT] = ACTIONS(4835),
    [anon_sym_where] = ACTIONS(4835),
    [anon_sym_EQ] = ACTIONS(4837),
    [anon_sym_COLON] = ACTIONS(4837),
    [anon_sym_PIPE] = ACTIONS(4837),
    [anon_sym_COLON_EQ] = ACTIONS(4835),
    [anon_sym_LPAREN] = ACTIONS(4835),
    [anon_sym_PLUS_EQ] = ACTIONS(4835),
    [anon_sym_DASH_EQ] = ACTIONS(4835),
    [anon_sym_STAR_EQ] = ACTIONS(4835),
    [anon_sym_SLASH_EQ] = ACTIONS(4835),
    [anon_sym_PERCENT_EQ] = ACTIONS(4835),
    [anon_sym_AMP_EQ] = ACTIONS(4835),
    [anon_sym_PIPE_EQ] = ACTIONS(4835),
    [anon_sym_CARET_EQ] = ACTIONS(4835),
    [anon_sym_LT_LT_EQ] = ACTIONS(4835),
    [anon_sym_GT_GT_EQ] = ACTIONS(4835),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4835),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4835),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4835),
    [anon_sym_if] = ACTIONS(4835),
    [anon_sym_SEMI] = ACTIONS(4835),
    [anon_sym_else] = ACTIONS(4835),
    [anon_sym_when] = ACTIONS(4835),
    [anon_sym_in] = ACTIONS(4835),
    [anon_sym_case] = ACTIONS(4835),
    [anon_sym_QMARK] = ACTIONS(4835),
    [anon_sym_PLUS] = ACTIONS(4837),
    [anon_sym_DASH] = ACTIONS(4837),
    [anon_sym_TILDE] = ACTIONS(4837),
    [anon_sym_AMP] = ACTIONS(4837),
    [anon_sym_PIPE_PIPE] = ACTIONS(4837),
    [anon_sym_or_else] = ACTIONS(4835),
    [anon_sym_AMP_AMP] = ACTIONS(4837),
    [anon_sym_GT] = ACTIONS(4837),
    [anon_sym_GT_EQ] = ACTIONS(4835),
    [anon_sym_LT_EQ] = ACTIONS(4835),
    [anon_sym_LT] = ACTIONS(4837),
    [anon_sym_EQ_EQ] = ACTIONS(4835),
    [anon_sym_BANG_EQ] = ACTIONS(4835),
    [anon_sym_TILDE_EQ] = ACTIONS(4835),
    [anon_sym_AMP_TILDE] = ACTIONS(4837),
    [anon_sym_LT_LT] = ACTIONS(4837),
    [anon_sym_GT_GT] = ACTIONS(4837),
    [anon_sym_STAR] = ACTIONS(4837),
    [anon_sym_SLASH] = ACTIONS(4837),
    [anon_sym_PERCENT] = ACTIONS(4837),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4835),
    [anon_sym_DOT] = ACTIONS(4837),
    [anon_sym_LBRACK] = ACTIONS(4835),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4835),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4835),
    [anon_sym_not_in] = ACTIONS(4835),
    [anon_sym_or_return] = ACTIONS(4835),
    [anon_sym_or_continue] = ACTIONS(4835),
    [anon_sym_or_break] = ACTIONS(4835),
    [anon_sym_CARET] = ACTIONS(4837),
    [sym_uninitialized] = ACTIONS(4835),
    [sym_tag] = ACTIONS(4835),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4835),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [757] = {
    [ts_builtin_sym_end] = ACTIONS(4839),
    [anon_sym_LBRACE] = ACTIONS(4839),
    [anon_sym_RBRACE] = ACTIONS(4839),
    [anon_sym_COMMA] = ACTIONS(4839),
    [anon_sym_COLON_COLON] = ACTIONS(4839),
    [anon_sym_DASH_GT] = ACTIONS(4839),
    [anon_sym_where] = ACTIONS(4839),
    [anon_sym_EQ] = ACTIONS(4841),
    [anon_sym_COLON] = ACTIONS(4841),
    [anon_sym_PIPE] = ACTIONS(4841),
    [anon_sym_COLON_EQ] = ACTIONS(4839),
    [anon_sym_LPAREN] = ACTIONS(4839),
    [anon_sym_PLUS_EQ] = ACTIONS(4839),
    [anon_sym_DASH_EQ] = ACTIONS(4839),
    [anon_sym_STAR_EQ] = ACTIONS(4839),
    [anon_sym_SLASH_EQ] = ACTIONS(4839),
    [anon_sym_PERCENT_EQ] = ACTIONS(4839),
    [anon_sym_AMP_EQ] = ACTIONS(4839),
    [anon_sym_PIPE_EQ] = ACTIONS(4839),
    [anon_sym_CARET_EQ] = ACTIONS(4839),
    [anon_sym_LT_LT_EQ] = ACTIONS(4839),
    [anon_sym_GT_GT_EQ] = ACTIONS(4839),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4839),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4839),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4839),
    [anon_sym_if] = ACTIONS(4839),
    [anon_sym_SEMI] = ACTIONS(4839),
    [anon_sym_else] = ACTIONS(4839),
    [anon_sym_when] = ACTIONS(4839),
    [anon_sym_in] = ACTIONS(4839),
    [anon_sym_case] = ACTIONS(4839),
    [anon_sym_QMARK] = ACTIONS(4839),
    [anon_sym_PLUS] = ACTIONS(4841),
    [anon_sym_DASH] = ACTIONS(4841),
    [anon_sym_TILDE] = ACTIONS(4841),
    [anon_sym_AMP] = ACTIONS(4841),
    [anon_sym_PIPE_PIPE] = ACTIONS(4841),
    [anon_sym_or_else] = ACTIONS(4839),
    [anon_sym_AMP_AMP] = ACTIONS(4841),
    [anon_sym_GT] = ACTIONS(4841),
    [anon_sym_GT_EQ] = ACTIONS(4839),
    [anon_sym_LT_EQ] = ACTIONS(4839),
    [anon_sym_LT] = ACTIONS(4841),
    [anon_sym_EQ_EQ] = ACTIONS(4839),
    [anon_sym_BANG_EQ] = ACTIONS(4839),
    [anon_sym_TILDE_EQ] = ACTIONS(4839),
    [anon_sym_AMP_TILDE] = ACTIONS(4841),
    [anon_sym_LT_LT] = ACTIONS(4841),
    [anon_sym_GT_GT] = ACTIONS(4841),
    [anon_sym_STAR] = ACTIONS(4841),
    [anon_sym_SLASH] = ACTIONS(4841),
    [anon_sym_PERCENT] = ACTIONS(4841),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4839),
    [anon_sym_DOT] = ACTIONS(4841),
    [anon_sym_LBRACK] = ACTIONS(4839),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4839),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4839),
    [anon_sym_not_in] = ACTIONS(4839),
    [anon_sym_or_return] = ACTIONS(4839),
    [anon_sym_or_continue] = ACTIONS(4839),
    [anon_sym_or_break] = ACTIONS(4839),
    [anon_sym_CARET] = ACTIONS(4841),
    [sym_uninitialized] = ACTIONS(4839),
    [sym_tag] = ACTIONS(4839),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4839),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [758] = {
    [ts_builtin_sym_end] = ACTIONS(4843),
    [anon_sym_LBRACE] = ACTIONS(4843),
    [anon_sym_RBRACE] = ACTIONS(4843),
    [anon_sym_COMMA] = ACTIONS(4843),
    [anon_sym_COLON_COLON] = ACTIONS(4843),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4843),
    [anon_sym_EQ] = ACTIONS(4845),
    [anon_sym_COLON] = ACTIONS(4845),
    [anon_sym_PIPE] = ACTIONS(4845),
    [anon_sym_COLON_EQ] = ACTIONS(4843),
    [anon_sym_LPAREN] = ACTIONS(4843),
    [anon_sym_PLUS_EQ] = ACTIONS(4843),
    [anon_sym_DASH_EQ] = ACTIONS(4843),
    [anon_sym_STAR_EQ] = ACTIONS(4843),
    [anon_sym_SLASH_EQ] = ACTIONS(4843),
    [anon_sym_PERCENT_EQ] = ACTIONS(4843),
    [anon_sym_AMP_EQ] = ACTIONS(4843),
    [anon_sym_PIPE_EQ] = ACTIONS(4843),
    [anon_sym_CARET_EQ] = ACTIONS(4843),
    [anon_sym_LT_LT_EQ] = ACTIONS(4843),
    [anon_sym_GT_GT_EQ] = ACTIONS(4843),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4843),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4843),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4843),
    [anon_sym_if] = ACTIONS(4843),
    [anon_sym_SEMI] = ACTIONS(4843),
    [anon_sym_else] = ACTIONS(4843),
    [anon_sym_when] = ACTIONS(4843),
    [anon_sym_in] = ACTIONS(4843),
    [anon_sym_case] = ACTIONS(4843),
    [anon_sym_QMARK] = ACTIONS(4843),
    [anon_sym_PLUS] = ACTIONS(4845),
    [anon_sym_DASH] = ACTIONS(4845),
    [anon_sym_TILDE] = ACTIONS(4845),
    [anon_sym_AMP] = ACTIONS(4845),
    [anon_sym_PIPE_PIPE] = ACTIONS(4845),
    [anon_sym_or_else] = ACTIONS(4843),
    [anon_sym_AMP_AMP] = ACTIONS(4845),
    [anon_sym_GT] = ACTIONS(4845),
    [anon_sym_GT_EQ] = ACTIONS(4843),
    [anon_sym_LT_EQ] = ACTIONS(4843),
    [anon_sym_LT] = ACTIONS(4845),
    [anon_sym_EQ_EQ] = ACTIONS(4843),
    [anon_sym_BANG_EQ] = ACTIONS(4843),
    [anon_sym_TILDE_EQ] = ACTIONS(4843),
    [anon_sym_AMP_TILDE] = ACTIONS(4845),
    [anon_sym_LT_LT] = ACTIONS(4845),
    [anon_sym_GT_GT] = ACTIONS(4845),
    [anon_sym_STAR] = ACTIONS(4845),
    [anon_sym_SLASH] = ACTIONS(4845),
    [anon_sym_PERCENT] = ACTIONS(4845),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4843),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4843),
    [anon_sym_or_return] = ACTIONS(4843),
    [anon_sym_or_continue] = ACTIONS(4843),
    [anon_sym_or_break] = ACTIONS(4843),
    [anon_sym_CARET] = ACTIONS(4845),
    [sym_uninitialized] = ACTIONS(4843),
    [sym_tag] = ACTIONS(4843),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4843),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [759] = {
    [ts_builtin_sym_end] = ACTIONS(4847),
    [anon_sym_LBRACE] = ACTIONS(4847),
    [anon_sym_RBRACE] = ACTIONS(4847),
    [anon_sym_COMMA] = ACTIONS(4847),
    [anon_sym_COLON_COLON] = ACTIONS(4847),
    [anon_sym_DASH_GT] = ACTIONS(4847),
    [anon_sym_where] = ACTIONS(4847),
    [anon_sym_EQ] = ACTIONS(4849),
    [anon_sym_COLON] = ACTIONS(4849),
    [anon_sym_PIPE] = ACTIONS(4849),
    [anon_sym_COLON_EQ] = ACTIONS(4847),
    [anon_sym_LPAREN] = ACTIONS(4847),
    [anon_sym_PLUS_EQ] = ACTIONS(4847),
    [anon_sym_DASH_EQ] = ACTIONS(4847),
    [anon_sym_STAR_EQ] = ACTIONS(4847),
    [anon_sym_SLASH_EQ] = ACTIONS(4847),
    [anon_sym_PERCENT_EQ] = ACTIONS(4847),
    [anon_sym_AMP_EQ] = ACTIONS(4847),
    [anon_sym_PIPE_EQ] = ACTIONS(4847),
    [anon_sym_CARET_EQ] = ACTIONS(4847),
    [anon_sym_LT_LT_EQ] = ACTIONS(4847),
    [anon_sym_GT_GT_EQ] = ACTIONS(4847),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4847),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4847),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4847),
    [anon_sym_if] = ACTIONS(4847),
    [anon_sym_SEMI] = ACTIONS(4847),
    [anon_sym_else] = ACTIONS(4847),
    [anon_sym_when] = ACTIONS(4847),
    [anon_sym_in] = ACTIONS(4847),
    [anon_sym_case] = ACTIONS(4847),
    [anon_sym_QMARK] = ACTIONS(4847),
    [anon_sym_PLUS] = ACTIONS(4849),
    [anon_sym_DASH] = ACTIONS(4849),
    [anon_sym_TILDE] = ACTIONS(4849),
    [anon_sym_AMP] = ACTIONS(4849),
    [anon_sym_PIPE_PIPE] = ACTIONS(4849),
    [anon_sym_or_else] = ACTIONS(4847),
    [anon_sym_AMP_AMP] = ACTIONS(4849),
    [anon_sym_GT] = ACTIONS(4849),
    [anon_sym_GT_EQ] = ACTIONS(4847),
    [anon_sym_LT_EQ] = ACTIONS(4847),
    [anon_sym_LT] = ACTIONS(4849),
    [anon_sym_EQ_EQ] = ACTIONS(4847),
    [anon_sym_BANG_EQ] = ACTIONS(4847),
    [anon_sym_TILDE_EQ] = ACTIONS(4847),
    [anon_sym_AMP_TILDE] = ACTIONS(4849),
    [anon_sym_LT_LT] = ACTIONS(4849),
    [anon_sym_GT_GT] = ACTIONS(4849),
    [anon_sym_STAR] = ACTIONS(4849),
    [anon_sym_SLASH] = ACTIONS(4849),
    [anon_sym_PERCENT] = ACTIONS(4849),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4847),
    [anon_sym_DOT] = ACTIONS(4849),
    [anon_sym_LBRACK] = ACTIONS(4847),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4847),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4847),
    [anon_sym_not_in] = ACTIONS(4847),
    [anon_sym_or_return] = ACTIONS(4847),
    [anon_sym_or_continue] = ACTIONS(4847),
    [anon_sym_or_break] = ACTIONS(4847),
    [anon_sym_CARET] = ACTIONS(4849),
    [sym_uninitialized] = ACTIONS(4847),
    [sym_tag] = ACTIONS(4847),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4847),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [760] = {
    [ts_builtin_sym_end] = ACTIONS(4851),
    [anon_sym_LBRACE] = ACTIONS(4851),
    [anon_sym_RBRACE] = ACTIONS(4851),
    [anon_sym_COMMA] = ACTIONS(4851),
    [anon_sym_COLON_COLON] = ACTIONS(4851),
    [anon_sym_DASH_GT] = ACTIONS(4851),
    [anon_sym_where] = ACTIONS(4851),
    [anon_sym_EQ] = ACTIONS(4853),
    [anon_sym_COLON] = ACTIONS(4853),
    [anon_sym_PIPE] = ACTIONS(4853),
    [anon_sym_COLON_EQ] = ACTIONS(4851),
    [anon_sym_LPAREN] = ACTIONS(4851),
    [anon_sym_PLUS_EQ] = ACTIONS(4851),
    [anon_sym_DASH_EQ] = ACTIONS(4851),
    [anon_sym_STAR_EQ] = ACTIONS(4851),
    [anon_sym_SLASH_EQ] = ACTIONS(4851),
    [anon_sym_PERCENT_EQ] = ACTIONS(4851),
    [anon_sym_AMP_EQ] = ACTIONS(4851),
    [anon_sym_PIPE_EQ] = ACTIONS(4851),
    [anon_sym_CARET_EQ] = ACTIONS(4851),
    [anon_sym_LT_LT_EQ] = ACTIONS(4851),
    [anon_sym_GT_GT_EQ] = ACTIONS(4851),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4851),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4851),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4851),
    [anon_sym_if] = ACTIONS(4851),
    [anon_sym_SEMI] = ACTIONS(4851),
    [anon_sym_else] = ACTIONS(4851),
    [anon_sym_when] = ACTIONS(4851),
    [anon_sym_in] = ACTIONS(4851),
    [anon_sym_case] = ACTIONS(4851),
    [anon_sym_QMARK] = ACTIONS(4851),
    [anon_sym_PLUS] = ACTIONS(4853),
    [anon_sym_DASH] = ACTIONS(4853),
    [anon_sym_TILDE] = ACTIONS(4853),
    [anon_sym_AMP] = ACTIONS(4853),
    [anon_sym_PIPE_PIPE] = ACTIONS(4853),
    [anon_sym_or_else] = ACTIONS(4851),
    [anon_sym_AMP_AMP] = ACTIONS(4853),
    [anon_sym_GT] = ACTIONS(4853),
    [anon_sym_GT_EQ] = ACTIONS(4851),
    [anon_sym_LT_EQ] = ACTIONS(4851),
    [anon_sym_LT] = ACTIONS(4853),
    [anon_sym_EQ_EQ] = ACTIONS(4851),
    [anon_sym_BANG_EQ] = ACTIONS(4851),
    [anon_sym_TILDE_EQ] = ACTIONS(4851),
    [anon_sym_AMP_TILDE] = ACTIONS(4853),
    [anon_sym_LT_LT] = ACTIONS(4853),
    [anon_sym_GT_GT] = ACTIONS(4853),
    [anon_sym_STAR] = ACTIONS(4853),
    [anon_sym_SLASH] = ACTIONS(4853),
    [anon_sym_PERCENT] = ACTIONS(4853),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4851),
    [anon_sym_DOT] = ACTIONS(4853),
    [anon_sym_LBRACK] = ACTIONS(4851),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4851),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4851),
    [anon_sym_not_in] = ACTIONS(4851),
    [anon_sym_or_return] = ACTIONS(4851),
    [anon_sym_or_continue] = ACTIONS(4851),
    [anon_sym_or_break] = ACTIONS(4851),
    [anon_sym_CARET] = ACTIONS(4853),
    [sym_uninitialized] = ACTIONS(4851),
    [sym_tag] = ACTIONS(4851),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4851),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [761] = {
    [ts_builtin_sym_end] = ACTIONS(4855),
    [anon_sym_LBRACE] = ACTIONS(4855),
    [anon_sym_RBRACE] = ACTIONS(4855),
    [anon_sym_COMMA] = ACTIONS(4855),
    [anon_sym_COLON_COLON] = ACTIONS(4855),
    [anon_sym_DASH_GT] = ACTIONS(4855),
    [anon_sym_where] = ACTIONS(4855),
    [anon_sym_EQ] = ACTIONS(4857),
    [anon_sym_COLON] = ACTIONS(4857),
    [anon_sym_PIPE] = ACTIONS(4857),
    [anon_sym_COLON_EQ] = ACTIONS(4855),
    [anon_sym_LPAREN] = ACTIONS(4855),
    [anon_sym_PLUS_EQ] = ACTIONS(4855),
    [anon_sym_DASH_EQ] = ACTIONS(4855),
    [anon_sym_STAR_EQ] = ACTIONS(4855),
    [anon_sym_SLASH_EQ] = ACTIONS(4855),
    [anon_sym_PERCENT_EQ] = ACTIONS(4855),
    [anon_sym_AMP_EQ] = ACTIONS(4855),
    [anon_sym_PIPE_EQ] = ACTIONS(4855),
    [anon_sym_CARET_EQ] = ACTIONS(4855),
    [anon_sym_LT_LT_EQ] = ACTIONS(4855),
    [anon_sym_GT_GT_EQ] = ACTIONS(4855),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4855),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4855),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4855),
    [anon_sym_if] = ACTIONS(4855),
    [anon_sym_SEMI] = ACTIONS(4855),
    [anon_sym_else] = ACTIONS(4855),
    [anon_sym_when] = ACTIONS(4855),
    [anon_sym_in] = ACTIONS(4855),
    [anon_sym_case] = ACTIONS(4855),
    [anon_sym_QMARK] = ACTIONS(4855),
    [anon_sym_PLUS] = ACTIONS(4857),
    [anon_sym_DASH] = ACTIONS(4857),
    [anon_sym_TILDE] = ACTIONS(4857),
    [anon_sym_AMP] = ACTIONS(4857),
    [anon_sym_PIPE_PIPE] = ACTIONS(4857),
    [anon_sym_or_else] = ACTIONS(4855),
    [anon_sym_AMP_AMP] = ACTIONS(4857),
    [anon_sym_GT] = ACTIONS(4857),
    [anon_sym_GT_EQ] = ACTIONS(4855),
    [anon_sym_LT_EQ] = ACTIONS(4855),
    [anon_sym_LT] = ACTIONS(4857),
    [anon_sym_EQ_EQ] = ACTIONS(4855),
    [anon_sym_BANG_EQ] = ACTIONS(4855),
    [anon_sym_TILDE_EQ] = ACTIONS(4855),
    [anon_sym_AMP_TILDE] = ACTIONS(4857),
    [anon_sym_LT_LT] = ACTIONS(4857),
    [anon_sym_GT_GT] = ACTIONS(4857),
    [anon_sym_STAR] = ACTIONS(4857),
    [anon_sym_SLASH] = ACTIONS(4857),
    [anon_sym_PERCENT] = ACTIONS(4857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4855),
    [anon_sym_DOT] = ACTIONS(4857),
    [anon_sym_LBRACK] = ACTIONS(4855),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4855),
    [anon_sym_not_in] = ACTIONS(4855),
    [anon_sym_or_return] = ACTIONS(4855),
    [anon_sym_or_continue] = ACTIONS(4855),
    [anon_sym_or_break] = ACTIONS(4855),
    [anon_sym_CARET] = ACTIONS(4857),
    [sym_uninitialized] = ACTIONS(4855),
    [sym_tag] = ACTIONS(4855),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4855),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [762] = {
    [ts_builtin_sym_end] = ACTIONS(4851),
    [anon_sym_LBRACE] = ACTIONS(4851),
    [anon_sym_RBRACE] = ACTIONS(4851),
    [anon_sym_COMMA] = ACTIONS(4851),
    [anon_sym_COLON_COLON] = ACTIONS(4851),
    [anon_sym_DASH_GT] = ACTIONS(4851),
    [anon_sym_where] = ACTIONS(4851),
    [anon_sym_EQ] = ACTIONS(4853),
    [anon_sym_COLON] = ACTIONS(4853),
    [anon_sym_PIPE] = ACTIONS(4853),
    [anon_sym_COLON_EQ] = ACTIONS(4851),
    [anon_sym_LPAREN] = ACTIONS(4851),
    [anon_sym_PLUS_EQ] = ACTIONS(4851),
    [anon_sym_DASH_EQ] = ACTIONS(4851),
    [anon_sym_STAR_EQ] = ACTIONS(4851),
    [anon_sym_SLASH_EQ] = ACTIONS(4851),
    [anon_sym_PERCENT_EQ] = ACTIONS(4851),
    [anon_sym_AMP_EQ] = ACTIONS(4851),
    [anon_sym_PIPE_EQ] = ACTIONS(4851),
    [anon_sym_CARET_EQ] = ACTIONS(4851),
    [anon_sym_LT_LT_EQ] = ACTIONS(4851),
    [anon_sym_GT_GT_EQ] = ACTIONS(4851),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4851),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4851),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4851),
    [anon_sym_if] = ACTIONS(4851),
    [anon_sym_SEMI] = ACTIONS(4851),
    [anon_sym_else] = ACTIONS(4851),
    [anon_sym_when] = ACTIONS(4851),
    [anon_sym_in] = ACTIONS(4851),
    [anon_sym_case] = ACTIONS(4851),
    [anon_sym_QMARK] = ACTIONS(4851),
    [anon_sym_PLUS] = ACTIONS(4853),
    [anon_sym_DASH] = ACTIONS(4853),
    [anon_sym_TILDE] = ACTIONS(4853),
    [anon_sym_AMP] = ACTIONS(4853),
    [anon_sym_PIPE_PIPE] = ACTIONS(4853),
    [anon_sym_or_else] = ACTIONS(4851),
    [anon_sym_AMP_AMP] = ACTIONS(4853),
    [anon_sym_GT] = ACTIONS(4853),
    [anon_sym_GT_EQ] = ACTIONS(4851),
    [anon_sym_LT_EQ] = ACTIONS(4851),
    [anon_sym_LT] = ACTIONS(4853),
    [anon_sym_EQ_EQ] = ACTIONS(4851),
    [anon_sym_BANG_EQ] = ACTIONS(4851),
    [anon_sym_TILDE_EQ] = ACTIONS(4851),
    [anon_sym_AMP_TILDE] = ACTIONS(4853),
    [anon_sym_LT_LT] = ACTIONS(4853),
    [anon_sym_GT_GT] = ACTIONS(4853),
    [anon_sym_STAR] = ACTIONS(4853),
    [anon_sym_SLASH] = ACTIONS(4853),
    [anon_sym_PERCENT] = ACTIONS(4853),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4851),
    [anon_sym_DOT] = ACTIONS(4853),
    [anon_sym_LBRACK] = ACTIONS(4851),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4851),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4851),
    [anon_sym_not_in] = ACTIONS(4851),
    [anon_sym_or_return] = ACTIONS(4851),
    [anon_sym_or_continue] = ACTIONS(4851),
    [anon_sym_or_break] = ACTIONS(4851),
    [anon_sym_CARET] = ACTIONS(4853),
    [sym_uninitialized] = ACTIONS(4851),
    [sym_tag] = ACTIONS(4851),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4851),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [763] = {
    [ts_builtin_sym_end] = ACTIONS(4859),
    [anon_sym_LBRACE] = ACTIONS(4859),
    [anon_sym_RBRACE] = ACTIONS(4859),
    [anon_sym_COMMA] = ACTIONS(4859),
    [anon_sym_COLON_COLON] = ACTIONS(4859),
    [anon_sym_DASH_GT] = ACTIONS(4859),
    [anon_sym_where] = ACTIONS(4859),
    [anon_sym_EQ] = ACTIONS(4861),
    [anon_sym_COLON] = ACTIONS(4861),
    [anon_sym_PIPE] = ACTIONS(4861),
    [anon_sym_COLON_EQ] = ACTIONS(4859),
    [anon_sym_LPAREN] = ACTIONS(4859),
    [anon_sym_PLUS_EQ] = ACTIONS(4859),
    [anon_sym_DASH_EQ] = ACTIONS(4859),
    [anon_sym_STAR_EQ] = ACTIONS(4859),
    [anon_sym_SLASH_EQ] = ACTIONS(4859),
    [anon_sym_PERCENT_EQ] = ACTIONS(4859),
    [anon_sym_AMP_EQ] = ACTIONS(4859),
    [anon_sym_PIPE_EQ] = ACTIONS(4859),
    [anon_sym_CARET_EQ] = ACTIONS(4859),
    [anon_sym_LT_LT_EQ] = ACTIONS(4859),
    [anon_sym_GT_GT_EQ] = ACTIONS(4859),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4859),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4859),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4859),
    [anon_sym_if] = ACTIONS(4859),
    [anon_sym_SEMI] = ACTIONS(4859),
    [anon_sym_else] = ACTIONS(4859),
    [anon_sym_when] = ACTIONS(4859),
    [anon_sym_in] = ACTIONS(4859),
    [anon_sym_case] = ACTIONS(4859),
    [anon_sym_QMARK] = ACTIONS(4859),
    [anon_sym_PLUS] = ACTIONS(4861),
    [anon_sym_DASH] = ACTIONS(4861),
    [anon_sym_TILDE] = ACTIONS(4861),
    [anon_sym_AMP] = ACTIONS(4861),
    [anon_sym_PIPE_PIPE] = ACTIONS(4861),
    [anon_sym_or_else] = ACTIONS(4859),
    [anon_sym_AMP_AMP] = ACTIONS(4861),
    [anon_sym_GT] = ACTIONS(4861),
    [anon_sym_GT_EQ] = ACTIONS(4859),
    [anon_sym_LT_EQ] = ACTIONS(4859),
    [anon_sym_LT] = ACTIONS(4861),
    [anon_sym_EQ_EQ] = ACTIONS(4859),
    [anon_sym_BANG_EQ] = ACTIONS(4859),
    [anon_sym_TILDE_EQ] = ACTIONS(4859),
    [anon_sym_AMP_TILDE] = ACTIONS(4861),
    [anon_sym_LT_LT] = ACTIONS(4861),
    [anon_sym_GT_GT] = ACTIONS(4861),
    [anon_sym_STAR] = ACTIONS(4861),
    [anon_sym_SLASH] = ACTIONS(4861),
    [anon_sym_PERCENT] = ACTIONS(4861),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4859),
    [anon_sym_DOT] = ACTIONS(4861),
    [anon_sym_LBRACK] = ACTIONS(4859),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4859),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4859),
    [anon_sym_not_in] = ACTIONS(4859),
    [anon_sym_or_return] = ACTIONS(4859),
    [anon_sym_or_continue] = ACTIONS(4859),
    [anon_sym_or_break] = ACTIONS(4859),
    [anon_sym_CARET] = ACTIONS(4861),
    [sym_uninitialized] = ACTIONS(4859),
    [sym_tag] = ACTIONS(4859),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4859),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [764] = {
    [ts_builtin_sym_end] = ACTIONS(4863),
    [anon_sym_LBRACE] = ACTIONS(4863),
    [anon_sym_RBRACE] = ACTIONS(4863),
    [anon_sym_COMMA] = ACTIONS(4863),
    [anon_sym_COLON_COLON] = ACTIONS(4863),
    [anon_sym_DASH_GT] = ACTIONS(4863),
    [anon_sym_where] = ACTIONS(4863),
    [anon_sym_EQ] = ACTIONS(4865),
    [anon_sym_COLON] = ACTIONS(4865),
    [anon_sym_PIPE] = ACTIONS(4865),
    [anon_sym_COLON_EQ] = ACTIONS(4863),
    [anon_sym_LPAREN] = ACTIONS(4863),
    [anon_sym_PLUS_EQ] = ACTIONS(4863),
    [anon_sym_DASH_EQ] = ACTIONS(4863),
    [anon_sym_STAR_EQ] = ACTIONS(4863),
    [anon_sym_SLASH_EQ] = ACTIONS(4863),
    [anon_sym_PERCENT_EQ] = ACTIONS(4863),
    [anon_sym_AMP_EQ] = ACTIONS(4863),
    [anon_sym_PIPE_EQ] = ACTIONS(4863),
    [anon_sym_CARET_EQ] = ACTIONS(4863),
    [anon_sym_LT_LT_EQ] = ACTIONS(4863),
    [anon_sym_GT_GT_EQ] = ACTIONS(4863),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4863),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4863),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4863),
    [anon_sym_if] = ACTIONS(4863),
    [anon_sym_SEMI] = ACTIONS(4863),
    [anon_sym_else] = ACTIONS(4863),
    [anon_sym_when] = ACTIONS(4863),
    [anon_sym_in] = ACTIONS(4863),
    [anon_sym_case] = ACTIONS(4863),
    [anon_sym_QMARK] = ACTIONS(4863),
    [anon_sym_PLUS] = ACTIONS(4865),
    [anon_sym_DASH] = ACTIONS(4865),
    [anon_sym_TILDE] = ACTIONS(4865),
    [anon_sym_AMP] = ACTIONS(4865),
    [anon_sym_PIPE_PIPE] = ACTIONS(4865),
    [anon_sym_or_else] = ACTIONS(4863),
    [anon_sym_AMP_AMP] = ACTIONS(4865),
    [anon_sym_GT] = ACTIONS(4865),
    [anon_sym_GT_EQ] = ACTIONS(4863),
    [anon_sym_LT_EQ] = ACTIONS(4863),
    [anon_sym_LT] = ACTIONS(4865),
    [anon_sym_EQ_EQ] = ACTIONS(4863),
    [anon_sym_BANG_EQ] = ACTIONS(4863),
    [anon_sym_TILDE_EQ] = ACTIONS(4863),
    [anon_sym_AMP_TILDE] = ACTIONS(4865),
    [anon_sym_LT_LT] = ACTIONS(4865),
    [anon_sym_GT_GT] = ACTIONS(4865),
    [anon_sym_STAR] = ACTIONS(4865),
    [anon_sym_SLASH] = ACTIONS(4865),
    [anon_sym_PERCENT] = ACTIONS(4865),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4863),
    [anon_sym_DOT] = ACTIONS(4865),
    [anon_sym_LBRACK] = ACTIONS(4863),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4863),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4863),
    [anon_sym_not_in] = ACTIONS(4863),
    [anon_sym_or_return] = ACTIONS(4863),
    [anon_sym_or_continue] = ACTIONS(4863),
    [anon_sym_or_break] = ACTIONS(4863),
    [anon_sym_CARET] = ACTIONS(4865),
    [sym_uninitialized] = ACTIONS(4863),
    [sym_tag] = ACTIONS(4863),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4863),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [765] = {
    [ts_builtin_sym_end] = ACTIONS(4867),
    [anon_sym_LBRACE] = ACTIONS(4867),
    [anon_sym_RBRACE] = ACTIONS(4867),
    [anon_sym_COMMA] = ACTIONS(4867),
    [anon_sym_COLON_COLON] = ACTIONS(4867),
    [anon_sym_DASH_GT] = ACTIONS(4867),
    [anon_sym_where] = ACTIONS(4867),
    [anon_sym_EQ] = ACTIONS(4869),
    [anon_sym_COLON] = ACTIONS(4869),
    [anon_sym_PIPE] = ACTIONS(4869),
    [anon_sym_COLON_EQ] = ACTIONS(4867),
    [anon_sym_LPAREN] = ACTIONS(4867),
    [anon_sym_PLUS_EQ] = ACTIONS(4867),
    [anon_sym_DASH_EQ] = ACTIONS(4867),
    [anon_sym_STAR_EQ] = ACTIONS(4867),
    [anon_sym_SLASH_EQ] = ACTIONS(4867),
    [anon_sym_PERCENT_EQ] = ACTIONS(4867),
    [anon_sym_AMP_EQ] = ACTIONS(4867),
    [anon_sym_PIPE_EQ] = ACTIONS(4867),
    [anon_sym_CARET_EQ] = ACTIONS(4867),
    [anon_sym_LT_LT_EQ] = ACTIONS(4867),
    [anon_sym_GT_GT_EQ] = ACTIONS(4867),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4867),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4867),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4867),
    [anon_sym_if] = ACTIONS(4867),
    [anon_sym_SEMI] = ACTIONS(4867),
    [anon_sym_else] = ACTIONS(4867),
    [anon_sym_when] = ACTIONS(4867),
    [anon_sym_in] = ACTIONS(4867),
    [anon_sym_case] = ACTIONS(4867),
    [anon_sym_QMARK] = ACTIONS(4867),
    [anon_sym_PLUS] = ACTIONS(4869),
    [anon_sym_DASH] = ACTIONS(4869),
    [anon_sym_TILDE] = ACTIONS(4869),
    [anon_sym_AMP] = ACTIONS(4869),
    [anon_sym_PIPE_PIPE] = ACTIONS(4869),
    [anon_sym_or_else] = ACTIONS(4867),
    [anon_sym_AMP_AMP] = ACTIONS(4869),
    [anon_sym_GT] = ACTIONS(4869),
    [anon_sym_GT_EQ] = ACTIONS(4867),
    [anon_sym_LT_EQ] = ACTIONS(4867),
    [anon_sym_LT] = ACTIONS(4869),
    [anon_sym_EQ_EQ] = ACTIONS(4867),
    [anon_sym_BANG_EQ] = ACTIONS(4867),
    [anon_sym_TILDE_EQ] = ACTIONS(4867),
    [anon_sym_AMP_TILDE] = ACTIONS(4869),
    [anon_sym_LT_LT] = ACTIONS(4869),
    [anon_sym_GT_GT] = ACTIONS(4869),
    [anon_sym_STAR] = ACTIONS(4869),
    [anon_sym_SLASH] = ACTIONS(4869),
    [anon_sym_PERCENT] = ACTIONS(4869),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4867),
    [anon_sym_DOT] = ACTIONS(4869),
    [anon_sym_LBRACK] = ACTIONS(4867),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4867),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4867),
    [anon_sym_not_in] = ACTIONS(4867),
    [anon_sym_or_return] = ACTIONS(4867),
    [anon_sym_or_continue] = ACTIONS(4867),
    [anon_sym_or_break] = ACTIONS(4867),
    [anon_sym_CARET] = ACTIONS(4869),
    [sym_uninitialized] = ACTIONS(4867),
    [sym_tag] = ACTIONS(4867),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4867),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [766] = {
    [ts_builtin_sym_end] = ACTIONS(4871),
    [anon_sym_LBRACE] = ACTIONS(4871),
    [anon_sym_RBRACE] = ACTIONS(4871),
    [anon_sym_COMMA] = ACTIONS(4871),
    [anon_sym_COLON_COLON] = ACTIONS(4871),
    [anon_sym_DASH_GT] = ACTIONS(4871),
    [anon_sym_where] = ACTIONS(4871),
    [anon_sym_EQ] = ACTIONS(4873),
    [anon_sym_COLON] = ACTIONS(4873),
    [anon_sym_PIPE] = ACTIONS(4873),
    [anon_sym_COLON_EQ] = ACTIONS(4871),
    [anon_sym_LPAREN] = ACTIONS(4871),
    [anon_sym_PLUS_EQ] = ACTIONS(4871),
    [anon_sym_DASH_EQ] = ACTIONS(4871),
    [anon_sym_STAR_EQ] = ACTIONS(4871),
    [anon_sym_SLASH_EQ] = ACTIONS(4871),
    [anon_sym_PERCENT_EQ] = ACTIONS(4871),
    [anon_sym_AMP_EQ] = ACTIONS(4871),
    [anon_sym_PIPE_EQ] = ACTIONS(4871),
    [anon_sym_CARET_EQ] = ACTIONS(4871),
    [anon_sym_LT_LT_EQ] = ACTIONS(4871),
    [anon_sym_GT_GT_EQ] = ACTIONS(4871),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4871),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4871),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4871),
    [anon_sym_if] = ACTIONS(4871),
    [anon_sym_SEMI] = ACTIONS(4871),
    [anon_sym_else] = ACTIONS(4871),
    [anon_sym_when] = ACTIONS(4871),
    [anon_sym_in] = ACTIONS(4871),
    [anon_sym_case] = ACTIONS(4871),
    [anon_sym_QMARK] = ACTIONS(4871),
    [anon_sym_PLUS] = ACTIONS(4873),
    [anon_sym_DASH] = ACTIONS(4873),
    [anon_sym_TILDE] = ACTIONS(4873),
    [anon_sym_AMP] = ACTIONS(4873),
    [anon_sym_PIPE_PIPE] = ACTIONS(4873),
    [anon_sym_or_else] = ACTIONS(4871),
    [anon_sym_AMP_AMP] = ACTIONS(4873),
    [anon_sym_GT] = ACTIONS(4873),
    [anon_sym_GT_EQ] = ACTIONS(4871),
    [anon_sym_LT_EQ] = ACTIONS(4871),
    [anon_sym_LT] = ACTIONS(4873),
    [anon_sym_EQ_EQ] = ACTIONS(4871),
    [anon_sym_BANG_EQ] = ACTIONS(4871),
    [anon_sym_TILDE_EQ] = ACTIONS(4871),
    [anon_sym_AMP_TILDE] = ACTIONS(4873),
    [anon_sym_LT_LT] = ACTIONS(4873),
    [anon_sym_GT_GT] = ACTIONS(4873),
    [anon_sym_STAR] = ACTIONS(4873),
    [anon_sym_SLASH] = ACTIONS(4873),
    [anon_sym_PERCENT] = ACTIONS(4873),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4871),
    [anon_sym_DOT] = ACTIONS(4873),
    [anon_sym_LBRACK] = ACTIONS(4871),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4871),
    [anon_sym_not_in] = ACTIONS(4871),
    [anon_sym_or_return] = ACTIONS(4871),
    [anon_sym_or_continue] = ACTIONS(4871),
    [anon_sym_or_break] = ACTIONS(4871),
    [anon_sym_CARET] = ACTIONS(4873),
    [sym_uninitialized] = ACTIONS(4871),
    [sym_tag] = ACTIONS(4871),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4871),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [767] = {
    [ts_builtin_sym_end] = ACTIONS(4875),
    [anon_sym_LBRACE] = ACTIONS(4875),
    [anon_sym_RBRACE] = ACTIONS(4875),
    [anon_sym_COMMA] = ACTIONS(4875),
    [anon_sym_COLON_COLON] = ACTIONS(4875),
    [anon_sym_DASH_GT] = ACTIONS(4875),
    [anon_sym_where] = ACTIONS(4875),
    [anon_sym_EQ] = ACTIONS(4877),
    [anon_sym_COLON] = ACTIONS(4877),
    [anon_sym_PIPE] = ACTIONS(4877),
    [anon_sym_COLON_EQ] = ACTIONS(4875),
    [anon_sym_LPAREN] = ACTIONS(4875),
    [anon_sym_PLUS_EQ] = ACTIONS(4875),
    [anon_sym_DASH_EQ] = ACTIONS(4875),
    [anon_sym_STAR_EQ] = ACTIONS(4875),
    [anon_sym_SLASH_EQ] = ACTIONS(4875),
    [anon_sym_PERCENT_EQ] = ACTIONS(4875),
    [anon_sym_AMP_EQ] = ACTIONS(4875),
    [anon_sym_PIPE_EQ] = ACTIONS(4875),
    [anon_sym_CARET_EQ] = ACTIONS(4875),
    [anon_sym_LT_LT_EQ] = ACTIONS(4875),
    [anon_sym_GT_GT_EQ] = ACTIONS(4875),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4875),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4875),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4875),
    [anon_sym_if] = ACTIONS(4875),
    [anon_sym_SEMI] = ACTIONS(4875),
    [anon_sym_else] = ACTIONS(4875),
    [anon_sym_when] = ACTIONS(4875),
    [anon_sym_in] = ACTIONS(4875),
    [anon_sym_case] = ACTIONS(4875),
    [anon_sym_QMARK] = ACTIONS(4875),
    [anon_sym_PLUS] = ACTIONS(4877),
    [anon_sym_DASH] = ACTIONS(4877),
    [anon_sym_TILDE] = ACTIONS(4877),
    [anon_sym_AMP] = ACTIONS(4877),
    [anon_sym_PIPE_PIPE] = ACTIONS(4877),
    [anon_sym_or_else] = ACTIONS(4875),
    [anon_sym_AMP_AMP] = ACTIONS(4877),
    [anon_sym_GT] = ACTIONS(4877),
    [anon_sym_GT_EQ] = ACTIONS(4875),
    [anon_sym_LT_EQ] = ACTIONS(4875),
    [anon_sym_LT] = ACTIONS(4877),
    [anon_sym_EQ_EQ] = ACTIONS(4875),
    [anon_sym_BANG_EQ] = ACTIONS(4875),
    [anon_sym_TILDE_EQ] = ACTIONS(4875),
    [anon_sym_AMP_TILDE] = ACTIONS(4877),
    [anon_sym_LT_LT] = ACTIONS(4877),
    [anon_sym_GT_GT] = ACTIONS(4877),
    [anon_sym_STAR] = ACTIONS(4877),
    [anon_sym_SLASH] = ACTIONS(4877),
    [anon_sym_PERCENT] = ACTIONS(4877),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4875),
    [anon_sym_DOT] = ACTIONS(4877),
    [anon_sym_LBRACK] = ACTIONS(4875),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4875),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4875),
    [anon_sym_not_in] = ACTIONS(4875),
    [anon_sym_or_return] = ACTIONS(4875),
    [anon_sym_or_continue] = ACTIONS(4875),
    [anon_sym_or_break] = ACTIONS(4875),
    [anon_sym_CARET] = ACTIONS(4877),
    [sym_uninitialized] = ACTIONS(4875),
    [sym_tag] = ACTIONS(4875),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4875),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [768] = {
    [ts_builtin_sym_end] = ACTIONS(4879),
    [anon_sym_LBRACE] = ACTIONS(4879),
    [anon_sym_RBRACE] = ACTIONS(4879),
    [anon_sym_COMMA] = ACTIONS(4879),
    [anon_sym_COLON_COLON] = ACTIONS(4879),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4879),
    [anon_sym_EQ] = ACTIONS(4881),
    [anon_sym_COLON] = ACTIONS(4881),
    [anon_sym_PIPE] = ACTIONS(4485),
    [anon_sym_COLON_EQ] = ACTIONS(4879),
    [anon_sym_LPAREN] = ACTIONS(4879),
    [anon_sym_PLUS_EQ] = ACTIONS(4879),
    [anon_sym_DASH_EQ] = ACTIONS(4879),
    [anon_sym_STAR_EQ] = ACTIONS(4879),
    [anon_sym_SLASH_EQ] = ACTIONS(4879),
    [anon_sym_PERCENT_EQ] = ACTIONS(4879),
    [anon_sym_AMP_EQ] = ACTIONS(4879),
    [anon_sym_PIPE_EQ] = ACTIONS(4879),
    [anon_sym_CARET_EQ] = ACTIONS(4879),
    [anon_sym_LT_LT_EQ] = ACTIONS(4879),
    [anon_sym_GT_GT_EQ] = ACTIONS(4879),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4879),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4879),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4879),
    [anon_sym_if] = ACTIONS(4879),
    [anon_sym_SEMI] = ACTIONS(4879),
    [anon_sym_else] = ACTIONS(4879),
    [anon_sym_when] = ACTIONS(4879),
    [anon_sym_in] = ACTIONS(4879),
    [anon_sym_case] = ACTIONS(4879),
    [anon_sym_QMARK] = ACTIONS(4879),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4493),
    [anon_sym_or_else] = ACTIONS(4495),
    [anon_sym_AMP_AMP] = ACTIONS(4497),
    [anon_sym_GT] = ACTIONS(4499),
    [anon_sym_GT_EQ] = ACTIONS(4501),
    [anon_sym_LT_EQ] = ACTIONS(4501),
    [anon_sym_LT] = ACTIONS(4499),
    [anon_sym_EQ_EQ] = ACTIONS(4503),
    [anon_sym_BANG_EQ] = ACTIONS(4503),
    [anon_sym_TILDE_EQ] = ACTIONS(4503),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4879),
    [anon_sym_or_return] = ACTIONS(4519),
    [anon_sym_or_continue] = ACTIONS(4521),
    [anon_sym_or_break] = ACTIONS(4523),
    [anon_sym_CARET] = ACTIONS(4525),
    [sym_uninitialized] = ACTIONS(4879),
    [sym_tag] = ACTIONS(4879),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4879),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [769] = {
    [ts_builtin_sym_end] = ACTIONS(4879),
    [anon_sym_LBRACE] = ACTIONS(4879),
    [anon_sym_RBRACE] = ACTIONS(4879),
    [anon_sym_COMMA] = ACTIONS(4879),
    [anon_sym_COLON_COLON] = ACTIONS(4879),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4879),
    [anon_sym_EQ] = ACTIONS(4881),
    [anon_sym_COLON] = ACTIONS(4881),
    [anon_sym_PIPE] = ACTIONS(4485),
    [anon_sym_COLON_EQ] = ACTIONS(4879),
    [anon_sym_LPAREN] = ACTIONS(4879),
    [anon_sym_PLUS_EQ] = ACTIONS(4879),
    [anon_sym_DASH_EQ] = ACTIONS(4879),
    [anon_sym_STAR_EQ] = ACTIONS(4879),
    [anon_sym_SLASH_EQ] = ACTIONS(4879),
    [anon_sym_PERCENT_EQ] = ACTIONS(4879),
    [anon_sym_AMP_EQ] = ACTIONS(4879),
    [anon_sym_PIPE_EQ] = ACTIONS(4879),
    [anon_sym_CARET_EQ] = ACTIONS(4879),
    [anon_sym_LT_LT_EQ] = ACTIONS(4879),
    [anon_sym_GT_GT_EQ] = ACTIONS(4879),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4879),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4879),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4879),
    [anon_sym_if] = ACTIONS(4879),
    [anon_sym_SEMI] = ACTIONS(4879),
    [anon_sym_else] = ACTIONS(4879),
    [anon_sym_when] = ACTIONS(4879),
    [anon_sym_in] = ACTIONS(4879),
    [anon_sym_case] = ACTIONS(4879),
    [anon_sym_QMARK] = ACTIONS(4879),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4493),
    [anon_sym_or_else] = ACTIONS(4495),
    [anon_sym_AMP_AMP] = ACTIONS(4497),
    [anon_sym_GT] = ACTIONS(4499),
    [anon_sym_GT_EQ] = ACTIONS(4501),
    [anon_sym_LT_EQ] = ACTIONS(4501),
    [anon_sym_LT] = ACTIONS(4499),
    [anon_sym_EQ_EQ] = ACTIONS(4503),
    [anon_sym_BANG_EQ] = ACTIONS(4503),
    [anon_sym_TILDE_EQ] = ACTIONS(4503),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4879),
    [anon_sym_or_return] = ACTIONS(4879),
    [anon_sym_or_continue] = ACTIONS(4879),
    [anon_sym_or_break] = ACTIONS(4879),
    [anon_sym_CARET] = ACTIONS(4881),
    [sym_uninitialized] = ACTIONS(4879),
    [sym_tag] = ACTIONS(4879),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4879),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [770] = {
    [ts_builtin_sym_end] = ACTIONS(4883),
    [anon_sym_LBRACE] = ACTIONS(4883),
    [anon_sym_RBRACE] = ACTIONS(4883),
    [anon_sym_COMMA] = ACTIONS(4883),
    [anon_sym_COLON_COLON] = ACTIONS(4883),
    [anon_sym_DASH_GT] = ACTIONS(4883),
    [anon_sym_where] = ACTIONS(4883),
    [anon_sym_EQ] = ACTIONS(4885),
    [anon_sym_COLON] = ACTIONS(4885),
    [anon_sym_PIPE] = ACTIONS(4885),
    [anon_sym_COLON_EQ] = ACTIONS(4883),
    [anon_sym_LPAREN] = ACTIONS(4883),
    [anon_sym_PLUS_EQ] = ACTIONS(4883),
    [anon_sym_DASH_EQ] = ACTIONS(4883),
    [anon_sym_STAR_EQ] = ACTIONS(4883),
    [anon_sym_SLASH_EQ] = ACTIONS(4883),
    [anon_sym_PERCENT_EQ] = ACTIONS(4883),
    [anon_sym_AMP_EQ] = ACTIONS(4883),
    [anon_sym_PIPE_EQ] = ACTIONS(4883),
    [anon_sym_CARET_EQ] = ACTIONS(4883),
    [anon_sym_LT_LT_EQ] = ACTIONS(4883),
    [anon_sym_GT_GT_EQ] = ACTIONS(4883),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4883),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4883),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4883),
    [anon_sym_if] = ACTIONS(4883),
    [anon_sym_SEMI] = ACTIONS(4883),
    [anon_sym_else] = ACTIONS(4883),
    [anon_sym_when] = ACTIONS(4883),
    [anon_sym_in] = ACTIONS(4883),
    [anon_sym_case] = ACTIONS(4883),
    [anon_sym_QMARK] = ACTIONS(4883),
    [anon_sym_PLUS] = ACTIONS(4885),
    [anon_sym_DASH] = ACTIONS(4885),
    [anon_sym_TILDE] = ACTIONS(4885),
    [anon_sym_AMP] = ACTIONS(4885),
    [anon_sym_PIPE_PIPE] = ACTIONS(4885),
    [anon_sym_or_else] = ACTIONS(4883),
    [anon_sym_AMP_AMP] = ACTIONS(4885),
    [anon_sym_GT] = ACTIONS(4885),
    [anon_sym_GT_EQ] = ACTIONS(4883),
    [anon_sym_LT_EQ] = ACTIONS(4883),
    [anon_sym_LT] = ACTIONS(4885),
    [anon_sym_EQ_EQ] = ACTIONS(4883),
    [anon_sym_BANG_EQ] = ACTIONS(4883),
    [anon_sym_TILDE_EQ] = ACTIONS(4883),
    [anon_sym_AMP_TILDE] = ACTIONS(4885),
    [anon_sym_LT_LT] = ACTIONS(4885),
    [anon_sym_GT_GT] = ACTIONS(4885),
    [anon_sym_STAR] = ACTIONS(4885),
    [anon_sym_SLASH] = ACTIONS(4885),
    [anon_sym_PERCENT] = ACTIONS(4885),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4883),
    [anon_sym_DOT] = ACTIONS(4885),
    [anon_sym_LBRACK] = ACTIONS(4883),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4883),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4883),
    [anon_sym_not_in] = ACTIONS(4883),
    [anon_sym_or_return] = ACTIONS(4883),
    [anon_sym_or_continue] = ACTIONS(4883),
    [anon_sym_or_break] = ACTIONS(4883),
    [anon_sym_CARET] = ACTIONS(4885),
    [sym_uninitialized] = ACTIONS(4883),
    [sym_tag] = ACTIONS(4883),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4883),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [771] = {
    [ts_builtin_sym_end] = ACTIONS(4887),
    [anon_sym_LBRACE] = ACTIONS(4887),
    [anon_sym_RBRACE] = ACTIONS(4887),
    [anon_sym_COMMA] = ACTIONS(4887),
    [anon_sym_COLON_COLON] = ACTIONS(4887),
    [anon_sym_DASH_GT] = ACTIONS(4887),
    [anon_sym_where] = ACTIONS(4887),
    [anon_sym_EQ] = ACTIONS(4889),
    [anon_sym_COLON] = ACTIONS(4889),
    [anon_sym_PIPE] = ACTIONS(4889),
    [anon_sym_COLON_EQ] = ACTIONS(4887),
    [anon_sym_LPAREN] = ACTIONS(4887),
    [anon_sym_PLUS_EQ] = ACTIONS(4887),
    [anon_sym_DASH_EQ] = ACTIONS(4887),
    [anon_sym_STAR_EQ] = ACTIONS(4887),
    [anon_sym_SLASH_EQ] = ACTIONS(4887),
    [anon_sym_PERCENT_EQ] = ACTIONS(4887),
    [anon_sym_AMP_EQ] = ACTIONS(4887),
    [anon_sym_PIPE_EQ] = ACTIONS(4887),
    [anon_sym_CARET_EQ] = ACTIONS(4887),
    [anon_sym_LT_LT_EQ] = ACTIONS(4887),
    [anon_sym_GT_GT_EQ] = ACTIONS(4887),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4887),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4887),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4887),
    [anon_sym_if] = ACTIONS(4887),
    [anon_sym_SEMI] = ACTIONS(4887),
    [anon_sym_else] = ACTIONS(4887),
    [anon_sym_when] = ACTIONS(4887),
    [anon_sym_in] = ACTIONS(4887),
    [anon_sym_case] = ACTIONS(4887),
    [anon_sym_QMARK] = ACTIONS(4887),
    [anon_sym_PLUS] = ACTIONS(4889),
    [anon_sym_DASH] = ACTIONS(4889),
    [anon_sym_TILDE] = ACTIONS(4889),
    [anon_sym_AMP] = ACTIONS(4889),
    [anon_sym_PIPE_PIPE] = ACTIONS(4889),
    [anon_sym_or_else] = ACTIONS(4887),
    [anon_sym_AMP_AMP] = ACTIONS(4889),
    [anon_sym_GT] = ACTIONS(4889),
    [anon_sym_GT_EQ] = ACTIONS(4887),
    [anon_sym_LT_EQ] = ACTIONS(4887),
    [anon_sym_LT] = ACTIONS(4889),
    [anon_sym_EQ_EQ] = ACTIONS(4887),
    [anon_sym_BANG_EQ] = ACTIONS(4887),
    [anon_sym_TILDE_EQ] = ACTIONS(4887),
    [anon_sym_AMP_TILDE] = ACTIONS(4889),
    [anon_sym_LT_LT] = ACTIONS(4889),
    [anon_sym_GT_GT] = ACTIONS(4889),
    [anon_sym_STAR] = ACTIONS(4889),
    [anon_sym_SLASH] = ACTIONS(4889),
    [anon_sym_PERCENT] = ACTIONS(4889),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4887),
    [anon_sym_DOT] = ACTIONS(4889),
    [anon_sym_LBRACK] = ACTIONS(4887),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4887),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4887),
    [anon_sym_not_in] = ACTIONS(4887),
    [anon_sym_or_return] = ACTIONS(4887),
    [anon_sym_or_continue] = ACTIONS(4887),
    [anon_sym_or_break] = ACTIONS(4887),
    [anon_sym_CARET] = ACTIONS(4889),
    [sym_uninitialized] = ACTIONS(4887),
    [sym_tag] = ACTIONS(4887),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4887),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [772] = {
    [ts_builtin_sym_end] = ACTIONS(4693),
    [anon_sym_LBRACE] = ACTIONS(4693),
    [anon_sym_RBRACE] = ACTIONS(4693),
    [anon_sym_COMMA] = ACTIONS(4693),
    [anon_sym_COLON_COLON] = ACTIONS(4693),
    [anon_sym_DASH_GT] = ACTIONS(4693),
    [anon_sym_where] = ACTIONS(4693),
    [anon_sym_EQ] = ACTIONS(4695),
    [anon_sym_COLON] = ACTIONS(4695),
    [anon_sym_PIPE] = ACTIONS(4695),
    [anon_sym_COLON_EQ] = ACTIONS(4693),
    [anon_sym_LPAREN] = ACTIONS(4693),
    [anon_sym_PLUS_EQ] = ACTIONS(4693),
    [anon_sym_DASH_EQ] = ACTIONS(4693),
    [anon_sym_STAR_EQ] = ACTIONS(4693),
    [anon_sym_SLASH_EQ] = ACTIONS(4693),
    [anon_sym_PERCENT_EQ] = ACTIONS(4693),
    [anon_sym_AMP_EQ] = ACTIONS(4693),
    [anon_sym_PIPE_EQ] = ACTIONS(4693),
    [anon_sym_CARET_EQ] = ACTIONS(4693),
    [anon_sym_LT_LT_EQ] = ACTIONS(4693),
    [anon_sym_GT_GT_EQ] = ACTIONS(4693),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4693),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4693),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4693),
    [anon_sym_if] = ACTIONS(4693),
    [anon_sym_SEMI] = ACTIONS(4693),
    [anon_sym_else] = ACTIONS(4693),
    [anon_sym_when] = ACTIONS(4693),
    [anon_sym_in] = ACTIONS(4693),
    [anon_sym_case] = ACTIONS(4693),
    [anon_sym_QMARK] = ACTIONS(4693),
    [anon_sym_PLUS] = ACTIONS(4695),
    [anon_sym_DASH] = ACTIONS(4695),
    [anon_sym_TILDE] = ACTIONS(4695),
    [anon_sym_AMP] = ACTIONS(4695),
    [anon_sym_PIPE_PIPE] = ACTIONS(4695),
    [anon_sym_or_else] = ACTIONS(4693),
    [anon_sym_AMP_AMP] = ACTIONS(4695),
    [anon_sym_GT] = ACTIONS(4695),
    [anon_sym_GT_EQ] = ACTIONS(4693),
    [anon_sym_LT_EQ] = ACTIONS(4693),
    [anon_sym_LT] = ACTIONS(4695),
    [anon_sym_EQ_EQ] = ACTIONS(4693),
    [anon_sym_BANG_EQ] = ACTIONS(4693),
    [anon_sym_TILDE_EQ] = ACTIONS(4693),
    [anon_sym_AMP_TILDE] = ACTIONS(4695),
    [anon_sym_LT_LT] = ACTIONS(4695),
    [anon_sym_GT_GT] = ACTIONS(4695),
    [anon_sym_STAR] = ACTIONS(4695),
    [anon_sym_SLASH] = ACTIONS(4695),
    [anon_sym_PERCENT] = ACTIONS(4695),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4693),
    [anon_sym_DOT] = ACTIONS(4695),
    [anon_sym_LBRACK] = ACTIONS(4693),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4693),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4693),
    [anon_sym_not_in] = ACTIONS(4693),
    [anon_sym_or_return] = ACTIONS(4693),
    [anon_sym_or_continue] = ACTIONS(4693),
    [anon_sym_or_break] = ACTIONS(4693),
    [anon_sym_CARET] = ACTIONS(4695),
    [sym_uninitialized] = ACTIONS(4693),
    [sym_tag] = ACTIONS(4693),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4693),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [773] = {
    [ts_builtin_sym_end] = ACTIONS(4891),
    [anon_sym_LBRACE] = ACTIONS(4891),
    [anon_sym_RBRACE] = ACTIONS(4891),
    [anon_sym_COMMA] = ACTIONS(4891),
    [anon_sym_COLON_COLON] = ACTIONS(4891),
    [anon_sym_DASH_GT] = ACTIONS(4891),
    [anon_sym_where] = ACTIONS(4891),
    [anon_sym_EQ] = ACTIONS(4893),
    [anon_sym_COLON] = ACTIONS(4893),
    [anon_sym_PIPE] = ACTIONS(4893),
    [anon_sym_COLON_EQ] = ACTIONS(4891),
    [anon_sym_LPAREN] = ACTIONS(4891),
    [anon_sym_PLUS_EQ] = ACTIONS(4891),
    [anon_sym_DASH_EQ] = ACTIONS(4891),
    [anon_sym_STAR_EQ] = ACTIONS(4891),
    [anon_sym_SLASH_EQ] = ACTIONS(4891),
    [anon_sym_PERCENT_EQ] = ACTIONS(4891),
    [anon_sym_AMP_EQ] = ACTIONS(4891),
    [anon_sym_PIPE_EQ] = ACTIONS(4891),
    [anon_sym_CARET_EQ] = ACTIONS(4891),
    [anon_sym_LT_LT_EQ] = ACTIONS(4891),
    [anon_sym_GT_GT_EQ] = ACTIONS(4891),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4891),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4891),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4891),
    [anon_sym_if] = ACTIONS(4891),
    [anon_sym_SEMI] = ACTIONS(4891),
    [anon_sym_else] = ACTIONS(4891),
    [anon_sym_when] = ACTIONS(4891),
    [anon_sym_in] = ACTIONS(4891),
    [anon_sym_case] = ACTIONS(4891),
    [anon_sym_QMARK] = ACTIONS(4891),
    [anon_sym_PLUS] = ACTIONS(4893),
    [anon_sym_DASH] = ACTIONS(4893),
    [anon_sym_TILDE] = ACTIONS(4893),
    [anon_sym_AMP] = ACTIONS(4893),
    [anon_sym_PIPE_PIPE] = ACTIONS(4893),
    [anon_sym_or_else] = ACTIONS(4891),
    [anon_sym_AMP_AMP] = ACTIONS(4893),
    [anon_sym_GT] = ACTIONS(4893),
    [anon_sym_GT_EQ] = ACTIONS(4891),
    [anon_sym_LT_EQ] = ACTIONS(4891),
    [anon_sym_LT] = ACTIONS(4893),
    [anon_sym_EQ_EQ] = ACTIONS(4891),
    [anon_sym_BANG_EQ] = ACTIONS(4891),
    [anon_sym_TILDE_EQ] = ACTIONS(4891),
    [anon_sym_AMP_TILDE] = ACTIONS(4893),
    [anon_sym_LT_LT] = ACTIONS(4893),
    [anon_sym_GT_GT] = ACTIONS(4893),
    [anon_sym_STAR] = ACTIONS(4893),
    [anon_sym_SLASH] = ACTIONS(4893),
    [anon_sym_PERCENT] = ACTIONS(4893),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4891),
    [anon_sym_DOT] = ACTIONS(4893),
    [anon_sym_LBRACK] = ACTIONS(4891),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4891),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4891),
    [anon_sym_not_in] = ACTIONS(4891),
    [anon_sym_or_return] = ACTIONS(4891),
    [anon_sym_or_continue] = ACTIONS(4891),
    [anon_sym_or_break] = ACTIONS(4891),
    [anon_sym_CARET] = ACTIONS(4893),
    [sym_uninitialized] = ACTIONS(4891),
    [sym_tag] = ACTIONS(4891),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4891),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [774] = {
    [sym_block] = STATE(1594),
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(3521),
    [sym_tag] = ACTIONS(3523),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [775] = {
    [sym_block] = STATE(1600),
    [ts_builtin_sym_end] = ACTIONS(4577),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(4577),
    [anon_sym_COMMA] = ACTIONS(4577),
    [anon_sym_COLON_COLON] = ACTIONS(4577),
    [anon_sym_DASH_GT] = ACTIONS(4577),
    [anon_sym_EQ] = ACTIONS(4579),
    [anon_sym_COLON] = ACTIONS(4579),
    [anon_sym_PIPE] = ACTIONS(4579),
    [anon_sym_COLON_EQ] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4577),
    [anon_sym_PLUS_EQ] = ACTIONS(4577),
    [anon_sym_DASH_EQ] = ACTIONS(4577),
    [anon_sym_STAR_EQ] = ACTIONS(4577),
    [anon_sym_SLASH_EQ] = ACTIONS(4577),
    [anon_sym_PERCENT_EQ] = ACTIONS(4577),
    [anon_sym_AMP_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_CARET_EQ] = ACTIONS(4577),
    [anon_sym_LT_LT_EQ] = ACTIONS(4577),
    [anon_sym_GT_GT_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_when] = ACTIONS(4577),
    [anon_sym_in] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [anon_sym_TILDE] = ACTIONS(4579),
    [anon_sym_AMP] = ACTIONS(4579),
    [anon_sym_PIPE_PIPE] = ACTIONS(4579),
    [anon_sym_or_else] = ACTIONS(4577),
    [anon_sym_AMP_AMP] = ACTIONS(4579),
    [anon_sym_GT] = ACTIONS(4579),
    [anon_sym_GT_EQ] = ACTIONS(4577),
    [anon_sym_LT_EQ] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4579),
    [anon_sym_EQ_EQ] = ACTIONS(4577),
    [anon_sym_BANG_EQ] = ACTIONS(4577),
    [anon_sym_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE] = ACTIONS(4579),
    [anon_sym_LT_LT] = ACTIONS(4579),
    [anon_sym_GT_GT] = ACTIONS(4579),
    [anon_sym_STAR] = ACTIONS(4579),
    [anon_sym_SLASH] = ACTIONS(4579),
    [anon_sym_PERCENT] = ACTIONS(4579),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4577),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4577),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4577),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4577),
    [anon_sym_not_in] = ACTIONS(4577),
    [anon_sym_or_return] = ACTIONS(4577),
    [anon_sym_or_continue] = ACTIONS(4577),
    [anon_sym_or_break] = ACTIONS(4577),
    [anon_sym_CARET] = ACTIONS(4579),
    [sym_uninitialized] = ACTIONS(4895),
    [sym_tag] = ACTIONS(4897),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4577),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [776] = {
    [sym_block] = STATE(2341),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3513),
    [sym_tag] = ACTIONS(4899),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [777] = {
    [ts_builtin_sym_end] = ACTIONS(4901),
    [anon_sym_LBRACE] = ACTIONS(4901),
    [anon_sym_RBRACE] = ACTIONS(4901),
    [anon_sym_COMMA] = ACTIONS(4901),
    [anon_sym_COLON_COLON] = ACTIONS(4901),
    [anon_sym_DASH_GT] = ACTIONS(4901),
    [anon_sym_where] = ACTIONS(4901),
    [anon_sym_EQ] = ACTIONS(4903),
    [anon_sym_COLON] = ACTIONS(4903),
    [anon_sym_PIPE] = ACTIONS(4903),
    [anon_sym_COLON_EQ] = ACTIONS(4901),
    [anon_sym_LPAREN] = ACTIONS(4901),
    [anon_sym_PLUS_EQ] = ACTIONS(4901),
    [anon_sym_DASH_EQ] = ACTIONS(4901),
    [anon_sym_STAR_EQ] = ACTIONS(4901),
    [anon_sym_SLASH_EQ] = ACTIONS(4901),
    [anon_sym_PERCENT_EQ] = ACTIONS(4901),
    [anon_sym_AMP_EQ] = ACTIONS(4901),
    [anon_sym_PIPE_EQ] = ACTIONS(4901),
    [anon_sym_CARET_EQ] = ACTIONS(4901),
    [anon_sym_LT_LT_EQ] = ACTIONS(4901),
    [anon_sym_GT_GT_EQ] = ACTIONS(4901),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4901),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4901),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4901),
    [anon_sym_if] = ACTIONS(4901),
    [anon_sym_SEMI] = ACTIONS(4901),
    [anon_sym_else] = ACTIONS(4901),
    [anon_sym_when] = ACTIONS(4901),
    [anon_sym_in] = ACTIONS(4901),
    [anon_sym_case] = ACTIONS(4901),
    [anon_sym_QMARK] = ACTIONS(4901),
    [anon_sym_PLUS] = ACTIONS(4903),
    [anon_sym_DASH] = ACTIONS(4903),
    [anon_sym_TILDE] = ACTIONS(4903),
    [anon_sym_AMP] = ACTIONS(4903),
    [anon_sym_PIPE_PIPE] = ACTIONS(4903),
    [anon_sym_or_else] = ACTIONS(4901),
    [anon_sym_AMP_AMP] = ACTIONS(4903),
    [anon_sym_GT] = ACTIONS(4903),
    [anon_sym_GT_EQ] = ACTIONS(4901),
    [anon_sym_LT_EQ] = ACTIONS(4901),
    [anon_sym_LT] = ACTIONS(4903),
    [anon_sym_EQ_EQ] = ACTIONS(4901),
    [anon_sym_BANG_EQ] = ACTIONS(4901),
    [anon_sym_TILDE_EQ] = ACTIONS(4901),
    [anon_sym_AMP_TILDE] = ACTIONS(4903),
    [anon_sym_LT_LT] = ACTIONS(4903),
    [anon_sym_GT_GT] = ACTIONS(4903),
    [anon_sym_STAR] = ACTIONS(4903),
    [anon_sym_SLASH] = ACTIONS(4903),
    [anon_sym_PERCENT] = ACTIONS(4903),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4901),
    [anon_sym_DOT] = ACTIONS(4903),
    [anon_sym_LBRACK] = ACTIONS(4901),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4901),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4901),
    [anon_sym_not_in] = ACTIONS(4901),
    [anon_sym_or_return] = ACTIONS(4901),
    [anon_sym_or_continue] = ACTIONS(4901),
    [anon_sym_or_break] = ACTIONS(4901),
    [anon_sym_CARET] = ACTIONS(4903),
    [sym_uninitialized] = ACTIONS(4901),
    [sym_tag] = ACTIONS(4901),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4901),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [778] = {
    [ts_builtin_sym_end] = ACTIONS(4901),
    [anon_sym_LBRACE] = ACTIONS(4901),
    [anon_sym_RBRACE] = ACTIONS(4901),
    [anon_sym_COMMA] = ACTIONS(4901),
    [anon_sym_COLON_COLON] = ACTIONS(4901),
    [anon_sym_DASH_GT] = ACTIONS(4901),
    [anon_sym_where] = ACTIONS(4901),
    [anon_sym_EQ] = ACTIONS(4903),
    [anon_sym_COLON] = ACTIONS(4903),
    [anon_sym_PIPE] = ACTIONS(4903),
    [anon_sym_COLON_EQ] = ACTIONS(4901),
    [anon_sym_LPAREN] = ACTIONS(4901),
    [anon_sym_PLUS_EQ] = ACTIONS(4901),
    [anon_sym_DASH_EQ] = ACTIONS(4901),
    [anon_sym_STAR_EQ] = ACTIONS(4901),
    [anon_sym_SLASH_EQ] = ACTIONS(4901),
    [anon_sym_PERCENT_EQ] = ACTIONS(4901),
    [anon_sym_AMP_EQ] = ACTIONS(4901),
    [anon_sym_PIPE_EQ] = ACTIONS(4901),
    [anon_sym_CARET_EQ] = ACTIONS(4901),
    [anon_sym_LT_LT_EQ] = ACTIONS(4901),
    [anon_sym_GT_GT_EQ] = ACTIONS(4901),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4901),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4901),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4901),
    [anon_sym_if] = ACTIONS(4901),
    [anon_sym_SEMI] = ACTIONS(4901),
    [anon_sym_else] = ACTIONS(4901),
    [anon_sym_when] = ACTIONS(4901),
    [anon_sym_in] = ACTIONS(4901),
    [anon_sym_case] = ACTIONS(4901),
    [anon_sym_QMARK] = ACTIONS(4901),
    [anon_sym_PLUS] = ACTIONS(4903),
    [anon_sym_DASH] = ACTIONS(4903),
    [anon_sym_TILDE] = ACTIONS(4903),
    [anon_sym_AMP] = ACTIONS(4903),
    [anon_sym_PIPE_PIPE] = ACTIONS(4903),
    [anon_sym_or_else] = ACTIONS(4901),
    [anon_sym_AMP_AMP] = ACTIONS(4903),
    [anon_sym_GT] = ACTIONS(4903),
    [anon_sym_GT_EQ] = ACTIONS(4901),
    [anon_sym_LT_EQ] = ACTIONS(4901),
    [anon_sym_LT] = ACTIONS(4903),
    [anon_sym_EQ_EQ] = ACTIONS(4901),
    [anon_sym_BANG_EQ] = ACTIONS(4901),
    [anon_sym_TILDE_EQ] = ACTIONS(4901),
    [anon_sym_AMP_TILDE] = ACTIONS(4903),
    [anon_sym_LT_LT] = ACTIONS(4903),
    [anon_sym_GT_GT] = ACTIONS(4903),
    [anon_sym_STAR] = ACTIONS(4903),
    [anon_sym_SLASH] = ACTIONS(4903),
    [anon_sym_PERCENT] = ACTIONS(4903),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4901),
    [anon_sym_DOT] = ACTIONS(4903),
    [anon_sym_LBRACK] = ACTIONS(4901),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4901),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4901),
    [anon_sym_not_in] = ACTIONS(4901),
    [anon_sym_or_return] = ACTIONS(4901),
    [anon_sym_or_continue] = ACTIONS(4901),
    [anon_sym_or_break] = ACTIONS(4901),
    [anon_sym_CARET] = ACTIONS(4903),
    [sym_uninitialized] = ACTIONS(4901),
    [sym_tag] = ACTIONS(4901),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4901),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [779] = {
    [ts_builtin_sym_end] = ACTIONS(4905),
    [anon_sym_LBRACE] = ACTIONS(4905),
    [anon_sym_RBRACE] = ACTIONS(4905),
    [anon_sym_COMMA] = ACTIONS(4905),
    [anon_sym_COLON_COLON] = ACTIONS(4905),
    [anon_sym_DASH_GT] = ACTIONS(4905),
    [anon_sym_where] = ACTIONS(4905),
    [anon_sym_EQ] = ACTIONS(4907),
    [anon_sym_COLON] = ACTIONS(4907),
    [anon_sym_PIPE] = ACTIONS(4907),
    [anon_sym_COLON_EQ] = ACTIONS(4905),
    [anon_sym_LPAREN] = ACTIONS(4905),
    [anon_sym_PLUS_EQ] = ACTIONS(4905),
    [anon_sym_DASH_EQ] = ACTIONS(4905),
    [anon_sym_STAR_EQ] = ACTIONS(4905),
    [anon_sym_SLASH_EQ] = ACTIONS(4905),
    [anon_sym_PERCENT_EQ] = ACTIONS(4905),
    [anon_sym_AMP_EQ] = ACTIONS(4905),
    [anon_sym_PIPE_EQ] = ACTIONS(4905),
    [anon_sym_CARET_EQ] = ACTIONS(4905),
    [anon_sym_LT_LT_EQ] = ACTIONS(4905),
    [anon_sym_GT_GT_EQ] = ACTIONS(4905),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4905),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4905),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4905),
    [anon_sym_if] = ACTIONS(4905),
    [anon_sym_SEMI] = ACTIONS(4905),
    [anon_sym_else] = ACTIONS(4905),
    [anon_sym_when] = ACTIONS(4905),
    [anon_sym_in] = ACTIONS(4905),
    [anon_sym_case] = ACTIONS(4905),
    [anon_sym_QMARK] = ACTIONS(4905),
    [anon_sym_PLUS] = ACTIONS(4907),
    [anon_sym_DASH] = ACTIONS(4907),
    [anon_sym_TILDE] = ACTIONS(4907),
    [anon_sym_AMP] = ACTIONS(4907),
    [anon_sym_PIPE_PIPE] = ACTIONS(4907),
    [anon_sym_or_else] = ACTIONS(4905),
    [anon_sym_AMP_AMP] = ACTIONS(4907),
    [anon_sym_GT] = ACTIONS(4907),
    [anon_sym_GT_EQ] = ACTIONS(4905),
    [anon_sym_LT_EQ] = ACTIONS(4905),
    [anon_sym_LT] = ACTIONS(4907),
    [anon_sym_EQ_EQ] = ACTIONS(4905),
    [anon_sym_BANG_EQ] = ACTIONS(4905),
    [anon_sym_TILDE_EQ] = ACTIONS(4905),
    [anon_sym_AMP_TILDE] = ACTIONS(4907),
    [anon_sym_LT_LT] = ACTIONS(4907),
    [anon_sym_GT_GT] = ACTIONS(4907),
    [anon_sym_STAR] = ACTIONS(4907),
    [anon_sym_SLASH] = ACTIONS(4907),
    [anon_sym_PERCENT] = ACTIONS(4907),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4905),
    [anon_sym_DOT] = ACTIONS(4907),
    [anon_sym_LBRACK] = ACTIONS(4905),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4905),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4905),
    [anon_sym_not_in] = ACTIONS(4905),
    [anon_sym_or_return] = ACTIONS(4905),
    [anon_sym_or_continue] = ACTIONS(4905),
    [anon_sym_or_break] = ACTIONS(4905),
    [anon_sym_CARET] = ACTIONS(4907),
    [sym_uninitialized] = ACTIONS(4905),
    [sym_tag] = ACTIONS(4905),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4905),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [780] = {
    [ts_builtin_sym_end] = ACTIONS(4909),
    [anon_sym_LBRACE] = ACTIONS(4909),
    [anon_sym_RBRACE] = ACTIONS(4909),
    [anon_sym_COMMA] = ACTIONS(4909),
    [anon_sym_COLON_COLON] = ACTIONS(4909),
    [anon_sym_DASH_GT] = ACTIONS(4909),
    [anon_sym_where] = ACTIONS(4909),
    [anon_sym_EQ] = ACTIONS(4911),
    [anon_sym_COLON] = ACTIONS(4911),
    [anon_sym_PIPE] = ACTIONS(4911),
    [anon_sym_COLON_EQ] = ACTIONS(4909),
    [anon_sym_LPAREN] = ACTIONS(4909),
    [anon_sym_PLUS_EQ] = ACTIONS(4909),
    [anon_sym_DASH_EQ] = ACTIONS(4909),
    [anon_sym_STAR_EQ] = ACTIONS(4909),
    [anon_sym_SLASH_EQ] = ACTIONS(4909),
    [anon_sym_PERCENT_EQ] = ACTIONS(4909),
    [anon_sym_AMP_EQ] = ACTIONS(4909),
    [anon_sym_PIPE_EQ] = ACTIONS(4909),
    [anon_sym_CARET_EQ] = ACTIONS(4909),
    [anon_sym_LT_LT_EQ] = ACTIONS(4909),
    [anon_sym_GT_GT_EQ] = ACTIONS(4909),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4909),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4909),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4909),
    [anon_sym_if] = ACTIONS(4909),
    [anon_sym_SEMI] = ACTIONS(4909),
    [anon_sym_else] = ACTIONS(4909),
    [anon_sym_when] = ACTIONS(4909),
    [anon_sym_in] = ACTIONS(4909),
    [anon_sym_case] = ACTIONS(4909),
    [anon_sym_QMARK] = ACTIONS(4909),
    [anon_sym_PLUS] = ACTIONS(4911),
    [anon_sym_DASH] = ACTIONS(4911),
    [anon_sym_TILDE] = ACTIONS(4911),
    [anon_sym_AMP] = ACTIONS(4911),
    [anon_sym_PIPE_PIPE] = ACTIONS(4911),
    [anon_sym_or_else] = ACTIONS(4909),
    [anon_sym_AMP_AMP] = ACTIONS(4911),
    [anon_sym_GT] = ACTIONS(4911),
    [anon_sym_GT_EQ] = ACTIONS(4909),
    [anon_sym_LT_EQ] = ACTIONS(4909),
    [anon_sym_LT] = ACTIONS(4911),
    [anon_sym_EQ_EQ] = ACTIONS(4909),
    [anon_sym_BANG_EQ] = ACTIONS(4909),
    [anon_sym_TILDE_EQ] = ACTIONS(4909),
    [anon_sym_AMP_TILDE] = ACTIONS(4911),
    [anon_sym_LT_LT] = ACTIONS(4911),
    [anon_sym_GT_GT] = ACTIONS(4911),
    [anon_sym_STAR] = ACTIONS(4911),
    [anon_sym_SLASH] = ACTIONS(4911),
    [anon_sym_PERCENT] = ACTIONS(4911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4909),
    [anon_sym_DOT] = ACTIONS(4911),
    [anon_sym_LBRACK] = ACTIONS(4909),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4909),
    [anon_sym_not_in] = ACTIONS(4909),
    [anon_sym_or_return] = ACTIONS(4909),
    [anon_sym_or_continue] = ACTIONS(4909),
    [anon_sym_or_break] = ACTIONS(4909),
    [anon_sym_CARET] = ACTIONS(4911),
    [sym_uninitialized] = ACTIONS(4909),
    [sym_tag] = ACTIONS(4909),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4909),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [781] = {
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3451),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3451),
    [anon_sym_where] = ACTIONS(3451),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(3451),
    [sym_tag] = ACTIONS(3451),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [782] = {
    [ts_builtin_sym_end] = ACTIONS(4913),
    [anon_sym_LBRACE] = ACTIONS(4913),
    [anon_sym_RBRACE] = ACTIONS(4913),
    [anon_sym_COMMA] = ACTIONS(4913),
    [anon_sym_COLON_COLON] = ACTIONS(4913),
    [anon_sym_DASH_GT] = ACTIONS(4913),
    [anon_sym_where] = ACTIONS(4913),
    [anon_sym_EQ] = ACTIONS(4915),
    [anon_sym_COLON] = ACTIONS(4915),
    [anon_sym_PIPE] = ACTIONS(4915),
    [anon_sym_COLON_EQ] = ACTIONS(4913),
    [anon_sym_LPAREN] = ACTIONS(4913),
    [anon_sym_PLUS_EQ] = ACTIONS(4913),
    [anon_sym_DASH_EQ] = ACTIONS(4913),
    [anon_sym_STAR_EQ] = ACTIONS(4913),
    [anon_sym_SLASH_EQ] = ACTIONS(4913),
    [anon_sym_PERCENT_EQ] = ACTIONS(4913),
    [anon_sym_AMP_EQ] = ACTIONS(4913),
    [anon_sym_PIPE_EQ] = ACTIONS(4913),
    [anon_sym_CARET_EQ] = ACTIONS(4913),
    [anon_sym_LT_LT_EQ] = ACTIONS(4913),
    [anon_sym_GT_GT_EQ] = ACTIONS(4913),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4913),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4913),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4913),
    [anon_sym_if] = ACTIONS(4913),
    [anon_sym_SEMI] = ACTIONS(4913),
    [anon_sym_else] = ACTIONS(4913),
    [anon_sym_when] = ACTIONS(4913),
    [anon_sym_in] = ACTIONS(4913),
    [anon_sym_case] = ACTIONS(4913),
    [anon_sym_QMARK] = ACTIONS(4913),
    [anon_sym_PLUS] = ACTIONS(4915),
    [anon_sym_DASH] = ACTIONS(4915),
    [anon_sym_TILDE] = ACTIONS(4915),
    [anon_sym_AMP] = ACTIONS(4915),
    [anon_sym_PIPE_PIPE] = ACTIONS(4915),
    [anon_sym_or_else] = ACTIONS(4913),
    [anon_sym_AMP_AMP] = ACTIONS(4915),
    [anon_sym_GT] = ACTIONS(4915),
    [anon_sym_GT_EQ] = ACTIONS(4913),
    [anon_sym_LT_EQ] = ACTIONS(4913),
    [anon_sym_LT] = ACTIONS(4915),
    [anon_sym_EQ_EQ] = ACTIONS(4913),
    [anon_sym_BANG_EQ] = ACTIONS(4913),
    [anon_sym_TILDE_EQ] = ACTIONS(4913),
    [anon_sym_AMP_TILDE] = ACTIONS(4915),
    [anon_sym_LT_LT] = ACTIONS(4915),
    [anon_sym_GT_GT] = ACTIONS(4915),
    [anon_sym_STAR] = ACTIONS(4915),
    [anon_sym_SLASH] = ACTIONS(4915),
    [anon_sym_PERCENT] = ACTIONS(4915),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4913),
    [anon_sym_DOT] = ACTIONS(4915),
    [anon_sym_LBRACK] = ACTIONS(4913),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4913),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4913),
    [anon_sym_not_in] = ACTIONS(4913),
    [anon_sym_or_return] = ACTIONS(4913),
    [anon_sym_or_continue] = ACTIONS(4913),
    [anon_sym_or_break] = ACTIONS(4913),
    [anon_sym_CARET] = ACTIONS(4915),
    [sym_uninitialized] = ACTIONS(4913),
    [sym_tag] = ACTIONS(4913),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4913),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [783] = {
    [ts_builtin_sym_end] = ACTIONS(4917),
    [anon_sym_LBRACE] = ACTIONS(4917),
    [anon_sym_RBRACE] = ACTIONS(4917),
    [anon_sym_COMMA] = ACTIONS(4917),
    [anon_sym_COLON_COLON] = ACTIONS(4917),
    [anon_sym_DASH_GT] = ACTIONS(4917),
    [anon_sym_where] = ACTIONS(4917),
    [anon_sym_EQ] = ACTIONS(4919),
    [anon_sym_COLON] = ACTIONS(4919),
    [anon_sym_PIPE] = ACTIONS(4919),
    [anon_sym_COLON_EQ] = ACTIONS(4917),
    [anon_sym_LPAREN] = ACTIONS(4917),
    [anon_sym_PLUS_EQ] = ACTIONS(4917),
    [anon_sym_DASH_EQ] = ACTIONS(4917),
    [anon_sym_STAR_EQ] = ACTIONS(4917),
    [anon_sym_SLASH_EQ] = ACTIONS(4917),
    [anon_sym_PERCENT_EQ] = ACTIONS(4917),
    [anon_sym_AMP_EQ] = ACTIONS(4917),
    [anon_sym_PIPE_EQ] = ACTIONS(4917),
    [anon_sym_CARET_EQ] = ACTIONS(4917),
    [anon_sym_LT_LT_EQ] = ACTIONS(4917),
    [anon_sym_GT_GT_EQ] = ACTIONS(4917),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4917),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4917),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4917),
    [anon_sym_if] = ACTIONS(4917),
    [anon_sym_SEMI] = ACTIONS(4917),
    [anon_sym_else] = ACTIONS(4917),
    [anon_sym_when] = ACTIONS(4917),
    [anon_sym_in] = ACTIONS(4917),
    [anon_sym_case] = ACTIONS(4917),
    [anon_sym_QMARK] = ACTIONS(4917),
    [anon_sym_PLUS] = ACTIONS(4919),
    [anon_sym_DASH] = ACTIONS(4919),
    [anon_sym_TILDE] = ACTIONS(4919),
    [anon_sym_AMP] = ACTIONS(4919),
    [anon_sym_PIPE_PIPE] = ACTIONS(4919),
    [anon_sym_or_else] = ACTIONS(4917),
    [anon_sym_AMP_AMP] = ACTIONS(4919),
    [anon_sym_GT] = ACTIONS(4919),
    [anon_sym_GT_EQ] = ACTIONS(4917),
    [anon_sym_LT_EQ] = ACTIONS(4917),
    [anon_sym_LT] = ACTIONS(4919),
    [anon_sym_EQ_EQ] = ACTIONS(4917),
    [anon_sym_BANG_EQ] = ACTIONS(4917),
    [anon_sym_TILDE_EQ] = ACTIONS(4917),
    [anon_sym_AMP_TILDE] = ACTIONS(4919),
    [anon_sym_LT_LT] = ACTIONS(4919),
    [anon_sym_GT_GT] = ACTIONS(4919),
    [anon_sym_STAR] = ACTIONS(4919),
    [anon_sym_SLASH] = ACTIONS(4919),
    [anon_sym_PERCENT] = ACTIONS(4919),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4917),
    [anon_sym_DOT] = ACTIONS(4919),
    [anon_sym_LBRACK] = ACTIONS(4917),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4917),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4917),
    [anon_sym_not_in] = ACTIONS(4917),
    [anon_sym_or_return] = ACTIONS(4917),
    [anon_sym_or_continue] = ACTIONS(4917),
    [anon_sym_or_break] = ACTIONS(4917),
    [anon_sym_CARET] = ACTIONS(4919),
    [sym_uninitialized] = ACTIONS(4917),
    [sym_tag] = ACTIONS(4917),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4917),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [784] = {
    [ts_builtin_sym_end] = ACTIONS(4921),
    [anon_sym_LBRACE] = ACTIONS(4921),
    [anon_sym_RBRACE] = ACTIONS(4921),
    [anon_sym_COMMA] = ACTIONS(4921),
    [anon_sym_COLON_COLON] = ACTIONS(4921),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4921),
    [anon_sym_EQ] = ACTIONS(4923),
    [anon_sym_COLON] = ACTIONS(4923),
    [anon_sym_PIPE] = ACTIONS(4923),
    [anon_sym_COLON_EQ] = ACTIONS(4921),
    [anon_sym_LPAREN] = ACTIONS(4921),
    [anon_sym_PLUS_EQ] = ACTIONS(4921),
    [anon_sym_DASH_EQ] = ACTIONS(4921),
    [anon_sym_STAR_EQ] = ACTIONS(4921),
    [anon_sym_SLASH_EQ] = ACTIONS(4921),
    [anon_sym_PERCENT_EQ] = ACTIONS(4921),
    [anon_sym_AMP_EQ] = ACTIONS(4921),
    [anon_sym_PIPE_EQ] = ACTIONS(4921),
    [anon_sym_CARET_EQ] = ACTIONS(4921),
    [anon_sym_LT_LT_EQ] = ACTIONS(4921),
    [anon_sym_GT_GT_EQ] = ACTIONS(4921),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4921),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4921),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4921),
    [anon_sym_if] = ACTIONS(4921),
    [anon_sym_SEMI] = ACTIONS(4921),
    [anon_sym_else] = ACTIONS(4921),
    [anon_sym_when] = ACTIONS(4921),
    [anon_sym_in] = ACTIONS(4921),
    [anon_sym_case] = ACTIONS(4921),
    [anon_sym_QMARK] = ACTIONS(4921),
    [anon_sym_PLUS] = ACTIONS(4923),
    [anon_sym_DASH] = ACTIONS(4923),
    [anon_sym_TILDE] = ACTIONS(4923),
    [anon_sym_AMP] = ACTIONS(4923),
    [anon_sym_PIPE_PIPE] = ACTIONS(4923),
    [anon_sym_or_else] = ACTIONS(4921),
    [anon_sym_AMP_AMP] = ACTIONS(4923),
    [anon_sym_GT] = ACTIONS(4923),
    [anon_sym_GT_EQ] = ACTIONS(4921),
    [anon_sym_LT_EQ] = ACTIONS(4921),
    [anon_sym_LT] = ACTIONS(4923),
    [anon_sym_EQ_EQ] = ACTIONS(4921),
    [anon_sym_BANG_EQ] = ACTIONS(4921),
    [anon_sym_TILDE_EQ] = ACTIONS(4921),
    [anon_sym_AMP_TILDE] = ACTIONS(4923),
    [anon_sym_LT_LT] = ACTIONS(4923),
    [anon_sym_GT_GT] = ACTIONS(4923),
    [anon_sym_STAR] = ACTIONS(4923),
    [anon_sym_SLASH] = ACTIONS(4923),
    [anon_sym_PERCENT] = ACTIONS(4923),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4921),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4921),
    [anon_sym_or_return] = ACTIONS(4921),
    [anon_sym_or_continue] = ACTIONS(4921),
    [anon_sym_or_break] = ACTIONS(4921),
    [anon_sym_CARET] = ACTIONS(4923),
    [sym_uninitialized] = ACTIONS(4921),
    [sym_tag] = ACTIONS(4921),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4921),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [785] = {
    [ts_builtin_sym_end] = ACTIONS(4925),
    [anon_sym_LBRACE] = ACTIONS(4925),
    [anon_sym_RBRACE] = ACTIONS(4925),
    [anon_sym_COMMA] = ACTIONS(4925),
    [anon_sym_COLON_COLON] = ACTIONS(4925),
    [anon_sym_DASH_GT] = ACTIONS(4925),
    [anon_sym_where] = ACTIONS(4925),
    [anon_sym_EQ] = ACTIONS(4927),
    [anon_sym_COLON] = ACTIONS(4927),
    [anon_sym_PIPE] = ACTIONS(4927),
    [anon_sym_COLON_EQ] = ACTIONS(4925),
    [anon_sym_LPAREN] = ACTIONS(4925),
    [anon_sym_PLUS_EQ] = ACTIONS(4925),
    [anon_sym_DASH_EQ] = ACTIONS(4925),
    [anon_sym_STAR_EQ] = ACTIONS(4925),
    [anon_sym_SLASH_EQ] = ACTIONS(4925),
    [anon_sym_PERCENT_EQ] = ACTIONS(4925),
    [anon_sym_AMP_EQ] = ACTIONS(4925),
    [anon_sym_PIPE_EQ] = ACTIONS(4925),
    [anon_sym_CARET_EQ] = ACTIONS(4925),
    [anon_sym_LT_LT_EQ] = ACTIONS(4925),
    [anon_sym_GT_GT_EQ] = ACTIONS(4925),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4925),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4925),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4925),
    [anon_sym_if] = ACTIONS(4925),
    [anon_sym_SEMI] = ACTIONS(4925),
    [anon_sym_else] = ACTIONS(4925),
    [anon_sym_when] = ACTIONS(4925),
    [anon_sym_in] = ACTIONS(4925),
    [anon_sym_case] = ACTIONS(4925),
    [anon_sym_QMARK] = ACTIONS(4925),
    [anon_sym_PLUS] = ACTIONS(4927),
    [anon_sym_DASH] = ACTIONS(4927),
    [anon_sym_TILDE] = ACTIONS(4927),
    [anon_sym_AMP] = ACTIONS(4927),
    [anon_sym_PIPE_PIPE] = ACTIONS(4927),
    [anon_sym_or_else] = ACTIONS(4925),
    [anon_sym_AMP_AMP] = ACTIONS(4927),
    [anon_sym_GT] = ACTIONS(4927),
    [anon_sym_GT_EQ] = ACTIONS(4925),
    [anon_sym_LT_EQ] = ACTIONS(4925),
    [anon_sym_LT] = ACTIONS(4927),
    [anon_sym_EQ_EQ] = ACTIONS(4925),
    [anon_sym_BANG_EQ] = ACTIONS(4925),
    [anon_sym_TILDE_EQ] = ACTIONS(4925),
    [anon_sym_AMP_TILDE] = ACTIONS(4927),
    [anon_sym_LT_LT] = ACTIONS(4927),
    [anon_sym_GT_GT] = ACTIONS(4927),
    [anon_sym_STAR] = ACTIONS(4927),
    [anon_sym_SLASH] = ACTIONS(4927),
    [anon_sym_PERCENT] = ACTIONS(4927),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4925),
    [anon_sym_DOT] = ACTIONS(4927),
    [anon_sym_LBRACK] = ACTIONS(4925),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4925),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4925),
    [anon_sym_not_in] = ACTIONS(4925),
    [anon_sym_or_return] = ACTIONS(4925),
    [anon_sym_or_continue] = ACTIONS(4925),
    [anon_sym_or_break] = ACTIONS(4925),
    [anon_sym_CARET] = ACTIONS(4927),
    [sym_uninitialized] = ACTIONS(4925),
    [sym_tag] = ACTIONS(4925),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4925),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [786] = {
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3425),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3425),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3425),
    [sym_tag] = ACTIONS(3425),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [787] = {
    [ts_builtin_sym_end] = ACTIONS(4929),
    [anon_sym_LBRACE] = ACTIONS(4929),
    [anon_sym_RBRACE] = ACTIONS(4929),
    [anon_sym_COMMA] = ACTIONS(4929),
    [anon_sym_COLON_COLON] = ACTIONS(4929),
    [anon_sym_DASH_GT] = ACTIONS(4929),
    [anon_sym_where] = ACTIONS(4929),
    [anon_sym_EQ] = ACTIONS(4931),
    [anon_sym_COLON] = ACTIONS(4931),
    [anon_sym_PIPE] = ACTIONS(4931),
    [anon_sym_COLON_EQ] = ACTIONS(4929),
    [anon_sym_LPAREN] = ACTIONS(4929),
    [anon_sym_PLUS_EQ] = ACTIONS(4929),
    [anon_sym_DASH_EQ] = ACTIONS(4929),
    [anon_sym_STAR_EQ] = ACTIONS(4929),
    [anon_sym_SLASH_EQ] = ACTIONS(4929),
    [anon_sym_PERCENT_EQ] = ACTIONS(4929),
    [anon_sym_AMP_EQ] = ACTIONS(4929),
    [anon_sym_PIPE_EQ] = ACTIONS(4929),
    [anon_sym_CARET_EQ] = ACTIONS(4929),
    [anon_sym_LT_LT_EQ] = ACTIONS(4929),
    [anon_sym_GT_GT_EQ] = ACTIONS(4929),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4929),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4929),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4929),
    [anon_sym_if] = ACTIONS(4929),
    [anon_sym_SEMI] = ACTIONS(4929),
    [anon_sym_else] = ACTIONS(4929),
    [anon_sym_when] = ACTIONS(4929),
    [anon_sym_in] = ACTIONS(4929),
    [anon_sym_case] = ACTIONS(4929),
    [anon_sym_QMARK] = ACTIONS(4929),
    [anon_sym_PLUS] = ACTIONS(4931),
    [anon_sym_DASH] = ACTIONS(4931),
    [anon_sym_TILDE] = ACTIONS(4931),
    [anon_sym_AMP] = ACTIONS(4931),
    [anon_sym_PIPE_PIPE] = ACTIONS(4931),
    [anon_sym_or_else] = ACTIONS(4929),
    [anon_sym_AMP_AMP] = ACTIONS(4931),
    [anon_sym_GT] = ACTIONS(4931),
    [anon_sym_GT_EQ] = ACTIONS(4929),
    [anon_sym_LT_EQ] = ACTIONS(4929),
    [anon_sym_LT] = ACTIONS(4931),
    [anon_sym_EQ_EQ] = ACTIONS(4929),
    [anon_sym_BANG_EQ] = ACTIONS(4929),
    [anon_sym_TILDE_EQ] = ACTIONS(4929),
    [anon_sym_AMP_TILDE] = ACTIONS(4931),
    [anon_sym_LT_LT] = ACTIONS(4931),
    [anon_sym_GT_GT] = ACTIONS(4931),
    [anon_sym_STAR] = ACTIONS(4931),
    [anon_sym_SLASH] = ACTIONS(4931),
    [anon_sym_PERCENT] = ACTIONS(4931),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4929),
    [anon_sym_DOT] = ACTIONS(4931),
    [anon_sym_LBRACK] = ACTIONS(4929),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4929),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4929),
    [anon_sym_not_in] = ACTIONS(4929),
    [anon_sym_or_return] = ACTIONS(4929),
    [anon_sym_or_continue] = ACTIONS(4929),
    [anon_sym_or_break] = ACTIONS(4929),
    [anon_sym_CARET] = ACTIONS(4931),
    [sym_uninitialized] = ACTIONS(4929),
    [sym_tag] = ACTIONS(4929),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4929),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [788] = {
    [ts_builtin_sym_end] = ACTIONS(4933),
    [anon_sym_LBRACE] = ACTIONS(4933),
    [anon_sym_RBRACE] = ACTIONS(4933),
    [anon_sym_COMMA] = ACTIONS(4933),
    [anon_sym_COLON_COLON] = ACTIONS(4933),
    [anon_sym_DASH_GT] = ACTIONS(4933),
    [anon_sym_where] = ACTIONS(4933),
    [anon_sym_EQ] = ACTIONS(4935),
    [anon_sym_COLON] = ACTIONS(4935),
    [anon_sym_PIPE] = ACTIONS(4935),
    [anon_sym_COLON_EQ] = ACTIONS(4933),
    [anon_sym_LPAREN] = ACTIONS(4933),
    [anon_sym_PLUS_EQ] = ACTIONS(4933),
    [anon_sym_DASH_EQ] = ACTIONS(4933),
    [anon_sym_STAR_EQ] = ACTIONS(4933),
    [anon_sym_SLASH_EQ] = ACTIONS(4933),
    [anon_sym_PERCENT_EQ] = ACTIONS(4933),
    [anon_sym_AMP_EQ] = ACTIONS(4933),
    [anon_sym_PIPE_EQ] = ACTIONS(4933),
    [anon_sym_CARET_EQ] = ACTIONS(4933),
    [anon_sym_LT_LT_EQ] = ACTIONS(4933),
    [anon_sym_GT_GT_EQ] = ACTIONS(4933),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4933),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4933),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4933),
    [anon_sym_if] = ACTIONS(4933),
    [anon_sym_SEMI] = ACTIONS(4933),
    [anon_sym_else] = ACTIONS(4933),
    [anon_sym_when] = ACTIONS(4933),
    [anon_sym_in] = ACTIONS(4933),
    [anon_sym_case] = ACTIONS(4933),
    [anon_sym_QMARK] = ACTIONS(4933),
    [anon_sym_PLUS] = ACTIONS(4935),
    [anon_sym_DASH] = ACTIONS(4935),
    [anon_sym_TILDE] = ACTIONS(4935),
    [anon_sym_AMP] = ACTIONS(4935),
    [anon_sym_PIPE_PIPE] = ACTIONS(4935),
    [anon_sym_or_else] = ACTIONS(4933),
    [anon_sym_AMP_AMP] = ACTIONS(4935),
    [anon_sym_GT] = ACTIONS(4935),
    [anon_sym_GT_EQ] = ACTIONS(4933),
    [anon_sym_LT_EQ] = ACTIONS(4933),
    [anon_sym_LT] = ACTIONS(4935),
    [anon_sym_EQ_EQ] = ACTIONS(4933),
    [anon_sym_BANG_EQ] = ACTIONS(4933),
    [anon_sym_TILDE_EQ] = ACTIONS(4933),
    [anon_sym_AMP_TILDE] = ACTIONS(4935),
    [anon_sym_LT_LT] = ACTIONS(4935),
    [anon_sym_GT_GT] = ACTIONS(4935),
    [anon_sym_STAR] = ACTIONS(4935),
    [anon_sym_SLASH] = ACTIONS(4935),
    [anon_sym_PERCENT] = ACTIONS(4935),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4933),
    [anon_sym_DOT] = ACTIONS(4935),
    [anon_sym_LBRACK] = ACTIONS(4933),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4933),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4933),
    [anon_sym_not_in] = ACTIONS(4933),
    [anon_sym_or_return] = ACTIONS(4933),
    [anon_sym_or_continue] = ACTIONS(4933),
    [anon_sym_or_break] = ACTIONS(4933),
    [anon_sym_CARET] = ACTIONS(4935),
    [sym_uninitialized] = ACTIONS(4933),
    [sym_tag] = ACTIONS(4933),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4933),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [789] = {
    [ts_builtin_sym_end] = ACTIONS(4937),
    [anon_sym_LBRACE] = ACTIONS(4937),
    [anon_sym_RBRACE] = ACTIONS(4937),
    [anon_sym_COMMA] = ACTIONS(4937),
    [anon_sym_COLON_COLON] = ACTIONS(4937),
    [anon_sym_DASH_GT] = ACTIONS(4937),
    [anon_sym_where] = ACTIONS(4937),
    [anon_sym_EQ] = ACTIONS(4939),
    [anon_sym_COLON] = ACTIONS(4939),
    [anon_sym_PIPE] = ACTIONS(4939),
    [anon_sym_COLON_EQ] = ACTIONS(4937),
    [anon_sym_LPAREN] = ACTIONS(4937),
    [anon_sym_PLUS_EQ] = ACTIONS(4937),
    [anon_sym_DASH_EQ] = ACTIONS(4937),
    [anon_sym_STAR_EQ] = ACTIONS(4937),
    [anon_sym_SLASH_EQ] = ACTIONS(4937),
    [anon_sym_PERCENT_EQ] = ACTIONS(4937),
    [anon_sym_AMP_EQ] = ACTIONS(4937),
    [anon_sym_PIPE_EQ] = ACTIONS(4937),
    [anon_sym_CARET_EQ] = ACTIONS(4937),
    [anon_sym_LT_LT_EQ] = ACTIONS(4937),
    [anon_sym_GT_GT_EQ] = ACTIONS(4937),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4937),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4937),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4937),
    [anon_sym_if] = ACTIONS(4937),
    [anon_sym_SEMI] = ACTIONS(4937),
    [anon_sym_else] = ACTIONS(4937),
    [anon_sym_when] = ACTIONS(4937),
    [anon_sym_in] = ACTIONS(4937),
    [anon_sym_case] = ACTIONS(4937),
    [anon_sym_QMARK] = ACTIONS(4937),
    [anon_sym_PLUS] = ACTIONS(4939),
    [anon_sym_DASH] = ACTIONS(4939),
    [anon_sym_TILDE] = ACTIONS(4939),
    [anon_sym_AMP] = ACTIONS(4939),
    [anon_sym_PIPE_PIPE] = ACTIONS(4939),
    [anon_sym_or_else] = ACTIONS(4937),
    [anon_sym_AMP_AMP] = ACTIONS(4939),
    [anon_sym_GT] = ACTIONS(4939),
    [anon_sym_GT_EQ] = ACTIONS(4937),
    [anon_sym_LT_EQ] = ACTIONS(4937),
    [anon_sym_LT] = ACTIONS(4939),
    [anon_sym_EQ_EQ] = ACTIONS(4937),
    [anon_sym_BANG_EQ] = ACTIONS(4937),
    [anon_sym_TILDE_EQ] = ACTIONS(4937),
    [anon_sym_AMP_TILDE] = ACTIONS(4939),
    [anon_sym_LT_LT] = ACTIONS(4939),
    [anon_sym_GT_GT] = ACTIONS(4939),
    [anon_sym_STAR] = ACTIONS(4939),
    [anon_sym_SLASH] = ACTIONS(4939),
    [anon_sym_PERCENT] = ACTIONS(4939),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4937),
    [anon_sym_DOT] = ACTIONS(4939),
    [anon_sym_LBRACK] = ACTIONS(4937),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4937),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4937),
    [anon_sym_not_in] = ACTIONS(4937),
    [anon_sym_or_return] = ACTIONS(4937),
    [anon_sym_or_continue] = ACTIONS(4937),
    [anon_sym_or_break] = ACTIONS(4937),
    [anon_sym_CARET] = ACTIONS(4939),
    [sym_uninitialized] = ACTIONS(4937),
    [sym_tag] = ACTIONS(4937),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4937),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [790] = {
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3368),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3368),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3368),
    [sym_tag] = ACTIONS(3368),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [791] = {
    [ts_builtin_sym_end] = ACTIONS(4941),
    [anon_sym_LBRACE] = ACTIONS(4941),
    [anon_sym_RBRACE] = ACTIONS(4941),
    [anon_sym_COMMA] = ACTIONS(4941),
    [anon_sym_COLON_COLON] = ACTIONS(4941),
    [anon_sym_DASH_GT] = ACTIONS(4941),
    [anon_sym_where] = ACTIONS(4941),
    [anon_sym_EQ] = ACTIONS(4943),
    [anon_sym_COLON] = ACTIONS(4943),
    [anon_sym_PIPE] = ACTIONS(4943),
    [anon_sym_COLON_EQ] = ACTIONS(4941),
    [anon_sym_LPAREN] = ACTIONS(4941),
    [anon_sym_PLUS_EQ] = ACTIONS(4941),
    [anon_sym_DASH_EQ] = ACTIONS(4941),
    [anon_sym_STAR_EQ] = ACTIONS(4941),
    [anon_sym_SLASH_EQ] = ACTIONS(4941),
    [anon_sym_PERCENT_EQ] = ACTIONS(4941),
    [anon_sym_AMP_EQ] = ACTIONS(4941),
    [anon_sym_PIPE_EQ] = ACTIONS(4941),
    [anon_sym_CARET_EQ] = ACTIONS(4941),
    [anon_sym_LT_LT_EQ] = ACTIONS(4941),
    [anon_sym_GT_GT_EQ] = ACTIONS(4941),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4941),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4941),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4941),
    [anon_sym_if] = ACTIONS(4941),
    [anon_sym_SEMI] = ACTIONS(4941),
    [anon_sym_else] = ACTIONS(4941),
    [anon_sym_when] = ACTIONS(4941),
    [anon_sym_in] = ACTIONS(4941),
    [anon_sym_case] = ACTIONS(4941),
    [anon_sym_QMARK] = ACTIONS(4941),
    [anon_sym_PLUS] = ACTIONS(4943),
    [anon_sym_DASH] = ACTIONS(4943),
    [anon_sym_TILDE] = ACTIONS(4943),
    [anon_sym_AMP] = ACTIONS(4943),
    [anon_sym_PIPE_PIPE] = ACTIONS(4943),
    [anon_sym_or_else] = ACTIONS(4941),
    [anon_sym_AMP_AMP] = ACTIONS(4943),
    [anon_sym_GT] = ACTIONS(4943),
    [anon_sym_GT_EQ] = ACTIONS(4941),
    [anon_sym_LT_EQ] = ACTIONS(4941),
    [anon_sym_LT] = ACTIONS(4943),
    [anon_sym_EQ_EQ] = ACTIONS(4941),
    [anon_sym_BANG_EQ] = ACTIONS(4941),
    [anon_sym_TILDE_EQ] = ACTIONS(4941),
    [anon_sym_AMP_TILDE] = ACTIONS(4943),
    [anon_sym_LT_LT] = ACTIONS(4943),
    [anon_sym_GT_GT] = ACTIONS(4943),
    [anon_sym_STAR] = ACTIONS(4943),
    [anon_sym_SLASH] = ACTIONS(4943),
    [anon_sym_PERCENT] = ACTIONS(4943),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4941),
    [anon_sym_DOT] = ACTIONS(4943),
    [anon_sym_LBRACK] = ACTIONS(4941),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4941),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4941),
    [anon_sym_not_in] = ACTIONS(4941),
    [anon_sym_or_return] = ACTIONS(4941),
    [anon_sym_or_continue] = ACTIONS(4941),
    [anon_sym_or_break] = ACTIONS(4941),
    [anon_sym_CARET] = ACTIONS(4943),
    [sym_uninitialized] = ACTIONS(4941),
    [sym_tag] = ACTIONS(4941),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4941),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [792] = {
    [ts_builtin_sym_end] = ACTIONS(4945),
    [anon_sym_LBRACE] = ACTIONS(4945),
    [anon_sym_RBRACE] = ACTIONS(4945),
    [anon_sym_COMMA] = ACTIONS(4945),
    [anon_sym_COLON_COLON] = ACTIONS(4945),
    [anon_sym_DASH_GT] = ACTIONS(4945),
    [anon_sym_where] = ACTIONS(4945),
    [anon_sym_EQ] = ACTIONS(4947),
    [anon_sym_COLON] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(4947),
    [anon_sym_COLON_EQ] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4945),
    [anon_sym_PLUS_EQ] = ACTIONS(4945),
    [anon_sym_DASH_EQ] = ACTIONS(4945),
    [anon_sym_STAR_EQ] = ACTIONS(4945),
    [anon_sym_SLASH_EQ] = ACTIONS(4945),
    [anon_sym_PERCENT_EQ] = ACTIONS(4945),
    [anon_sym_AMP_EQ] = ACTIONS(4945),
    [anon_sym_PIPE_EQ] = ACTIONS(4945),
    [anon_sym_CARET_EQ] = ACTIONS(4945),
    [anon_sym_LT_LT_EQ] = ACTIONS(4945),
    [anon_sym_GT_GT_EQ] = ACTIONS(4945),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4945),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4945),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4945),
    [anon_sym_if] = ACTIONS(4945),
    [anon_sym_SEMI] = ACTIONS(4945),
    [anon_sym_else] = ACTIONS(4945),
    [anon_sym_when] = ACTIONS(4945),
    [anon_sym_in] = ACTIONS(4945),
    [anon_sym_case] = ACTIONS(4945),
    [anon_sym_QMARK] = ACTIONS(4945),
    [anon_sym_PLUS] = ACTIONS(4947),
    [anon_sym_DASH] = ACTIONS(4947),
    [anon_sym_TILDE] = ACTIONS(4947),
    [anon_sym_AMP] = ACTIONS(4947),
    [anon_sym_PIPE_PIPE] = ACTIONS(4947),
    [anon_sym_or_else] = ACTIONS(4945),
    [anon_sym_AMP_AMP] = ACTIONS(4947),
    [anon_sym_GT] = ACTIONS(4947),
    [anon_sym_GT_EQ] = ACTIONS(4945),
    [anon_sym_LT_EQ] = ACTIONS(4945),
    [anon_sym_LT] = ACTIONS(4947),
    [anon_sym_EQ_EQ] = ACTIONS(4945),
    [anon_sym_BANG_EQ] = ACTIONS(4945),
    [anon_sym_TILDE_EQ] = ACTIONS(4945),
    [anon_sym_AMP_TILDE] = ACTIONS(4947),
    [anon_sym_LT_LT] = ACTIONS(4947),
    [anon_sym_GT_GT] = ACTIONS(4947),
    [anon_sym_STAR] = ACTIONS(4947),
    [anon_sym_SLASH] = ACTIONS(4947),
    [anon_sym_PERCENT] = ACTIONS(4947),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4945),
    [anon_sym_DOT] = ACTIONS(4947),
    [anon_sym_LBRACK] = ACTIONS(4945),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4945),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4945),
    [anon_sym_not_in] = ACTIONS(4945),
    [anon_sym_or_return] = ACTIONS(4945),
    [anon_sym_or_continue] = ACTIONS(4945),
    [anon_sym_or_break] = ACTIONS(4945),
    [anon_sym_CARET] = ACTIONS(4947),
    [sym_uninitialized] = ACTIONS(4945),
    [sym_tag] = ACTIONS(4945),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4945),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [793] = {
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3384),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3384),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3384),
    [sym_tag] = ACTIONS(3384),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [794] = {
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3400),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_where] = ACTIONS(3400),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(3400),
    [sym_tag] = ACTIONS(3400),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [795] = {
    [sym_block] = STATE(2342),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3394),
    [sym_tag] = ACTIONS(3487),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [796] = {
    [ts_builtin_sym_end] = ACTIONS(4577),
    [anon_sym_LBRACE] = ACTIONS(4577),
    [anon_sym_RBRACE] = ACTIONS(4577),
    [anon_sym_COMMA] = ACTIONS(4577),
    [anon_sym_COLON_COLON] = ACTIONS(4577),
    [anon_sym_DASH_GT] = ACTIONS(4577),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_EQ] = ACTIONS(4579),
    [anon_sym_COLON] = ACTIONS(4579),
    [anon_sym_PIPE] = ACTIONS(4579),
    [anon_sym_COLON_EQ] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4577),
    [anon_sym_PLUS_EQ] = ACTIONS(4577),
    [anon_sym_DASH_EQ] = ACTIONS(4577),
    [anon_sym_STAR_EQ] = ACTIONS(4577),
    [anon_sym_SLASH_EQ] = ACTIONS(4577),
    [anon_sym_PERCENT_EQ] = ACTIONS(4577),
    [anon_sym_AMP_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_CARET_EQ] = ACTIONS(4577),
    [anon_sym_LT_LT_EQ] = ACTIONS(4577),
    [anon_sym_GT_GT_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_when] = ACTIONS(4577),
    [anon_sym_in] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [anon_sym_TILDE] = ACTIONS(4579),
    [anon_sym_AMP] = ACTIONS(4579),
    [anon_sym_PIPE_PIPE] = ACTIONS(4579),
    [anon_sym_or_else] = ACTIONS(4577),
    [anon_sym_AMP_AMP] = ACTIONS(4579),
    [anon_sym_GT] = ACTIONS(4579),
    [anon_sym_GT_EQ] = ACTIONS(4577),
    [anon_sym_LT_EQ] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4579),
    [anon_sym_EQ_EQ] = ACTIONS(4577),
    [anon_sym_BANG_EQ] = ACTIONS(4577),
    [anon_sym_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE] = ACTIONS(4579),
    [anon_sym_LT_LT] = ACTIONS(4579),
    [anon_sym_GT_GT] = ACTIONS(4579),
    [anon_sym_STAR] = ACTIONS(4579),
    [anon_sym_SLASH] = ACTIONS(4579),
    [anon_sym_PERCENT] = ACTIONS(4579),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4577),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4577),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4577),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4577),
    [anon_sym_not_in] = ACTIONS(4577),
    [anon_sym_or_return] = ACTIONS(4577),
    [anon_sym_or_continue] = ACTIONS(4577),
    [anon_sym_or_break] = ACTIONS(4577),
    [anon_sym_CARET] = ACTIONS(4579),
    [sym_uninitialized] = ACTIONS(4577),
    [sym_tag] = ACTIONS(4577),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4577),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [797] = {
    [ts_builtin_sym_end] = ACTIONS(893),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_where] = ACTIONS(893),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(893),
    [anon_sym_PLUS_EQ] = ACTIONS(893),
    [anon_sym_DASH_EQ] = ACTIONS(893),
    [anon_sym_STAR_EQ] = ACTIONS(893),
    [anon_sym_SLASH_EQ] = ACTIONS(893),
    [anon_sym_PERCENT_EQ] = ACTIONS(893),
    [anon_sym_AMP_EQ] = ACTIONS(893),
    [anon_sym_PIPE_EQ] = ACTIONS(893),
    [anon_sym_CARET_EQ] = ACTIONS(893),
    [anon_sym_LT_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_GT_EQ] = ACTIONS(893),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(893),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(893),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(893),
    [anon_sym_when] = ACTIONS(893),
    [anon_sym_in] = ACTIONS(893),
    [anon_sym_case] = ACTIONS(893),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(895),
    [anon_sym_or_else] = ACTIONS(893),
    [anon_sym_AMP_AMP] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(895),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(893),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(893),
    [anon_sym_or_return] = ACTIONS(893),
    [anon_sym_or_continue] = ACTIONS(893),
    [anon_sym_or_break] = ACTIONS(893),
    [anon_sym_CARET] = ACTIONS(895),
    [sym_uninitialized] = ACTIONS(893),
    [sym_tag] = ACTIONS(893),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [798] = {
    [ts_builtin_sym_end] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(4585),
    [anon_sym_RBRACE] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_COLON_COLON] = ACTIONS(4585),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_where] = ACTIONS(4585),
    [anon_sym_EQ] = ACTIONS(4587),
    [anon_sym_COLON] = ACTIONS(4587),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_COLON_EQ] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_PLUS_EQ] = ACTIONS(4585),
    [anon_sym_DASH_EQ] = ACTIONS(4585),
    [anon_sym_STAR_EQ] = ACTIONS(4585),
    [anon_sym_SLASH_EQ] = ACTIONS(4585),
    [anon_sym_PERCENT_EQ] = ACTIONS(4585),
    [anon_sym_AMP_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_CARET_EQ] = ACTIONS(4585),
    [anon_sym_LT_LT_EQ] = ACTIONS(4585),
    [anon_sym_GT_GT_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_if] = ACTIONS(4585),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_else] = ACTIONS(4585),
    [anon_sym_when] = ACTIONS(4585),
    [anon_sym_in] = ACTIONS(4585),
    [anon_sym_case] = ACTIONS(4585),
    [anon_sym_QMARK] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_TILDE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_PIPE_PIPE] = ACTIONS(4587),
    [anon_sym_or_else] = ACTIONS(4585),
    [anon_sym_AMP_AMP] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4587),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4587),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4587),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4585),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4585),
    [anon_sym_not_in] = ACTIONS(4585),
    [anon_sym_or_return] = ACTIONS(4585),
    [anon_sym_or_continue] = ACTIONS(4585),
    [anon_sym_or_break] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4587),
    [sym_uninitialized] = ACTIONS(4585),
    [sym_tag] = ACTIONS(4585),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4585),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [799] = {
    [ts_builtin_sym_end] = ACTIONS(4949),
    [anon_sym_LBRACE] = ACTIONS(4949),
    [anon_sym_RBRACE] = ACTIONS(4949),
    [anon_sym_COMMA] = ACTIONS(4949),
    [anon_sym_COLON_COLON] = ACTIONS(4949),
    [anon_sym_DASH_GT] = ACTIONS(4949),
    [anon_sym_where] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(4951),
    [anon_sym_COLON] = ACTIONS(4951),
    [anon_sym_PIPE] = ACTIONS(4951),
    [anon_sym_COLON_EQ] = ACTIONS(4949),
    [anon_sym_LPAREN] = ACTIONS(4949),
    [anon_sym_PLUS_EQ] = ACTIONS(4949),
    [anon_sym_DASH_EQ] = ACTIONS(4949),
    [anon_sym_STAR_EQ] = ACTIONS(4949),
    [anon_sym_SLASH_EQ] = ACTIONS(4949),
    [anon_sym_PERCENT_EQ] = ACTIONS(4949),
    [anon_sym_AMP_EQ] = ACTIONS(4949),
    [anon_sym_PIPE_EQ] = ACTIONS(4949),
    [anon_sym_CARET_EQ] = ACTIONS(4949),
    [anon_sym_LT_LT_EQ] = ACTIONS(4949),
    [anon_sym_GT_GT_EQ] = ACTIONS(4949),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4949),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4949),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4949),
    [anon_sym_if] = ACTIONS(4949),
    [anon_sym_SEMI] = ACTIONS(4949),
    [anon_sym_else] = ACTIONS(4949),
    [anon_sym_when] = ACTIONS(4949),
    [anon_sym_in] = ACTIONS(4949),
    [anon_sym_case] = ACTIONS(4949),
    [anon_sym_QMARK] = ACTIONS(4949),
    [anon_sym_PLUS] = ACTIONS(4951),
    [anon_sym_DASH] = ACTIONS(4951),
    [anon_sym_TILDE] = ACTIONS(4951),
    [anon_sym_AMP] = ACTIONS(4951),
    [anon_sym_PIPE_PIPE] = ACTIONS(4951),
    [anon_sym_or_else] = ACTIONS(4949),
    [anon_sym_AMP_AMP] = ACTIONS(4951),
    [anon_sym_GT] = ACTIONS(4951),
    [anon_sym_GT_EQ] = ACTIONS(4949),
    [anon_sym_LT_EQ] = ACTIONS(4949),
    [anon_sym_LT] = ACTIONS(4951),
    [anon_sym_EQ_EQ] = ACTIONS(4949),
    [anon_sym_BANG_EQ] = ACTIONS(4949),
    [anon_sym_TILDE_EQ] = ACTIONS(4949),
    [anon_sym_AMP_TILDE] = ACTIONS(4951),
    [anon_sym_LT_LT] = ACTIONS(4951),
    [anon_sym_GT_GT] = ACTIONS(4951),
    [anon_sym_STAR] = ACTIONS(4951),
    [anon_sym_SLASH] = ACTIONS(4951),
    [anon_sym_PERCENT] = ACTIONS(4951),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4949),
    [anon_sym_DOT] = ACTIONS(4951),
    [anon_sym_LBRACK] = ACTIONS(4949),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4949),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4949),
    [anon_sym_not_in] = ACTIONS(4949),
    [anon_sym_or_return] = ACTIONS(4949),
    [anon_sym_or_continue] = ACTIONS(4949),
    [anon_sym_or_break] = ACTIONS(4949),
    [anon_sym_CARET] = ACTIONS(4951),
    [sym_uninitialized] = ACTIONS(4949),
    [sym_tag] = ACTIONS(4949),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4949),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [800] = {
    [ts_builtin_sym_end] = ACTIONS(4953),
    [anon_sym_LBRACE] = ACTIONS(4953),
    [anon_sym_RBRACE] = ACTIONS(4953),
    [anon_sym_COMMA] = ACTIONS(4953),
    [anon_sym_COLON_COLON] = ACTIONS(4953),
    [anon_sym_DASH_GT] = ACTIONS(4953),
    [anon_sym_where] = ACTIONS(4953),
    [anon_sym_EQ] = ACTIONS(4955),
    [anon_sym_COLON] = ACTIONS(4955),
    [anon_sym_PIPE] = ACTIONS(4955),
    [anon_sym_COLON_EQ] = ACTIONS(4953),
    [anon_sym_LPAREN] = ACTIONS(4953),
    [anon_sym_PLUS_EQ] = ACTIONS(4953),
    [anon_sym_DASH_EQ] = ACTIONS(4953),
    [anon_sym_STAR_EQ] = ACTIONS(4953),
    [anon_sym_SLASH_EQ] = ACTIONS(4953),
    [anon_sym_PERCENT_EQ] = ACTIONS(4953),
    [anon_sym_AMP_EQ] = ACTIONS(4953),
    [anon_sym_PIPE_EQ] = ACTIONS(4953),
    [anon_sym_CARET_EQ] = ACTIONS(4953),
    [anon_sym_LT_LT_EQ] = ACTIONS(4953),
    [anon_sym_GT_GT_EQ] = ACTIONS(4953),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4953),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4953),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4953),
    [anon_sym_if] = ACTIONS(4953),
    [anon_sym_SEMI] = ACTIONS(4953),
    [anon_sym_else] = ACTIONS(4953),
    [anon_sym_when] = ACTIONS(4953),
    [anon_sym_in] = ACTIONS(4953),
    [anon_sym_case] = ACTIONS(4953),
    [anon_sym_QMARK] = ACTIONS(4953),
    [anon_sym_PLUS] = ACTIONS(4955),
    [anon_sym_DASH] = ACTIONS(4955),
    [anon_sym_TILDE] = ACTIONS(4955),
    [anon_sym_AMP] = ACTIONS(4955),
    [anon_sym_PIPE_PIPE] = ACTIONS(4955),
    [anon_sym_or_else] = ACTIONS(4953),
    [anon_sym_AMP_AMP] = ACTIONS(4955),
    [anon_sym_GT] = ACTIONS(4955),
    [anon_sym_GT_EQ] = ACTIONS(4953),
    [anon_sym_LT_EQ] = ACTIONS(4953),
    [anon_sym_LT] = ACTIONS(4955),
    [anon_sym_EQ_EQ] = ACTIONS(4953),
    [anon_sym_BANG_EQ] = ACTIONS(4953),
    [anon_sym_TILDE_EQ] = ACTIONS(4953),
    [anon_sym_AMP_TILDE] = ACTIONS(4955),
    [anon_sym_LT_LT] = ACTIONS(4955),
    [anon_sym_GT_GT] = ACTIONS(4955),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_SLASH] = ACTIONS(4955),
    [anon_sym_PERCENT] = ACTIONS(4955),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4953),
    [anon_sym_DOT] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4953),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4953),
    [anon_sym_not_in] = ACTIONS(4953),
    [anon_sym_or_return] = ACTIONS(4953),
    [anon_sym_or_continue] = ACTIONS(4953),
    [anon_sym_or_break] = ACTIONS(4953),
    [anon_sym_CARET] = ACTIONS(4955),
    [sym_uninitialized] = ACTIONS(4953),
    [sym_tag] = ACTIONS(4953),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4953),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [801] = {
    [ts_builtin_sym_end] = ACTIONS(4957),
    [anon_sym_LBRACE] = ACTIONS(4957),
    [anon_sym_RBRACE] = ACTIONS(4957),
    [anon_sym_COMMA] = ACTIONS(4957),
    [anon_sym_COLON_COLON] = ACTIONS(4957),
    [anon_sym_DASH_GT] = ACTIONS(4957),
    [anon_sym_where] = ACTIONS(4957),
    [anon_sym_EQ] = ACTIONS(4959),
    [anon_sym_COLON] = ACTIONS(4959),
    [anon_sym_PIPE] = ACTIONS(4959),
    [anon_sym_COLON_EQ] = ACTIONS(4957),
    [anon_sym_LPAREN] = ACTIONS(4957),
    [anon_sym_PLUS_EQ] = ACTIONS(4957),
    [anon_sym_DASH_EQ] = ACTIONS(4957),
    [anon_sym_STAR_EQ] = ACTIONS(4957),
    [anon_sym_SLASH_EQ] = ACTIONS(4957),
    [anon_sym_PERCENT_EQ] = ACTIONS(4957),
    [anon_sym_AMP_EQ] = ACTIONS(4957),
    [anon_sym_PIPE_EQ] = ACTIONS(4957),
    [anon_sym_CARET_EQ] = ACTIONS(4957),
    [anon_sym_LT_LT_EQ] = ACTIONS(4957),
    [anon_sym_GT_GT_EQ] = ACTIONS(4957),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4957),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4957),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4957),
    [anon_sym_if] = ACTIONS(4957),
    [anon_sym_SEMI] = ACTIONS(4957),
    [anon_sym_else] = ACTIONS(4957),
    [anon_sym_when] = ACTIONS(4957),
    [anon_sym_in] = ACTIONS(4957),
    [anon_sym_case] = ACTIONS(4957),
    [anon_sym_QMARK] = ACTIONS(4957),
    [anon_sym_PLUS] = ACTIONS(4959),
    [anon_sym_DASH] = ACTIONS(4959),
    [anon_sym_TILDE] = ACTIONS(4959),
    [anon_sym_AMP] = ACTIONS(4959),
    [anon_sym_PIPE_PIPE] = ACTIONS(4959),
    [anon_sym_or_else] = ACTIONS(4957),
    [anon_sym_AMP_AMP] = ACTIONS(4959),
    [anon_sym_GT] = ACTIONS(4959),
    [anon_sym_GT_EQ] = ACTIONS(4957),
    [anon_sym_LT_EQ] = ACTIONS(4957),
    [anon_sym_LT] = ACTIONS(4959),
    [anon_sym_EQ_EQ] = ACTIONS(4957),
    [anon_sym_BANG_EQ] = ACTIONS(4957),
    [anon_sym_TILDE_EQ] = ACTIONS(4957),
    [anon_sym_AMP_TILDE] = ACTIONS(4959),
    [anon_sym_LT_LT] = ACTIONS(4959),
    [anon_sym_GT_GT] = ACTIONS(4959),
    [anon_sym_STAR] = ACTIONS(4959),
    [anon_sym_SLASH] = ACTIONS(4959),
    [anon_sym_PERCENT] = ACTIONS(4959),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4957),
    [anon_sym_DOT] = ACTIONS(4959),
    [anon_sym_LBRACK] = ACTIONS(4957),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4957),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4957),
    [anon_sym_not_in] = ACTIONS(4957),
    [anon_sym_or_return] = ACTIONS(4957),
    [anon_sym_or_continue] = ACTIONS(4957),
    [anon_sym_or_break] = ACTIONS(4957),
    [anon_sym_CARET] = ACTIONS(4959),
    [sym_uninitialized] = ACTIONS(4957),
    [sym_tag] = ACTIONS(4957),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4957),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [802] = {
    [ts_builtin_sym_end] = ACTIONS(3481),
    [anon_sym_LBRACE] = ACTIONS(3481),
    [anon_sym_RBRACE] = ACTIONS(3481),
    [anon_sym_COMMA] = ACTIONS(3481),
    [anon_sym_COLON_COLON] = ACTIONS(3481),
    [anon_sym_DASH_GT] = ACTIONS(3481),
    [anon_sym_where] = ACTIONS(3481),
    [anon_sym_EQ] = ACTIONS(3483),
    [anon_sym_COLON] = ACTIONS(3483),
    [anon_sym_PIPE] = ACTIONS(3483),
    [anon_sym_COLON_EQ] = ACTIONS(3481),
    [anon_sym_LPAREN] = ACTIONS(3481),
    [anon_sym_PLUS_EQ] = ACTIONS(3481),
    [anon_sym_DASH_EQ] = ACTIONS(3481),
    [anon_sym_STAR_EQ] = ACTIONS(3481),
    [anon_sym_SLASH_EQ] = ACTIONS(3481),
    [anon_sym_PERCENT_EQ] = ACTIONS(3481),
    [anon_sym_AMP_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_CARET_EQ] = ACTIONS(3481),
    [anon_sym_LT_LT_EQ] = ACTIONS(3481),
    [anon_sym_GT_GT_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(3481),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_else] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_in] = ACTIONS(3481),
    [anon_sym_case] = ACTIONS(3481),
    [anon_sym_QMARK] = ACTIONS(3481),
    [anon_sym_PLUS] = ACTIONS(3483),
    [anon_sym_DASH] = ACTIONS(3483),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_AMP] = ACTIONS(3483),
    [anon_sym_PIPE_PIPE] = ACTIONS(3483),
    [anon_sym_or_else] = ACTIONS(3481),
    [anon_sym_AMP_AMP] = ACTIONS(3483),
    [anon_sym_GT] = ACTIONS(3483),
    [anon_sym_GT_EQ] = ACTIONS(3481),
    [anon_sym_LT_EQ] = ACTIONS(3481),
    [anon_sym_LT] = ACTIONS(3483),
    [anon_sym_EQ_EQ] = ACTIONS(3481),
    [anon_sym_BANG_EQ] = ACTIONS(3481),
    [anon_sym_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE] = ACTIONS(3483),
    [anon_sym_LT_LT] = ACTIONS(3483),
    [anon_sym_GT_GT] = ACTIONS(3483),
    [anon_sym_STAR] = ACTIONS(3483),
    [anon_sym_SLASH] = ACTIONS(3483),
    [anon_sym_PERCENT] = ACTIONS(3483),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3481),
    [anon_sym_DOT] = ACTIONS(3483),
    [anon_sym_LBRACK] = ACTIONS(3481),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3481),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3481),
    [anon_sym_not_in] = ACTIONS(3481),
    [anon_sym_or_return] = ACTIONS(3481),
    [anon_sym_or_continue] = ACTIONS(3481),
    [anon_sym_or_break] = ACTIONS(3481),
    [anon_sym_CARET] = ACTIONS(3483),
    [sym_uninitialized] = ACTIONS(3481),
    [sym_tag] = ACTIONS(3481),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3481),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [803] = {
    [ts_builtin_sym_end] = ACTIONS(4961),
    [anon_sym_LBRACE] = ACTIONS(4961),
    [anon_sym_RBRACE] = ACTIONS(4961),
    [anon_sym_COMMA] = ACTIONS(4961),
    [anon_sym_COLON_COLON] = ACTIONS(4961),
    [anon_sym_DASH_GT] = ACTIONS(4961),
    [anon_sym_where] = ACTIONS(4961),
    [anon_sym_EQ] = ACTIONS(4963),
    [anon_sym_COLON] = ACTIONS(4963),
    [anon_sym_PIPE] = ACTIONS(4963),
    [anon_sym_COLON_EQ] = ACTIONS(4961),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(4961),
    [anon_sym_DASH_EQ] = ACTIONS(4961),
    [anon_sym_STAR_EQ] = ACTIONS(4961),
    [anon_sym_SLASH_EQ] = ACTIONS(4961),
    [anon_sym_PERCENT_EQ] = ACTIONS(4961),
    [anon_sym_AMP_EQ] = ACTIONS(4961),
    [anon_sym_PIPE_EQ] = ACTIONS(4961),
    [anon_sym_CARET_EQ] = ACTIONS(4961),
    [anon_sym_LT_LT_EQ] = ACTIONS(4961),
    [anon_sym_GT_GT_EQ] = ACTIONS(4961),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4961),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4961),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4961),
    [anon_sym_if] = ACTIONS(4961),
    [anon_sym_SEMI] = ACTIONS(4961),
    [anon_sym_else] = ACTIONS(4961),
    [anon_sym_when] = ACTIONS(4961),
    [anon_sym_in] = ACTIONS(4961),
    [anon_sym_case] = ACTIONS(4961),
    [anon_sym_QMARK] = ACTIONS(4961),
    [anon_sym_PLUS] = ACTIONS(4963),
    [anon_sym_DASH] = ACTIONS(4963),
    [anon_sym_TILDE] = ACTIONS(4963),
    [anon_sym_AMP] = ACTIONS(4963),
    [anon_sym_PIPE_PIPE] = ACTIONS(4963),
    [anon_sym_or_else] = ACTIONS(4961),
    [anon_sym_AMP_AMP] = ACTIONS(4963),
    [anon_sym_GT] = ACTIONS(4963),
    [anon_sym_GT_EQ] = ACTIONS(4961),
    [anon_sym_LT_EQ] = ACTIONS(4961),
    [anon_sym_LT] = ACTIONS(4963),
    [anon_sym_EQ_EQ] = ACTIONS(4961),
    [anon_sym_BANG_EQ] = ACTIONS(4961),
    [anon_sym_TILDE_EQ] = ACTIONS(4961),
    [anon_sym_AMP_TILDE] = ACTIONS(4963),
    [anon_sym_LT_LT] = ACTIONS(4963),
    [anon_sym_GT_GT] = ACTIONS(4963),
    [anon_sym_STAR] = ACTIONS(4963),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(4963),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4961),
    [anon_sym_DOT] = ACTIONS(4963),
    [anon_sym_LBRACK] = ACTIONS(4961),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4961),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4961),
    [anon_sym_not_in] = ACTIONS(4961),
    [anon_sym_or_return] = ACTIONS(4961),
    [anon_sym_or_continue] = ACTIONS(4961),
    [anon_sym_or_break] = ACTIONS(4961),
    [anon_sym_CARET] = ACTIONS(4963),
    [sym_uninitialized] = ACTIONS(4961),
    [sym_tag] = ACTIONS(4961),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4961),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [804] = {
    [sym_expression] = STATE(6196),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_pointer_type] = STATE(8744),
    [sym_array_type] = STATE(8744),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(2928),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(2932),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(2934),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [805] = {
    [ts_builtin_sym_end] = ACTIONS(4965),
    [anon_sym_LBRACE] = ACTIONS(4965),
    [anon_sym_RBRACE] = ACTIONS(4965),
    [anon_sym_COMMA] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(4965),
    [anon_sym_DASH_GT] = ACTIONS(4965),
    [anon_sym_where] = ACTIONS(4965),
    [anon_sym_EQ] = ACTIONS(4967),
    [anon_sym_COLON] = ACTIONS(4967),
    [anon_sym_PIPE] = ACTIONS(4967),
    [anon_sym_COLON_EQ] = ACTIONS(4965),
    [anon_sym_LPAREN] = ACTIONS(4965),
    [anon_sym_PLUS_EQ] = ACTIONS(4965),
    [anon_sym_DASH_EQ] = ACTIONS(4965),
    [anon_sym_STAR_EQ] = ACTIONS(4965),
    [anon_sym_SLASH_EQ] = ACTIONS(4965),
    [anon_sym_PERCENT_EQ] = ACTIONS(4965),
    [anon_sym_AMP_EQ] = ACTIONS(4965),
    [anon_sym_PIPE_EQ] = ACTIONS(4965),
    [anon_sym_CARET_EQ] = ACTIONS(4965),
    [anon_sym_LT_LT_EQ] = ACTIONS(4965),
    [anon_sym_GT_GT_EQ] = ACTIONS(4965),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4965),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4965),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4965),
    [anon_sym_if] = ACTIONS(4965),
    [anon_sym_SEMI] = ACTIONS(4965),
    [anon_sym_else] = ACTIONS(4965),
    [anon_sym_when] = ACTIONS(4965),
    [anon_sym_in] = ACTIONS(4965),
    [anon_sym_case] = ACTIONS(4965),
    [anon_sym_QMARK] = ACTIONS(4965),
    [anon_sym_PLUS] = ACTIONS(4967),
    [anon_sym_DASH] = ACTIONS(4967),
    [anon_sym_TILDE] = ACTIONS(4967),
    [anon_sym_AMP] = ACTIONS(4967),
    [anon_sym_PIPE_PIPE] = ACTIONS(4967),
    [anon_sym_or_else] = ACTIONS(4965),
    [anon_sym_AMP_AMP] = ACTIONS(4967),
    [anon_sym_GT] = ACTIONS(4967),
    [anon_sym_GT_EQ] = ACTIONS(4965),
    [anon_sym_LT_EQ] = ACTIONS(4965),
    [anon_sym_LT] = ACTIONS(4967),
    [anon_sym_EQ_EQ] = ACTIONS(4965),
    [anon_sym_BANG_EQ] = ACTIONS(4965),
    [anon_sym_TILDE_EQ] = ACTIONS(4965),
    [anon_sym_AMP_TILDE] = ACTIONS(4967),
    [anon_sym_LT_LT] = ACTIONS(4967),
    [anon_sym_GT_GT] = ACTIONS(4967),
    [anon_sym_STAR] = ACTIONS(4967),
    [anon_sym_SLASH] = ACTIONS(4967),
    [anon_sym_PERCENT] = ACTIONS(4967),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4965),
    [anon_sym_DOT] = ACTIONS(4967),
    [anon_sym_LBRACK] = ACTIONS(4965),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4965),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4965),
    [anon_sym_not_in] = ACTIONS(4965),
    [anon_sym_or_return] = ACTIONS(4965),
    [anon_sym_or_continue] = ACTIONS(4965),
    [anon_sym_or_break] = ACTIONS(4965),
    [anon_sym_CARET] = ACTIONS(4967),
    [sym_uninitialized] = ACTIONS(4965),
    [sym_tag] = ACTIONS(4965),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4965),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [806] = {
    [ts_builtin_sym_end] = ACTIONS(4965),
    [anon_sym_LBRACE] = ACTIONS(4965),
    [anon_sym_RBRACE] = ACTIONS(4965),
    [anon_sym_COMMA] = ACTIONS(4965),
    [anon_sym_COLON_COLON] = ACTIONS(4965),
    [anon_sym_DASH_GT] = ACTIONS(4965),
    [anon_sym_where] = ACTIONS(4965),
    [anon_sym_EQ] = ACTIONS(4967),
    [anon_sym_COLON] = ACTIONS(4967),
    [anon_sym_PIPE] = ACTIONS(4967),
    [anon_sym_COLON_EQ] = ACTIONS(4965),
    [anon_sym_LPAREN] = ACTIONS(4965),
    [anon_sym_PLUS_EQ] = ACTIONS(4965),
    [anon_sym_DASH_EQ] = ACTIONS(4965),
    [anon_sym_STAR_EQ] = ACTIONS(4965),
    [anon_sym_SLASH_EQ] = ACTIONS(4965),
    [anon_sym_PERCENT_EQ] = ACTIONS(4965),
    [anon_sym_AMP_EQ] = ACTIONS(4965),
    [anon_sym_PIPE_EQ] = ACTIONS(4965),
    [anon_sym_CARET_EQ] = ACTIONS(4965),
    [anon_sym_LT_LT_EQ] = ACTIONS(4965),
    [anon_sym_GT_GT_EQ] = ACTIONS(4965),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4965),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4965),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4965),
    [anon_sym_if] = ACTIONS(4965),
    [anon_sym_SEMI] = ACTIONS(4965),
    [anon_sym_else] = ACTIONS(4965),
    [anon_sym_when] = ACTIONS(4965),
    [anon_sym_in] = ACTIONS(4965),
    [anon_sym_case] = ACTIONS(4965),
    [anon_sym_QMARK] = ACTIONS(4965),
    [anon_sym_PLUS] = ACTIONS(4967),
    [anon_sym_DASH] = ACTIONS(4967),
    [anon_sym_TILDE] = ACTIONS(4967),
    [anon_sym_AMP] = ACTIONS(4967),
    [anon_sym_PIPE_PIPE] = ACTIONS(4967),
    [anon_sym_or_else] = ACTIONS(4965),
    [anon_sym_AMP_AMP] = ACTIONS(4967),
    [anon_sym_GT] = ACTIONS(4967),
    [anon_sym_GT_EQ] = ACTIONS(4965),
    [anon_sym_LT_EQ] = ACTIONS(4965),
    [anon_sym_LT] = ACTIONS(4967),
    [anon_sym_EQ_EQ] = ACTIONS(4965),
    [anon_sym_BANG_EQ] = ACTIONS(4965),
    [anon_sym_TILDE_EQ] = ACTIONS(4965),
    [anon_sym_AMP_TILDE] = ACTIONS(4967),
    [anon_sym_LT_LT] = ACTIONS(4967),
    [anon_sym_GT_GT] = ACTIONS(4967),
    [anon_sym_STAR] = ACTIONS(4967),
    [anon_sym_SLASH] = ACTIONS(4967),
    [anon_sym_PERCENT] = ACTIONS(4967),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4965),
    [anon_sym_DOT] = ACTIONS(4967),
    [anon_sym_LBRACK] = ACTIONS(4965),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4965),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4965),
    [anon_sym_not_in] = ACTIONS(4965),
    [anon_sym_or_return] = ACTIONS(4965),
    [anon_sym_or_continue] = ACTIONS(4965),
    [anon_sym_or_break] = ACTIONS(4965),
    [anon_sym_CARET] = ACTIONS(4967),
    [sym_uninitialized] = ACTIONS(4965),
    [sym_tag] = ACTIONS(4965),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4965),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [807] = {
    [sym_block] = STATE(2356),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3390),
    [sym_tag] = ACTIONS(3398),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [808] = {
    [ts_builtin_sym_end] = ACTIONS(4969),
    [anon_sym_LBRACE] = ACTIONS(4969),
    [anon_sym_RBRACE] = ACTIONS(4969),
    [anon_sym_COMMA] = ACTIONS(4969),
    [anon_sym_COLON_COLON] = ACTIONS(4969),
    [anon_sym_DASH_GT] = ACTIONS(4969),
    [anon_sym_where] = ACTIONS(4969),
    [anon_sym_EQ] = ACTIONS(4971),
    [anon_sym_COLON] = ACTIONS(4971),
    [anon_sym_PIPE] = ACTIONS(4971),
    [anon_sym_COLON_EQ] = ACTIONS(4969),
    [anon_sym_LPAREN] = ACTIONS(4969),
    [anon_sym_PLUS_EQ] = ACTIONS(4969),
    [anon_sym_DASH_EQ] = ACTIONS(4969),
    [anon_sym_STAR_EQ] = ACTIONS(4969),
    [anon_sym_SLASH_EQ] = ACTIONS(4969),
    [anon_sym_PERCENT_EQ] = ACTIONS(4969),
    [anon_sym_AMP_EQ] = ACTIONS(4969),
    [anon_sym_PIPE_EQ] = ACTIONS(4969),
    [anon_sym_CARET_EQ] = ACTIONS(4969),
    [anon_sym_LT_LT_EQ] = ACTIONS(4969),
    [anon_sym_GT_GT_EQ] = ACTIONS(4969),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4969),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4969),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4969),
    [anon_sym_if] = ACTIONS(4969),
    [anon_sym_SEMI] = ACTIONS(4969),
    [anon_sym_else] = ACTIONS(4969),
    [anon_sym_when] = ACTIONS(4969),
    [anon_sym_in] = ACTIONS(4969),
    [anon_sym_case] = ACTIONS(4969),
    [anon_sym_QMARK] = ACTIONS(4969),
    [anon_sym_PLUS] = ACTIONS(4971),
    [anon_sym_DASH] = ACTIONS(4971),
    [anon_sym_TILDE] = ACTIONS(4971),
    [anon_sym_AMP] = ACTIONS(4971),
    [anon_sym_PIPE_PIPE] = ACTIONS(4971),
    [anon_sym_or_else] = ACTIONS(4969),
    [anon_sym_AMP_AMP] = ACTIONS(4971),
    [anon_sym_GT] = ACTIONS(4971),
    [anon_sym_GT_EQ] = ACTIONS(4969),
    [anon_sym_LT_EQ] = ACTIONS(4969),
    [anon_sym_LT] = ACTIONS(4971),
    [anon_sym_EQ_EQ] = ACTIONS(4969),
    [anon_sym_BANG_EQ] = ACTIONS(4969),
    [anon_sym_TILDE_EQ] = ACTIONS(4969),
    [anon_sym_AMP_TILDE] = ACTIONS(4971),
    [anon_sym_LT_LT] = ACTIONS(4971),
    [anon_sym_GT_GT] = ACTIONS(4971),
    [anon_sym_STAR] = ACTIONS(4971),
    [anon_sym_SLASH] = ACTIONS(4971),
    [anon_sym_PERCENT] = ACTIONS(4971),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4969),
    [anon_sym_DOT] = ACTIONS(4971),
    [anon_sym_LBRACK] = ACTIONS(4969),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4969),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4969),
    [anon_sym_not_in] = ACTIONS(4969),
    [anon_sym_or_return] = ACTIONS(4969),
    [anon_sym_or_continue] = ACTIONS(4969),
    [anon_sym_or_break] = ACTIONS(4969),
    [anon_sym_CARET] = ACTIONS(4971),
    [sym_uninitialized] = ACTIONS(4969),
    [sym_tag] = ACTIONS(4969),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4969),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [809] = {
    [ts_builtin_sym_end] = ACTIONS(4973),
    [anon_sym_LBRACE] = ACTIONS(4973),
    [anon_sym_RBRACE] = ACTIONS(4973),
    [anon_sym_COMMA] = ACTIONS(4973),
    [anon_sym_COLON_COLON] = ACTIONS(4973),
    [anon_sym_DASH_GT] = ACTIONS(4973),
    [anon_sym_where] = ACTIONS(4973),
    [anon_sym_EQ] = ACTIONS(4975),
    [anon_sym_COLON] = ACTIONS(4975),
    [anon_sym_PIPE] = ACTIONS(4975),
    [anon_sym_COLON_EQ] = ACTIONS(4973),
    [anon_sym_LPAREN] = ACTIONS(4973),
    [anon_sym_PLUS_EQ] = ACTIONS(4973),
    [anon_sym_DASH_EQ] = ACTIONS(4973),
    [anon_sym_STAR_EQ] = ACTIONS(4973),
    [anon_sym_SLASH_EQ] = ACTIONS(4973),
    [anon_sym_PERCENT_EQ] = ACTIONS(4973),
    [anon_sym_AMP_EQ] = ACTIONS(4973),
    [anon_sym_PIPE_EQ] = ACTIONS(4973),
    [anon_sym_CARET_EQ] = ACTIONS(4973),
    [anon_sym_LT_LT_EQ] = ACTIONS(4973),
    [anon_sym_GT_GT_EQ] = ACTIONS(4973),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4973),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4973),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4973),
    [anon_sym_if] = ACTIONS(4973),
    [anon_sym_SEMI] = ACTIONS(4973),
    [anon_sym_else] = ACTIONS(4973),
    [anon_sym_when] = ACTIONS(4973),
    [anon_sym_in] = ACTIONS(4973),
    [anon_sym_case] = ACTIONS(4973),
    [anon_sym_QMARK] = ACTIONS(4973),
    [anon_sym_PLUS] = ACTIONS(4975),
    [anon_sym_DASH] = ACTIONS(4975),
    [anon_sym_TILDE] = ACTIONS(4975),
    [anon_sym_AMP] = ACTIONS(4975),
    [anon_sym_PIPE_PIPE] = ACTIONS(4975),
    [anon_sym_or_else] = ACTIONS(4973),
    [anon_sym_AMP_AMP] = ACTIONS(4975),
    [anon_sym_GT] = ACTIONS(4975),
    [anon_sym_GT_EQ] = ACTIONS(4973),
    [anon_sym_LT_EQ] = ACTIONS(4973),
    [anon_sym_LT] = ACTIONS(4975),
    [anon_sym_EQ_EQ] = ACTIONS(4973),
    [anon_sym_BANG_EQ] = ACTIONS(4973),
    [anon_sym_TILDE_EQ] = ACTIONS(4973),
    [anon_sym_AMP_TILDE] = ACTIONS(4975),
    [anon_sym_LT_LT] = ACTIONS(4975),
    [anon_sym_GT_GT] = ACTIONS(4975),
    [anon_sym_STAR] = ACTIONS(4975),
    [anon_sym_SLASH] = ACTIONS(4975),
    [anon_sym_PERCENT] = ACTIONS(4975),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4973),
    [anon_sym_DOT] = ACTIONS(4975),
    [anon_sym_LBRACK] = ACTIONS(4973),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4973),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4973),
    [anon_sym_not_in] = ACTIONS(4973),
    [anon_sym_or_return] = ACTIONS(4973),
    [anon_sym_or_continue] = ACTIONS(4973),
    [anon_sym_or_break] = ACTIONS(4973),
    [anon_sym_CARET] = ACTIONS(4975),
    [sym_uninitialized] = ACTIONS(4973),
    [sym_tag] = ACTIONS(4973),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4973),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [810] = {
    [sym_block] = STATE(2357),
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(3404),
    [sym_tag] = ACTIONS(3406),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [811] = {
    [sym_block] = STATE(2359),
    [ts_builtin_sym_end] = ACTIONS(4577),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(4577),
    [anon_sym_COMMA] = ACTIONS(4577),
    [anon_sym_COLON_COLON] = ACTIONS(4577),
    [anon_sym_DASH_GT] = ACTIONS(4577),
    [anon_sym_EQ] = ACTIONS(4579),
    [anon_sym_COLON] = ACTIONS(4579),
    [anon_sym_PIPE] = ACTIONS(4579),
    [anon_sym_COLON_EQ] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4577),
    [anon_sym_PLUS_EQ] = ACTIONS(4577),
    [anon_sym_DASH_EQ] = ACTIONS(4577),
    [anon_sym_STAR_EQ] = ACTIONS(4577),
    [anon_sym_SLASH_EQ] = ACTIONS(4577),
    [anon_sym_PERCENT_EQ] = ACTIONS(4577),
    [anon_sym_AMP_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_CARET_EQ] = ACTIONS(4577),
    [anon_sym_LT_LT_EQ] = ACTIONS(4577),
    [anon_sym_GT_GT_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_when] = ACTIONS(4577),
    [anon_sym_in] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [anon_sym_TILDE] = ACTIONS(4579),
    [anon_sym_AMP] = ACTIONS(4579),
    [anon_sym_PIPE_PIPE] = ACTIONS(4579),
    [anon_sym_or_else] = ACTIONS(4577),
    [anon_sym_AMP_AMP] = ACTIONS(4579),
    [anon_sym_GT] = ACTIONS(4579),
    [anon_sym_GT_EQ] = ACTIONS(4577),
    [anon_sym_LT_EQ] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4579),
    [anon_sym_EQ_EQ] = ACTIONS(4577),
    [anon_sym_BANG_EQ] = ACTIONS(4577),
    [anon_sym_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE] = ACTIONS(4579),
    [anon_sym_LT_LT] = ACTIONS(4579),
    [anon_sym_GT_GT] = ACTIONS(4579),
    [anon_sym_STAR] = ACTIONS(4579),
    [anon_sym_SLASH] = ACTIONS(4579),
    [anon_sym_PERCENT] = ACTIONS(4579),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4577),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4577),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4577),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4577),
    [anon_sym_not_in] = ACTIONS(4577),
    [anon_sym_or_return] = ACTIONS(4577),
    [anon_sym_or_continue] = ACTIONS(4577),
    [anon_sym_or_break] = ACTIONS(4577),
    [anon_sym_CARET] = ACTIONS(4579),
    [sym_uninitialized] = ACTIONS(4977),
    [sym_tag] = ACTIONS(4979),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4577),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [812] = {
    [ts_builtin_sym_end] = ACTIONS(4981),
    [anon_sym_LBRACE] = ACTIONS(4981),
    [anon_sym_RBRACE] = ACTIONS(4981),
    [anon_sym_COMMA] = ACTIONS(4981),
    [anon_sym_COLON_COLON] = ACTIONS(4981),
    [anon_sym_DASH_GT] = ACTIONS(4981),
    [anon_sym_where] = ACTIONS(4981),
    [anon_sym_EQ] = ACTIONS(4983),
    [anon_sym_COLON] = ACTIONS(4983),
    [anon_sym_PIPE] = ACTIONS(4983),
    [anon_sym_COLON_EQ] = ACTIONS(4981),
    [anon_sym_LPAREN] = ACTIONS(4981),
    [anon_sym_PLUS_EQ] = ACTIONS(4981),
    [anon_sym_DASH_EQ] = ACTIONS(4981),
    [anon_sym_STAR_EQ] = ACTIONS(4981),
    [anon_sym_SLASH_EQ] = ACTIONS(4981),
    [anon_sym_PERCENT_EQ] = ACTIONS(4981),
    [anon_sym_AMP_EQ] = ACTIONS(4981),
    [anon_sym_PIPE_EQ] = ACTIONS(4981),
    [anon_sym_CARET_EQ] = ACTIONS(4981),
    [anon_sym_LT_LT_EQ] = ACTIONS(4981),
    [anon_sym_GT_GT_EQ] = ACTIONS(4981),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4981),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4981),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4981),
    [anon_sym_if] = ACTIONS(4981),
    [anon_sym_SEMI] = ACTIONS(4981),
    [anon_sym_else] = ACTIONS(4981),
    [anon_sym_when] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4981),
    [anon_sym_case] = ACTIONS(4981),
    [anon_sym_QMARK] = ACTIONS(4981),
    [anon_sym_PLUS] = ACTIONS(4983),
    [anon_sym_DASH] = ACTIONS(4983),
    [anon_sym_TILDE] = ACTIONS(4983),
    [anon_sym_AMP] = ACTIONS(4983),
    [anon_sym_PIPE_PIPE] = ACTIONS(4983),
    [anon_sym_or_else] = ACTIONS(4981),
    [anon_sym_AMP_AMP] = ACTIONS(4983),
    [anon_sym_GT] = ACTIONS(4983),
    [anon_sym_GT_EQ] = ACTIONS(4981),
    [anon_sym_LT_EQ] = ACTIONS(4981),
    [anon_sym_LT] = ACTIONS(4983),
    [anon_sym_EQ_EQ] = ACTIONS(4981),
    [anon_sym_BANG_EQ] = ACTIONS(4981),
    [anon_sym_TILDE_EQ] = ACTIONS(4981),
    [anon_sym_AMP_TILDE] = ACTIONS(4983),
    [anon_sym_LT_LT] = ACTIONS(4983),
    [anon_sym_GT_GT] = ACTIONS(4983),
    [anon_sym_STAR] = ACTIONS(4983),
    [anon_sym_SLASH] = ACTIONS(4983),
    [anon_sym_PERCENT] = ACTIONS(4983),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4981),
    [anon_sym_DOT] = ACTIONS(4983),
    [anon_sym_LBRACK] = ACTIONS(4981),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4981),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4981),
    [anon_sym_not_in] = ACTIONS(4981),
    [anon_sym_or_return] = ACTIONS(4981),
    [anon_sym_or_continue] = ACTIONS(4981),
    [anon_sym_or_break] = ACTIONS(4981),
    [anon_sym_CARET] = ACTIONS(4983),
    [sym_uninitialized] = ACTIONS(4981),
    [sym_tag] = ACTIONS(4981),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4981),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [813] = {
    [ts_builtin_sym_end] = ACTIONS(4985),
    [anon_sym_LBRACE] = ACTIONS(4985),
    [anon_sym_RBRACE] = ACTIONS(4985),
    [anon_sym_COMMA] = ACTIONS(4985),
    [anon_sym_COLON_COLON] = ACTIONS(4985),
    [anon_sym_DASH_GT] = ACTIONS(4985),
    [anon_sym_where] = ACTIONS(4985),
    [anon_sym_EQ] = ACTIONS(4987),
    [anon_sym_COLON] = ACTIONS(4987),
    [anon_sym_PIPE] = ACTIONS(4987),
    [anon_sym_COLON_EQ] = ACTIONS(4985),
    [anon_sym_LPAREN] = ACTIONS(4985),
    [anon_sym_PLUS_EQ] = ACTIONS(4985),
    [anon_sym_DASH_EQ] = ACTIONS(4985),
    [anon_sym_STAR_EQ] = ACTIONS(4985),
    [anon_sym_SLASH_EQ] = ACTIONS(4985),
    [anon_sym_PERCENT_EQ] = ACTIONS(4985),
    [anon_sym_AMP_EQ] = ACTIONS(4985),
    [anon_sym_PIPE_EQ] = ACTIONS(4985),
    [anon_sym_CARET_EQ] = ACTIONS(4985),
    [anon_sym_LT_LT_EQ] = ACTIONS(4985),
    [anon_sym_GT_GT_EQ] = ACTIONS(4985),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4985),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4985),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4985),
    [anon_sym_if] = ACTIONS(4985),
    [anon_sym_SEMI] = ACTIONS(4985),
    [anon_sym_else] = ACTIONS(4985),
    [anon_sym_when] = ACTIONS(4985),
    [anon_sym_in] = ACTIONS(4985),
    [anon_sym_case] = ACTIONS(4985),
    [anon_sym_QMARK] = ACTIONS(4985),
    [anon_sym_PLUS] = ACTIONS(4987),
    [anon_sym_DASH] = ACTIONS(4987),
    [anon_sym_TILDE] = ACTIONS(4987),
    [anon_sym_AMP] = ACTIONS(4987),
    [anon_sym_PIPE_PIPE] = ACTIONS(4987),
    [anon_sym_or_else] = ACTIONS(4985),
    [anon_sym_AMP_AMP] = ACTIONS(4987),
    [anon_sym_GT] = ACTIONS(4987),
    [anon_sym_GT_EQ] = ACTIONS(4985),
    [anon_sym_LT_EQ] = ACTIONS(4985),
    [anon_sym_LT] = ACTIONS(4987),
    [anon_sym_EQ_EQ] = ACTIONS(4985),
    [anon_sym_BANG_EQ] = ACTIONS(4985),
    [anon_sym_TILDE_EQ] = ACTIONS(4985),
    [anon_sym_AMP_TILDE] = ACTIONS(4987),
    [anon_sym_LT_LT] = ACTIONS(4987),
    [anon_sym_GT_GT] = ACTIONS(4987),
    [anon_sym_STAR] = ACTIONS(4987),
    [anon_sym_SLASH] = ACTIONS(4987),
    [anon_sym_PERCENT] = ACTIONS(4987),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4985),
    [anon_sym_DOT] = ACTIONS(4987),
    [anon_sym_LBRACK] = ACTIONS(4985),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4985),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4985),
    [anon_sym_not_in] = ACTIONS(4985),
    [anon_sym_or_return] = ACTIONS(4985),
    [anon_sym_or_continue] = ACTIONS(4985),
    [anon_sym_or_break] = ACTIONS(4985),
    [anon_sym_CARET] = ACTIONS(4987),
    [sym_uninitialized] = ACTIONS(4985),
    [sym_tag] = ACTIONS(4985),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4985),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [814] = {
    [ts_builtin_sym_end] = ACTIONS(4989),
    [anon_sym_LBRACE] = ACTIONS(4989),
    [anon_sym_RBRACE] = ACTIONS(4989),
    [anon_sym_COMMA] = ACTIONS(4989),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_DASH_GT] = ACTIONS(4989),
    [anon_sym_where] = ACTIONS(4989),
    [anon_sym_EQ] = ACTIONS(4991),
    [anon_sym_COLON] = ACTIONS(4991),
    [anon_sym_PIPE] = ACTIONS(4991),
    [anon_sym_COLON_EQ] = ACTIONS(4989),
    [anon_sym_LPAREN] = ACTIONS(4989),
    [anon_sym_PLUS_EQ] = ACTIONS(4989),
    [anon_sym_DASH_EQ] = ACTIONS(4989),
    [anon_sym_STAR_EQ] = ACTIONS(4989),
    [anon_sym_SLASH_EQ] = ACTIONS(4989),
    [anon_sym_PERCENT_EQ] = ACTIONS(4989),
    [anon_sym_AMP_EQ] = ACTIONS(4989),
    [anon_sym_PIPE_EQ] = ACTIONS(4989),
    [anon_sym_CARET_EQ] = ACTIONS(4989),
    [anon_sym_LT_LT_EQ] = ACTIONS(4989),
    [anon_sym_GT_GT_EQ] = ACTIONS(4989),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4989),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4989),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4989),
    [anon_sym_if] = ACTIONS(4989),
    [anon_sym_SEMI] = ACTIONS(4989),
    [anon_sym_else] = ACTIONS(4989),
    [anon_sym_when] = ACTIONS(4989),
    [anon_sym_in] = ACTIONS(4989),
    [anon_sym_case] = ACTIONS(4989),
    [anon_sym_QMARK] = ACTIONS(4989),
    [anon_sym_PLUS] = ACTIONS(4991),
    [anon_sym_DASH] = ACTIONS(4991),
    [anon_sym_TILDE] = ACTIONS(4991),
    [anon_sym_AMP] = ACTIONS(4991),
    [anon_sym_PIPE_PIPE] = ACTIONS(4991),
    [anon_sym_or_else] = ACTIONS(4989),
    [anon_sym_AMP_AMP] = ACTIONS(4991),
    [anon_sym_GT] = ACTIONS(4991),
    [anon_sym_GT_EQ] = ACTIONS(4989),
    [anon_sym_LT_EQ] = ACTIONS(4989),
    [anon_sym_LT] = ACTIONS(4991),
    [anon_sym_EQ_EQ] = ACTIONS(4989),
    [anon_sym_BANG_EQ] = ACTIONS(4989),
    [anon_sym_TILDE_EQ] = ACTIONS(4989),
    [anon_sym_AMP_TILDE] = ACTIONS(4991),
    [anon_sym_LT_LT] = ACTIONS(4991),
    [anon_sym_GT_GT] = ACTIONS(4991),
    [anon_sym_STAR] = ACTIONS(4991),
    [anon_sym_SLASH] = ACTIONS(4991),
    [anon_sym_PERCENT] = ACTIONS(4991),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4989),
    [anon_sym_DOT] = ACTIONS(4991),
    [anon_sym_LBRACK] = ACTIONS(4989),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4989),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4989),
    [anon_sym_not_in] = ACTIONS(4989),
    [anon_sym_or_return] = ACTIONS(4989),
    [anon_sym_or_continue] = ACTIONS(4989),
    [anon_sym_or_break] = ACTIONS(4989),
    [anon_sym_CARET] = ACTIONS(4991),
    [sym_uninitialized] = ACTIONS(4989),
    [sym_tag] = ACTIONS(4989),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4989),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [815] = {
    [sym_expression] = STATE(6246),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4993),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(4995),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4997),
    [anon_sym_dynamic] = ACTIONS(4999),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [816] = {
    [ts_builtin_sym_end] = ACTIONS(5001),
    [anon_sym_LBRACE] = ACTIONS(5001),
    [anon_sym_RBRACE] = ACTIONS(5001),
    [anon_sym_COMMA] = ACTIONS(5001),
    [anon_sym_COLON_COLON] = ACTIONS(5001),
    [anon_sym_DASH_GT] = ACTIONS(5001),
    [anon_sym_where] = ACTIONS(5001),
    [anon_sym_EQ] = ACTIONS(5003),
    [anon_sym_COLON] = ACTIONS(5003),
    [anon_sym_PIPE] = ACTIONS(5003),
    [anon_sym_COLON_EQ] = ACTIONS(5001),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(5001),
    [anon_sym_DASH_EQ] = ACTIONS(5001),
    [anon_sym_STAR_EQ] = ACTIONS(5001),
    [anon_sym_SLASH_EQ] = ACTIONS(5001),
    [anon_sym_PERCENT_EQ] = ACTIONS(5001),
    [anon_sym_AMP_EQ] = ACTIONS(5001),
    [anon_sym_PIPE_EQ] = ACTIONS(5001),
    [anon_sym_CARET_EQ] = ACTIONS(5001),
    [anon_sym_LT_LT_EQ] = ACTIONS(5001),
    [anon_sym_GT_GT_EQ] = ACTIONS(5001),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5001),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5001),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5001),
    [anon_sym_if] = ACTIONS(5001),
    [anon_sym_SEMI] = ACTIONS(5001),
    [anon_sym_else] = ACTIONS(5001),
    [anon_sym_when] = ACTIONS(5001),
    [anon_sym_in] = ACTIONS(5001),
    [anon_sym_case] = ACTIONS(5001),
    [anon_sym_QMARK] = ACTIONS(5001),
    [anon_sym_PLUS] = ACTIONS(5003),
    [anon_sym_DASH] = ACTIONS(5003),
    [anon_sym_TILDE] = ACTIONS(5003),
    [anon_sym_AMP] = ACTIONS(5003),
    [anon_sym_PIPE_PIPE] = ACTIONS(5003),
    [anon_sym_or_else] = ACTIONS(5001),
    [anon_sym_AMP_AMP] = ACTIONS(5003),
    [anon_sym_GT] = ACTIONS(5003),
    [anon_sym_GT_EQ] = ACTIONS(5001),
    [anon_sym_LT_EQ] = ACTIONS(5001),
    [anon_sym_LT] = ACTIONS(5003),
    [anon_sym_EQ_EQ] = ACTIONS(5001),
    [anon_sym_BANG_EQ] = ACTIONS(5001),
    [anon_sym_TILDE_EQ] = ACTIONS(5001),
    [anon_sym_AMP_TILDE] = ACTIONS(5003),
    [anon_sym_LT_LT] = ACTIONS(5003),
    [anon_sym_GT_GT] = ACTIONS(5003),
    [anon_sym_STAR] = ACTIONS(5003),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(5003),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5001),
    [anon_sym_DOT] = ACTIONS(5003),
    [anon_sym_LBRACK] = ACTIONS(5001),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5001),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5001),
    [anon_sym_not_in] = ACTIONS(5001),
    [anon_sym_or_return] = ACTIONS(5001),
    [anon_sym_or_continue] = ACTIONS(5001),
    [anon_sym_or_break] = ACTIONS(5001),
    [anon_sym_CARET] = ACTIONS(5003),
    [sym_uninitialized] = ACTIONS(5001),
    [sym_tag] = ACTIONS(5001),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5001),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [817] = {
    [ts_builtin_sym_end] = ACTIONS(5005),
    [anon_sym_LBRACE] = ACTIONS(5005),
    [anon_sym_RBRACE] = ACTIONS(5005),
    [anon_sym_COMMA] = ACTIONS(5005),
    [anon_sym_COLON_COLON] = ACTIONS(5005),
    [anon_sym_DASH_GT] = ACTIONS(5005),
    [anon_sym_where] = ACTIONS(5005),
    [anon_sym_EQ] = ACTIONS(5007),
    [anon_sym_COLON] = ACTIONS(5009),
    [anon_sym_PIPE] = ACTIONS(5009),
    [anon_sym_COLON_EQ] = ACTIONS(5005),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(5005),
    [anon_sym_DASH_EQ] = ACTIONS(5005),
    [anon_sym_STAR_EQ] = ACTIONS(5005),
    [anon_sym_SLASH_EQ] = ACTIONS(5005),
    [anon_sym_PERCENT_EQ] = ACTIONS(5005),
    [anon_sym_AMP_EQ] = ACTIONS(5005),
    [anon_sym_PIPE_EQ] = ACTIONS(5005),
    [anon_sym_CARET_EQ] = ACTIONS(5005),
    [anon_sym_LT_LT_EQ] = ACTIONS(5005),
    [anon_sym_GT_GT_EQ] = ACTIONS(5005),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5005),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5005),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5005),
    [anon_sym_if] = ACTIONS(5005),
    [anon_sym_SEMI] = ACTIONS(5005),
    [anon_sym_else] = ACTIONS(5005),
    [anon_sym_when] = ACTIONS(5005),
    [anon_sym_in] = ACTIONS(5005),
    [anon_sym_case] = ACTIONS(5005),
    [anon_sym_QMARK] = ACTIONS(5005),
    [anon_sym_PLUS] = ACTIONS(5009),
    [anon_sym_DASH] = ACTIONS(5009),
    [anon_sym_TILDE] = ACTIONS(5009),
    [anon_sym_AMP] = ACTIONS(5009),
    [anon_sym_PIPE_PIPE] = ACTIONS(5009),
    [anon_sym_or_else] = ACTIONS(5005),
    [anon_sym_AMP_AMP] = ACTIONS(5009),
    [anon_sym_GT] = ACTIONS(5009),
    [anon_sym_GT_EQ] = ACTIONS(5005),
    [anon_sym_LT_EQ] = ACTIONS(5005),
    [anon_sym_LT] = ACTIONS(5009),
    [anon_sym_EQ_EQ] = ACTIONS(5005),
    [anon_sym_BANG_EQ] = ACTIONS(5005),
    [anon_sym_TILDE_EQ] = ACTIONS(5005),
    [anon_sym_AMP_TILDE] = ACTIONS(5009),
    [anon_sym_LT_LT] = ACTIONS(5009),
    [anon_sym_GT_GT] = ACTIONS(5009),
    [anon_sym_STAR] = ACTIONS(5009),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(5009),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5005),
    [anon_sym_DOT] = ACTIONS(5009),
    [anon_sym_LBRACK] = ACTIONS(5005),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5005),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5005),
    [anon_sym_not_in] = ACTIONS(5005),
    [anon_sym_or_return] = ACTIONS(5005),
    [anon_sym_or_continue] = ACTIONS(5005),
    [anon_sym_or_break] = ACTIONS(5005),
    [anon_sym_CARET] = ACTIONS(5009),
    [sym_uninitialized] = ACTIONS(5005),
    [sym_tag] = ACTIONS(5005),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5005),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [818] = {
    [ts_builtin_sym_end] = ACTIONS(5011),
    [anon_sym_LBRACE] = ACTIONS(5011),
    [anon_sym_RBRACE] = ACTIONS(5011),
    [anon_sym_COMMA] = ACTIONS(5011),
    [anon_sym_COLON_COLON] = ACTIONS(5011),
    [anon_sym_DASH_GT] = ACTIONS(5011),
    [anon_sym_where] = ACTIONS(5011),
    [anon_sym_EQ] = ACTIONS(5013),
    [anon_sym_COLON] = ACTIONS(5013),
    [anon_sym_PIPE] = ACTIONS(5013),
    [anon_sym_COLON_EQ] = ACTIONS(5011),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(5011),
    [anon_sym_DASH_EQ] = ACTIONS(5011),
    [anon_sym_STAR_EQ] = ACTIONS(5011),
    [anon_sym_SLASH_EQ] = ACTIONS(5011),
    [anon_sym_PERCENT_EQ] = ACTIONS(5011),
    [anon_sym_AMP_EQ] = ACTIONS(5011),
    [anon_sym_PIPE_EQ] = ACTIONS(5011),
    [anon_sym_CARET_EQ] = ACTIONS(5011),
    [anon_sym_LT_LT_EQ] = ACTIONS(5011),
    [anon_sym_GT_GT_EQ] = ACTIONS(5011),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5011),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5011),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5011),
    [anon_sym_if] = ACTIONS(5011),
    [anon_sym_SEMI] = ACTIONS(5011),
    [anon_sym_else] = ACTIONS(5011),
    [anon_sym_when] = ACTIONS(5011),
    [anon_sym_in] = ACTIONS(5011),
    [anon_sym_case] = ACTIONS(5011),
    [anon_sym_QMARK] = ACTIONS(5011),
    [anon_sym_PLUS] = ACTIONS(5013),
    [anon_sym_DASH] = ACTIONS(5013),
    [anon_sym_TILDE] = ACTIONS(5013),
    [anon_sym_AMP] = ACTIONS(5013),
    [anon_sym_PIPE_PIPE] = ACTIONS(5013),
    [anon_sym_or_else] = ACTIONS(5011),
    [anon_sym_AMP_AMP] = ACTIONS(5013),
    [anon_sym_GT] = ACTIONS(5013),
    [anon_sym_GT_EQ] = ACTIONS(5011),
    [anon_sym_LT_EQ] = ACTIONS(5011),
    [anon_sym_LT] = ACTIONS(5013),
    [anon_sym_EQ_EQ] = ACTIONS(5011),
    [anon_sym_BANG_EQ] = ACTIONS(5011),
    [anon_sym_TILDE_EQ] = ACTIONS(5011),
    [anon_sym_AMP_TILDE] = ACTIONS(5013),
    [anon_sym_LT_LT] = ACTIONS(5013),
    [anon_sym_GT_GT] = ACTIONS(5013),
    [anon_sym_STAR] = ACTIONS(5013),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(5013),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5011),
    [anon_sym_DOT] = ACTIONS(5013),
    [anon_sym_LBRACK] = ACTIONS(5011),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5011),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5011),
    [anon_sym_not_in] = ACTIONS(5011),
    [anon_sym_or_return] = ACTIONS(5011),
    [anon_sym_or_continue] = ACTIONS(5011),
    [anon_sym_or_break] = ACTIONS(5011),
    [anon_sym_CARET] = ACTIONS(5013),
    [sym_uninitialized] = ACTIONS(5011),
    [sym_tag] = ACTIONS(5011),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5011),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [819] = {
    [ts_builtin_sym_end] = ACTIONS(5015),
    [anon_sym_LBRACE] = ACTIONS(5015),
    [anon_sym_RBRACE] = ACTIONS(5015),
    [anon_sym_COMMA] = ACTIONS(5015),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_DASH_GT] = ACTIONS(5015),
    [anon_sym_where] = ACTIONS(5015),
    [anon_sym_EQ] = ACTIONS(5017),
    [anon_sym_COLON] = ACTIONS(5017),
    [anon_sym_PIPE] = ACTIONS(5017),
    [anon_sym_COLON_EQ] = ACTIONS(5015),
    [anon_sym_LPAREN] = ACTIONS(5015),
    [anon_sym_PLUS_EQ] = ACTIONS(5015),
    [anon_sym_DASH_EQ] = ACTIONS(5015),
    [anon_sym_STAR_EQ] = ACTIONS(5015),
    [anon_sym_SLASH_EQ] = ACTIONS(5015),
    [anon_sym_PERCENT_EQ] = ACTIONS(5015),
    [anon_sym_AMP_EQ] = ACTIONS(5015),
    [anon_sym_PIPE_EQ] = ACTIONS(5015),
    [anon_sym_CARET_EQ] = ACTIONS(5015),
    [anon_sym_LT_LT_EQ] = ACTIONS(5015),
    [anon_sym_GT_GT_EQ] = ACTIONS(5015),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5015),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5015),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5015),
    [anon_sym_if] = ACTIONS(5015),
    [anon_sym_SEMI] = ACTIONS(5015),
    [anon_sym_else] = ACTIONS(5015),
    [anon_sym_when] = ACTIONS(5015),
    [anon_sym_in] = ACTIONS(5015),
    [anon_sym_case] = ACTIONS(5015),
    [anon_sym_QMARK] = ACTIONS(5015),
    [anon_sym_PLUS] = ACTIONS(5017),
    [anon_sym_DASH] = ACTIONS(5017),
    [anon_sym_TILDE] = ACTIONS(5017),
    [anon_sym_AMP] = ACTIONS(5017),
    [anon_sym_PIPE_PIPE] = ACTIONS(5017),
    [anon_sym_or_else] = ACTIONS(5015),
    [anon_sym_AMP_AMP] = ACTIONS(5017),
    [anon_sym_GT] = ACTIONS(5017),
    [anon_sym_GT_EQ] = ACTIONS(5015),
    [anon_sym_LT_EQ] = ACTIONS(5015),
    [anon_sym_LT] = ACTIONS(5017),
    [anon_sym_EQ_EQ] = ACTIONS(5015),
    [anon_sym_BANG_EQ] = ACTIONS(5015),
    [anon_sym_TILDE_EQ] = ACTIONS(5015),
    [anon_sym_AMP_TILDE] = ACTIONS(5017),
    [anon_sym_LT_LT] = ACTIONS(5017),
    [anon_sym_GT_GT] = ACTIONS(5017),
    [anon_sym_STAR] = ACTIONS(5017),
    [anon_sym_SLASH] = ACTIONS(5017),
    [anon_sym_PERCENT] = ACTIONS(5017),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5015),
    [anon_sym_DOT] = ACTIONS(5017),
    [anon_sym_LBRACK] = ACTIONS(5015),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5015),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5015),
    [anon_sym_not_in] = ACTIONS(5015),
    [anon_sym_or_return] = ACTIONS(5015),
    [anon_sym_or_continue] = ACTIONS(5015),
    [anon_sym_or_break] = ACTIONS(5015),
    [anon_sym_CARET] = ACTIONS(5017),
    [sym_uninitialized] = ACTIONS(5015),
    [sym_tag] = ACTIONS(5015),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5015),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [820] = {
    [ts_builtin_sym_end] = ACTIONS(5019),
    [anon_sym_LBRACE] = ACTIONS(5019),
    [anon_sym_RBRACE] = ACTIONS(5019),
    [anon_sym_COMMA] = ACTIONS(5019),
    [anon_sym_COLON_COLON] = ACTIONS(5019),
    [anon_sym_DASH_GT] = ACTIONS(5019),
    [anon_sym_where] = ACTIONS(5019),
    [anon_sym_EQ] = ACTIONS(5021),
    [anon_sym_COLON] = ACTIONS(5021),
    [anon_sym_PIPE] = ACTIONS(5021),
    [anon_sym_COLON_EQ] = ACTIONS(5019),
    [anon_sym_LPAREN] = ACTIONS(5019),
    [anon_sym_PLUS_EQ] = ACTIONS(5019),
    [anon_sym_DASH_EQ] = ACTIONS(5019),
    [anon_sym_STAR_EQ] = ACTIONS(5019),
    [anon_sym_SLASH_EQ] = ACTIONS(5019),
    [anon_sym_PERCENT_EQ] = ACTIONS(5019),
    [anon_sym_AMP_EQ] = ACTIONS(5019),
    [anon_sym_PIPE_EQ] = ACTIONS(5019),
    [anon_sym_CARET_EQ] = ACTIONS(5019),
    [anon_sym_LT_LT_EQ] = ACTIONS(5019),
    [anon_sym_GT_GT_EQ] = ACTIONS(5019),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5019),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5019),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5019),
    [anon_sym_if] = ACTIONS(5019),
    [anon_sym_SEMI] = ACTIONS(5019),
    [anon_sym_else] = ACTIONS(5019),
    [anon_sym_when] = ACTIONS(5019),
    [anon_sym_in] = ACTIONS(5019),
    [anon_sym_case] = ACTIONS(5019),
    [anon_sym_QMARK] = ACTIONS(5019),
    [anon_sym_PLUS] = ACTIONS(5021),
    [anon_sym_DASH] = ACTIONS(5021),
    [anon_sym_TILDE] = ACTIONS(5021),
    [anon_sym_AMP] = ACTIONS(5021),
    [anon_sym_PIPE_PIPE] = ACTIONS(5021),
    [anon_sym_or_else] = ACTIONS(5019),
    [anon_sym_AMP_AMP] = ACTIONS(5021),
    [anon_sym_GT] = ACTIONS(5021),
    [anon_sym_GT_EQ] = ACTIONS(5019),
    [anon_sym_LT_EQ] = ACTIONS(5019),
    [anon_sym_LT] = ACTIONS(5021),
    [anon_sym_EQ_EQ] = ACTIONS(5019),
    [anon_sym_BANG_EQ] = ACTIONS(5019),
    [anon_sym_TILDE_EQ] = ACTIONS(5019),
    [anon_sym_AMP_TILDE] = ACTIONS(5021),
    [anon_sym_LT_LT] = ACTIONS(5021),
    [anon_sym_GT_GT] = ACTIONS(5021),
    [anon_sym_STAR] = ACTIONS(5021),
    [anon_sym_SLASH] = ACTIONS(5021),
    [anon_sym_PERCENT] = ACTIONS(5021),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5019),
    [anon_sym_DOT] = ACTIONS(5021),
    [anon_sym_LBRACK] = ACTIONS(5019),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5019),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5019),
    [anon_sym_not_in] = ACTIONS(5019),
    [anon_sym_or_return] = ACTIONS(5019),
    [anon_sym_or_continue] = ACTIONS(5019),
    [anon_sym_or_break] = ACTIONS(5019),
    [anon_sym_CARET] = ACTIONS(5021),
    [sym_uninitialized] = ACTIONS(5019),
    [sym_tag] = ACTIONS(5019),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5019),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [821] = {
    [ts_builtin_sym_end] = ACTIONS(5023),
    [anon_sym_LBRACE] = ACTIONS(5023),
    [anon_sym_RBRACE] = ACTIONS(5023),
    [anon_sym_COMMA] = ACTIONS(5023),
    [anon_sym_COLON_COLON] = ACTIONS(5023),
    [anon_sym_DASH_GT] = ACTIONS(5023),
    [anon_sym_where] = ACTIONS(5023),
    [anon_sym_EQ] = ACTIONS(5025),
    [anon_sym_COLON] = ACTIONS(5025),
    [anon_sym_PIPE] = ACTIONS(5025),
    [anon_sym_COLON_EQ] = ACTIONS(5023),
    [anon_sym_LPAREN] = ACTIONS(5023),
    [anon_sym_PLUS_EQ] = ACTIONS(5023),
    [anon_sym_DASH_EQ] = ACTIONS(5023),
    [anon_sym_STAR_EQ] = ACTIONS(5023),
    [anon_sym_SLASH_EQ] = ACTIONS(5023),
    [anon_sym_PERCENT_EQ] = ACTIONS(5023),
    [anon_sym_AMP_EQ] = ACTIONS(5023),
    [anon_sym_PIPE_EQ] = ACTIONS(5023),
    [anon_sym_CARET_EQ] = ACTIONS(5023),
    [anon_sym_LT_LT_EQ] = ACTIONS(5023),
    [anon_sym_GT_GT_EQ] = ACTIONS(5023),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5023),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5023),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5023),
    [anon_sym_if] = ACTIONS(5023),
    [anon_sym_SEMI] = ACTIONS(5023),
    [anon_sym_else] = ACTIONS(5023),
    [anon_sym_when] = ACTIONS(5023),
    [anon_sym_in] = ACTIONS(5023),
    [anon_sym_case] = ACTIONS(5023),
    [anon_sym_QMARK] = ACTIONS(5023),
    [anon_sym_PLUS] = ACTIONS(5025),
    [anon_sym_DASH] = ACTIONS(5025),
    [anon_sym_TILDE] = ACTIONS(5025),
    [anon_sym_AMP] = ACTIONS(5025),
    [anon_sym_PIPE_PIPE] = ACTIONS(5025),
    [anon_sym_or_else] = ACTIONS(5023),
    [anon_sym_AMP_AMP] = ACTIONS(5025),
    [anon_sym_GT] = ACTIONS(5025),
    [anon_sym_GT_EQ] = ACTIONS(5023),
    [anon_sym_LT_EQ] = ACTIONS(5023),
    [anon_sym_LT] = ACTIONS(5025),
    [anon_sym_EQ_EQ] = ACTIONS(5023),
    [anon_sym_BANG_EQ] = ACTIONS(5023),
    [anon_sym_TILDE_EQ] = ACTIONS(5023),
    [anon_sym_AMP_TILDE] = ACTIONS(5025),
    [anon_sym_LT_LT] = ACTIONS(5025),
    [anon_sym_GT_GT] = ACTIONS(5025),
    [anon_sym_STAR] = ACTIONS(5025),
    [anon_sym_SLASH] = ACTIONS(5025),
    [anon_sym_PERCENT] = ACTIONS(5025),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5023),
    [anon_sym_DOT] = ACTIONS(5025),
    [anon_sym_LBRACK] = ACTIONS(5023),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5023),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5023),
    [anon_sym_not_in] = ACTIONS(5023),
    [anon_sym_or_return] = ACTIONS(5023),
    [anon_sym_or_continue] = ACTIONS(5023),
    [anon_sym_or_break] = ACTIONS(5023),
    [anon_sym_CARET] = ACTIONS(5025),
    [sym_uninitialized] = ACTIONS(5023),
    [sym_tag] = ACTIONS(5023),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5023),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [822] = {
    [ts_builtin_sym_end] = ACTIONS(5027),
    [anon_sym_LBRACE] = ACTIONS(5027),
    [anon_sym_RBRACE] = ACTIONS(5027),
    [anon_sym_COMMA] = ACTIONS(5027),
    [anon_sym_COLON_COLON] = ACTIONS(5027),
    [anon_sym_DASH_GT] = ACTIONS(5027),
    [anon_sym_where] = ACTIONS(5027),
    [anon_sym_EQ] = ACTIONS(5029),
    [anon_sym_COLON] = ACTIONS(5029),
    [anon_sym_PIPE] = ACTIONS(5029),
    [anon_sym_COLON_EQ] = ACTIONS(5027),
    [anon_sym_LPAREN] = ACTIONS(5027),
    [anon_sym_PLUS_EQ] = ACTIONS(5027),
    [anon_sym_DASH_EQ] = ACTIONS(5027),
    [anon_sym_STAR_EQ] = ACTIONS(5027),
    [anon_sym_SLASH_EQ] = ACTIONS(5027),
    [anon_sym_PERCENT_EQ] = ACTIONS(5027),
    [anon_sym_AMP_EQ] = ACTIONS(5027),
    [anon_sym_PIPE_EQ] = ACTIONS(5027),
    [anon_sym_CARET_EQ] = ACTIONS(5027),
    [anon_sym_LT_LT_EQ] = ACTIONS(5027),
    [anon_sym_GT_GT_EQ] = ACTIONS(5027),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5027),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5027),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5027),
    [anon_sym_if] = ACTIONS(5027),
    [anon_sym_SEMI] = ACTIONS(5027),
    [anon_sym_else] = ACTIONS(5027),
    [anon_sym_when] = ACTIONS(5027),
    [anon_sym_in] = ACTIONS(5027),
    [anon_sym_case] = ACTIONS(5027),
    [anon_sym_QMARK] = ACTIONS(5027),
    [anon_sym_PLUS] = ACTIONS(5029),
    [anon_sym_DASH] = ACTIONS(5029),
    [anon_sym_TILDE] = ACTIONS(5029),
    [anon_sym_AMP] = ACTIONS(5029),
    [anon_sym_PIPE_PIPE] = ACTIONS(5029),
    [anon_sym_or_else] = ACTIONS(5027),
    [anon_sym_AMP_AMP] = ACTIONS(5029),
    [anon_sym_GT] = ACTIONS(5029),
    [anon_sym_GT_EQ] = ACTIONS(5027),
    [anon_sym_LT_EQ] = ACTIONS(5027),
    [anon_sym_LT] = ACTIONS(5029),
    [anon_sym_EQ_EQ] = ACTIONS(5027),
    [anon_sym_BANG_EQ] = ACTIONS(5027),
    [anon_sym_TILDE_EQ] = ACTIONS(5027),
    [anon_sym_AMP_TILDE] = ACTIONS(5029),
    [anon_sym_LT_LT] = ACTIONS(5029),
    [anon_sym_GT_GT] = ACTIONS(5029),
    [anon_sym_STAR] = ACTIONS(5029),
    [anon_sym_SLASH] = ACTIONS(5029),
    [anon_sym_PERCENT] = ACTIONS(5029),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5027),
    [anon_sym_DOT] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5027),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5027),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5027),
    [anon_sym_not_in] = ACTIONS(5027),
    [anon_sym_or_return] = ACTIONS(5027),
    [anon_sym_or_continue] = ACTIONS(5027),
    [anon_sym_or_break] = ACTIONS(5027),
    [anon_sym_CARET] = ACTIONS(5029),
    [sym_uninitialized] = ACTIONS(5027),
    [sym_tag] = ACTIONS(5027),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5027),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [823] = {
    [ts_builtin_sym_end] = ACTIONS(4725),
    [anon_sym_LBRACE] = ACTIONS(4725),
    [anon_sym_RBRACE] = ACTIONS(4725),
    [anon_sym_COMMA] = ACTIONS(4725),
    [anon_sym_COLON_COLON] = ACTIONS(4725),
    [anon_sym_DASH_GT] = ACTIONS(4725),
    [anon_sym_where] = ACTIONS(4725),
    [anon_sym_EQ] = ACTIONS(4727),
    [anon_sym_COLON] = ACTIONS(4727),
    [anon_sym_PIPE] = ACTIONS(4727),
    [anon_sym_COLON_EQ] = ACTIONS(4725),
    [anon_sym_LPAREN] = ACTIONS(4725),
    [anon_sym_PLUS_EQ] = ACTIONS(4725),
    [anon_sym_DASH_EQ] = ACTIONS(4725),
    [anon_sym_STAR_EQ] = ACTIONS(4725),
    [anon_sym_SLASH_EQ] = ACTIONS(4725),
    [anon_sym_PERCENT_EQ] = ACTIONS(4725),
    [anon_sym_AMP_EQ] = ACTIONS(4725),
    [anon_sym_PIPE_EQ] = ACTIONS(4725),
    [anon_sym_CARET_EQ] = ACTIONS(4725),
    [anon_sym_LT_LT_EQ] = ACTIONS(4725),
    [anon_sym_GT_GT_EQ] = ACTIONS(4725),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4725),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4725),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4725),
    [anon_sym_if] = ACTIONS(4725),
    [anon_sym_SEMI] = ACTIONS(4725),
    [anon_sym_else] = ACTIONS(4725),
    [anon_sym_when] = ACTIONS(4725),
    [anon_sym_in] = ACTIONS(4725),
    [anon_sym_case] = ACTIONS(4725),
    [anon_sym_QMARK] = ACTIONS(4725),
    [anon_sym_PLUS] = ACTIONS(4727),
    [anon_sym_DASH] = ACTIONS(4727),
    [anon_sym_TILDE] = ACTIONS(4727),
    [anon_sym_AMP] = ACTIONS(4727),
    [anon_sym_PIPE_PIPE] = ACTIONS(4727),
    [anon_sym_or_else] = ACTIONS(4725),
    [anon_sym_AMP_AMP] = ACTIONS(4727),
    [anon_sym_GT] = ACTIONS(4727),
    [anon_sym_GT_EQ] = ACTIONS(4725),
    [anon_sym_LT_EQ] = ACTIONS(4725),
    [anon_sym_LT] = ACTIONS(4727),
    [anon_sym_EQ_EQ] = ACTIONS(4725),
    [anon_sym_BANG_EQ] = ACTIONS(4725),
    [anon_sym_TILDE_EQ] = ACTIONS(4725),
    [anon_sym_AMP_TILDE] = ACTIONS(4727),
    [anon_sym_LT_LT] = ACTIONS(4727),
    [anon_sym_GT_GT] = ACTIONS(4727),
    [anon_sym_STAR] = ACTIONS(4727),
    [anon_sym_SLASH] = ACTIONS(4727),
    [anon_sym_PERCENT] = ACTIONS(4727),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4725),
    [anon_sym_DOT] = ACTIONS(4727),
    [anon_sym_LBRACK] = ACTIONS(4725),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4725),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4725),
    [anon_sym_not_in] = ACTIONS(4725),
    [anon_sym_or_return] = ACTIONS(4725),
    [anon_sym_or_continue] = ACTIONS(4725),
    [anon_sym_or_break] = ACTIONS(4725),
    [anon_sym_CARET] = ACTIONS(4727),
    [sym_uninitialized] = ACTIONS(4725),
    [sym_tag] = ACTIONS(4725),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4725),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [824] = {
    [ts_builtin_sym_end] = ACTIONS(5031),
    [anon_sym_LBRACE] = ACTIONS(5031),
    [anon_sym_RBRACE] = ACTIONS(5031),
    [anon_sym_COMMA] = ACTIONS(5031),
    [anon_sym_COLON_COLON] = ACTIONS(5031),
    [anon_sym_DASH_GT] = ACTIONS(5031),
    [anon_sym_where] = ACTIONS(5031),
    [anon_sym_EQ] = ACTIONS(5033),
    [anon_sym_COLON] = ACTIONS(5033),
    [anon_sym_PIPE] = ACTIONS(5033),
    [anon_sym_COLON_EQ] = ACTIONS(5031),
    [anon_sym_LPAREN] = ACTIONS(5031),
    [anon_sym_PLUS_EQ] = ACTIONS(5031),
    [anon_sym_DASH_EQ] = ACTIONS(5031),
    [anon_sym_STAR_EQ] = ACTIONS(5031),
    [anon_sym_SLASH_EQ] = ACTIONS(5031),
    [anon_sym_PERCENT_EQ] = ACTIONS(5031),
    [anon_sym_AMP_EQ] = ACTIONS(5031),
    [anon_sym_PIPE_EQ] = ACTIONS(5031),
    [anon_sym_CARET_EQ] = ACTIONS(5031),
    [anon_sym_LT_LT_EQ] = ACTIONS(5031),
    [anon_sym_GT_GT_EQ] = ACTIONS(5031),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5031),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5031),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5031),
    [anon_sym_if] = ACTIONS(5031),
    [anon_sym_SEMI] = ACTIONS(5031),
    [anon_sym_else] = ACTIONS(5031),
    [anon_sym_when] = ACTIONS(5031),
    [anon_sym_in] = ACTIONS(5031),
    [anon_sym_case] = ACTIONS(5031),
    [anon_sym_QMARK] = ACTIONS(5031),
    [anon_sym_PLUS] = ACTIONS(5033),
    [anon_sym_DASH] = ACTIONS(5033),
    [anon_sym_TILDE] = ACTIONS(5033),
    [anon_sym_AMP] = ACTIONS(5033),
    [anon_sym_PIPE_PIPE] = ACTIONS(5033),
    [anon_sym_or_else] = ACTIONS(5031),
    [anon_sym_AMP_AMP] = ACTIONS(5033),
    [anon_sym_GT] = ACTIONS(5033),
    [anon_sym_GT_EQ] = ACTIONS(5031),
    [anon_sym_LT_EQ] = ACTIONS(5031),
    [anon_sym_LT] = ACTIONS(5033),
    [anon_sym_EQ_EQ] = ACTIONS(5031),
    [anon_sym_BANG_EQ] = ACTIONS(5031),
    [anon_sym_TILDE_EQ] = ACTIONS(5031),
    [anon_sym_AMP_TILDE] = ACTIONS(5033),
    [anon_sym_LT_LT] = ACTIONS(5033),
    [anon_sym_GT_GT] = ACTIONS(5033),
    [anon_sym_STAR] = ACTIONS(5033),
    [anon_sym_SLASH] = ACTIONS(5033),
    [anon_sym_PERCENT] = ACTIONS(5033),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5031),
    [anon_sym_DOT] = ACTIONS(5033),
    [anon_sym_LBRACK] = ACTIONS(5031),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5031),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5031),
    [anon_sym_not_in] = ACTIONS(5031),
    [anon_sym_or_return] = ACTIONS(5031),
    [anon_sym_or_continue] = ACTIONS(5031),
    [anon_sym_or_break] = ACTIONS(5031),
    [anon_sym_CARET] = ACTIONS(5033),
    [sym_uninitialized] = ACTIONS(5031),
    [sym_tag] = ACTIONS(5031),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5031),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [825] = {
    [ts_builtin_sym_end] = ACTIONS(5035),
    [anon_sym_LBRACE] = ACTIONS(5035),
    [anon_sym_RBRACE] = ACTIONS(5035),
    [anon_sym_COMMA] = ACTIONS(5035),
    [anon_sym_COLON_COLON] = ACTIONS(5035),
    [anon_sym_DASH_GT] = ACTIONS(5035),
    [anon_sym_where] = ACTIONS(5035),
    [anon_sym_EQ] = ACTIONS(5037),
    [anon_sym_COLON] = ACTIONS(5037),
    [anon_sym_PIPE] = ACTIONS(5037),
    [anon_sym_COLON_EQ] = ACTIONS(5035),
    [anon_sym_LPAREN] = ACTIONS(5035),
    [anon_sym_PLUS_EQ] = ACTIONS(5035),
    [anon_sym_DASH_EQ] = ACTIONS(5035),
    [anon_sym_STAR_EQ] = ACTIONS(5035),
    [anon_sym_SLASH_EQ] = ACTIONS(5035),
    [anon_sym_PERCENT_EQ] = ACTIONS(5035),
    [anon_sym_AMP_EQ] = ACTIONS(5035),
    [anon_sym_PIPE_EQ] = ACTIONS(5035),
    [anon_sym_CARET_EQ] = ACTIONS(5035),
    [anon_sym_LT_LT_EQ] = ACTIONS(5035),
    [anon_sym_GT_GT_EQ] = ACTIONS(5035),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5035),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5035),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5035),
    [anon_sym_if] = ACTIONS(5035),
    [anon_sym_SEMI] = ACTIONS(5035),
    [anon_sym_else] = ACTIONS(5035),
    [anon_sym_when] = ACTIONS(5035),
    [anon_sym_in] = ACTIONS(5035),
    [anon_sym_case] = ACTIONS(5035),
    [anon_sym_QMARK] = ACTIONS(5035),
    [anon_sym_PLUS] = ACTIONS(5037),
    [anon_sym_DASH] = ACTIONS(5037),
    [anon_sym_TILDE] = ACTIONS(5037),
    [anon_sym_AMP] = ACTIONS(5037),
    [anon_sym_PIPE_PIPE] = ACTIONS(5037),
    [anon_sym_or_else] = ACTIONS(5035),
    [anon_sym_AMP_AMP] = ACTIONS(5037),
    [anon_sym_GT] = ACTIONS(5037),
    [anon_sym_GT_EQ] = ACTIONS(5035),
    [anon_sym_LT_EQ] = ACTIONS(5035),
    [anon_sym_LT] = ACTIONS(5037),
    [anon_sym_EQ_EQ] = ACTIONS(5035),
    [anon_sym_BANG_EQ] = ACTIONS(5035),
    [anon_sym_TILDE_EQ] = ACTIONS(5035),
    [anon_sym_AMP_TILDE] = ACTIONS(5037),
    [anon_sym_LT_LT] = ACTIONS(5037),
    [anon_sym_GT_GT] = ACTIONS(5037),
    [anon_sym_STAR] = ACTIONS(5037),
    [anon_sym_SLASH] = ACTIONS(5037),
    [anon_sym_PERCENT] = ACTIONS(5037),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5035),
    [anon_sym_DOT] = ACTIONS(5037),
    [anon_sym_LBRACK] = ACTIONS(5035),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5035),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5035),
    [anon_sym_not_in] = ACTIONS(5035),
    [anon_sym_or_return] = ACTIONS(5035),
    [anon_sym_or_continue] = ACTIONS(5035),
    [anon_sym_or_break] = ACTIONS(5035),
    [anon_sym_CARET] = ACTIONS(5037),
    [sym_uninitialized] = ACTIONS(5035),
    [sym_tag] = ACTIONS(5035),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5035),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [826] = {
    [ts_builtin_sym_end] = ACTIONS(5039),
    [anon_sym_LBRACE] = ACTIONS(5039),
    [anon_sym_RBRACE] = ACTIONS(5039),
    [anon_sym_COMMA] = ACTIONS(5039),
    [anon_sym_COLON_COLON] = ACTIONS(5039),
    [anon_sym_DASH_GT] = ACTIONS(5039),
    [anon_sym_where] = ACTIONS(5039),
    [anon_sym_EQ] = ACTIONS(5041),
    [anon_sym_COLON] = ACTIONS(5041),
    [anon_sym_PIPE] = ACTIONS(5041),
    [anon_sym_COLON_EQ] = ACTIONS(5039),
    [anon_sym_LPAREN] = ACTIONS(5039),
    [anon_sym_PLUS_EQ] = ACTIONS(5039),
    [anon_sym_DASH_EQ] = ACTIONS(5039),
    [anon_sym_STAR_EQ] = ACTIONS(5039),
    [anon_sym_SLASH_EQ] = ACTIONS(5039),
    [anon_sym_PERCENT_EQ] = ACTIONS(5039),
    [anon_sym_AMP_EQ] = ACTIONS(5039),
    [anon_sym_PIPE_EQ] = ACTIONS(5039),
    [anon_sym_CARET_EQ] = ACTIONS(5039),
    [anon_sym_LT_LT_EQ] = ACTIONS(5039),
    [anon_sym_GT_GT_EQ] = ACTIONS(5039),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5039),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5039),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5039),
    [anon_sym_if] = ACTIONS(5039),
    [anon_sym_SEMI] = ACTIONS(5039),
    [anon_sym_else] = ACTIONS(5039),
    [anon_sym_when] = ACTIONS(5039),
    [anon_sym_in] = ACTIONS(5039),
    [anon_sym_case] = ACTIONS(5039),
    [anon_sym_QMARK] = ACTIONS(5039),
    [anon_sym_PLUS] = ACTIONS(5041),
    [anon_sym_DASH] = ACTIONS(5041),
    [anon_sym_TILDE] = ACTIONS(5041),
    [anon_sym_AMP] = ACTIONS(5041),
    [anon_sym_PIPE_PIPE] = ACTIONS(5041),
    [anon_sym_or_else] = ACTIONS(5039),
    [anon_sym_AMP_AMP] = ACTIONS(5041),
    [anon_sym_GT] = ACTIONS(5041),
    [anon_sym_GT_EQ] = ACTIONS(5039),
    [anon_sym_LT_EQ] = ACTIONS(5039),
    [anon_sym_LT] = ACTIONS(5041),
    [anon_sym_EQ_EQ] = ACTIONS(5039),
    [anon_sym_BANG_EQ] = ACTIONS(5039),
    [anon_sym_TILDE_EQ] = ACTIONS(5039),
    [anon_sym_AMP_TILDE] = ACTIONS(5041),
    [anon_sym_LT_LT] = ACTIONS(5041),
    [anon_sym_GT_GT] = ACTIONS(5041),
    [anon_sym_STAR] = ACTIONS(5041),
    [anon_sym_SLASH] = ACTIONS(5041),
    [anon_sym_PERCENT] = ACTIONS(5041),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5039),
    [anon_sym_DOT] = ACTIONS(5041),
    [anon_sym_LBRACK] = ACTIONS(5039),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5039),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5039),
    [anon_sym_not_in] = ACTIONS(5039),
    [anon_sym_or_return] = ACTIONS(5039),
    [anon_sym_or_continue] = ACTIONS(5039),
    [anon_sym_or_break] = ACTIONS(5039),
    [anon_sym_CARET] = ACTIONS(5041),
    [sym_uninitialized] = ACTIONS(5039),
    [sym_tag] = ACTIONS(5039),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5039),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [827] = {
    [sym_procedure] = STATE(3930),
    [sym_expression] = STATE(6198),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym__procedure_type] = STATE(8648),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [828] = {
    [ts_builtin_sym_end] = ACTIONS(5043),
    [anon_sym_LBRACE] = ACTIONS(5043),
    [anon_sym_RBRACE] = ACTIONS(5043),
    [anon_sym_COMMA] = ACTIONS(5043),
    [anon_sym_COLON_COLON] = ACTIONS(5043),
    [anon_sym_DASH_GT] = ACTIONS(5043),
    [anon_sym_where] = ACTIONS(5043),
    [anon_sym_EQ] = ACTIONS(5045),
    [anon_sym_COLON] = ACTIONS(5045),
    [anon_sym_PIPE] = ACTIONS(5045),
    [anon_sym_COLON_EQ] = ACTIONS(5043),
    [anon_sym_LPAREN] = ACTIONS(5043),
    [anon_sym_PLUS_EQ] = ACTIONS(5043),
    [anon_sym_DASH_EQ] = ACTIONS(5043),
    [anon_sym_STAR_EQ] = ACTIONS(5043),
    [anon_sym_SLASH_EQ] = ACTIONS(5043),
    [anon_sym_PERCENT_EQ] = ACTIONS(5043),
    [anon_sym_AMP_EQ] = ACTIONS(5043),
    [anon_sym_PIPE_EQ] = ACTIONS(5043),
    [anon_sym_CARET_EQ] = ACTIONS(5043),
    [anon_sym_LT_LT_EQ] = ACTIONS(5043),
    [anon_sym_GT_GT_EQ] = ACTIONS(5043),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5043),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5043),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5043),
    [anon_sym_if] = ACTIONS(5043),
    [anon_sym_SEMI] = ACTIONS(5043),
    [anon_sym_else] = ACTIONS(5043),
    [anon_sym_when] = ACTIONS(5043),
    [anon_sym_in] = ACTIONS(5043),
    [anon_sym_case] = ACTIONS(5043),
    [anon_sym_QMARK] = ACTIONS(5043),
    [anon_sym_PLUS] = ACTIONS(5045),
    [anon_sym_DASH] = ACTIONS(5045),
    [anon_sym_TILDE] = ACTIONS(5045),
    [anon_sym_AMP] = ACTIONS(5045),
    [anon_sym_PIPE_PIPE] = ACTIONS(5045),
    [anon_sym_or_else] = ACTIONS(5043),
    [anon_sym_AMP_AMP] = ACTIONS(5045),
    [anon_sym_GT] = ACTIONS(5045),
    [anon_sym_GT_EQ] = ACTIONS(5043),
    [anon_sym_LT_EQ] = ACTIONS(5043),
    [anon_sym_LT] = ACTIONS(5045),
    [anon_sym_EQ_EQ] = ACTIONS(5043),
    [anon_sym_BANG_EQ] = ACTIONS(5043),
    [anon_sym_TILDE_EQ] = ACTIONS(5043),
    [anon_sym_AMP_TILDE] = ACTIONS(5045),
    [anon_sym_LT_LT] = ACTIONS(5045),
    [anon_sym_GT_GT] = ACTIONS(5045),
    [anon_sym_STAR] = ACTIONS(5045),
    [anon_sym_SLASH] = ACTIONS(5045),
    [anon_sym_PERCENT] = ACTIONS(5045),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5043),
    [anon_sym_DOT] = ACTIONS(5045),
    [anon_sym_LBRACK] = ACTIONS(5043),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5043),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5043),
    [anon_sym_not_in] = ACTIONS(5043),
    [anon_sym_or_return] = ACTIONS(5043),
    [anon_sym_or_continue] = ACTIONS(5043),
    [anon_sym_or_break] = ACTIONS(5043),
    [anon_sym_CARET] = ACTIONS(5045),
    [sym_uninitialized] = ACTIONS(5043),
    [sym_tag] = ACTIONS(5043),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5043),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [829] = {
    [ts_builtin_sym_end] = ACTIONS(5047),
    [anon_sym_LBRACE] = ACTIONS(5047),
    [anon_sym_RBRACE] = ACTIONS(5047),
    [anon_sym_COMMA] = ACTIONS(5047),
    [anon_sym_COLON_COLON] = ACTIONS(5047),
    [anon_sym_DASH_GT] = ACTIONS(5047),
    [anon_sym_where] = ACTIONS(5047),
    [anon_sym_EQ] = ACTIONS(5049),
    [anon_sym_COLON] = ACTIONS(5049),
    [anon_sym_PIPE] = ACTIONS(5049),
    [anon_sym_COLON_EQ] = ACTIONS(5047),
    [anon_sym_LPAREN] = ACTIONS(5047),
    [anon_sym_PLUS_EQ] = ACTIONS(5047),
    [anon_sym_DASH_EQ] = ACTIONS(5047),
    [anon_sym_STAR_EQ] = ACTIONS(5047),
    [anon_sym_SLASH_EQ] = ACTIONS(5047),
    [anon_sym_PERCENT_EQ] = ACTIONS(5047),
    [anon_sym_AMP_EQ] = ACTIONS(5047),
    [anon_sym_PIPE_EQ] = ACTIONS(5047),
    [anon_sym_CARET_EQ] = ACTIONS(5047),
    [anon_sym_LT_LT_EQ] = ACTIONS(5047),
    [anon_sym_GT_GT_EQ] = ACTIONS(5047),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5047),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5047),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5047),
    [anon_sym_if] = ACTIONS(5047),
    [anon_sym_SEMI] = ACTIONS(5047),
    [anon_sym_else] = ACTIONS(5047),
    [anon_sym_when] = ACTIONS(5047),
    [anon_sym_in] = ACTIONS(5047),
    [anon_sym_case] = ACTIONS(5047),
    [anon_sym_QMARK] = ACTIONS(5047),
    [anon_sym_PLUS] = ACTIONS(5049),
    [anon_sym_DASH] = ACTIONS(5049),
    [anon_sym_TILDE] = ACTIONS(5049),
    [anon_sym_AMP] = ACTIONS(5049),
    [anon_sym_PIPE_PIPE] = ACTIONS(5049),
    [anon_sym_or_else] = ACTIONS(5047),
    [anon_sym_AMP_AMP] = ACTIONS(5049),
    [anon_sym_GT] = ACTIONS(5049),
    [anon_sym_GT_EQ] = ACTIONS(5047),
    [anon_sym_LT_EQ] = ACTIONS(5047),
    [anon_sym_LT] = ACTIONS(5049),
    [anon_sym_EQ_EQ] = ACTIONS(5047),
    [anon_sym_BANG_EQ] = ACTIONS(5047),
    [anon_sym_TILDE_EQ] = ACTIONS(5047),
    [anon_sym_AMP_TILDE] = ACTIONS(5049),
    [anon_sym_LT_LT] = ACTIONS(5049),
    [anon_sym_GT_GT] = ACTIONS(5049),
    [anon_sym_STAR] = ACTIONS(5049),
    [anon_sym_SLASH] = ACTIONS(5049),
    [anon_sym_PERCENT] = ACTIONS(5049),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5047),
    [anon_sym_DOT] = ACTIONS(5049),
    [anon_sym_LBRACK] = ACTIONS(5047),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5047),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5047),
    [anon_sym_not_in] = ACTIONS(5047),
    [anon_sym_or_return] = ACTIONS(5047),
    [anon_sym_or_continue] = ACTIONS(5047),
    [anon_sym_or_break] = ACTIONS(5047),
    [anon_sym_CARET] = ACTIONS(5049),
    [sym_uninitialized] = ACTIONS(5047),
    [sym_tag] = ACTIONS(5047),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5047),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [830] = {
    [ts_builtin_sym_end] = ACTIONS(5051),
    [anon_sym_LBRACE] = ACTIONS(5051),
    [anon_sym_RBRACE] = ACTIONS(5051),
    [anon_sym_COMMA] = ACTIONS(5051),
    [anon_sym_COLON_COLON] = ACTIONS(5051),
    [anon_sym_DASH_GT] = ACTIONS(5051),
    [anon_sym_where] = ACTIONS(5051),
    [anon_sym_EQ] = ACTIONS(5053),
    [anon_sym_COLON] = ACTIONS(5053),
    [anon_sym_PIPE] = ACTIONS(5053),
    [anon_sym_COLON_EQ] = ACTIONS(5051),
    [anon_sym_LPAREN] = ACTIONS(5051),
    [anon_sym_PLUS_EQ] = ACTIONS(5051),
    [anon_sym_DASH_EQ] = ACTIONS(5051),
    [anon_sym_STAR_EQ] = ACTIONS(5051),
    [anon_sym_SLASH_EQ] = ACTIONS(5051),
    [anon_sym_PERCENT_EQ] = ACTIONS(5051),
    [anon_sym_AMP_EQ] = ACTIONS(5051),
    [anon_sym_PIPE_EQ] = ACTIONS(5051),
    [anon_sym_CARET_EQ] = ACTIONS(5051),
    [anon_sym_LT_LT_EQ] = ACTIONS(5051),
    [anon_sym_GT_GT_EQ] = ACTIONS(5051),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5051),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5051),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5051),
    [anon_sym_if] = ACTIONS(5051),
    [anon_sym_SEMI] = ACTIONS(5051),
    [anon_sym_else] = ACTIONS(5051),
    [anon_sym_when] = ACTIONS(5051),
    [anon_sym_in] = ACTIONS(5051),
    [anon_sym_case] = ACTIONS(5051),
    [anon_sym_QMARK] = ACTIONS(5051),
    [anon_sym_PLUS] = ACTIONS(5053),
    [anon_sym_DASH] = ACTIONS(5053),
    [anon_sym_TILDE] = ACTIONS(5053),
    [anon_sym_AMP] = ACTIONS(5053),
    [anon_sym_PIPE_PIPE] = ACTIONS(5053),
    [anon_sym_or_else] = ACTIONS(5051),
    [anon_sym_AMP_AMP] = ACTIONS(5053),
    [anon_sym_GT] = ACTIONS(5053),
    [anon_sym_GT_EQ] = ACTIONS(5051),
    [anon_sym_LT_EQ] = ACTIONS(5051),
    [anon_sym_LT] = ACTIONS(5053),
    [anon_sym_EQ_EQ] = ACTIONS(5051),
    [anon_sym_BANG_EQ] = ACTIONS(5051),
    [anon_sym_TILDE_EQ] = ACTIONS(5051),
    [anon_sym_AMP_TILDE] = ACTIONS(5053),
    [anon_sym_LT_LT] = ACTIONS(5053),
    [anon_sym_GT_GT] = ACTIONS(5053),
    [anon_sym_STAR] = ACTIONS(5053),
    [anon_sym_SLASH] = ACTIONS(5053),
    [anon_sym_PERCENT] = ACTIONS(5053),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5051),
    [anon_sym_DOT] = ACTIONS(5053),
    [anon_sym_LBRACK] = ACTIONS(5051),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5051),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5051),
    [anon_sym_not_in] = ACTIONS(5051),
    [anon_sym_or_return] = ACTIONS(5051),
    [anon_sym_or_continue] = ACTIONS(5051),
    [anon_sym_or_break] = ACTIONS(5051),
    [anon_sym_CARET] = ACTIONS(5053),
    [sym_uninitialized] = ACTIONS(5051),
    [sym_tag] = ACTIONS(5051),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5051),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [831] = {
    [ts_builtin_sym_end] = ACTIONS(4466),
    [anon_sym_LBRACE] = ACTIONS(4466),
    [anon_sym_RBRACE] = ACTIONS(4466),
    [anon_sym_COMMA] = ACTIONS(4466),
    [anon_sym_COLON_COLON] = ACTIONS(4466),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4466),
    [anon_sym_EQ] = ACTIONS(4471),
    [anon_sym_COLON] = ACTIONS(4471),
    [anon_sym_PIPE] = ACTIONS(4485),
    [anon_sym_COLON_EQ] = ACTIONS(4466),
    [anon_sym_LPAREN] = ACTIONS(4466),
    [anon_sym_PLUS_EQ] = ACTIONS(4466),
    [anon_sym_DASH_EQ] = ACTIONS(4466),
    [anon_sym_STAR_EQ] = ACTIONS(4466),
    [anon_sym_SLASH_EQ] = ACTIONS(4466),
    [anon_sym_PERCENT_EQ] = ACTIONS(4466),
    [anon_sym_AMP_EQ] = ACTIONS(4466),
    [anon_sym_PIPE_EQ] = ACTIONS(4466),
    [anon_sym_CARET_EQ] = ACTIONS(4466),
    [anon_sym_LT_LT_EQ] = ACTIONS(4466),
    [anon_sym_GT_GT_EQ] = ACTIONS(4466),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4466),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4466),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4466),
    [anon_sym_if] = ACTIONS(4466),
    [anon_sym_SEMI] = ACTIONS(4466),
    [anon_sym_else] = ACTIONS(4466),
    [anon_sym_when] = ACTIONS(4466),
    [anon_sym_in] = ACTIONS(4466),
    [anon_sym_case] = ACTIONS(4466),
    [anon_sym_QMARK] = ACTIONS(4466),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4493),
    [anon_sym_or_else] = ACTIONS(4495),
    [anon_sym_AMP_AMP] = ACTIONS(4497),
    [anon_sym_GT] = ACTIONS(4499),
    [anon_sym_GT_EQ] = ACTIONS(4501),
    [anon_sym_LT_EQ] = ACTIONS(4501),
    [anon_sym_LT] = ACTIONS(4499),
    [anon_sym_EQ_EQ] = ACTIONS(4503),
    [anon_sym_BANG_EQ] = ACTIONS(4503),
    [anon_sym_TILDE_EQ] = ACTIONS(4503),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4466),
    [anon_sym_or_return] = ACTIONS(4519),
    [anon_sym_or_continue] = ACTIONS(4521),
    [anon_sym_or_break] = ACTIONS(4523),
    [anon_sym_CARET] = ACTIONS(4525),
    [sym_uninitialized] = ACTIONS(4466),
    [sym_tag] = ACTIONS(4466),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4466),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [832] = {
    [ts_builtin_sym_end] = ACTIONS(5055),
    [anon_sym_LBRACE] = ACTIONS(5055),
    [anon_sym_RBRACE] = ACTIONS(5055),
    [anon_sym_COMMA] = ACTIONS(5055),
    [anon_sym_COLON_COLON] = ACTIONS(5055),
    [anon_sym_DASH_GT] = ACTIONS(5055),
    [anon_sym_where] = ACTIONS(5055),
    [anon_sym_EQ] = ACTIONS(5057),
    [anon_sym_COLON] = ACTIONS(5057),
    [anon_sym_PIPE] = ACTIONS(5057),
    [anon_sym_COLON_EQ] = ACTIONS(5055),
    [anon_sym_LPAREN] = ACTIONS(5055),
    [anon_sym_PLUS_EQ] = ACTIONS(5055),
    [anon_sym_DASH_EQ] = ACTIONS(5055),
    [anon_sym_STAR_EQ] = ACTIONS(5055),
    [anon_sym_SLASH_EQ] = ACTIONS(5055),
    [anon_sym_PERCENT_EQ] = ACTIONS(5055),
    [anon_sym_AMP_EQ] = ACTIONS(5055),
    [anon_sym_PIPE_EQ] = ACTIONS(5055),
    [anon_sym_CARET_EQ] = ACTIONS(5055),
    [anon_sym_LT_LT_EQ] = ACTIONS(5055),
    [anon_sym_GT_GT_EQ] = ACTIONS(5055),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5055),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5055),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5055),
    [anon_sym_if] = ACTIONS(5055),
    [anon_sym_SEMI] = ACTIONS(5055),
    [anon_sym_else] = ACTIONS(5055),
    [anon_sym_when] = ACTIONS(5055),
    [anon_sym_in] = ACTIONS(5055),
    [anon_sym_case] = ACTIONS(5055),
    [anon_sym_QMARK] = ACTIONS(5055),
    [anon_sym_PLUS] = ACTIONS(5057),
    [anon_sym_DASH] = ACTIONS(5057),
    [anon_sym_TILDE] = ACTIONS(5057),
    [anon_sym_AMP] = ACTIONS(5057),
    [anon_sym_PIPE_PIPE] = ACTIONS(5057),
    [anon_sym_or_else] = ACTIONS(5055),
    [anon_sym_AMP_AMP] = ACTIONS(5057),
    [anon_sym_GT] = ACTIONS(5057),
    [anon_sym_GT_EQ] = ACTIONS(5055),
    [anon_sym_LT_EQ] = ACTIONS(5055),
    [anon_sym_LT] = ACTIONS(5057),
    [anon_sym_EQ_EQ] = ACTIONS(5055),
    [anon_sym_BANG_EQ] = ACTIONS(5055),
    [anon_sym_TILDE_EQ] = ACTIONS(5055),
    [anon_sym_AMP_TILDE] = ACTIONS(5057),
    [anon_sym_LT_LT] = ACTIONS(5057),
    [anon_sym_GT_GT] = ACTIONS(5057),
    [anon_sym_STAR] = ACTIONS(5057),
    [anon_sym_SLASH] = ACTIONS(5057),
    [anon_sym_PERCENT] = ACTIONS(5057),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5055),
    [anon_sym_DOT] = ACTIONS(5057),
    [anon_sym_LBRACK] = ACTIONS(5055),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5055),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5055),
    [anon_sym_not_in] = ACTIONS(5055),
    [anon_sym_or_return] = ACTIONS(5055),
    [anon_sym_or_continue] = ACTIONS(5055),
    [anon_sym_or_break] = ACTIONS(5055),
    [anon_sym_CARET] = ACTIONS(5057),
    [sym_uninitialized] = ACTIONS(5055),
    [sym_tag] = ACTIONS(5055),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5055),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [833] = {
    [ts_builtin_sym_end] = ACTIONS(5051),
    [anon_sym_LBRACE] = ACTIONS(5051),
    [anon_sym_RBRACE] = ACTIONS(5051),
    [anon_sym_COMMA] = ACTIONS(5051),
    [anon_sym_COLON_COLON] = ACTIONS(5051),
    [anon_sym_DASH_GT] = ACTIONS(5051),
    [anon_sym_where] = ACTIONS(5051),
    [anon_sym_EQ] = ACTIONS(5053),
    [anon_sym_COLON] = ACTIONS(5053),
    [anon_sym_PIPE] = ACTIONS(5053),
    [anon_sym_COLON_EQ] = ACTIONS(5051),
    [anon_sym_LPAREN] = ACTIONS(5051),
    [anon_sym_PLUS_EQ] = ACTIONS(5051),
    [anon_sym_DASH_EQ] = ACTIONS(5051),
    [anon_sym_STAR_EQ] = ACTIONS(5051),
    [anon_sym_SLASH_EQ] = ACTIONS(5051),
    [anon_sym_PERCENT_EQ] = ACTIONS(5051),
    [anon_sym_AMP_EQ] = ACTIONS(5051),
    [anon_sym_PIPE_EQ] = ACTIONS(5051),
    [anon_sym_CARET_EQ] = ACTIONS(5051),
    [anon_sym_LT_LT_EQ] = ACTIONS(5051),
    [anon_sym_GT_GT_EQ] = ACTIONS(5051),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5051),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5051),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5051),
    [anon_sym_if] = ACTIONS(5051),
    [anon_sym_SEMI] = ACTIONS(5051),
    [anon_sym_else] = ACTIONS(5051),
    [anon_sym_when] = ACTIONS(5051),
    [anon_sym_in] = ACTIONS(5051),
    [anon_sym_case] = ACTIONS(5051),
    [anon_sym_QMARK] = ACTIONS(5051),
    [anon_sym_PLUS] = ACTIONS(5053),
    [anon_sym_DASH] = ACTIONS(5053),
    [anon_sym_TILDE] = ACTIONS(5053),
    [anon_sym_AMP] = ACTIONS(5053),
    [anon_sym_PIPE_PIPE] = ACTIONS(5053),
    [anon_sym_or_else] = ACTIONS(5051),
    [anon_sym_AMP_AMP] = ACTIONS(5053),
    [anon_sym_GT] = ACTIONS(5053),
    [anon_sym_GT_EQ] = ACTIONS(5051),
    [anon_sym_LT_EQ] = ACTIONS(5051),
    [anon_sym_LT] = ACTIONS(5053),
    [anon_sym_EQ_EQ] = ACTIONS(5051),
    [anon_sym_BANG_EQ] = ACTIONS(5051),
    [anon_sym_TILDE_EQ] = ACTIONS(5051),
    [anon_sym_AMP_TILDE] = ACTIONS(5053),
    [anon_sym_LT_LT] = ACTIONS(5053),
    [anon_sym_GT_GT] = ACTIONS(5053),
    [anon_sym_STAR] = ACTIONS(5053),
    [anon_sym_SLASH] = ACTIONS(5053),
    [anon_sym_PERCENT] = ACTIONS(5053),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5051),
    [anon_sym_DOT] = ACTIONS(5053),
    [anon_sym_LBRACK] = ACTIONS(5051),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5051),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5051),
    [anon_sym_not_in] = ACTIONS(5051),
    [anon_sym_or_return] = ACTIONS(5051),
    [anon_sym_or_continue] = ACTIONS(5051),
    [anon_sym_or_break] = ACTIONS(5051),
    [anon_sym_CARET] = ACTIONS(5053),
    [sym_uninitialized] = ACTIONS(5051),
    [sym_tag] = ACTIONS(5051),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5051),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [834] = {
    [ts_builtin_sym_end] = ACTIONS(4635),
    [anon_sym_LBRACE] = ACTIONS(4635),
    [anon_sym_RBRACE] = ACTIONS(4635),
    [anon_sym_COMMA] = ACTIONS(4635),
    [anon_sym_COLON_COLON] = ACTIONS(4635),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(4635),
    [anon_sym_EQ] = ACTIONS(4637),
    [anon_sym_COLON] = ACTIONS(4637),
    [anon_sym_PIPE] = ACTIONS(4637),
    [anon_sym_COLON_EQ] = ACTIONS(4635),
    [anon_sym_LPAREN] = ACTIONS(4635),
    [anon_sym_PLUS_EQ] = ACTIONS(4635),
    [anon_sym_DASH_EQ] = ACTIONS(4635),
    [anon_sym_STAR_EQ] = ACTIONS(4635),
    [anon_sym_SLASH_EQ] = ACTIONS(4635),
    [anon_sym_PERCENT_EQ] = ACTIONS(4635),
    [anon_sym_AMP_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_CARET_EQ] = ACTIONS(4635),
    [anon_sym_LT_LT_EQ] = ACTIONS(4635),
    [anon_sym_GT_GT_EQ] = ACTIONS(4635),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_if] = ACTIONS(4635),
    [anon_sym_SEMI] = ACTIONS(4635),
    [anon_sym_else] = ACTIONS(4635),
    [anon_sym_when] = ACTIONS(4635),
    [anon_sym_in] = ACTIONS(4635),
    [anon_sym_case] = ACTIONS(4635),
    [anon_sym_QMARK] = ACTIONS(4635),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4637),
    [anon_sym_or_else] = ACTIONS(4635),
    [anon_sym_AMP_AMP] = ACTIONS(4637),
    [anon_sym_GT] = ACTIONS(4637),
    [anon_sym_GT_EQ] = ACTIONS(4635),
    [anon_sym_LT_EQ] = ACTIONS(4635),
    [anon_sym_LT] = ACTIONS(4637),
    [anon_sym_EQ_EQ] = ACTIONS(4635),
    [anon_sym_BANG_EQ] = ACTIONS(4635),
    [anon_sym_TILDE_EQ] = ACTIONS(4635),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(4635),
    [anon_sym_or_return] = ACTIONS(4635),
    [anon_sym_or_continue] = ACTIONS(4635),
    [anon_sym_or_break] = ACTIONS(4635),
    [anon_sym_CARET] = ACTIONS(4637),
    [sym_uninitialized] = ACTIONS(4635),
    [sym_tag] = ACTIONS(4635),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4635),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [835] = {
    [ts_builtin_sym_end] = ACTIONS(5059),
    [anon_sym_LBRACE] = ACTIONS(5059),
    [anon_sym_RBRACE] = ACTIONS(5059),
    [anon_sym_COMMA] = ACTIONS(5059),
    [anon_sym_COLON_COLON] = ACTIONS(5059),
    [anon_sym_DASH_GT] = ACTIONS(5059),
    [anon_sym_where] = ACTIONS(5059),
    [anon_sym_EQ] = ACTIONS(5061),
    [anon_sym_COLON] = ACTIONS(5061),
    [anon_sym_PIPE] = ACTIONS(5061),
    [anon_sym_COLON_EQ] = ACTIONS(5059),
    [anon_sym_LPAREN] = ACTIONS(5059),
    [anon_sym_PLUS_EQ] = ACTIONS(5059),
    [anon_sym_DASH_EQ] = ACTIONS(5059),
    [anon_sym_STAR_EQ] = ACTIONS(5059),
    [anon_sym_SLASH_EQ] = ACTIONS(5059),
    [anon_sym_PERCENT_EQ] = ACTIONS(5059),
    [anon_sym_AMP_EQ] = ACTIONS(5059),
    [anon_sym_PIPE_EQ] = ACTIONS(5059),
    [anon_sym_CARET_EQ] = ACTIONS(5059),
    [anon_sym_LT_LT_EQ] = ACTIONS(5059),
    [anon_sym_GT_GT_EQ] = ACTIONS(5059),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5059),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5059),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5059),
    [anon_sym_if] = ACTIONS(5059),
    [anon_sym_SEMI] = ACTIONS(5059),
    [anon_sym_else] = ACTIONS(5059),
    [anon_sym_when] = ACTIONS(5059),
    [anon_sym_in] = ACTIONS(5059),
    [anon_sym_case] = ACTIONS(5059),
    [anon_sym_QMARK] = ACTIONS(5059),
    [anon_sym_PLUS] = ACTIONS(5061),
    [anon_sym_DASH] = ACTIONS(5061),
    [anon_sym_TILDE] = ACTIONS(5061),
    [anon_sym_AMP] = ACTIONS(5061),
    [anon_sym_PIPE_PIPE] = ACTIONS(5061),
    [anon_sym_or_else] = ACTIONS(5059),
    [anon_sym_AMP_AMP] = ACTIONS(5061),
    [anon_sym_GT] = ACTIONS(5061),
    [anon_sym_GT_EQ] = ACTIONS(5059),
    [anon_sym_LT_EQ] = ACTIONS(5059),
    [anon_sym_LT] = ACTIONS(5061),
    [anon_sym_EQ_EQ] = ACTIONS(5059),
    [anon_sym_BANG_EQ] = ACTIONS(5059),
    [anon_sym_TILDE_EQ] = ACTIONS(5059),
    [anon_sym_AMP_TILDE] = ACTIONS(5061),
    [anon_sym_LT_LT] = ACTIONS(5061),
    [anon_sym_GT_GT] = ACTIONS(5061),
    [anon_sym_STAR] = ACTIONS(5061),
    [anon_sym_SLASH] = ACTIONS(5061),
    [anon_sym_PERCENT] = ACTIONS(5061),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5059),
    [anon_sym_DOT] = ACTIONS(5061),
    [anon_sym_LBRACK] = ACTIONS(5059),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5059),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5059),
    [anon_sym_not_in] = ACTIONS(5059),
    [anon_sym_or_return] = ACTIONS(5059),
    [anon_sym_or_continue] = ACTIONS(5059),
    [anon_sym_or_break] = ACTIONS(5059),
    [anon_sym_CARET] = ACTIONS(5061),
    [sym_uninitialized] = ACTIONS(5059),
    [sym_tag] = ACTIONS(5059),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5059),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [836] = {
    [ts_builtin_sym_end] = ACTIONS(5063),
    [anon_sym_LBRACE] = ACTIONS(5063),
    [anon_sym_RBRACE] = ACTIONS(5063),
    [anon_sym_COMMA] = ACTIONS(5063),
    [anon_sym_COLON_COLON] = ACTIONS(5063),
    [anon_sym_DASH_GT] = ACTIONS(5063),
    [anon_sym_where] = ACTIONS(5063),
    [anon_sym_EQ] = ACTIONS(5065),
    [anon_sym_COLON] = ACTIONS(5065),
    [anon_sym_PIPE] = ACTIONS(5065),
    [anon_sym_COLON_EQ] = ACTIONS(5063),
    [anon_sym_LPAREN] = ACTIONS(5063),
    [anon_sym_PLUS_EQ] = ACTIONS(5063),
    [anon_sym_DASH_EQ] = ACTIONS(5063),
    [anon_sym_STAR_EQ] = ACTIONS(5063),
    [anon_sym_SLASH_EQ] = ACTIONS(5063),
    [anon_sym_PERCENT_EQ] = ACTIONS(5063),
    [anon_sym_AMP_EQ] = ACTIONS(5063),
    [anon_sym_PIPE_EQ] = ACTIONS(5063),
    [anon_sym_CARET_EQ] = ACTIONS(5063),
    [anon_sym_LT_LT_EQ] = ACTIONS(5063),
    [anon_sym_GT_GT_EQ] = ACTIONS(5063),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5063),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5063),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5063),
    [anon_sym_if] = ACTIONS(5063),
    [anon_sym_SEMI] = ACTIONS(5063),
    [anon_sym_else] = ACTIONS(5063),
    [anon_sym_when] = ACTIONS(5063),
    [anon_sym_in] = ACTIONS(5063),
    [anon_sym_case] = ACTIONS(5063),
    [anon_sym_QMARK] = ACTIONS(5063),
    [anon_sym_PLUS] = ACTIONS(5065),
    [anon_sym_DASH] = ACTIONS(5065),
    [anon_sym_TILDE] = ACTIONS(5065),
    [anon_sym_AMP] = ACTIONS(5065),
    [anon_sym_PIPE_PIPE] = ACTIONS(5065),
    [anon_sym_or_else] = ACTIONS(5063),
    [anon_sym_AMP_AMP] = ACTIONS(5065),
    [anon_sym_GT] = ACTIONS(5065),
    [anon_sym_GT_EQ] = ACTIONS(5063),
    [anon_sym_LT_EQ] = ACTIONS(5063),
    [anon_sym_LT] = ACTIONS(5065),
    [anon_sym_EQ_EQ] = ACTIONS(5063),
    [anon_sym_BANG_EQ] = ACTIONS(5063),
    [anon_sym_TILDE_EQ] = ACTIONS(5063),
    [anon_sym_AMP_TILDE] = ACTIONS(5065),
    [anon_sym_LT_LT] = ACTIONS(5065),
    [anon_sym_GT_GT] = ACTIONS(5065),
    [anon_sym_STAR] = ACTIONS(5065),
    [anon_sym_SLASH] = ACTIONS(5065),
    [anon_sym_PERCENT] = ACTIONS(5065),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5063),
    [anon_sym_DOT] = ACTIONS(5065),
    [anon_sym_LBRACK] = ACTIONS(5063),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5063),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5063),
    [anon_sym_not_in] = ACTIONS(5063),
    [anon_sym_or_return] = ACTIONS(5063),
    [anon_sym_or_continue] = ACTIONS(5063),
    [anon_sym_or_break] = ACTIONS(5063),
    [anon_sym_CARET] = ACTIONS(5065),
    [sym_uninitialized] = ACTIONS(5063),
    [sym_tag] = ACTIONS(5063),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5063),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [837] = {
    [ts_builtin_sym_end] = ACTIONS(871),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_where] = ACTIONS(871),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(871),
    [anon_sym_PLUS_EQ] = ACTIONS(871),
    [anon_sym_DASH_EQ] = ACTIONS(871),
    [anon_sym_STAR_EQ] = ACTIONS(871),
    [anon_sym_SLASH_EQ] = ACTIONS(871),
    [anon_sym_PERCENT_EQ] = ACTIONS(871),
    [anon_sym_AMP_EQ] = ACTIONS(871),
    [anon_sym_PIPE_EQ] = ACTIONS(871),
    [anon_sym_CARET_EQ] = ACTIONS(871),
    [anon_sym_LT_LT_EQ] = ACTIONS(871),
    [anon_sym_GT_GT_EQ] = ACTIONS(871),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(871),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(871),
    [anon_sym_if] = ACTIONS(871),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(871),
    [anon_sym_when] = ACTIONS(871),
    [anon_sym_in] = ACTIONS(871),
    [anon_sym_case] = ACTIONS(871),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(874),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(874),
    [anon_sym_or_else] = ACTIONS(871),
    [anon_sym_AMP_AMP] = ACTIONS(874),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(874),
    [anon_sym_LT_LT] = ACTIONS(874),
    [anon_sym_GT_GT] = ACTIONS(874),
    [anon_sym_STAR] = ACTIONS(874),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(871),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(871),
    [anon_sym_or_return] = ACTIONS(871),
    [anon_sym_or_continue] = ACTIONS(871),
    [anon_sym_or_break] = ACTIONS(871),
    [anon_sym_CARET] = ACTIONS(874),
    [sym_uninitialized] = ACTIONS(871),
    [sym_tag] = ACTIONS(871),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [838] = {
    [ts_builtin_sym_end] = ACTIONS(5067),
    [anon_sym_LBRACE] = ACTIONS(5067),
    [anon_sym_RBRACE] = ACTIONS(5067),
    [anon_sym_COMMA] = ACTIONS(5067),
    [anon_sym_COLON_COLON] = ACTIONS(5067),
    [anon_sym_DASH_GT] = ACTIONS(4481),
    [anon_sym_where] = ACTIONS(5067),
    [anon_sym_EQ] = ACTIONS(5069),
    [anon_sym_COLON] = ACTIONS(5069),
    [anon_sym_PIPE] = ACTIONS(4485),
    [anon_sym_COLON_EQ] = ACTIONS(5067),
    [anon_sym_LPAREN] = ACTIONS(5067),
    [anon_sym_PLUS_EQ] = ACTIONS(5067),
    [anon_sym_DASH_EQ] = ACTIONS(5067),
    [anon_sym_STAR_EQ] = ACTIONS(5067),
    [anon_sym_SLASH_EQ] = ACTIONS(5067),
    [anon_sym_PERCENT_EQ] = ACTIONS(5067),
    [anon_sym_AMP_EQ] = ACTIONS(5067),
    [anon_sym_PIPE_EQ] = ACTIONS(5067),
    [anon_sym_CARET_EQ] = ACTIONS(5067),
    [anon_sym_LT_LT_EQ] = ACTIONS(5067),
    [anon_sym_GT_GT_EQ] = ACTIONS(5067),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5067),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5067),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5067),
    [anon_sym_if] = ACTIONS(5067),
    [anon_sym_SEMI] = ACTIONS(5067),
    [anon_sym_else] = ACTIONS(5067),
    [anon_sym_when] = ACTIONS(5067),
    [anon_sym_in] = ACTIONS(5071),
    [anon_sym_case] = ACTIONS(5067),
    [anon_sym_QMARK] = ACTIONS(5067),
    [anon_sym_PLUS] = ACTIONS(4487),
    [anon_sym_DASH] = ACTIONS(4487),
    [anon_sym_TILDE] = ACTIONS(4489),
    [anon_sym_AMP] = ACTIONS(4491),
    [anon_sym_PIPE_PIPE] = ACTIONS(4493),
    [anon_sym_or_else] = ACTIONS(4495),
    [anon_sym_AMP_AMP] = ACTIONS(4497),
    [anon_sym_GT] = ACTIONS(4499),
    [anon_sym_GT_EQ] = ACTIONS(4501),
    [anon_sym_LT_EQ] = ACTIONS(4501),
    [anon_sym_LT] = ACTIONS(4499),
    [anon_sym_EQ_EQ] = ACTIONS(4503),
    [anon_sym_BANG_EQ] = ACTIONS(4503),
    [anon_sym_TILDE_EQ] = ACTIONS(4503),
    [anon_sym_AMP_TILDE] = ACTIONS(4505),
    [anon_sym_LT_LT] = ACTIONS(4507),
    [anon_sym_GT_GT] = ACTIONS(4507),
    [anon_sym_STAR] = ACTIONS(4509),
    [anon_sym_SLASH] = ACTIONS(4509),
    [anon_sym_PERCENT] = ACTIONS(4509),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4511),
    [anon_sym_DOT] = ACTIONS(4513),
    [anon_sym_LBRACK] = ACTIONS(4515),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4517),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4517),
    [anon_sym_not_in] = ACTIONS(5071),
    [anon_sym_or_return] = ACTIONS(4519),
    [anon_sym_or_continue] = ACTIONS(4521),
    [anon_sym_or_break] = ACTIONS(4523),
    [anon_sym_CARET] = ACTIONS(4525),
    [sym_uninitialized] = ACTIONS(5067),
    [sym_tag] = ACTIONS(5067),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5067),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [839] = {
    [ts_builtin_sym_end] = ACTIONS(5073),
    [anon_sym_LBRACE] = ACTIONS(5073),
    [anon_sym_RBRACE] = ACTIONS(5073),
    [anon_sym_COMMA] = ACTIONS(5073),
    [anon_sym_COLON_COLON] = ACTIONS(5073),
    [anon_sym_DASH_GT] = ACTIONS(5073),
    [anon_sym_where] = ACTIONS(5073),
    [anon_sym_EQ] = ACTIONS(5075),
    [anon_sym_COLON] = ACTIONS(5075),
    [anon_sym_PIPE] = ACTIONS(5075),
    [anon_sym_COLON_EQ] = ACTIONS(5073),
    [anon_sym_LPAREN] = ACTIONS(5073),
    [anon_sym_PLUS_EQ] = ACTIONS(5073),
    [anon_sym_DASH_EQ] = ACTIONS(5073),
    [anon_sym_STAR_EQ] = ACTIONS(5073),
    [anon_sym_SLASH_EQ] = ACTIONS(5073),
    [anon_sym_PERCENT_EQ] = ACTIONS(5073),
    [anon_sym_AMP_EQ] = ACTIONS(5073),
    [anon_sym_PIPE_EQ] = ACTIONS(5073),
    [anon_sym_CARET_EQ] = ACTIONS(5073),
    [anon_sym_LT_LT_EQ] = ACTIONS(5073),
    [anon_sym_GT_GT_EQ] = ACTIONS(5073),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5073),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5073),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5073),
    [anon_sym_if] = ACTIONS(5073),
    [anon_sym_SEMI] = ACTIONS(5073),
    [anon_sym_else] = ACTIONS(5073),
    [anon_sym_when] = ACTIONS(5073),
    [anon_sym_in] = ACTIONS(5073),
    [anon_sym_case] = ACTIONS(5073),
    [anon_sym_QMARK] = ACTIONS(5073),
    [anon_sym_PLUS] = ACTIONS(5075),
    [anon_sym_DASH] = ACTIONS(5075),
    [anon_sym_TILDE] = ACTIONS(5075),
    [anon_sym_AMP] = ACTIONS(5075),
    [anon_sym_PIPE_PIPE] = ACTIONS(5075),
    [anon_sym_or_else] = ACTIONS(5073),
    [anon_sym_AMP_AMP] = ACTIONS(5075),
    [anon_sym_GT] = ACTIONS(5075),
    [anon_sym_GT_EQ] = ACTIONS(5073),
    [anon_sym_LT_EQ] = ACTIONS(5073),
    [anon_sym_LT] = ACTIONS(5075),
    [anon_sym_EQ_EQ] = ACTIONS(5073),
    [anon_sym_BANG_EQ] = ACTIONS(5073),
    [anon_sym_TILDE_EQ] = ACTIONS(5073),
    [anon_sym_AMP_TILDE] = ACTIONS(5075),
    [anon_sym_LT_LT] = ACTIONS(5075),
    [anon_sym_GT_GT] = ACTIONS(5075),
    [anon_sym_STAR] = ACTIONS(5075),
    [anon_sym_SLASH] = ACTIONS(5075),
    [anon_sym_PERCENT] = ACTIONS(5075),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5073),
    [anon_sym_DOT] = ACTIONS(5075),
    [anon_sym_LBRACK] = ACTIONS(5073),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5073),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5073),
    [anon_sym_not_in] = ACTIONS(5073),
    [anon_sym_or_return] = ACTIONS(5073),
    [anon_sym_or_continue] = ACTIONS(5073),
    [anon_sym_or_break] = ACTIONS(5073),
    [anon_sym_CARET] = ACTIONS(5075),
    [sym_uninitialized] = ACTIONS(5073),
    [sym_tag] = ACTIONS(5073),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5073),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [840] = {
    [ts_builtin_sym_end] = ACTIONS(5077),
    [anon_sym_LBRACE] = ACTIONS(5077),
    [anon_sym_RBRACE] = ACTIONS(5077),
    [anon_sym_COMMA] = ACTIONS(5077),
    [anon_sym_COLON_COLON] = ACTIONS(5077),
    [anon_sym_DASH_GT] = ACTIONS(5077),
    [anon_sym_where] = ACTIONS(5077),
    [anon_sym_EQ] = ACTIONS(5079),
    [anon_sym_COLON] = ACTIONS(5079),
    [anon_sym_PIPE] = ACTIONS(5079),
    [anon_sym_COLON_EQ] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(5077),
    [anon_sym_PLUS_EQ] = ACTIONS(5077),
    [anon_sym_DASH_EQ] = ACTIONS(5077),
    [anon_sym_STAR_EQ] = ACTIONS(5077),
    [anon_sym_SLASH_EQ] = ACTIONS(5077),
    [anon_sym_PERCENT_EQ] = ACTIONS(5077),
    [anon_sym_AMP_EQ] = ACTIONS(5077),
    [anon_sym_PIPE_EQ] = ACTIONS(5077),
    [anon_sym_CARET_EQ] = ACTIONS(5077),
    [anon_sym_LT_LT_EQ] = ACTIONS(5077),
    [anon_sym_GT_GT_EQ] = ACTIONS(5077),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5077),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5077),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5077),
    [anon_sym_if] = ACTIONS(5077),
    [anon_sym_SEMI] = ACTIONS(5077),
    [anon_sym_else] = ACTIONS(5077),
    [anon_sym_when] = ACTIONS(5077),
    [anon_sym_in] = ACTIONS(5077),
    [anon_sym_case] = ACTIONS(5077),
    [anon_sym_QMARK] = ACTIONS(5077),
    [anon_sym_PLUS] = ACTIONS(5079),
    [anon_sym_DASH] = ACTIONS(5079),
    [anon_sym_TILDE] = ACTIONS(5079),
    [anon_sym_AMP] = ACTIONS(5079),
    [anon_sym_PIPE_PIPE] = ACTIONS(5079),
    [anon_sym_or_else] = ACTIONS(5077),
    [anon_sym_AMP_AMP] = ACTIONS(5079),
    [anon_sym_GT] = ACTIONS(5079),
    [anon_sym_GT_EQ] = ACTIONS(5077),
    [anon_sym_LT_EQ] = ACTIONS(5077),
    [anon_sym_LT] = ACTIONS(5079),
    [anon_sym_EQ_EQ] = ACTIONS(5077),
    [anon_sym_BANG_EQ] = ACTIONS(5077),
    [anon_sym_TILDE_EQ] = ACTIONS(5077),
    [anon_sym_AMP_TILDE] = ACTIONS(5079),
    [anon_sym_LT_LT] = ACTIONS(5079),
    [anon_sym_GT_GT] = ACTIONS(5079),
    [anon_sym_STAR] = ACTIONS(5079),
    [anon_sym_SLASH] = ACTIONS(5079),
    [anon_sym_PERCENT] = ACTIONS(5079),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5077),
    [anon_sym_DOT] = ACTIONS(5079),
    [anon_sym_LBRACK] = ACTIONS(5077),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5077),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5077),
    [anon_sym_not_in] = ACTIONS(5077),
    [anon_sym_or_return] = ACTIONS(5077),
    [anon_sym_or_continue] = ACTIONS(5077),
    [anon_sym_or_break] = ACTIONS(5077),
    [anon_sym_CARET] = ACTIONS(5079),
    [sym_uninitialized] = ACTIONS(5077),
    [sym_tag] = ACTIONS(5077),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5077),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [841] = {
    [ts_builtin_sym_end] = ACTIONS(5081),
    [anon_sym_LBRACE] = ACTIONS(5081),
    [anon_sym_RBRACE] = ACTIONS(5081),
    [anon_sym_COMMA] = ACTIONS(5081),
    [anon_sym_COLON_COLON] = ACTIONS(5081),
    [anon_sym_DASH_GT] = ACTIONS(5081),
    [anon_sym_where] = ACTIONS(5081),
    [anon_sym_EQ] = ACTIONS(5084),
    [anon_sym_COLON] = ACTIONS(5084),
    [anon_sym_PIPE] = ACTIONS(5084),
    [anon_sym_COLON_EQ] = ACTIONS(5081),
    [anon_sym_LPAREN] = ACTIONS(5081),
    [anon_sym_PLUS_EQ] = ACTIONS(5081),
    [anon_sym_DASH_EQ] = ACTIONS(5081),
    [anon_sym_STAR_EQ] = ACTIONS(5081),
    [anon_sym_SLASH_EQ] = ACTIONS(5081),
    [anon_sym_PERCENT_EQ] = ACTIONS(5081),
    [anon_sym_AMP_EQ] = ACTIONS(5081),
    [anon_sym_PIPE_EQ] = ACTIONS(5081),
    [anon_sym_CARET_EQ] = ACTIONS(5081),
    [anon_sym_LT_LT_EQ] = ACTIONS(5081),
    [anon_sym_GT_GT_EQ] = ACTIONS(5081),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5081),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5081),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5081),
    [anon_sym_if] = ACTIONS(5081),
    [anon_sym_SEMI] = ACTIONS(5081),
    [anon_sym_else] = ACTIONS(5081),
    [anon_sym_when] = ACTIONS(5081),
    [anon_sym_in] = ACTIONS(5081),
    [anon_sym_case] = ACTIONS(5081),
    [anon_sym_QMARK] = ACTIONS(5081),
    [anon_sym_PLUS] = ACTIONS(5084),
    [anon_sym_DASH] = ACTIONS(5084),
    [anon_sym_TILDE] = ACTIONS(5084),
    [anon_sym_AMP] = ACTIONS(5084),
    [anon_sym_PIPE_PIPE] = ACTIONS(5084),
    [anon_sym_or_else] = ACTIONS(5081),
    [anon_sym_AMP_AMP] = ACTIONS(5084),
    [anon_sym_GT] = ACTIONS(5084),
    [anon_sym_GT_EQ] = ACTIONS(5081),
    [anon_sym_LT_EQ] = ACTIONS(5081),
    [anon_sym_LT] = ACTIONS(5084),
    [anon_sym_EQ_EQ] = ACTIONS(5081),
    [anon_sym_BANG_EQ] = ACTIONS(5081),
    [anon_sym_TILDE_EQ] = ACTIONS(5081),
    [anon_sym_AMP_TILDE] = ACTIONS(5084),
    [anon_sym_LT_LT] = ACTIONS(5084),
    [anon_sym_GT_GT] = ACTIONS(5084),
    [anon_sym_STAR] = ACTIONS(5084),
    [anon_sym_SLASH] = ACTIONS(5084),
    [anon_sym_PERCENT] = ACTIONS(5084),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5081),
    [anon_sym_DOT] = ACTIONS(5084),
    [anon_sym_LBRACK] = ACTIONS(5081),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5081),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5081),
    [anon_sym_not_in] = ACTIONS(5081),
    [anon_sym_or_return] = ACTIONS(5081),
    [anon_sym_or_continue] = ACTIONS(5081),
    [anon_sym_or_break] = ACTIONS(5081),
    [anon_sym_CARET] = ACTIONS(5084),
    [sym_uninitialized] = ACTIONS(5081),
    [sym_tag] = ACTIONS(5081),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5081),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [842] = {
    [sym_expression] = STATE(6380),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5087),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5089),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5091),
    [anon_sym_dynamic] = ACTIONS(5093),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [843] = {
    [ts_builtin_sym_end] = ACTIONS(5095),
    [anon_sym_LBRACE] = ACTIONS(5095),
    [anon_sym_RBRACE] = ACTIONS(5095),
    [anon_sym_COMMA] = ACTIONS(5095),
    [anon_sym_COLON_COLON] = ACTIONS(5095),
    [anon_sym_DASH_GT] = ACTIONS(5095),
    [anon_sym_where] = ACTIONS(5095),
    [anon_sym_EQ] = ACTIONS(5097),
    [anon_sym_COLON] = ACTIONS(5097),
    [anon_sym_PIPE] = ACTIONS(5097),
    [anon_sym_COLON_EQ] = ACTIONS(5095),
    [anon_sym_LPAREN] = ACTIONS(5095),
    [anon_sym_PLUS_EQ] = ACTIONS(5095),
    [anon_sym_DASH_EQ] = ACTIONS(5095),
    [anon_sym_STAR_EQ] = ACTIONS(5095),
    [anon_sym_SLASH_EQ] = ACTIONS(5095),
    [anon_sym_PERCENT_EQ] = ACTIONS(5095),
    [anon_sym_AMP_EQ] = ACTIONS(5095),
    [anon_sym_PIPE_EQ] = ACTIONS(5095),
    [anon_sym_CARET_EQ] = ACTIONS(5095),
    [anon_sym_LT_LT_EQ] = ACTIONS(5095),
    [anon_sym_GT_GT_EQ] = ACTIONS(5095),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5095),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5095),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5095),
    [anon_sym_if] = ACTIONS(5095),
    [anon_sym_SEMI] = ACTIONS(5095),
    [anon_sym_else] = ACTIONS(5095),
    [anon_sym_when] = ACTIONS(5095),
    [anon_sym_in] = ACTIONS(5095),
    [anon_sym_case] = ACTIONS(5095),
    [anon_sym_QMARK] = ACTIONS(5095),
    [anon_sym_PLUS] = ACTIONS(5097),
    [anon_sym_DASH] = ACTIONS(5097),
    [anon_sym_TILDE] = ACTIONS(5097),
    [anon_sym_AMP] = ACTIONS(5097),
    [anon_sym_PIPE_PIPE] = ACTIONS(5097),
    [anon_sym_or_else] = ACTIONS(5095),
    [anon_sym_AMP_AMP] = ACTIONS(5097),
    [anon_sym_GT] = ACTIONS(5097),
    [anon_sym_GT_EQ] = ACTIONS(5095),
    [anon_sym_LT_EQ] = ACTIONS(5095),
    [anon_sym_LT] = ACTIONS(5097),
    [anon_sym_EQ_EQ] = ACTIONS(5095),
    [anon_sym_BANG_EQ] = ACTIONS(5095),
    [anon_sym_TILDE_EQ] = ACTIONS(5095),
    [anon_sym_AMP_TILDE] = ACTIONS(5097),
    [anon_sym_LT_LT] = ACTIONS(5097),
    [anon_sym_GT_GT] = ACTIONS(5097),
    [anon_sym_STAR] = ACTIONS(5097),
    [anon_sym_SLASH] = ACTIONS(5097),
    [anon_sym_PERCENT] = ACTIONS(5097),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5095),
    [anon_sym_DOT] = ACTIONS(5097),
    [anon_sym_LBRACK] = ACTIONS(5095),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5095),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5095),
    [anon_sym_not_in] = ACTIONS(5095),
    [anon_sym_or_return] = ACTIONS(5095),
    [anon_sym_or_continue] = ACTIONS(5095),
    [anon_sym_or_break] = ACTIONS(5095),
    [anon_sym_CARET] = ACTIONS(5097),
    [sym_uninitialized] = ACTIONS(5095),
    [sym_tag] = ACTIONS(5095),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5095),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [844] = {
    [ts_builtin_sym_end] = ACTIONS(3701),
    [anon_sym_LBRACE] = ACTIONS(3701),
    [anon_sym_RBRACE] = ACTIONS(3701),
    [anon_sym_COMMA] = ACTIONS(3701),
    [anon_sym_COLON_COLON] = ACTIONS(3701),
    [anon_sym_DASH_GT] = ACTIONS(3701),
    [anon_sym_where] = ACTIONS(3701),
    [anon_sym_EQ] = ACTIONS(3706),
    [anon_sym_COLON] = ACTIONS(3706),
    [anon_sym_PIPE] = ACTIONS(3706),
    [anon_sym_COLON_EQ] = ACTIONS(3701),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_PLUS_EQ] = ACTIONS(3701),
    [anon_sym_DASH_EQ] = ACTIONS(3701),
    [anon_sym_STAR_EQ] = ACTIONS(3701),
    [anon_sym_SLASH_EQ] = ACTIONS(3701),
    [anon_sym_PERCENT_EQ] = ACTIONS(3701),
    [anon_sym_AMP_EQ] = ACTIONS(3701),
    [anon_sym_PIPE_EQ] = ACTIONS(3701),
    [anon_sym_CARET_EQ] = ACTIONS(3701),
    [anon_sym_LT_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT_GT_EQ] = ACTIONS(3701),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3701),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3701),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3701),
    [anon_sym_if] = ACTIONS(3701),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_else] = ACTIONS(3701),
    [anon_sym_when] = ACTIONS(3701),
    [anon_sym_in] = ACTIONS(3701),
    [anon_sym_case] = ACTIONS(3701),
    [anon_sym_QMARK] = ACTIONS(3701),
    [anon_sym_PLUS] = ACTIONS(3706),
    [anon_sym_DASH] = ACTIONS(3706),
    [anon_sym_TILDE] = ACTIONS(3706),
    [anon_sym_AMP] = ACTIONS(3706),
    [anon_sym_PIPE_PIPE] = ACTIONS(3706),
    [anon_sym_or_else] = ACTIONS(3701),
    [anon_sym_AMP_AMP] = ACTIONS(3706),
    [anon_sym_GT] = ACTIONS(3706),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_LT] = ACTIONS(3706),
    [anon_sym_EQ_EQ] = ACTIONS(3701),
    [anon_sym_BANG_EQ] = ACTIONS(3701),
    [anon_sym_TILDE_EQ] = ACTIONS(3701),
    [anon_sym_AMP_TILDE] = ACTIONS(3706),
    [anon_sym_LT_LT] = ACTIONS(3706),
    [anon_sym_GT_GT] = ACTIONS(3706),
    [anon_sym_STAR] = ACTIONS(3706),
    [anon_sym_SLASH] = ACTIONS(3706),
    [anon_sym_PERCENT] = ACTIONS(3706),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(3706),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3701),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3701),
    [anon_sym_not_in] = ACTIONS(3701),
    [anon_sym_or_return] = ACTIONS(3701),
    [anon_sym_or_continue] = ACTIONS(3701),
    [anon_sym_or_break] = ACTIONS(3701),
    [anon_sym_CARET] = ACTIONS(3706),
    [sym_uninitialized] = ACTIONS(3701),
    [sym_tag] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3701),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [845] = {
    [ts_builtin_sym_end] = ACTIONS(5099),
    [anon_sym_LBRACE] = ACTIONS(5099),
    [anon_sym_RBRACE] = ACTIONS(5099),
    [anon_sym_COMMA] = ACTIONS(5099),
    [anon_sym_COLON_COLON] = ACTIONS(5099),
    [anon_sym_DASH_GT] = ACTIONS(5099),
    [anon_sym_where] = ACTIONS(5099),
    [anon_sym_EQ] = ACTIONS(5101),
    [anon_sym_COLON] = ACTIONS(5101),
    [anon_sym_PIPE] = ACTIONS(5101),
    [anon_sym_COLON_EQ] = ACTIONS(5099),
    [anon_sym_LPAREN] = ACTIONS(5099),
    [anon_sym_PLUS_EQ] = ACTIONS(5099),
    [anon_sym_DASH_EQ] = ACTIONS(5099),
    [anon_sym_STAR_EQ] = ACTIONS(5099),
    [anon_sym_SLASH_EQ] = ACTIONS(5099),
    [anon_sym_PERCENT_EQ] = ACTIONS(5099),
    [anon_sym_AMP_EQ] = ACTIONS(5099),
    [anon_sym_PIPE_EQ] = ACTIONS(5099),
    [anon_sym_CARET_EQ] = ACTIONS(5099),
    [anon_sym_LT_LT_EQ] = ACTIONS(5099),
    [anon_sym_GT_GT_EQ] = ACTIONS(5099),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5099),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5099),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5099),
    [anon_sym_if] = ACTIONS(5099),
    [anon_sym_SEMI] = ACTIONS(5099),
    [anon_sym_else] = ACTIONS(5099),
    [anon_sym_when] = ACTIONS(5099),
    [anon_sym_in] = ACTIONS(5099),
    [anon_sym_case] = ACTIONS(5099),
    [anon_sym_QMARK] = ACTIONS(5099),
    [anon_sym_PLUS] = ACTIONS(5101),
    [anon_sym_DASH] = ACTIONS(5101),
    [anon_sym_TILDE] = ACTIONS(5101),
    [anon_sym_AMP] = ACTIONS(5101),
    [anon_sym_PIPE_PIPE] = ACTIONS(5101),
    [anon_sym_or_else] = ACTIONS(5099),
    [anon_sym_AMP_AMP] = ACTIONS(5101),
    [anon_sym_GT] = ACTIONS(5101),
    [anon_sym_GT_EQ] = ACTIONS(5099),
    [anon_sym_LT_EQ] = ACTIONS(5099),
    [anon_sym_LT] = ACTIONS(5101),
    [anon_sym_EQ_EQ] = ACTIONS(5099),
    [anon_sym_BANG_EQ] = ACTIONS(5099),
    [anon_sym_TILDE_EQ] = ACTIONS(5099),
    [anon_sym_AMP_TILDE] = ACTIONS(5101),
    [anon_sym_LT_LT] = ACTIONS(5101),
    [anon_sym_GT_GT] = ACTIONS(5101),
    [anon_sym_STAR] = ACTIONS(5101),
    [anon_sym_SLASH] = ACTIONS(5101),
    [anon_sym_PERCENT] = ACTIONS(5101),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5099),
    [anon_sym_DOT] = ACTIONS(5101),
    [anon_sym_LBRACK] = ACTIONS(5099),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5099),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5099),
    [anon_sym_not_in] = ACTIONS(5099),
    [anon_sym_or_return] = ACTIONS(5099),
    [anon_sym_or_continue] = ACTIONS(5099),
    [anon_sym_or_break] = ACTIONS(5099),
    [anon_sym_CARET] = ACTIONS(5101),
    [sym_uninitialized] = ACTIONS(5099),
    [sym_tag] = ACTIONS(5099),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5099),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [846] = {
    [ts_builtin_sym_end] = ACTIONS(5103),
    [anon_sym_LBRACE] = ACTIONS(5103),
    [anon_sym_RBRACE] = ACTIONS(5103),
    [anon_sym_COMMA] = ACTIONS(5103),
    [anon_sym_COLON_COLON] = ACTIONS(5103),
    [anon_sym_DASH_GT] = ACTIONS(5103),
    [anon_sym_where] = ACTIONS(5103),
    [anon_sym_EQ] = ACTIONS(5105),
    [anon_sym_COLON] = ACTIONS(5105),
    [anon_sym_PIPE] = ACTIONS(5105),
    [anon_sym_COLON_EQ] = ACTIONS(5103),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(5103),
    [anon_sym_DASH_EQ] = ACTIONS(5103),
    [anon_sym_STAR_EQ] = ACTIONS(5103),
    [anon_sym_SLASH_EQ] = ACTIONS(5103),
    [anon_sym_PERCENT_EQ] = ACTIONS(5103),
    [anon_sym_AMP_EQ] = ACTIONS(5103),
    [anon_sym_PIPE_EQ] = ACTIONS(5103),
    [anon_sym_CARET_EQ] = ACTIONS(5103),
    [anon_sym_LT_LT_EQ] = ACTIONS(5103),
    [anon_sym_GT_GT_EQ] = ACTIONS(5103),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5103),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5103),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5103),
    [anon_sym_if] = ACTIONS(5103),
    [anon_sym_SEMI] = ACTIONS(5103),
    [anon_sym_else] = ACTIONS(5103),
    [anon_sym_when] = ACTIONS(5103),
    [anon_sym_in] = ACTIONS(5103),
    [anon_sym_case] = ACTIONS(5103),
    [anon_sym_QMARK] = ACTIONS(5103),
    [anon_sym_PLUS] = ACTIONS(5105),
    [anon_sym_DASH] = ACTIONS(5105),
    [anon_sym_TILDE] = ACTIONS(5105),
    [anon_sym_AMP] = ACTIONS(5105),
    [anon_sym_PIPE_PIPE] = ACTIONS(5105),
    [anon_sym_or_else] = ACTIONS(5103),
    [anon_sym_AMP_AMP] = ACTIONS(5105),
    [anon_sym_GT] = ACTIONS(5105),
    [anon_sym_GT_EQ] = ACTIONS(5103),
    [anon_sym_LT_EQ] = ACTIONS(5103),
    [anon_sym_LT] = ACTIONS(5105),
    [anon_sym_EQ_EQ] = ACTIONS(5103),
    [anon_sym_BANG_EQ] = ACTIONS(5103),
    [anon_sym_TILDE_EQ] = ACTIONS(5103),
    [anon_sym_AMP_TILDE] = ACTIONS(5105),
    [anon_sym_LT_LT] = ACTIONS(5105),
    [anon_sym_GT_GT] = ACTIONS(5105),
    [anon_sym_STAR] = ACTIONS(5105),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(5105),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5103),
    [anon_sym_DOT] = ACTIONS(5105),
    [anon_sym_LBRACK] = ACTIONS(5103),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5103),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5103),
    [anon_sym_not_in] = ACTIONS(5103),
    [anon_sym_or_return] = ACTIONS(5103),
    [anon_sym_or_continue] = ACTIONS(5103),
    [anon_sym_or_break] = ACTIONS(5103),
    [anon_sym_CARET] = ACTIONS(5105),
    [sym_uninitialized] = ACTIONS(5103),
    [sym_tag] = ACTIONS(5103),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5103),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [847] = {
    [sym_block] = STATE(7170),
    [sym_expression] = STATE(5928),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(4767),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_SEMI] = ACTIONS(5107),
    [anon_sym_do] = ACTIONS(5109),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [848] = {
    [ts_builtin_sym_end] = ACTIONS(5111),
    [anon_sym_LBRACE] = ACTIONS(5111),
    [anon_sym_RBRACE] = ACTIONS(5111),
    [anon_sym_COMMA] = ACTIONS(5111),
    [anon_sym_COLON_COLON] = ACTIONS(5111),
    [anon_sym_DASH_GT] = ACTIONS(5111),
    [anon_sym_where] = ACTIONS(5111),
    [anon_sym_EQ] = ACTIONS(5113),
    [anon_sym_COLON] = ACTIONS(5113),
    [anon_sym_PIPE] = ACTIONS(5113),
    [anon_sym_COLON_EQ] = ACTIONS(5111),
    [anon_sym_LPAREN] = ACTIONS(5111),
    [anon_sym_PLUS_EQ] = ACTIONS(5111),
    [anon_sym_DASH_EQ] = ACTIONS(5111),
    [anon_sym_STAR_EQ] = ACTIONS(5111),
    [anon_sym_SLASH_EQ] = ACTIONS(5111),
    [anon_sym_PERCENT_EQ] = ACTIONS(5111),
    [anon_sym_AMP_EQ] = ACTIONS(5111),
    [anon_sym_PIPE_EQ] = ACTIONS(5111),
    [anon_sym_CARET_EQ] = ACTIONS(5111),
    [anon_sym_LT_LT_EQ] = ACTIONS(5111),
    [anon_sym_GT_GT_EQ] = ACTIONS(5111),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5111),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5111),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5111),
    [anon_sym_if] = ACTIONS(5111),
    [anon_sym_SEMI] = ACTIONS(5111),
    [anon_sym_else] = ACTIONS(5111),
    [anon_sym_when] = ACTIONS(5111),
    [anon_sym_in] = ACTIONS(5111),
    [anon_sym_case] = ACTIONS(5111),
    [anon_sym_QMARK] = ACTIONS(5111),
    [anon_sym_PLUS] = ACTIONS(5113),
    [anon_sym_DASH] = ACTIONS(5113),
    [anon_sym_TILDE] = ACTIONS(5113),
    [anon_sym_AMP] = ACTIONS(5113),
    [anon_sym_PIPE_PIPE] = ACTIONS(5113),
    [anon_sym_or_else] = ACTIONS(5111),
    [anon_sym_AMP_AMP] = ACTIONS(5113),
    [anon_sym_GT] = ACTIONS(5113),
    [anon_sym_GT_EQ] = ACTIONS(5111),
    [anon_sym_LT_EQ] = ACTIONS(5111),
    [anon_sym_LT] = ACTIONS(5113),
    [anon_sym_EQ_EQ] = ACTIONS(5111),
    [anon_sym_BANG_EQ] = ACTIONS(5111),
    [anon_sym_TILDE_EQ] = ACTIONS(5111),
    [anon_sym_AMP_TILDE] = ACTIONS(5113),
    [anon_sym_LT_LT] = ACTIONS(5113),
    [anon_sym_GT_GT] = ACTIONS(5113),
    [anon_sym_STAR] = ACTIONS(5113),
    [anon_sym_SLASH] = ACTIONS(5113),
    [anon_sym_PERCENT] = ACTIONS(5113),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5111),
    [anon_sym_DOT] = ACTIONS(5113),
    [anon_sym_LBRACK] = ACTIONS(5111),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5111),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5111),
    [anon_sym_not_in] = ACTIONS(5111),
    [anon_sym_or_return] = ACTIONS(5111),
    [anon_sym_or_continue] = ACTIONS(5111),
    [anon_sym_or_break] = ACTIONS(5111),
    [anon_sym_CARET] = ACTIONS(5113),
    [sym_uninitialized] = ACTIONS(5111),
    [sym_tag] = ACTIONS(5111),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5111),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [849] = {
    [ts_builtin_sym_end] = ACTIONS(5115),
    [anon_sym_LBRACE] = ACTIONS(5115),
    [anon_sym_RBRACE] = ACTIONS(5115),
    [anon_sym_COMMA] = ACTIONS(5115),
    [anon_sym_COLON_COLON] = ACTIONS(5115),
    [anon_sym_DASH_GT] = ACTIONS(5115),
    [anon_sym_where] = ACTIONS(5115),
    [anon_sym_EQ] = ACTIONS(5117),
    [anon_sym_COLON] = ACTIONS(5117),
    [anon_sym_PIPE] = ACTIONS(5117),
    [anon_sym_COLON_EQ] = ACTIONS(5115),
    [anon_sym_LPAREN] = ACTIONS(5115),
    [anon_sym_PLUS_EQ] = ACTIONS(5115),
    [anon_sym_DASH_EQ] = ACTIONS(5115),
    [anon_sym_STAR_EQ] = ACTIONS(5115),
    [anon_sym_SLASH_EQ] = ACTIONS(5115),
    [anon_sym_PERCENT_EQ] = ACTIONS(5115),
    [anon_sym_AMP_EQ] = ACTIONS(5115),
    [anon_sym_PIPE_EQ] = ACTIONS(5115),
    [anon_sym_CARET_EQ] = ACTIONS(5115),
    [anon_sym_LT_LT_EQ] = ACTIONS(5115),
    [anon_sym_GT_GT_EQ] = ACTIONS(5115),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5115),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5115),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5115),
    [anon_sym_if] = ACTIONS(5115),
    [anon_sym_SEMI] = ACTIONS(5115),
    [anon_sym_else] = ACTIONS(5115),
    [anon_sym_when] = ACTIONS(5115),
    [anon_sym_in] = ACTIONS(5115),
    [anon_sym_case] = ACTIONS(5115),
    [anon_sym_QMARK] = ACTIONS(5115),
    [anon_sym_PLUS] = ACTIONS(5117),
    [anon_sym_DASH] = ACTIONS(5117),
    [anon_sym_TILDE] = ACTIONS(5117),
    [anon_sym_AMP] = ACTIONS(5117),
    [anon_sym_PIPE_PIPE] = ACTIONS(5117),
    [anon_sym_or_else] = ACTIONS(5115),
    [anon_sym_AMP_AMP] = ACTIONS(5117),
    [anon_sym_GT] = ACTIONS(5117),
    [anon_sym_GT_EQ] = ACTIONS(5115),
    [anon_sym_LT_EQ] = ACTIONS(5115),
    [anon_sym_LT] = ACTIONS(5117),
    [anon_sym_EQ_EQ] = ACTIONS(5115),
    [anon_sym_BANG_EQ] = ACTIONS(5115),
    [anon_sym_TILDE_EQ] = ACTIONS(5115),
    [anon_sym_AMP_TILDE] = ACTIONS(5117),
    [anon_sym_LT_LT] = ACTIONS(5117),
    [anon_sym_GT_GT] = ACTIONS(5117),
    [anon_sym_STAR] = ACTIONS(5117),
    [anon_sym_SLASH] = ACTIONS(5117),
    [anon_sym_PERCENT] = ACTIONS(5117),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5115),
    [anon_sym_DOT] = ACTIONS(5117),
    [anon_sym_LBRACK] = ACTIONS(5115),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5115),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5115),
    [anon_sym_not_in] = ACTIONS(5115),
    [anon_sym_or_return] = ACTIONS(5115),
    [anon_sym_or_continue] = ACTIONS(5115),
    [anon_sym_or_break] = ACTIONS(5115),
    [anon_sym_CARET] = ACTIONS(5117),
    [sym_uninitialized] = ACTIONS(5115),
    [sym_tag] = ACTIONS(5115),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5115),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [850] = {
    [ts_builtin_sym_end] = ACTIONS(5119),
    [anon_sym_LBRACE] = ACTIONS(5119),
    [anon_sym_RBRACE] = ACTIONS(5119),
    [anon_sym_COMMA] = ACTIONS(5119),
    [anon_sym_COLON_COLON] = ACTIONS(5119),
    [anon_sym_DASH_GT] = ACTIONS(5119),
    [anon_sym_where] = ACTIONS(5119),
    [anon_sym_EQ] = ACTIONS(5121),
    [anon_sym_COLON] = ACTIONS(5121),
    [anon_sym_PIPE] = ACTIONS(5121),
    [anon_sym_COLON_EQ] = ACTIONS(5119),
    [anon_sym_LPAREN] = ACTIONS(5119),
    [anon_sym_PLUS_EQ] = ACTIONS(5119),
    [anon_sym_DASH_EQ] = ACTIONS(5119),
    [anon_sym_STAR_EQ] = ACTIONS(5119),
    [anon_sym_SLASH_EQ] = ACTIONS(5119),
    [anon_sym_PERCENT_EQ] = ACTIONS(5119),
    [anon_sym_AMP_EQ] = ACTIONS(5119),
    [anon_sym_PIPE_EQ] = ACTIONS(5119),
    [anon_sym_CARET_EQ] = ACTIONS(5119),
    [anon_sym_LT_LT_EQ] = ACTIONS(5119),
    [anon_sym_GT_GT_EQ] = ACTIONS(5119),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5119),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5119),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5119),
    [anon_sym_if] = ACTIONS(5119),
    [anon_sym_SEMI] = ACTIONS(5119),
    [anon_sym_else] = ACTIONS(5119),
    [anon_sym_when] = ACTIONS(5119),
    [anon_sym_in] = ACTIONS(5119),
    [anon_sym_case] = ACTIONS(5119),
    [anon_sym_QMARK] = ACTIONS(5119),
    [anon_sym_PLUS] = ACTIONS(5121),
    [anon_sym_DASH] = ACTIONS(5121),
    [anon_sym_TILDE] = ACTIONS(5121),
    [anon_sym_AMP] = ACTIONS(5121),
    [anon_sym_PIPE_PIPE] = ACTIONS(5121),
    [anon_sym_or_else] = ACTIONS(5119),
    [anon_sym_AMP_AMP] = ACTIONS(5121),
    [anon_sym_GT] = ACTIONS(5121),
    [anon_sym_GT_EQ] = ACTIONS(5119),
    [anon_sym_LT_EQ] = ACTIONS(5119),
    [anon_sym_LT] = ACTIONS(5121),
    [anon_sym_EQ_EQ] = ACTIONS(5119),
    [anon_sym_BANG_EQ] = ACTIONS(5119),
    [anon_sym_TILDE_EQ] = ACTIONS(5119),
    [anon_sym_AMP_TILDE] = ACTIONS(5121),
    [anon_sym_LT_LT] = ACTIONS(5121),
    [anon_sym_GT_GT] = ACTIONS(5121),
    [anon_sym_STAR] = ACTIONS(5121),
    [anon_sym_SLASH] = ACTIONS(5121),
    [anon_sym_PERCENT] = ACTIONS(5121),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5119),
    [anon_sym_DOT] = ACTIONS(5121),
    [anon_sym_LBRACK] = ACTIONS(5119),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5119),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5119),
    [anon_sym_not_in] = ACTIONS(5119),
    [anon_sym_or_return] = ACTIONS(5119),
    [anon_sym_or_continue] = ACTIONS(5119),
    [anon_sym_or_break] = ACTIONS(5119),
    [anon_sym_CARET] = ACTIONS(5121),
    [sym_uninitialized] = ACTIONS(5119),
    [sym_tag] = ACTIONS(5119),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5119),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [851] = {
    [ts_builtin_sym_end] = ACTIONS(5123),
    [anon_sym_LBRACE] = ACTIONS(5123),
    [anon_sym_RBRACE] = ACTIONS(5123),
    [anon_sym_COMMA] = ACTIONS(5123),
    [anon_sym_COLON_COLON] = ACTIONS(5123),
    [anon_sym_DASH_GT] = ACTIONS(5123),
    [anon_sym_where] = ACTIONS(5123),
    [anon_sym_EQ] = ACTIONS(5125),
    [anon_sym_COLON] = ACTIONS(5125),
    [anon_sym_PIPE] = ACTIONS(5125),
    [anon_sym_COLON_EQ] = ACTIONS(5123),
    [anon_sym_LPAREN] = ACTIONS(5123),
    [anon_sym_PLUS_EQ] = ACTIONS(5123),
    [anon_sym_DASH_EQ] = ACTIONS(5123),
    [anon_sym_STAR_EQ] = ACTIONS(5123),
    [anon_sym_SLASH_EQ] = ACTIONS(5123),
    [anon_sym_PERCENT_EQ] = ACTIONS(5123),
    [anon_sym_AMP_EQ] = ACTIONS(5123),
    [anon_sym_PIPE_EQ] = ACTIONS(5123),
    [anon_sym_CARET_EQ] = ACTIONS(5123),
    [anon_sym_LT_LT_EQ] = ACTIONS(5123),
    [anon_sym_GT_GT_EQ] = ACTIONS(5123),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5123),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5123),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5123),
    [anon_sym_if] = ACTIONS(5123),
    [anon_sym_SEMI] = ACTIONS(5123),
    [anon_sym_else] = ACTIONS(5123),
    [anon_sym_when] = ACTIONS(5123),
    [anon_sym_in] = ACTIONS(5123),
    [anon_sym_case] = ACTIONS(5123),
    [anon_sym_QMARK] = ACTIONS(5123),
    [anon_sym_PLUS] = ACTIONS(5125),
    [anon_sym_DASH] = ACTIONS(5125),
    [anon_sym_TILDE] = ACTIONS(5125),
    [anon_sym_AMP] = ACTIONS(5125),
    [anon_sym_PIPE_PIPE] = ACTIONS(5125),
    [anon_sym_or_else] = ACTIONS(5123),
    [anon_sym_AMP_AMP] = ACTIONS(5125),
    [anon_sym_GT] = ACTIONS(5125),
    [anon_sym_GT_EQ] = ACTIONS(5123),
    [anon_sym_LT_EQ] = ACTIONS(5123),
    [anon_sym_LT] = ACTIONS(5125),
    [anon_sym_EQ_EQ] = ACTIONS(5123),
    [anon_sym_BANG_EQ] = ACTIONS(5123),
    [anon_sym_TILDE_EQ] = ACTIONS(5123),
    [anon_sym_AMP_TILDE] = ACTIONS(5125),
    [anon_sym_LT_LT] = ACTIONS(5125),
    [anon_sym_GT_GT] = ACTIONS(5125),
    [anon_sym_STAR] = ACTIONS(5125),
    [anon_sym_SLASH] = ACTIONS(5125),
    [anon_sym_PERCENT] = ACTIONS(5125),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5123),
    [anon_sym_DOT] = ACTIONS(5125),
    [anon_sym_LBRACK] = ACTIONS(5123),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5123),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5123),
    [anon_sym_not_in] = ACTIONS(5123),
    [anon_sym_or_return] = ACTIONS(5123),
    [anon_sym_or_continue] = ACTIONS(5123),
    [anon_sym_or_break] = ACTIONS(5123),
    [anon_sym_CARET] = ACTIONS(5125),
    [sym_uninitialized] = ACTIONS(5123),
    [sym_tag] = ACTIONS(5123),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5123),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [852] = {
    [ts_builtin_sym_end] = ACTIONS(5127),
    [anon_sym_LBRACE] = ACTIONS(5127),
    [anon_sym_RBRACE] = ACTIONS(5127),
    [anon_sym_COMMA] = ACTIONS(5127),
    [anon_sym_COLON_COLON] = ACTIONS(5127),
    [anon_sym_DASH_GT] = ACTIONS(5127),
    [anon_sym_where] = ACTIONS(5127),
    [anon_sym_EQ] = ACTIONS(5129),
    [anon_sym_COLON] = ACTIONS(5129),
    [anon_sym_PIPE] = ACTIONS(5129),
    [anon_sym_COLON_EQ] = ACTIONS(5127),
    [anon_sym_LPAREN] = ACTIONS(5127),
    [anon_sym_PLUS_EQ] = ACTIONS(5127),
    [anon_sym_DASH_EQ] = ACTIONS(5127),
    [anon_sym_STAR_EQ] = ACTIONS(5127),
    [anon_sym_SLASH_EQ] = ACTIONS(5127),
    [anon_sym_PERCENT_EQ] = ACTIONS(5127),
    [anon_sym_AMP_EQ] = ACTIONS(5127),
    [anon_sym_PIPE_EQ] = ACTIONS(5127),
    [anon_sym_CARET_EQ] = ACTIONS(5127),
    [anon_sym_LT_LT_EQ] = ACTIONS(5127),
    [anon_sym_GT_GT_EQ] = ACTIONS(5127),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5127),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5127),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5127),
    [anon_sym_if] = ACTIONS(5127),
    [anon_sym_SEMI] = ACTIONS(5127),
    [anon_sym_else] = ACTIONS(5127),
    [anon_sym_when] = ACTIONS(5127),
    [anon_sym_in] = ACTIONS(5127),
    [anon_sym_case] = ACTIONS(5127),
    [anon_sym_QMARK] = ACTIONS(5127),
    [anon_sym_PLUS] = ACTIONS(5129),
    [anon_sym_DASH] = ACTIONS(5129),
    [anon_sym_TILDE] = ACTIONS(5129),
    [anon_sym_AMP] = ACTIONS(5129),
    [anon_sym_PIPE_PIPE] = ACTIONS(5129),
    [anon_sym_or_else] = ACTIONS(5127),
    [anon_sym_AMP_AMP] = ACTIONS(5129),
    [anon_sym_GT] = ACTIONS(5129),
    [anon_sym_GT_EQ] = ACTIONS(5127),
    [anon_sym_LT_EQ] = ACTIONS(5127),
    [anon_sym_LT] = ACTIONS(5129),
    [anon_sym_EQ_EQ] = ACTIONS(5127),
    [anon_sym_BANG_EQ] = ACTIONS(5127),
    [anon_sym_TILDE_EQ] = ACTIONS(5127),
    [anon_sym_AMP_TILDE] = ACTIONS(5129),
    [anon_sym_LT_LT] = ACTIONS(5129),
    [anon_sym_GT_GT] = ACTIONS(5129),
    [anon_sym_STAR] = ACTIONS(5129),
    [anon_sym_SLASH] = ACTIONS(5129),
    [anon_sym_PERCENT] = ACTIONS(5129),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5127),
    [anon_sym_DOT] = ACTIONS(5129),
    [anon_sym_LBRACK] = ACTIONS(5127),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5127),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5127),
    [anon_sym_not_in] = ACTIONS(5127),
    [anon_sym_or_return] = ACTIONS(5127),
    [anon_sym_or_continue] = ACTIONS(5127),
    [anon_sym_or_break] = ACTIONS(5127),
    [anon_sym_CARET] = ACTIONS(5129),
    [sym_uninitialized] = ACTIONS(5127),
    [sym_tag] = ACTIONS(5127),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5127),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [853] = {
    [ts_builtin_sym_end] = ACTIONS(5131),
    [anon_sym_LBRACE] = ACTIONS(5131),
    [anon_sym_RBRACE] = ACTIONS(5131),
    [anon_sym_COMMA] = ACTIONS(5131),
    [anon_sym_COLON_COLON] = ACTIONS(5131),
    [anon_sym_DASH_GT] = ACTIONS(5131),
    [anon_sym_where] = ACTIONS(5131),
    [anon_sym_EQ] = ACTIONS(5133),
    [anon_sym_COLON] = ACTIONS(5133),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_COLON_EQ] = ACTIONS(5131),
    [anon_sym_LPAREN] = ACTIONS(5131),
    [anon_sym_PLUS_EQ] = ACTIONS(5131),
    [anon_sym_DASH_EQ] = ACTIONS(5131),
    [anon_sym_STAR_EQ] = ACTIONS(5131),
    [anon_sym_SLASH_EQ] = ACTIONS(5131),
    [anon_sym_PERCENT_EQ] = ACTIONS(5131),
    [anon_sym_AMP_EQ] = ACTIONS(5131),
    [anon_sym_PIPE_EQ] = ACTIONS(5131),
    [anon_sym_CARET_EQ] = ACTIONS(5131),
    [anon_sym_LT_LT_EQ] = ACTIONS(5131),
    [anon_sym_GT_GT_EQ] = ACTIONS(5131),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5131),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5131),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5131),
    [anon_sym_if] = ACTIONS(5131),
    [anon_sym_SEMI] = ACTIONS(5131),
    [anon_sym_else] = ACTIONS(5131),
    [anon_sym_when] = ACTIONS(5131),
    [anon_sym_in] = ACTIONS(5131),
    [anon_sym_case] = ACTIONS(5131),
    [anon_sym_QMARK] = ACTIONS(5131),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_TILDE] = ACTIONS(5133),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_PIPE_PIPE] = ACTIONS(5133),
    [anon_sym_or_else] = ACTIONS(5131),
    [anon_sym_AMP_AMP] = ACTIONS(5133),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5131),
    [anon_sym_LT_EQ] = ACTIONS(5131),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5131),
    [anon_sym_BANG_EQ] = ACTIONS(5131),
    [anon_sym_TILDE_EQ] = ACTIONS(5131),
    [anon_sym_AMP_TILDE] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5133),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5133),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5131),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_LBRACK] = ACTIONS(5131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5131),
    [anon_sym_not_in] = ACTIONS(5131),
    [anon_sym_or_return] = ACTIONS(5131),
    [anon_sym_or_continue] = ACTIONS(5131),
    [anon_sym_or_break] = ACTIONS(5131),
    [anon_sym_CARET] = ACTIONS(5133),
    [sym_uninitialized] = ACTIONS(5131),
    [sym_tag] = ACTIONS(5131),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5131),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [854] = {
    [ts_builtin_sym_end] = ACTIONS(5135),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_RBRACE] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_COLON_COLON] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [anon_sym_where] = ACTIONS(5135),
    [anon_sym_EQ] = ACTIONS(5137),
    [anon_sym_COLON] = ACTIONS(5137),
    [anon_sym_PIPE] = ACTIONS(5137),
    [anon_sym_COLON_EQ] = ACTIONS(5135),
    [anon_sym_LPAREN] = ACTIONS(5135),
    [anon_sym_PLUS_EQ] = ACTIONS(5135),
    [anon_sym_DASH_EQ] = ACTIONS(5135),
    [anon_sym_STAR_EQ] = ACTIONS(5135),
    [anon_sym_SLASH_EQ] = ACTIONS(5135),
    [anon_sym_PERCENT_EQ] = ACTIONS(5135),
    [anon_sym_AMP_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_CARET_EQ] = ACTIONS(5135),
    [anon_sym_LT_LT_EQ] = ACTIONS(5135),
    [anon_sym_GT_GT_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5135),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5135),
    [anon_sym_if] = ACTIONS(5135),
    [anon_sym_SEMI] = ACTIONS(5135),
    [anon_sym_else] = ACTIONS(5135),
    [anon_sym_when] = ACTIONS(5135),
    [anon_sym_in] = ACTIONS(5135),
    [anon_sym_case] = ACTIONS(5135),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_PLUS] = ACTIONS(5137),
    [anon_sym_DASH] = ACTIONS(5137),
    [anon_sym_TILDE] = ACTIONS(5137),
    [anon_sym_AMP] = ACTIONS(5137),
    [anon_sym_PIPE_PIPE] = ACTIONS(5137),
    [anon_sym_or_else] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5137),
    [anon_sym_GT] = ACTIONS(5137),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5135),
    [anon_sym_LT] = ACTIONS(5137),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_TILDE_EQ] = ACTIONS(5135),
    [anon_sym_AMP_TILDE] = ACTIONS(5137),
    [anon_sym_LT_LT] = ACTIONS(5137),
    [anon_sym_GT_GT] = ACTIONS(5137),
    [anon_sym_STAR] = ACTIONS(5137),
    [anon_sym_SLASH] = ACTIONS(5137),
    [anon_sym_PERCENT] = ACTIONS(5137),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5137),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5135),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5135),
    [anon_sym_not_in] = ACTIONS(5135),
    [anon_sym_or_return] = ACTIONS(5135),
    [anon_sym_or_continue] = ACTIONS(5135),
    [anon_sym_or_break] = ACTIONS(5135),
    [anon_sym_CARET] = ACTIONS(5137),
    [sym_uninitialized] = ACTIONS(5135),
    [sym_tag] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5135),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [855] = {
    [sym_expression] = STATE(5771),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_foreign] = ACTIONS(4777),
    [anon_sym_import] = ACTIONS(4779),
    [anon_sym_using] = ACTIONS(4781),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [856] = {
    [ts_builtin_sym_end] = ACTIONS(5139),
    [anon_sym_LBRACE] = ACTIONS(5139),
    [anon_sym_RBRACE] = ACTIONS(5139),
    [anon_sym_COMMA] = ACTIONS(5139),
    [anon_sym_COLON_COLON] = ACTIONS(5139),
    [anon_sym_DASH_GT] = ACTIONS(5139),
    [anon_sym_where] = ACTIONS(5139),
    [anon_sym_EQ] = ACTIONS(5141),
    [anon_sym_COLON] = ACTIONS(5141),
    [anon_sym_PIPE] = ACTIONS(5141),
    [anon_sym_COLON_EQ] = ACTIONS(5139),
    [anon_sym_LPAREN] = ACTIONS(5139),
    [anon_sym_PLUS_EQ] = ACTIONS(5139),
    [anon_sym_DASH_EQ] = ACTIONS(5139),
    [anon_sym_STAR_EQ] = ACTIONS(5139),
    [anon_sym_SLASH_EQ] = ACTIONS(5139),
    [anon_sym_PERCENT_EQ] = ACTIONS(5139),
    [anon_sym_AMP_EQ] = ACTIONS(5139),
    [anon_sym_PIPE_EQ] = ACTIONS(5139),
    [anon_sym_CARET_EQ] = ACTIONS(5139),
    [anon_sym_LT_LT_EQ] = ACTIONS(5139),
    [anon_sym_GT_GT_EQ] = ACTIONS(5139),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5139),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5139),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5139),
    [anon_sym_if] = ACTIONS(5139),
    [anon_sym_SEMI] = ACTIONS(5139),
    [anon_sym_else] = ACTIONS(5139),
    [anon_sym_when] = ACTIONS(5139),
    [anon_sym_in] = ACTIONS(5139),
    [anon_sym_case] = ACTIONS(5139),
    [anon_sym_QMARK] = ACTIONS(5139),
    [anon_sym_PLUS] = ACTIONS(5141),
    [anon_sym_DASH] = ACTIONS(5141),
    [anon_sym_TILDE] = ACTIONS(5141),
    [anon_sym_AMP] = ACTIONS(5141),
    [anon_sym_PIPE_PIPE] = ACTIONS(5141),
    [anon_sym_or_else] = ACTIONS(5139),
    [anon_sym_AMP_AMP] = ACTIONS(5141),
    [anon_sym_GT] = ACTIONS(5141),
    [anon_sym_GT_EQ] = ACTIONS(5139),
    [anon_sym_LT_EQ] = ACTIONS(5139),
    [anon_sym_LT] = ACTIONS(5141),
    [anon_sym_EQ_EQ] = ACTIONS(5139),
    [anon_sym_BANG_EQ] = ACTIONS(5139),
    [anon_sym_TILDE_EQ] = ACTIONS(5139),
    [anon_sym_AMP_TILDE] = ACTIONS(5141),
    [anon_sym_LT_LT] = ACTIONS(5141),
    [anon_sym_GT_GT] = ACTIONS(5141),
    [anon_sym_STAR] = ACTIONS(5141),
    [anon_sym_SLASH] = ACTIONS(5141),
    [anon_sym_PERCENT] = ACTIONS(5141),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5139),
    [anon_sym_DOT] = ACTIONS(5141),
    [anon_sym_LBRACK] = ACTIONS(5139),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5139),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5139),
    [anon_sym_not_in] = ACTIONS(5139),
    [anon_sym_or_return] = ACTIONS(5139),
    [anon_sym_or_continue] = ACTIONS(5139),
    [anon_sym_or_break] = ACTIONS(5139),
    [anon_sym_CARET] = ACTIONS(5141),
    [sym_uninitialized] = ACTIONS(5139),
    [sym_tag] = ACTIONS(5139),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5139),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [857] = {
    [ts_builtin_sym_end] = ACTIONS(4751),
    [anon_sym_LBRACE] = ACTIONS(5143),
    [anon_sym_RBRACE] = ACTIONS(4751),
    [anon_sym_COMMA] = ACTIONS(4751),
    [anon_sym_COLON_COLON] = ACTIONS(4751),
    [anon_sym_DASH_GT] = ACTIONS(4751),
    [anon_sym_where] = ACTIONS(4751),
    [anon_sym_EQ] = ACTIONS(4753),
    [anon_sym_COLON] = ACTIONS(4753),
    [anon_sym_PIPE] = ACTIONS(4753),
    [anon_sym_COLON_EQ] = ACTIONS(4751),
    [anon_sym_LPAREN] = ACTIONS(3376),
    [anon_sym_PLUS_EQ] = ACTIONS(4751),
    [anon_sym_DASH_EQ] = ACTIONS(4751),
    [anon_sym_STAR_EQ] = ACTIONS(4751),
    [anon_sym_SLASH_EQ] = ACTIONS(4751),
    [anon_sym_PERCENT_EQ] = ACTIONS(4751),
    [anon_sym_AMP_EQ] = ACTIONS(4751),
    [anon_sym_PIPE_EQ] = ACTIONS(4751),
    [anon_sym_CARET_EQ] = ACTIONS(4751),
    [anon_sym_LT_LT_EQ] = ACTIONS(4751),
    [anon_sym_GT_GT_EQ] = ACTIONS(4751),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4751),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4751),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4751),
    [anon_sym_if] = ACTIONS(4751),
    [anon_sym_SEMI] = ACTIONS(4751),
    [anon_sym_else] = ACTIONS(4751),
    [anon_sym_when] = ACTIONS(4751),
    [anon_sym_in] = ACTIONS(4751),
    [anon_sym_case] = ACTIONS(4751),
    [anon_sym_QMARK] = ACTIONS(4751),
    [anon_sym_PLUS] = ACTIONS(4753),
    [anon_sym_DASH] = ACTIONS(4753),
    [anon_sym_TILDE] = ACTIONS(4753),
    [anon_sym_AMP] = ACTIONS(4753),
    [anon_sym_PIPE_PIPE] = ACTIONS(4753),
    [anon_sym_or_else] = ACTIONS(4751),
    [anon_sym_AMP_AMP] = ACTIONS(4753),
    [anon_sym_GT] = ACTIONS(4753),
    [anon_sym_GT_EQ] = ACTIONS(4751),
    [anon_sym_LT_EQ] = ACTIONS(4751),
    [anon_sym_LT] = ACTIONS(4753),
    [anon_sym_EQ_EQ] = ACTIONS(4751),
    [anon_sym_BANG_EQ] = ACTIONS(4751),
    [anon_sym_TILDE_EQ] = ACTIONS(4751),
    [anon_sym_AMP_TILDE] = ACTIONS(4753),
    [anon_sym_LT_LT] = ACTIONS(4753),
    [anon_sym_GT_GT] = ACTIONS(4753),
    [anon_sym_STAR] = ACTIONS(4753),
    [anon_sym_SLASH] = ACTIONS(3378),
    [anon_sym_PERCENT] = ACTIONS(4753),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4751),
    [anon_sym_DOT] = ACTIONS(4753),
    [anon_sym_LBRACK] = ACTIONS(4751),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4751),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4751),
    [anon_sym_not_in] = ACTIONS(4751),
    [anon_sym_or_return] = ACTIONS(4751),
    [anon_sym_or_continue] = ACTIONS(4751),
    [anon_sym_or_break] = ACTIONS(4751),
    [anon_sym_CARET] = ACTIONS(4753),
    [sym_uninitialized] = ACTIONS(4751),
    [sym_tag] = ACTIONS(4751),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4751),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [858] = {
    [ts_builtin_sym_end] = ACTIONS(5145),
    [anon_sym_LBRACE] = ACTIONS(5145),
    [anon_sym_RBRACE] = ACTIONS(5145),
    [anon_sym_COMMA] = ACTIONS(5145),
    [anon_sym_COLON_COLON] = ACTIONS(5145),
    [anon_sym_DASH_GT] = ACTIONS(5145),
    [anon_sym_where] = ACTIONS(5145),
    [anon_sym_EQ] = ACTIONS(5147),
    [anon_sym_COLON] = ACTIONS(5147),
    [anon_sym_PIPE] = ACTIONS(5147),
    [anon_sym_COLON_EQ] = ACTIONS(5145),
    [anon_sym_LPAREN] = ACTIONS(5145),
    [anon_sym_PLUS_EQ] = ACTIONS(5145),
    [anon_sym_DASH_EQ] = ACTIONS(5145),
    [anon_sym_STAR_EQ] = ACTIONS(5145),
    [anon_sym_SLASH_EQ] = ACTIONS(5145),
    [anon_sym_PERCENT_EQ] = ACTIONS(5145),
    [anon_sym_AMP_EQ] = ACTIONS(5145),
    [anon_sym_PIPE_EQ] = ACTIONS(5145),
    [anon_sym_CARET_EQ] = ACTIONS(5145),
    [anon_sym_LT_LT_EQ] = ACTIONS(5145),
    [anon_sym_GT_GT_EQ] = ACTIONS(5145),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5145),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5145),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5145),
    [anon_sym_if] = ACTIONS(5145),
    [anon_sym_SEMI] = ACTIONS(5145),
    [anon_sym_else] = ACTIONS(5145),
    [anon_sym_when] = ACTIONS(5145),
    [anon_sym_in] = ACTIONS(5145),
    [anon_sym_case] = ACTIONS(5145),
    [anon_sym_QMARK] = ACTIONS(5145),
    [anon_sym_PLUS] = ACTIONS(5147),
    [anon_sym_DASH] = ACTIONS(5147),
    [anon_sym_TILDE] = ACTIONS(5147),
    [anon_sym_AMP] = ACTIONS(5147),
    [anon_sym_PIPE_PIPE] = ACTIONS(5147),
    [anon_sym_or_else] = ACTIONS(5145),
    [anon_sym_AMP_AMP] = ACTIONS(5147),
    [anon_sym_GT] = ACTIONS(5147),
    [anon_sym_GT_EQ] = ACTIONS(5145),
    [anon_sym_LT_EQ] = ACTIONS(5145),
    [anon_sym_LT] = ACTIONS(5147),
    [anon_sym_EQ_EQ] = ACTIONS(5145),
    [anon_sym_BANG_EQ] = ACTIONS(5145),
    [anon_sym_TILDE_EQ] = ACTIONS(5145),
    [anon_sym_AMP_TILDE] = ACTIONS(5147),
    [anon_sym_LT_LT] = ACTIONS(5147),
    [anon_sym_GT_GT] = ACTIONS(5147),
    [anon_sym_STAR] = ACTIONS(5147),
    [anon_sym_SLASH] = ACTIONS(5147),
    [anon_sym_PERCENT] = ACTIONS(5147),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5145),
    [anon_sym_DOT] = ACTIONS(5147),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5145),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5145),
    [anon_sym_not_in] = ACTIONS(5145),
    [anon_sym_or_return] = ACTIONS(5145),
    [anon_sym_or_continue] = ACTIONS(5145),
    [anon_sym_or_break] = ACTIONS(5145),
    [anon_sym_CARET] = ACTIONS(5147),
    [sym_uninitialized] = ACTIONS(5145),
    [sym_tag] = ACTIONS(5145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5145),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [859] = {
    [sym_expression] = STATE(6471),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5149),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5151),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5153),
    [anon_sym_dynamic] = ACTIONS(5155),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [860] = {
    [sym_expression] = STATE(6480),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5157),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5159),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5161),
    [anon_sym_dynamic] = ACTIONS(5163),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [861] = {
    [sym_expression] = STATE(6487),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5165),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5167),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5169),
    [anon_sym_dynamic] = ACTIONS(5171),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [862] = {
    [sym_expression] = STATE(6495),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5173),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5175),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5177),
    [anon_sym_dynamic] = ACTIONS(5179),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [863] = {
    [sym_expression] = STATE(6504),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5181),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5183),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5185),
    [anon_sym_dynamic] = ACTIONS(5187),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [864] = {
    [sym_expression] = STATE(6513),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5189),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5191),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5193),
    [anon_sym_dynamic] = ACTIONS(5195),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [865] = {
    [sym_expression] = STATE(6520),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5197),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5199),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5201),
    [anon_sym_dynamic] = ACTIONS(5203),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [866] = {
    [sym_expression] = STATE(6527),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5205),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5207),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5209),
    [anon_sym_dynamic] = ACTIONS(5211),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [867] = {
    [sym_expression] = STATE(6531),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5213),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5215),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5217),
    [anon_sym_dynamic] = ACTIONS(5219),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [868] = {
    [sym_expression] = STATE(6539),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5221),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5223),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5225),
    [anon_sym_dynamic] = ACTIONS(5227),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [869] = {
    [sym_expression] = STATE(6546),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5229),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5231),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5233),
    [anon_sym_dynamic] = ACTIONS(5235),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [870] = {
    [ts_builtin_sym_end] = ACTIONS(809),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_where] = ACTIONS(809),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_PLUS_EQ] = ACTIONS(809),
    [anon_sym_DASH_EQ] = ACTIONS(809),
    [anon_sym_STAR_EQ] = ACTIONS(809),
    [anon_sym_SLASH_EQ] = ACTIONS(809),
    [anon_sym_PERCENT_EQ] = ACTIONS(809),
    [anon_sym_AMP_EQ] = ACTIONS(809),
    [anon_sym_PIPE_EQ] = ACTIONS(809),
    [anon_sym_CARET_EQ] = ACTIONS(809),
    [anon_sym_LT_LT_EQ] = ACTIONS(809),
    [anon_sym_GT_GT_EQ] = ACTIONS(809),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(809),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(809),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(809),
    [anon_sym_when] = ACTIONS(809),
    [anon_sym_in] = ACTIONS(809),
    [anon_sym_case] = ACTIONS(809),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(812),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(812),
    [anon_sym_or_else] = ACTIONS(809),
    [anon_sym_AMP_AMP] = ACTIONS(812),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(812),
    [anon_sym_LT_LT] = ACTIONS(812),
    [anon_sym_GT_GT] = ACTIONS(812),
    [anon_sym_STAR] = ACTIONS(812),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(809),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(809),
    [anon_sym_or_return] = ACTIONS(809),
    [anon_sym_or_continue] = ACTIONS(809),
    [anon_sym_or_break] = ACTIONS(809),
    [anon_sym_CARET] = ACTIONS(812),
    [sym_uninitialized] = ACTIONS(809),
    [sym_tag] = ACTIONS(809),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [871] = {
    [ts_builtin_sym_end] = ACTIONS(5237),
    [anon_sym_LBRACE] = ACTIONS(5237),
    [anon_sym_RBRACE] = ACTIONS(5237),
    [anon_sym_COMMA] = ACTIONS(5237),
    [anon_sym_COLON_COLON] = ACTIONS(5237),
    [anon_sym_DASH_GT] = ACTIONS(5237),
    [anon_sym_where] = ACTIONS(5237),
    [anon_sym_EQ] = ACTIONS(5239),
    [anon_sym_COLON] = ACTIONS(5239),
    [anon_sym_PIPE] = ACTIONS(5239),
    [anon_sym_COLON_EQ] = ACTIONS(5237),
    [anon_sym_LPAREN] = ACTIONS(5237),
    [anon_sym_PLUS_EQ] = ACTIONS(5237),
    [anon_sym_DASH_EQ] = ACTIONS(5237),
    [anon_sym_STAR_EQ] = ACTIONS(5237),
    [anon_sym_SLASH_EQ] = ACTIONS(5237),
    [anon_sym_PERCENT_EQ] = ACTIONS(5237),
    [anon_sym_AMP_EQ] = ACTIONS(5237),
    [anon_sym_PIPE_EQ] = ACTIONS(5237),
    [anon_sym_CARET_EQ] = ACTIONS(5237),
    [anon_sym_LT_LT_EQ] = ACTIONS(5237),
    [anon_sym_GT_GT_EQ] = ACTIONS(5237),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5237),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5237),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5237),
    [anon_sym_if] = ACTIONS(5237),
    [anon_sym_SEMI] = ACTIONS(5237),
    [anon_sym_else] = ACTIONS(5237),
    [anon_sym_when] = ACTIONS(5237),
    [anon_sym_in] = ACTIONS(5237),
    [anon_sym_case] = ACTIONS(5237),
    [anon_sym_QMARK] = ACTIONS(5237),
    [anon_sym_PLUS] = ACTIONS(5239),
    [anon_sym_DASH] = ACTIONS(5239),
    [anon_sym_TILDE] = ACTIONS(5239),
    [anon_sym_AMP] = ACTIONS(5239),
    [anon_sym_PIPE_PIPE] = ACTIONS(5239),
    [anon_sym_or_else] = ACTIONS(5237),
    [anon_sym_AMP_AMP] = ACTIONS(5239),
    [anon_sym_GT] = ACTIONS(5239),
    [anon_sym_GT_EQ] = ACTIONS(5237),
    [anon_sym_LT_EQ] = ACTIONS(5237),
    [anon_sym_LT] = ACTIONS(5239),
    [anon_sym_EQ_EQ] = ACTIONS(5237),
    [anon_sym_BANG_EQ] = ACTIONS(5237),
    [anon_sym_TILDE_EQ] = ACTIONS(5237),
    [anon_sym_AMP_TILDE] = ACTIONS(5239),
    [anon_sym_LT_LT] = ACTIONS(5239),
    [anon_sym_GT_GT] = ACTIONS(5239),
    [anon_sym_STAR] = ACTIONS(5239),
    [anon_sym_SLASH] = ACTIONS(5239),
    [anon_sym_PERCENT] = ACTIONS(5239),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5237),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_LBRACK] = ACTIONS(5237),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5237),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5237),
    [anon_sym_not_in] = ACTIONS(5237),
    [anon_sym_or_return] = ACTIONS(5237),
    [anon_sym_or_continue] = ACTIONS(5237),
    [anon_sym_or_break] = ACTIONS(5237),
    [anon_sym_CARET] = ACTIONS(5239),
    [sym_uninitialized] = ACTIONS(5237),
    [sym_tag] = ACTIONS(5237),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5237),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [872] = {
    [ts_builtin_sym_end] = ACTIONS(5241),
    [anon_sym_LBRACE] = ACTIONS(5241),
    [anon_sym_RBRACE] = ACTIONS(5241),
    [anon_sym_COMMA] = ACTIONS(5241),
    [anon_sym_COLON_COLON] = ACTIONS(5241),
    [anon_sym_DASH_GT] = ACTIONS(5241),
    [anon_sym_where] = ACTIONS(5241),
    [anon_sym_EQ] = ACTIONS(5243),
    [anon_sym_COLON] = ACTIONS(5243),
    [anon_sym_PIPE] = ACTIONS(5243),
    [anon_sym_COLON_EQ] = ACTIONS(5241),
    [anon_sym_LPAREN] = ACTIONS(5241),
    [anon_sym_PLUS_EQ] = ACTIONS(5241),
    [anon_sym_DASH_EQ] = ACTIONS(5241),
    [anon_sym_STAR_EQ] = ACTIONS(5241),
    [anon_sym_SLASH_EQ] = ACTIONS(5241),
    [anon_sym_PERCENT_EQ] = ACTIONS(5241),
    [anon_sym_AMP_EQ] = ACTIONS(5241),
    [anon_sym_PIPE_EQ] = ACTIONS(5241),
    [anon_sym_CARET_EQ] = ACTIONS(5241),
    [anon_sym_LT_LT_EQ] = ACTIONS(5241),
    [anon_sym_GT_GT_EQ] = ACTIONS(5241),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5241),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5241),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5241),
    [anon_sym_if] = ACTIONS(5241),
    [anon_sym_SEMI] = ACTIONS(5241),
    [anon_sym_else] = ACTIONS(5241),
    [anon_sym_when] = ACTIONS(5241),
    [anon_sym_in] = ACTIONS(5241),
    [anon_sym_case] = ACTIONS(5241),
    [anon_sym_QMARK] = ACTIONS(5241),
    [anon_sym_PLUS] = ACTIONS(5243),
    [anon_sym_DASH] = ACTIONS(5243),
    [anon_sym_TILDE] = ACTIONS(5243),
    [anon_sym_AMP] = ACTIONS(5243),
    [anon_sym_PIPE_PIPE] = ACTIONS(5243),
    [anon_sym_or_else] = ACTIONS(5241),
    [anon_sym_AMP_AMP] = ACTIONS(5243),
    [anon_sym_GT] = ACTIONS(5243),
    [anon_sym_GT_EQ] = ACTIONS(5241),
    [anon_sym_LT_EQ] = ACTIONS(5241),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_EQ_EQ] = ACTIONS(5241),
    [anon_sym_BANG_EQ] = ACTIONS(5241),
    [anon_sym_TILDE_EQ] = ACTIONS(5241),
    [anon_sym_AMP_TILDE] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(5243),
    [anon_sym_GT_GT] = ACTIONS(5243),
    [anon_sym_STAR] = ACTIONS(5243),
    [anon_sym_SLASH] = ACTIONS(5243),
    [anon_sym_PERCENT] = ACTIONS(5243),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5241),
    [anon_sym_DOT] = ACTIONS(5243),
    [anon_sym_LBRACK] = ACTIONS(5241),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5241),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5241),
    [anon_sym_not_in] = ACTIONS(5241),
    [anon_sym_or_return] = ACTIONS(5241),
    [anon_sym_or_continue] = ACTIONS(5241),
    [anon_sym_or_break] = ACTIONS(5241),
    [anon_sym_CARET] = ACTIONS(5243),
    [sym_uninitialized] = ACTIONS(5241),
    [sym_tag] = ACTIONS(5241),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5241),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [873] = {
    [ts_builtin_sym_end] = ACTIONS(5245),
    [anon_sym_LBRACE] = ACTIONS(5245),
    [anon_sym_RBRACE] = ACTIONS(5245),
    [anon_sym_COMMA] = ACTIONS(5245),
    [anon_sym_COLON_COLON] = ACTIONS(5245),
    [anon_sym_DASH_GT] = ACTIONS(5245),
    [anon_sym_where] = ACTIONS(5245),
    [anon_sym_EQ] = ACTIONS(5247),
    [anon_sym_COLON] = ACTIONS(5247),
    [anon_sym_PIPE] = ACTIONS(5247),
    [anon_sym_COLON_EQ] = ACTIONS(5245),
    [anon_sym_LPAREN] = ACTIONS(5245),
    [anon_sym_PLUS_EQ] = ACTIONS(5245),
    [anon_sym_DASH_EQ] = ACTIONS(5245),
    [anon_sym_STAR_EQ] = ACTIONS(5245),
    [anon_sym_SLASH_EQ] = ACTIONS(5245),
    [anon_sym_PERCENT_EQ] = ACTIONS(5245),
    [anon_sym_AMP_EQ] = ACTIONS(5245),
    [anon_sym_PIPE_EQ] = ACTIONS(5245),
    [anon_sym_CARET_EQ] = ACTIONS(5245),
    [anon_sym_LT_LT_EQ] = ACTIONS(5245),
    [anon_sym_GT_GT_EQ] = ACTIONS(5245),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5245),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5245),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5245),
    [anon_sym_if] = ACTIONS(5245),
    [anon_sym_SEMI] = ACTIONS(5245),
    [anon_sym_else] = ACTIONS(5245),
    [anon_sym_when] = ACTIONS(5245),
    [anon_sym_in] = ACTIONS(5245),
    [anon_sym_case] = ACTIONS(5245),
    [anon_sym_QMARK] = ACTIONS(5245),
    [anon_sym_PLUS] = ACTIONS(5247),
    [anon_sym_DASH] = ACTIONS(5247),
    [anon_sym_TILDE] = ACTIONS(5247),
    [anon_sym_AMP] = ACTIONS(5247),
    [anon_sym_PIPE_PIPE] = ACTIONS(5247),
    [anon_sym_or_else] = ACTIONS(5245),
    [anon_sym_AMP_AMP] = ACTIONS(5247),
    [anon_sym_GT] = ACTIONS(5247),
    [anon_sym_GT_EQ] = ACTIONS(5245),
    [anon_sym_LT_EQ] = ACTIONS(5245),
    [anon_sym_LT] = ACTIONS(5247),
    [anon_sym_EQ_EQ] = ACTIONS(5245),
    [anon_sym_BANG_EQ] = ACTIONS(5245),
    [anon_sym_TILDE_EQ] = ACTIONS(5245),
    [anon_sym_AMP_TILDE] = ACTIONS(5247),
    [anon_sym_LT_LT] = ACTIONS(5247),
    [anon_sym_GT_GT] = ACTIONS(5247),
    [anon_sym_STAR] = ACTIONS(5247),
    [anon_sym_SLASH] = ACTIONS(5247),
    [anon_sym_PERCENT] = ACTIONS(5247),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5245),
    [anon_sym_DOT] = ACTIONS(5247),
    [anon_sym_LBRACK] = ACTIONS(5245),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5245),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5245),
    [anon_sym_not_in] = ACTIONS(5245),
    [anon_sym_or_return] = ACTIONS(5245),
    [anon_sym_or_continue] = ACTIONS(5245),
    [anon_sym_or_break] = ACTIONS(5245),
    [anon_sym_CARET] = ACTIONS(5247),
    [sym_uninitialized] = ACTIONS(5245),
    [sym_tag] = ACTIONS(5245),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5245),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [874] = {
    [ts_builtin_sym_end] = ACTIONS(5249),
    [anon_sym_LBRACE] = ACTIONS(5249),
    [anon_sym_RBRACE] = ACTIONS(5249),
    [anon_sym_COMMA] = ACTIONS(5249),
    [anon_sym_COLON_COLON] = ACTIONS(5249),
    [anon_sym_DASH_GT] = ACTIONS(5249),
    [anon_sym_where] = ACTIONS(5249),
    [anon_sym_EQ] = ACTIONS(5251),
    [anon_sym_COLON] = ACTIONS(5251),
    [anon_sym_PIPE] = ACTIONS(5251),
    [anon_sym_COLON_EQ] = ACTIONS(5249),
    [anon_sym_LPAREN] = ACTIONS(5249),
    [anon_sym_PLUS_EQ] = ACTIONS(5249),
    [anon_sym_DASH_EQ] = ACTIONS(5249),
    [anon_sym_STAR_EQ] = ACTIONS(5249),
    [anon_sym_SLASH_EQ] = ACTIONS(5249),
    [anon_sym_PERCENT_EQ] = ACTIONS(5249),
    [anon_sym_AMP_EQ] = ACTIONS(5249),
    [anon_sym_PIPE_EQ] = ACTIONS(5249),
    [anon_sym_CARET_EQ] = ACTIONS(5249),
    [anon_sym_LT_LT_EQ] = ACTIONS(5249),
    [anon_sym_GT_GT_EQ] = ACTIONS(5249),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5249),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5249),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5249),
    [anon_sym_if] = ACTIONS(5249),
    [anon_sym_SEMI] = ACTIONS(5249),
    [anon_sym_else] = ACTIONS(5249),
    [anon_sym_when] = ACTIONS(5249),
    [anon_sym_in] = ACTIONS(5249),
    [anon_sym_case] = ACTIONS(5249),
    [anon_sym_QMARK] = ACTIONS(5249),
    [anon_sym_PLUS] = ACTIONS(5251),
    [anon_sym_DASH] = ACTIONS(5251),
    [anon_sym_TILDE] = ACTIONS(5251),
    [anon_sym_AMP] = ACTIONS(5251),
    [anon_sym_PIPE_PIPE] = ACTIONS(5251),
    [anon_sym_or_else] = ACTIONS(5249),
    [anon_sym_AMP_AMP] = ACTIONS(5251),
    [anon_sym_GT] = ACTIONS(5251),
    [anon_sym_GT_EQ] = ACTIONS(5249),
    [anon_sym_LT_EQ] = ACTIONS(5249),
    [anon_sym_LT] = ACTIONS(5251),
    [anon_sym_EQ_EQ] = ACTIONS(5249),
    [anon_sym_BANG_EQ] = ACTIONS(5249),
    [anon_sym_TILDE_EQ] = ACTIONS(5249),
    [anon_sym_AMP_TILDE] = ACTIONS(5251),
    [anon_sym_LT_LT] = ACTIONS(5251),
    [anon_sym_GT_GT] = ACTIONS(5251),
    [anon_sym_STAR] = ACTIONS(5251),
    [anon_sym_SLASH] = ACTIONS(5251),
    [anon_sym_PERCENT] = ACTIONS(5251),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5249),
    [anon_sym_DOT] = ACTIONS(5251),
    [anon_sym_LBRACK] = ACTIONS(5249),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5249),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5249),
    [anon_sym_not_in] = ACTIONS(5249),
    [anon_sym_or_return] = ACTIONS(5249),
    [anon_sym_or_continue] = ACTIONS(5249),
    [anon_sym_or_break] = ACTIONS(5249),
    [anon_sym_CARET] = ACTIONS(5251),
    [sym_uninitialized] = ACTIONS(5249),
    [sym_tag] = ACTIONS(5249),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5249),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [875] = {
    [ts_builtin_sym_end] = ACTIONS(5253),
    [anon_sym_LBRACE] = ACTIONS(5253),
    [anon_sym_RBRACE] = ACTIONS(5253),
    [anon_sym_COMMA] = ACTIONS(5253),
    [anon_sym_COLON_COLON] = ACTIONS(5253),
    [anon_sym_DASH_GT] = ACTIONS(5253),
    [anon_sym_where] = ACTIONS(5253),
    [anon_sym_EQ] = ACTIONS(5255),
    [anon_sym_COLON] = ACTIONS(5255),
    [anon_sym_PIPE] = ACTIONS(5255),
    [anon_sym_COLON_EQ] = ACTIONS(5253),
    [anon_sym_LPAREN] = ACTIONS(5253),
    [anon_sym_PLUS_EQ] = ACTIONS(5253),
    [anon_sym_DASH_EQ] = ACTIONS(5253),
    [anon_sym_STAR_EQ] = ACTIONS(5253),
    [anon_sym_SLASH_EQ] = ACTIONS(5253),
    [anon_sym_PERCENT_EQ] = ACTIONS(5253),
    [anon_sym_AMP_EQ] = ACTIONS(5253),
    [anon_sym_PIPE_EQ] = ACTIONS(5253),
    [anon_sym_CARET_EQ] = ACTIONS(5253),
    [anon_sym_LT_LT_EQ] = ACTIONS(5253),
    [anon_sym_GT_GT_EQ] = ACTIONS(5253),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5253),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5253),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5253),
    [anon_sym_if] = ACTIONS(5253),
    [anon_sym_SEMI] = ACTIONS(5253),
    [anon_sym_else] = ACTIONS(5253),
    [anon_sym_when] = ACTIONS(5253),
    [anon_sym_in] = ACTIONS(5253),
    [anon_sym_case] = ACTIONS(5253),
    [anon_sym_QMARK] = ACTIONS(5253),
    [anon_sym_PLUS] = ACTIONS(5255),
    [anon_sym_DASH] = ACTIONS(5255),
    [anon_sym_TILDE] = ACTIONS(5255),
    [anon_sym_AMP] = ACTIONS(5255),
    [anon_sym_PIPE_PIPE] = ACTIONS(5255),
    [anon_sym_or_else] = ACTIONS(5253),
    [anon_sym_AMP_AMP] = ACTIONS(5255),
    [anon_sym_GT] = ACTIONS(5255),
    [anon_sym_GT_EQ] = ACTIONS(5253),
    [anon_sym_LT_EQ] = ACTIONS(5253),
    [anon_sym_LT] = ACTIONS(5255),
    [anon_sym_EQ_EQ] = ACTIONS(5253),
    [anon_sym_BANG_EQ] = ACTIONS(5253),
    [anon_sym_TILDE_EQ] = ACTIONS(5253),
    [anon_sym_AMP_TILDE] = ACTIONS(5255),
    [anon_sym_LT_LT] = ACTIONS(5255),
    [anon_sym_GT_GT] = ACTIONS(5255),
    [anon_sym_STAR] = ACTIONS(5255),
    [anon_sym_SLASH] = ACTIONS(5255),
    [anon_sym_PERCENT] = ACTIONS(5255),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5253),
    [anon_sym_DOT] = ACTIONS(5255),
    [anon_sym_LBRACK] = ACTIONS(5253),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5253),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5253),
    [anon_sym_not_in] = ACTIONS(5253),
    [anon_sym_or_return] = ACTIONS(5253),
    [anon_sym_or_continue] = ACTIONS(5253),
    [anon_sym_or_break] = ACTIONS(5253),
    [anon_sym_CARET] = ACTIONS(5255),
    [sym_uninitialized] = ACTIONS(5253),
    [sym_tag] = ACTIONS(5253),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5253),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [876] = {
    [ts_builtin_sym_end] = ACTIONS(5257),
    [anon_sym_LBRACE] = ACTIONS(5257),
    [anon_sym_RBRACE] = ACTIONS(5257),
    [anon_sym_COMMA] = ACTIONS(5257),
    [anon_sym_COLON_COLON] = ACTIONS(5257),
    [anon_sym_DASH_GT] = ACTIONS(5257),
    [anon_sym_where] = ACTIONS(5257),
    [anon_sym_EQ] = ACTIONS(5259),
    [anon_sym_COLON] = ACTIONS(5259),
    [anon_sym_PIPE] = ACTIONS(5259),
    [anon_sym_COLON_EQ] = ACTIONS(5257),
    [anon_sym_LPAREN] = ACTIONS(5257),
    [anon_sym_PLUS_EQ] = ACTIONS(5257),
    [anon_sym_DASH_EQ] = ACTIONS(5257),
    [anon_sym_STAR_EQ] = ACTIONS(5257),
    [anon_sym_SLASH_EQ] = ACTIONS(5257),
    [anon_sym_PERCENT_EQ] = ACTIONS(5257),
    [anon_sym_AMP_EQ] = ACTIONS(5257),
    [anon_sym_PIPE_EQ] = ACTIONS(5257),
    [anon_sym_CARET_EQ] = ACTIONS(5257),
    [anon_sym_LT_LT_EQ] = ACTIONS(5257),
    [anon_sym_GT_GT_EQ] = ACTIONS(5257),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5257),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5257),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5257),
    [anon_sym_if] = ACTIONS(5257),
    [anon_sym_SEMI] = ACTIONS(5257),
    [anon_sym_else] = ACTIONS(5257),
    [anon_sym_when] = ACTIONS(5257),
    [anon_sym_in] = ACTIONS(5257),
    [anon_sym_case] = ACTIONS(5257),
    [anon_sym_QMARK] = ACTIONS(5257),
    [anon_sym_PLUS] = ACTIONS(5259),
    [anon_sym_DASH] = ACTIONS(5259),
    [anon_sym_TILDE] = ACTIONS(5259),
    [anon_sym_AMP] = ACTIONS(5259),
    [anon_sym_PIPE_PIPE] = ACTIONS(5259),
    [anon_sym_or_else] = ACTIONS(5257),
    [anon_sym_AMP_AMP] = ACTIONS(5259),
    [anon_sym_GT] = ACTIONS(5259),
    [anon_sym_GT_EQ] = ACTIONS(5257),
    [anon_sym_LT_EQ] = ACTIONS(5257),
    [anon_sym_LT] = ACTIONS(5259),
    [anon_sym_EQ_EQ] = ACTIONS(5257),
    [anon_sym_BANG_EQ] = ACTIONS(5257),
    [anon_sym_TILDE_EQ] = ACTIONS(5257),
    [anon_sym_AMP_TILDE] = ACTIONS(5259),
    [anon_sym_LT_LT] = ACTIONS(5259),
    [anon_sym_GT_GT] = ACTIONS(5259),
    [anon_sym_STAR] = ACTIONS(5259),
    [anon_sym_SLASH] = ACTIONS(5259),
    [anon_sym_PERCENT] = ACTIONS(5259),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5257),
    [anon_sym_DOT] = ACTIONS(5259),
    [anon_sym_LBRACK] = ACTIONS(5257),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5257),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5257),
    [anon_sym_not_in] = ACTIONS(5257),
    [anon_sym_or_return] = ACTIONS(5257),
    [anon_sym_or_continue] = ACTIONS(5257),
    [anon_sym_or_break] = ACTIONS(5257),
    [anon_sym_CARET] = ACTIONS(5259),
    [sym_uninitialized] = ACTIONS(5257),
    [sym_tag] = ACTIONS(5257),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5257),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [877] = {
    [aux_sym_field_type_repeat1] = STATE(877),
    [ts_builtin_sym_end] = ACTIONS(3408),
    [anon_sym_LBRACE] = ACTIONS(3408),
    [anon_sym_RBRACE] = ACTIONS(3408),
    [anon_sym_COMMA] = ACTIONS(3408),
    [anon_sym_COLON_COLON] = ACTIONS(3408),
    [anon_sym_DASH_GT] = ACTIONS(3408),
    [anon_sym_EQ] = ACTIONS(3410),
    [anon_sym_COLON] = ACTIONS(3410),
    [anon_sym_PIPE] = ACTIONS(3410),
    [anon_sym_COLON_EQ] = ACTIONS(3408),
    [anon_sym_LPAREN] = ACTIONS(3408),
    [anon_sym_PLUS_EQ] = ACTIONS(3408),
    [anon_sym_DASH_EQ] = ACTIONS(3408),
    [anon_sym_STAR_EQ] = ACTIONS(3408),
    [anon_sym_SLASH_EQ] = ACTIONS(3408),
    [anon_sym_PERCENT_EQ] = ACTIONS(3408),
    [anon_sym_AMP_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_CARET_EQ] = ACTIONS(3408),
    [anon_sym_LT_LT_EQ] = ACTIONS(3408),
    [anon_sym_GT_GT_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_if] = ACTIONS(3408),
    [anon_sym_SEMI] = ACTIONS(3408),
    [anon_sym_else] = ACTIONS(3408),
    [anon_sym_when] = ACTIONS(3408),
    [anon_sym_in] = ACTIONS(3408),
    [anon_sym_case] = ACTIONS(3408),
    [anon_sym_QMARK] = ACTIONS(3408),
    [anon_sym_PLUS] = ACTIONS(3410),
    [anon_sym_DASH] = ACTIONS(3410),
    [anon_sym_TILDE] = ACTIONS(3410),
    [anon_sym_AMP] = ACTIONS(3410),
    [anon_sym_PIPE_PIPE] = ACTIONS(3410),
    [anon_sym_or_else] = ACTIONS(3408),
    [anon_sym_AMP_AMP] = ACTIONS(3410),
    [anon_sym_GT] = ACTIONS(3410),
    [anon_sym_GT_EQ] = ACTIONS(3408),
    [anon_sym_LT_EQ] = ACTIONS(3408),
    [anon_sym_LT] = ACTIONS(3410),
    [anon_sym_EQ_EQ] = ACTIONS(3408),
    [anon_sym_BANG_EQ] = ACTIONS(3408),
    [anon_sym_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE] = ACTIONS(3410),
    [anon_sym_LT_LT] = ACTIONS(3410),
    [anon_sym_GT_GT] = ACTIONS(3410),
    [anon_sym_STAR] = ACTIONS(3410),
    [anon_sym_SLASH] = ACTIONS(3410),
    [anon_sym_PERCENT] = ACTIONS(3410),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3408),
    [anon_sym_DOT] = ACTIONS(3410),
    [anon_sym_LBRACK] = ACTIONS(3408),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3408),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3408),
    [anon_sym_not_in] = ACTIONS(3408),
    [anon_sym_or_return] = ACTIONS(3408),
    [anon_sym_or_continue] = ACTIONS(3408),
    [anon_sym_or_break] = ACTIONS(3408),
    [anon_sym_CARET] = ACTIONS(3410),
    [anon_sym_DOT2] = ACTIONS(5261),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3408),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [878] = {
    [sym_expression] = STATE(6224),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5264),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5266),
    [anon_sym_dynamic] = ACTIONS(5268),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [879] = {
    [sym_block] = STATE(2326),
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3451),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(3471),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [880] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8264),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5270),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [881] = {
    [sym_block] = STATE(2341),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3513),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [882] = {
    [sym_expression] = STATE(6255),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9010),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [883] = {
    [sym_expression] = STATE(6256),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9010),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [884] = {
    [sym_block] = STATE(2342),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3394),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [885] = {
    [sym_expression] = STATE(6577),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5274),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5276),
    [anon_sym_dynamic] = ACTIONS(5278),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [886] = {
    [sym_procedure] = STATE(7399),
    [sym_expression] = STATE(5721),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [887] = {
    [sym_block] = STATE(2356),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3390),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [888] = {
    [sym_block] = STATE(2357),
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(3404),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [889] = {
    [sym_block] = STATE(2359),
    [ts_builtin_sym_end] = ACTIONS(4577),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(4577),
    [anon_sym_COMMA] = ACTIONS(4577),
    [anon_sym_COLON_COLON] = ACTIONS(4577),
    [anon_sym_DASH_GT] = ACTIONS(4577),
    [anon_sym_EQ] = ACTIONS(4579),
    [anon_sym_COLON] = ACTIONS(4579),
    [anon_sym_PIPE] = ACTIONS(4579),
    [anon_sym_COLON_EQ] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4577),
    [anon_sym_PLUS_EQ] = ACTIONS(4577),
    [anon_sym_DASH_EQ] = ACTIONS(4577),
    [anon_sym_STAR_EQ] = ACTIONS(4577),
    [anon_sym_SLASH_EQ] = ACTIONS(4577),
    [anon_sym_PERCENT_EQ] = ACTIONS(4577),
    [anon_sym_AMP_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_CARET_EQ] = ACTIONS(4577),
    [anon_sym_LT_LT_EQ] = ACTIONS(4577),
    [anon_sym_GT_GT_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_when] = ACTIONS(4577),
    [anon_sym_in] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [anon_sym_TILDE] = ACTIONS(4579),
    [anon_sym_AMP] = ACTIONS(4579),
    [anon_sym_PIPE_PIPE] = ACTIONS(4579),
    [anon_sym_or_else] = ACTIONS(4577),
    [anon_sym_AMP_AMP] = ACTIONS(4579),
    [anon_sym_GT] = ACTIONS(4579),
    [anon_sym_GT_EQ] = ACTIONS(4577),
    [anon_sym_LT_EQ] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4579),
    [anon_sym_EQ_EQ] = ACTIONS(4577),
    [anon_sym_BANG_EQ] = ACTIONS(4577),
    [anon_sym_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE] = ACTIONS(4579),
    [anon_sym_LT_LT] = ACTIONS(4579),
    [anon_sym_GT_GT] = ACTIONS(4579),
    [anon_sym_STAR] = ACTIONS(4579),
    [anon_sym_SLASH] = ACTIONS(4579),
    [anon_sym_PERCENT] = ACTIONS(4579),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4577),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4577),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4577),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4577),
    [anon_sym_not_in] = ACTIONS(4577),
    [anon_sym_or_return] = ACTIONS(4577),
    [anon_sym_or_continue] = ACTIONS(4577),
    [anon_sym_or_break] = ACTIONS(4577),
    [anon_sym_CARET] = ACTIONS(4579),
    [sym_uninitialized] = ACTIONS(4977),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4577),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [890] = {
    [sym_block] = STATE(2361),
    [ts_builtin_sym_end] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(3386),
    [anon_sym_RBRACE] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_COLON_COLON] = ACTIONS(4585),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_EQ] = ACTIONS(4587),
    [anon_sym_COLON] = ACTIONS(4587),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_COLON_EQ] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_PLUS_EQ] = ACTIONS(4585),
    [anon_sym_DASH_EQ] = ACTIONS(4585),
    [anon_sym_STAR_EQ] = ACTIONS(4585),
    [anon_sym_SLASH_EQ] = ACTIONS(4585),
    [anon_sym_PERCENT_EQ] = ACTIONS(4585),
    [anon_sym_AMP_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_CARET_EQ] = ACTIONS(4585),
    [anon_sym_LT_LT_EQ] = ACTIONS(4585),
    [anon_sym_GT_GT_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_if] = ACTIONS(4585),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_else] = ACTIONS(4585),
    [anon_sym_when] = ACTIONS(4585),
    [anon_sym_in] = ACTIONS(4585),
    [anon_sym_case] = ACTIONS(4585),
    [anon_sym_QMARK] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_TILDE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_PIPE_PIPE] = ACTIONS(4587),
    [anon_sym_or_else] = ACTIONS(4585),
    [anon_sym_AMP_AMP] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4587),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4587),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4587),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4585),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4585),
    [anon_sym_not_in] = ACTIONS(4585),
    [anon_sym_or_return] = ACTIONS(4585),
    [anon_sym_or_continue] = ACTIONS(4585),
    [anon_sym_or_break] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4587),
    [sym_uninitialized] = ACTIONS(5280),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4585),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [891] = {
    [sym_procedure] = STATE(7450),
    [sym_expression] = STATE(5745),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [892] = {
    [sym_expression] = STATE(6206),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8629),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [893] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7803),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5282),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [894] = {
    [sym_procedure] = STATE(7000),
    [sym_expression] = STATE(4959),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(5284),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [895] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8409),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [896] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5288),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [897] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [898] = {
    [sym_expression] = STATE(6420),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3693),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3697),
    [anon_sym_dynamic] = ACTIONS(3699),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [899] = {
    [sym_procedure] = STATE(7027),
    [sym_expression] = STATE(4957),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(5290),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [900] = {
    [sym_procedure] = STATE(7067),
    [sym_expression] = STATE(4983),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [901] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5292),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [902] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8096),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5292),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [903] = {
    [sym_expression] = STATE(6154),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8629),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [904] = {
    [aux_sym_field_type_repeat1] = STATE(907),
    [ts_builtin_sym_end] = ACTIONS(3481),
    [anon_sym_LBRACE] = ACTIONS(3481),
    [anon_sym_RBRACE] = ACTIONS(3481),
    [anon_sym_COMMA] = ACTIONS(3481),
    [anon_sym_COLON_COLON] = ACTIONS(3481),
    [anon_sym_DASH_GT] = ACTIONS(3481),
    [anon_sym_EQ] = ACTIONS(3483),
    [anon_sym_COLON] = ACTIONS(3483),
    [anon_sym_PIPE] = ACTIONS(3483),
    [anon_sym_COLON_EQ] = ACTIONS(3481),
    [anon_sym_LPAREN] = ACTIONS(3481),
    [anon_sym_PLUS_EQ] = ACTIONS(3481),
    [anon_sym_DASH_EQ] = ACTIONS(3481),
    [anon_sym_STAR_EQ] = ACTIONS(3481),
    [anon_sym_SLASH_EQ] = ACTIONS(3481),
    [anon_sym_PERCENT_EQ] = ACTIONS(3481),
    [anon_sym_AMP_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_CARET_EQ] = ACTIONS(3481),
    [anon_sym_LT_LT_EQ] = ACTIONS(3481),
    [anon_sym_GT_GT_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(3481),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_else] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_in] = ACTIONS(3481),
    [anon_sym_case] = ACTIONS(3481),
    [anon_sym_QMARK] = ACTIONS(3481),
    [anon_sym_PLUS] = ACTIONS(3483),
    [anon_sym_DASH] = ACTIONS(3483),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_AMP] = ACTIONS(3483),
    [anon_sym_PIPE_PIPE] = ACTIONS(3483),
    [anon_sym_or_else] = ACTIONS(3481),
    [anon_sym_AMP_AMP] = ACTIONS(3483),
    [anon_sym_GT] = ACTIONS(3483),
    [anon_sym_GT_EQ] = ACTIONS(3481),
    [anon_sym_LT_EQ] = ACTIONS(3481),
    [anon_sym_LT] = ACTIONS(3483),
    [anon_sym_EQ_EQ] = ACTIONS(3481),
    [anon_sym_BANG_EQ] = ACTIONS(3481),
    [anon_sym_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE] = ACTIONS(3483),
    [anon_sym_LT_LT] = ACTIONS(3483),
    [anon_sym_GT_GT] = ACTIONS(3483),
    [anon_sym_STAR] = ACTIONS(3483),
    [anon_sym_SLASH] = ACTIONS(3483),
    [anon_sym_PERCENT] = ACTIONS(3483),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3481),
    [anon_sym_DOT] = ACTIONS(3483),
    [anon_sym_LBRACK] = ACTIONS(3481),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3481),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3481),
    [anon_sym_not_in] = ACTIONS(3481),
    [anon_sym_or_return] = ACTIONS(3481),
    [anon_sym_or_continue] = ACTIONS(3481),
    [anon_sym_or_break] = ACTIONS(3481),
    [anon_sym_CARET] = ACTIONS(3483),
    [anon_sym_DOT2] = ACTIONS(5294),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3481),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [905] = {
    [sym_expression] = STATE(6603),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9473),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [906] = {
    [sym_expression] = STATE(6328),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9473),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [907] = {
    [aux_sym_field_type_repeat1] = STATE(877),
    [ts_builtin_sym_end] = ACTIONS(3433),
    [anon_sym_LBRACE] = ACTIONS(3433),
    [anon_sym_RBRACE] = ACTIONS(3433),
    [anon_sym_COMMA] = ACTIONS(3433),
    [anon_sym_COLON_COLON] = ACTIONS(3433),
    [anon_sym_DASH_GT] = ACTIONS(3433),
    [anon_sym_EQ] = ACTIONS(3435),
    [anon_sym_COLON] = ACTIONS(3435),
    [anon_sym_PIPE] = ACTIONS(3435),
    [anon_sym_COLON_EQ] = ACTIONS(3433),
    [anon_sym_LPAREN] = ACTIONS(3433),
    [anon_sym_PLUS_EQ] = ACTIONS(3433),
    [anon_sym_DASH_EQ] = ACTIONS(3433),
    [anon_sym_STAR_EQ] = ACTIONS(3433),
    [anon_sym_SLASH_EQ] = ACTIONS(3433),
    [anon_sym_PERCENT_EQ] = ACTIONS(3433),
    [anon_sym_AMP_EQ] = ACTIONS(3433),
    [anon_sym_PIPE_EQ] = ACTIONS(3433),
    [anon_sym_CARET_EQ] = ACTIONS(3433),
    [anon_sym_LT_LT_EQ] = ACTIONS(3433),
    [anon_sym_GT_GT_EQ] = ACTIONS(3433),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3433),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3433),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3433),
    [anon_sym_if] = ACTIONS(3433),
    [anon_sym_SEMI] = ACTIONS(3433),
    [anon_sym_else] = ACTIONS(3433),
    [anon_sym_when] = ACTIONS(3433),
    [anon_sym_in] = ACTIONS(3433),
    [anon_sym_case] = ACTIONS(3433),
    [anon_sym_QMARK] = ACTIONS(3433),
    [anon_sym_PLUS] = ACTIONS(3435),
    [anon_sym_DASH] = ACTIONS(3435),
    [anon_sym_TILDE] = ACTIONS(3435),
    [anon_sym_AMP] = ACTIONS(3435),
    [anon_sym_PIPE_PIPE] = ACTIONS(3435),
    [anon_sym_or_else] = ACTIONS(3433),
    [anon_sym_AMP_AMP] = ACTIONS(3435),
    [anon_sym_GT] = ACTIONS(3435),
    [anon_sym_GT_EQ] = ACTIONS(3433),
    [anon_sym_LT_EQ] = ACTIONS(3433),
    [anon_sym_LT] = ACTIONS(3435),
    [anon_sym_EQ_EQ] = ACTIONS(3433),
    [anon_sym_BANG_EQ] = ACTIONS(3433),
    [anon_sym_TILDE_EQ] = ACTIONS(3433),
    [anon_sym_AMP_TILDE] = ACTIONS(3435),
    [anon_sym_LT_LT] = ACTIONS(3435),
    [anon_sym_GT_GT] = ACTIONS(3435),
    [anon_sym_STAR] = ACTIONS(3435),
    [anon_sym_SLASH] = ACTIONS(3435),
    [anon_sym_PERCENT] = ACTIONS(3435),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3433),
    [anon_sym_DOT] = ACTIONS(3435),
    [anon_sym_LBRACK] = ACTIONS(3433),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3433),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3433),
    [anon_sym_not_in] = ACTIONS(3433),
    [anon_sym_or_return] = ACTIONS(3433),
    [anon_sym_or_continue] = ACTIONS(3433),
    [anon_sym_or_break] = ACTIONS(3433),
    [anon_sym_CARET] = ACTIONS(3435),
    [anon_sym_DOT2] = ACTIONS(5294),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3433),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [908] = {
    [sym_procedure] = STATE(7412),
    [sym_expression] = STATE(5807),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [909] = {
    [sym_procedure] = STATE(7016),
    [sym_expression] = STATE(4961),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(5296),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [910] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5298),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [911] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5300),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [912] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5270),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [913] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5302),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [914] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8132),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5304),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [915] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8183),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5306),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [916] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5308),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [917] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5310),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [918] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8270),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5310),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [919] = {
    [sym_expression] = STATE(6153),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8659),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [920] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8349),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5312),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [921] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5312),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [922] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5314),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [923] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8433),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5314),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [924] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5316),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [925] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5318),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [926] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5320),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [927] = {
    [sym_block] = STATE(1551),
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3451),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(3533),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [928] = {
    [sym_block] = STATE(1558),
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(3429),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [929] = {
    [sym_block] = STATE(1568),
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(3380),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [930] = {
    [sym_block] = STATE(1587),
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(3421),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [931] = {
    [sym_block] = STATE(1594),
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(3521),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [932] = {
    [sym_block] = STATE(1600),
    [ts_builtin_sym_end] = ACTIONS(4577),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(4577),
    [anon_sym_COMMA] = ACTIONS(4577),
    [anon_sym_COLON_COLON] = ACTIONS(4577),
    [anon_sym_DASH_GT] = ACTIONS(4577),
    [anon_sym_EQ] = ACTIONS(4579),
    [anon_sym_COLON] = ACTIONS(4579),
    [anon_sym_PIPE] = ACTIONS(4579),
    [anon_sym_COLON_EQ] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4577),
    [anon_sym_PLUS_EQ] = ACTIONS(4577),
    [anon_sym_DASH_EQ] = ACTIONS(4577),
    [anon_sym_STAR_EQ] = ACTIONS(4577),
    [anon_sym_SLASH_EQ] = ACTIONS(4577),
    [anon_sym_PERCENT_EQ] = ACTIONS(4577),
    [anon_sym_AMP_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_CARET_EQ] = ACTIONS(4577),
    [anon_sym_LT_LT_EQ] = ACTIONS(4577),
    [anon_sym_GT_GT_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_when] = ACTIONS(4577),
    [anon_sym_in] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [anon_sym_TILDE] = ACTIONS(4579),
    [anon_sym_AMP] = ACTIONS(4579),
    [anon_sym_PIPE_PIPE] = ACTIONS(4579),
    [anon_sym_or_else] = ACTIONS(4577),
    [anon_sym_AMP_AMP] = ACTIONS(4579),
    [anon_sym_GT] = ACTIONS(4579),
    [anon_sym_GT_EQ] = ACTIONS(4577),
    [anon_sym_LT_EQ] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4579),
    [anon_sym_EQ_EQ] = ACTIONS(4577),
    [anon_sym_BANG_EQ] = ACTIONS(4577),
    [anon_sym_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE] = ACTIONS(4579),
    [anon_sym_LT_LT] = ACTIONS(4579),
    [anon_sym_GT_GT] = ACTIONS(4579),
    [anon_sym_STAR] = ACTIONS(4579),
    [anon_sym_SLASH] = ACTIONS(4579),
    [anon_sym_PERCENT] = ACTIONS(4579),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4577),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4577),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4577),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4577),
    [anon_sym_not_in] = ACTIONS(4577),
    [anon_sym_or_return] = ACTIONS(4577),
    [anon_sym_or_continue] = ACTIONS(4577),
    [anon_sym_or_break] = ACTIONS(4577),
    [anon_sym_CARET] = ACTIONS(4579),
    [sym_uninitialized] = ACTIONS(4895),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4577),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [933] = {
    [sym_block] = STATE(1608),
    [ts_builtin_sym_end] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(3370),
    [anon_sym_RBRACE] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_COLON_COLON] = ACTIONS(4585),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_EQ] = ACTIONS(4587),
    [anon_sym_COLON] = ACTIONS(4587),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_COLON_EQ] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_PLUS_EQ] = ACTIONS(4585),
    [anon_sym_DASH_EQ] = ACTIONS(4585),
    [anon_sym_STAR_EQ] = ACTIONS(4585),
    [anon_sym_SLASH_EQ] = ACTIONS(4585),
    [anon_sym_PERCENT_EQ] = ACTIONS(4585),
    [anon_sym_AMP_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_CARET_EQ] = ACTIONS(4585),
    [anon_sym_LT_LT_EQ] = ACTIONS(4585),
    [anon_sym_GT_GT_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_if] = ACTIONS(4585),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_else] = ACTIONS(4585),
    [anon_sym_when] = ACTIONS(4585),
    [anon_sym_in] = ACTIONS(4585),
    [anon_sym_case] = ACTIONS(4585),
    [anon_sym_QMARK] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_TILDE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_PIPE_PIPE] = ACTIONS(4587),
    [anon_sym_or_else] = ACTIONS(4585),
    [anon_sym_AMP_AMP] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4587),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4587),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4587),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4585),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4585),
    [anon_sym_not_in] = ACTIONS(4585),
    [anon_sym_or_return] = ACTIONS(4585),
    [anon_sym_or_continue] = ACTIONS(4585),
    [anon_sym_or_break] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4587),
    [sym_uninitialized] = ACTIONS(5322),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4585),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [934] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8077),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5324),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [935] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8201),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5326),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [936] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5328),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [937] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5330),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [938] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8013),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5330),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [939] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5332),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [940] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5332),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [941] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5334),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [942] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8480),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5334),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [943] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5336),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [944] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5338),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [945] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5340),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [946] = {
    [sym_procedure] = STATE(8384),
    [sym_expression] = STATE(6121),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(5342),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [947] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8377),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5344),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [948] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8060),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5346),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [949] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5348),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [950] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5350),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [951] = {
    [sym_procedure] = STATE(7777),
    [sym_expression] = STATE(5971),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(5352),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [952] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8129),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5350),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [953] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8186),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5354),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [954] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5354),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [955] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5356),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [956] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8256),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5356),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [957] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5358),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [958] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5360),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [959] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5362),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [960] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7833),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5364),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [961] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8473),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5366),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [962] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5368),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [963] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5370),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [964] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8584),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5370),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [965] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7773),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5372),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [966] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5372),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [967] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5374),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [968] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7798),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5374),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [969] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5376),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [970] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7843),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5378),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [971] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5380),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [972] = {
    [sym_procedure] = STATE(7856),
    [sym_expression] = STATE(6064),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(5382),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [973] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5384),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [974] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8000),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5386),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [975] = {
    [sym_procedure] = STATE(8918),
    [sym_expression] = STATE(6199),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [976] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7854),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5388),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [977] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5390),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [978] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5392),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [979] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7891),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5392),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [980] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7912),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5394),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [981] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5394),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [982] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5396),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [983] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7933),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5396),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [984] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5398),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [985] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5400),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [986] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5402),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [987] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7953),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5404),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [988] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7976),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5406),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [989] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5408),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [990] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5410),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [991] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7998),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5410),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [992] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8014),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5412),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [993] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5412),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [994] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5414),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [995] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8031),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5414),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [996] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5416),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [997] = {
    [sym_procedure] = STATE(7902),
    [sym_expression] = STATE(6033),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_proc] = ACTIONS(1465),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(5418),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [998] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5420),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [999] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5422),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1000] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8047),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5424),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1001] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8067),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5426),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1002] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5428),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1003] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5430),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1004] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8104),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5430),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1005] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8120),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5432),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1006] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5432),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1007] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5434),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1008] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8140),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5434),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1009] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5436),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1010] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5438),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1011] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5440),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1012] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8157),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5442),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1013] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8178),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5444),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1014] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5446),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1015] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5448),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1016] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8204),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5448),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1017] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8224),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5450),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1018] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5450),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1019] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5452),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1020] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8246),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5452),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1021] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5454),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1022] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5456),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1023] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5458),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1024] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8267),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5460),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1025] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8302),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5462),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1026] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5464),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1027] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5466),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1028] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8348),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5466),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1029] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8378),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5468),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1030] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5468),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1031] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5470),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1032] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8412),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5470),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1033] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5472),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1034] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5474),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1035] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5476),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1036] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8438),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5478),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1037] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8464),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5480),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1038] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5482),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1039] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5484),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1040] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8496),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5484),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1041] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8511),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5486),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1042] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5486),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1043] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5488),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1044] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8530),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5488),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1045] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5490),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1046] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5492),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1047] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5494),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1048] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8545),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5496),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1049] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8563),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5498),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1050] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5500),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1051] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5502),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1052] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8583),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5502),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1053] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8614),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5504),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1054] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5504),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1055] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5506),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1056] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8566),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5506),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1057] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5508),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1058] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5510),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1059] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5512),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1060] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8310),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5514),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1061] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7986),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5516),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1062] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5518),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1063] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5520),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1064] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8215),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5520),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1065] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8450),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5522),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1066] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5522),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1067] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5524),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1068] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(7825),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5524),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1069] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5526),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1070] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5528),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1071] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5530),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1072] = {
    [sym_procedure] = STATE(7002),
    [sym_expression] = STATE(4967),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_proc] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(4729),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1073] = {
    [sym_expression] = STATE(6250),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4603),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4607),
    [anon_sym_dynamic] = ACTIONS(4609),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1074] = {
    [sym_expression] = STATE(6170),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8659),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1075] = {
    [sym_expression] = STATE(6525),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5532),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5534),
    [anon_sym_dynamic] = ACTIONS(5536),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1076] = {
    [sym_expression] = STATE(6424),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9307),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1077] = {
    [sym_expression] = STATE(6584),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9307),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1078] = {
    [sym_expression] = STATE(6392),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5538),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5540),
    [anon_sym_dynamic] = ACTIONS(5542),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1079] = {
    [sym_expression] = STATE(6580),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3563),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3567),
    [anon_sym_dynamic] = ACTIONS(3569),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1080] = {
    [sym_expression] = STATE(6210),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8668),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1081] = {
    [sym_expression] = STATE(6291),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5544),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5546),
    [anon_sym_dynamic] = ACTIONS(5548),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1082] = {
    [sym_expression] = STATE(6281),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8990),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1083] = {
    [sym_expression] = STATE(6317),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8990),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1084] = {
    [sym_expression] = STATE(6438),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5550),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5552),
    [anon_sym_dynamic] = ACTIONS(5554),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1085] = {
    [sym_expression] = STATE(6243),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3830),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3834),
    [anon_sym_dynamic] = ACTIONS(3836),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1086] = {
    [sym_expression] = STATE(6151),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8837),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1087] = {
    [sym_expression] = STATE(6434),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5556),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5558),
    [anon_sym_dynamic] = ACTIONS(5560),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1088] = {
    [sym_expression] = STATE(6512),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9494),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1089] = {
    [sym_expression] = STATE(6523),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9494),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1090] = {
    [sym_expression] = STATE(6217),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5562),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5564),
    [anon_sym_dynamic] = ACTIONS(5566),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1091] = {
    [sym_expression] = STATE(6429),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3593),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3597),
    [anon_sym_dynamic] = ACTIONS(3599),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1092] = {
    [sym_expression] = STATE(6187),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8876),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1093] = {
    [sym_expression] = STATE(6349),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9170),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1094] = {
    [sym_expression] = STATE(6216),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9573),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1095] = {
    [sym_expression] = STATE(6259),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8950),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1096] = {
    [sym_expression] = STATE(6452),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5568),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5570),
    [anon_sym_dynamic] = ACTIONS(5572),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1097] = {
    [sym_expression] = STATE(6578),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4432),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4436),
    [anon_sym_dynamic] = ACTIONS(4438),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1098] = {
    [sym_expression] = STATE(6148),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8716),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1099] = {
    [sym_expression] = STATE(6442),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5574),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5576),
    [anon_sym_dynamic] = ACTIONS(5578),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1100] = {
    [sym_expression] = STATE(6360),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9073),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1101] = {
    [sym_expression] = STATE(6431),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9208),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1102] = {
    [sym_expression] = STATE(6261),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5580),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5582),
    [anon_sym_dynamic] = ACTIONS(5584),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1103] = {
    [sym_expression] = STATE(6226),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3673),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3677),
    [anon_sym_dynamic] = ACTIONS(3679),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1104] = {
    [sym_expression] = STATE(6208),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8689),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1105] = {
    [sym_expression] = STATE(6505),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5586),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5588),
    [anon_sym_dynamic] = ACTIONS(5590),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1106] = {
    [sym_expression] = STATE(6460),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8950),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1107] = {
    [sym_expression] = STATE(6448),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9573),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1108] = {
    [sym_expression] = STATE(6245),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5592),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5594),
    [anon_sym_dynamic] = ACTIONS(5596),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1109] = {
    [sym_expression] = STATE(6517),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3633),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3637),
    [anon_sym_dynamic] = ACTIONS(3639),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1110] = {
    [sym_expression] = STATE(6181),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8821),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1111] = {
    [sym_expression] = STATE(6576),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5598),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5600),
    [anon_sym_dynamic] = ACTIONS(5602),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1112] = {
    [sym_expression] = STATE(6536),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9388),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1113] = {
    [sym_expression] = STATE(6342),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9073),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1114] = {
    [sym_expression] = STATE(6521),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5604),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5606),
    [anon_sym_dynamic] = ACTIONS(5608),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1115] = {
    [sym_expression] = STATE(6221),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3720),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3724),
    [anon_sym_dynamic] = ACTIONS(3726),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1116] = {
    [sym_expression] = STATE(6165),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8640),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1117] = {
    [sym_expression] = STATE(6366),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5610),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5612),
    [anon_sym_dynamic] = ACTIONS(5614),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1118] = {
    [sym_expression] = STATE(6607),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9248),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1119] = {
    [sym_expression] = STATE(6543),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9388),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1120] = {
    [sym_expression] = STATE(6401),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5616),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5618),
    [anon_sym_dynamic] = ACTIONS(5620),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1121] = {
    [sym_expression] = STATE(6575),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3860),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3864),
    [anon_sym_dynamic] = ACTIONS(3866),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1122] = {
    [sym_expression] = STATE(6160),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8727),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1123] = {
    [sym_expression] = STATE(6402),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5622),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5624),
    [anon_sym_dynamic] = ACTIONS(5626),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1124] = {
    [sym_expression] = STATE(6237),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8989),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1125] = {
    [sym_expression] = STATE(6242),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9345),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1126] = {
    [sym_expression] = STATE(6474),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5628),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5630),
    [anon_sym_dynamic] = ACTIONS(5632),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1127] = {
    [sym_expression] = STATE(6364),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3894),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3898),
    [anon_sym_dynamic] = ACTIONS(3900),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1128] = {
    [sym_expression] = STATE(6190),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8825),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1129] = {
    [sym_expression] = STATE(6537),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5634),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5636),
    [anon_sym_dynamic] = ACTIONS(5638),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1130] = {
    [sym_expression] = STATE(6316),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9294),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1131] = {
    [sym_expression] = STATE(6496),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9248),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1132] = {
    [sym_expression] = STATE(6604),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5640),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5642),
    [anon_sym_dynamic] = ACTIONS(5644),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1133] = {
    [sym_expression] = STATE(6509),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3934),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3938),
    [anon_sym_dynamic] = ACTIONS(3940),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1134] = {
    [sym_expression] = STATE(6155),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8902),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1135] = {
    [sym_expression] = STATE(6275),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5646),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5648),
    [anon_sym_dynamic] = ACTIONS(5650),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1136] = {
    [sym_expression] = STATE(6398),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9048),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1137] = {
    [sym_expression] = STATE(6378),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9392),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1138] = {
    [sym_expression] = STATE(6306),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5652),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5654),
    [anon_sym_dynamic] = ACTIONS(5656),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1139] = {
    [sym_expression] = STATE(6218),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3760),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3764),
    [anon_sym_dynamic] = ACTIONS(3766),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1140] = {
    [sym_expression] = STATE(6157),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8883),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1141] = {
    [sym_expression] = STATE(6258),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5658),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5660),
    [anon_sym_dynamic] = ACTIONS(5662),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1142] = {
    [sym_expression] = STATE(6456),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9535),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1143] = {
    [sym_expression] = STATE(6417),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8989),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1144] = {
    [sym_expression] = STATE(6289),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5664),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5666),
    [anon_sym_dynamic] = ACTIONS(5668),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1145] = {
    [sym_expression] = STATE(6427),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3964),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3968),
    [anon_sym_dynamic] = ACTIONS(3970),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1146] = {
    [sym_expression] = STATE(6186),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8717),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1147] = {
    [sym_expression] = STATE(6440),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5670),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5672),
    [anon_sym_dynamic] = ACTIONS(5674),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1148] = {
    [sym_expression] = STATE(6502),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9228),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1149] = {
    [sym_expression] = STATE(6518),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9262),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1150] = {
    [sym_expression] = STATE(6447),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5676),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5678),
    [anon_sym_dynamic] = ACTIONS(5680),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1151] = {
    [sym_expression] = STATE(6479),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3790),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3794),
    [anon_sym_dynamic] = ACTIONS(3796),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1152] = {
    [sym_expression] = STATE(6193),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8639),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1153] = {
    [sym_expression] = STATE(6490),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5682),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5684),
    [anon_sym_dynamic] = ACTIONS(5686),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1154] = {
    [sym_expression] = STATE(6532),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9342),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1155] = {
    [sym_expression] = STATE(6410),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9204),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1156] = {
    [sym_expression] = STATE(6507),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5688),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5690),
    [anon_sym_dynamic] = ACTIONS(5692),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1157] = {
    [sym_expression] = STATE(6541),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3994),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3998),
    [anon_sym_dynamic] = ACTIONS(4000),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1158] = {
    [sym_expression] = STATE(6204),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8754),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1159] = {
    [sym_expression] = STATE(6562),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5694),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5696),
    [anon_sym_dynamic] = ACTIONS(5698),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1160] = {
    [sym_expression] = STATE(6565),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9276),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1161] = {
    [sym_expression] = STATE(6569),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5700),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5702),
    [anon_sym_dynamic] = ACTIONS(5704),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1162] = {
    [sym_expression] = STATE(6605),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4044),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4048),
    [anon_sym_dynamic] = ACTIONS(4050),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1163] = {
    [sym_expression] = STATE(6184),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8728),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1164] = {
    [sym_expression] = STATE(6265),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5706),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5708),
    [anon_sym_dynamic] = ACTIONS(5710),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1165] = {
    [sym_expression] = STATE(6526),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9267),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1166] = {
    [sym_expression] = STATE(6488),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5712),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5714),
    [anon_sym_dynamic] = ACTIONS(5716),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1167] = {
    [sym_expression] = STATE(6234),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4074),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4078),
    [anon_sym_dynamic] = ACTIONS(4080),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1168] = {
    [sym_expression] = STATE(6253),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5718),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5720),
    [anon_sym_dynamic] = ACTIONS(5722),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1169] = {
    [sym_expression] = STATE(6290),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9554),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1170] = {
    [sym_expression] = STATE(6269),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5724),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5726),
    [anon_sym_dynamic] = ACTIONS(5728),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1171] = {
    [sym_expression] = STATE(6334),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4104),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4108),
    [anon_sym_dynamic] = ACTIONS(4110),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1172] = {
    [sym_expression] = STATE(6348),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5730),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5732),
    [anon_sym_dynamic] = ACTIONS(5734),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1173] = {
    [sym_expression] = STATE(6545),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9294),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1174] = {
    [sym_expression] = STATE(6353),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5736),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5738),
    [anon_sym_dynamic] = ACTIONS(5740),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1175] = {
    [sym_expression] = STATE(6377),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_dynamic] = ACTIONS(4140),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1176] = {
    [sym_expression] = STATE(6387),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5742),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5744),
    [anon_sym_dynamic] = ACTIONS(5746),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1177] = {
    [sym_expression] = STATE(6267),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8983),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1178] = {
    [sym_expression] = STATE(6396),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5748),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5750),
    [anon_sym_dynamic] = ACTIONS(5752),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1179] = {
    [sym_expression] = STATE(6412),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4168),
    [anon_sym_dynamic] = ACTIONS(4170),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1180] = {
    [sym_expression] = STATE(6423),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5754),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5756),
    [anon_sym_dynamic] = ACTIONS(5758),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1181] = {
    [sym_expression] = STATE(6441),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9048),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1182] = {
    [sym_expression] = STATE(6425),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5760),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5762),
    [anon_sym_dynamic] = ACTIONS(5764),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1183] = {
    [sym_expression] = STATE(6443),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4014),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4018),
    [anon_sym_dynamic] = ACTIONS(4020),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1184] = {
    [sym_expression] = STATE(6449),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5766),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5768),
    [anon_sym_dynamic] = ACTIONS(5770),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1185] = {
    [sym_expression] = STATE(6491),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9535),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1186] = {
    [sym_expression] = STATE(6451),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5772),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5774),
    [anon_sym_dynamic] = ACTIONS(5776),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1187] = {
    [sym_expression] = STATE(6461),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4224),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4228),
    [anon_sym_dynamic] = ACTIONS(4230),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1188] = {
    [sym_expression] = STATE(6472),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5778),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5780),
    [anon_sym_dynamic] = ACTIONS(5782),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1189] = {
    [sym_expression] = STATE(6563),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9202),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1190] = {
    [sym_expression] = STATE(6482),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5784),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5786),
    [anon_sym_dynamic] = ACTIONS(5788),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1191] = {
    [sym_expression] = STATE(6506),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4254),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4258),
    [anon_sym_dynamic] = ACTIONS(4260),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1192] = {
    [sym_expression] = STATE(6522),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5790),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5792),
    [anon_sym_dynamic] = ACTIONS(5794),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1193] = {
    [sym_expression] = STATE(6419),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9298),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1194] = {
    [sym_expression] = STATE(6528),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5796),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5798),
    [anon_sym_dynamic] = ACTIONS(5800),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1195] = {
    [sym_expression] = STATE(6557),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4284),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4288),
    [anon_sym_dynamic] = ACTIONS(4290),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1196] = {
    [sym_expression] = STATE(6571),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5802),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5804),
    [anon_sym_dynamic] = ACTIONS(5806),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1197] = {
    [sym_expression] = STATE(6583),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9228),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1198] = {
    [sym_expression] = STATE(6574),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5808),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5810),
    [anon_sym_dynamic] = ACTIONS(5812),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1199] = {
    [sym_expression] = STATE(6293),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4194),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4198),
    [anon_sym_dynamic] = ACTIONS(4200),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1200] = {
    [sym_expression] = STATE(6324),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5814),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5816),
    [anon_sym_dynamic] = ACTIONS(5818),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1201] = {
    [sym_expression] = STATE(6282),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9219),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1202] = {
    [sym_expression] = STATE(6542),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5820),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5822),
    [anon_sym_dynamic] = ACTIONS(5824),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1203] = {
    [sym_expression] = STATE(6435),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4314),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4318),
    [anon_sym_dynamic] = ACTIONS(4320),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1204] = {
    [sym_expression] = STATE(6572),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5826),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5828),
    [anon_sym_dynamic] = ACTIONS(5830),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1205] = {
    [sym_expression] = STATE(6579),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9342),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1206] = {
    [sym_expression] = STATE(6598),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5832),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5834),
    [anon_sym_dynamic] = ACTIONS(5836),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1207] = {
    [sym_expression] = STATE(6462),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4344),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4348),
    [anon_sym_dynamic] = ACTIONS(4350),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1208] = {
    [sym_expression] = STATE(6519),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5838),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5840),
    [anon_sym_dynamic] = ACTIONS(5842),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1209] = {
    [sym_expression] = STATE(6566),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5844),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5846),
    [anon_sym_dynamic] = ACTIONS(5848),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1210] = {
    [sym_expression] = STATE(6270),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4374),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4378),
    [anon_sym_dynamic] = ACTIONS(4380),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1211] = {
    [sym_expression] = STATE(6345),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5850),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5852),
    [anon_sym_dynamic] = ACTIONS(5854),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1212] = {
    [sym_expression] = STATE(6213),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5856),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5858),
    [anon_sym_dynamic] = ACTIONS(5860),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1213] = {
    [sym_expression] = STATE(6467),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4394),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4398),
    [anon_sym_dynamic] = ACTIONS(4400),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1214] = {
    [sym_expression] = STATE(6476),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5862),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5864),
    [anon_sym_dynamic] = ACTIONS(5866),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1215] = {
    [sym_expression] = STATE(6493),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5868),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5870),
    [anon_sym_dynamic] = ACTIONS(5872),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1216] = {
    [sym_expression] = STATE(6383),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9173),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1217] = {
    [sym_expression] = STATE(6426),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9005),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1218] = {
    [sym_expression] = STATE(6240),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5874),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5876),
    [anon_sym_dynamic] = ACTIONS(5878),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1219] = {
    [sym_expression] = STATE(6231),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(4529),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(4533),
    [anon_sym_dynamic] = ACTIONS(4535),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1220] = {
    [sym_expression] = STATE(6596),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9175),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1221] = {
    [sym_expression] = STATE(6394),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5880),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5882),
    [anon_sym_dynamic] = ACTIONS(5884),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1222] = {
    [sym_expression] = STATE(6388),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9033),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1223] = {
    [sym_expression] = STATE(6475),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(3539),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(3543),
    [anon_sym_dynamic] = ACTIONS(3545),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1224] = {
    [sym_expression] = STATE(6486),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5886),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5888),
    [anon_sym_dynamic] = ACTIONS(5890),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1225] = {
    [sym_expression] = STATE(6515),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5892),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5894),
    [anon_sym_dynamic] = ACTIONS(5896),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1226] = {
    [sym_expression] = STATE(6252),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9465),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1227] = {
    [sym_expression] = STATE(6489),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9278),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1228] = {
    [sym_expression] = STATE(6215),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9578),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1229] = {
    [sym_expression] = STATE(6238),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9362),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1230] = {
    [sym_expression] = STATE(6254),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8966),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1231] = {
    [sym_expression] = STATE(6266),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8987),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1232] = {
    [sym_expression] = STATE(6277),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9029),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1233] = {
    [sym_expression] = STATE(6288),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9071),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1234] = {
    [sym_expression] = STATE(6297),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9088),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1235] = {
    [sym_expression] = STATE(6305),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9101),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1236] = {
    [sym_expression] = STATE(6313),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9050),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1237] = {
    [sym_expression] = STATE(6321),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9008),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1238] = {
    [sym_expression] = STATE(6331),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9112),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1239] = {
    [sym_expression] = STATE(6341),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9122),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1240] = {
    [sym_expression] = STATE(6347),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9129),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1241] = {
    [sym_expression] = STATE(6352),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9133),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1242] = {
    [sym_expression] = STATE(6356),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9137),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1243] = {
    [sym_expression] = STATE(6359),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9145),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1244] = {
    [sym_expression] = STATE(6361),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9149),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1245] = {
    [sym_expression] = STATE(6363),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9153),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1246] = {
    [sym_expression] = STATE(6365),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9141),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1247] = {
    [sym_expression] = STATE(6367),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9157),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1248] = {
    [sym_expression] = STATE(6368),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9161),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1249] = {
    [sym_expression] = STATE(6370),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9167),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1250] = {
    [sym_expression] = STATE(6372),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9164),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1251] = {
    [sym_expression] = STATE(6374),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9170),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1252] = {
    [sym_expression] = STATE(6280),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9173),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1253] = {
    [sym_expression] = STATE(6322),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9190),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1254] = {
    [sym_expression] = STATE(6465),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8943),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1255] = {
    [sym_expression] = STATE(6232),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9278),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1256] = {
    [sym_expression] = STATE(6244),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9362),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1257] = {
    [sym_expression] = STATE(6260),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8966),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1258] = {
    [sym_expression] = STATE(6271),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(8987),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1259] = {
    [sym_expression] = STATE(6283),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9465),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1260] = {
    [sym_expression] = STATE(6294),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9008),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1261] = {
    [sym_expression] = STATE(6301),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9050),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1262] = {
    [sym_expression] = STATE(6309),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9088),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1263] = {
    [sym_expression] = STATE(6318),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9141),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1264] = {
    [sym_expression] = STATE(6327),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9149),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1265] = {
    [sym_expression] = STATE(6337),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9153),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1266] = {
    [sym_expression] = STATE(6344),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_constant_type] = STATE(9164),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_DOLLAR] = ACTIONS(5272),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1267] = {
    [sym_expression] = STATE(6445),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(5898),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_CARET] = ACTIONS(5900),
    [anon_sym_dynamic] = ACTIONS(5902),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1268] = {
    [aux_sym_field_type_repeat1] = STATE(1268),
    [ts_builtin_sym_end] = ACTIONS(3408),
    [anon_sym_RBRACE] = ACTIONS(3408),
    [anon_sym_COMMA] = ACTIONS(3408),
    [anon_sym_COLON_COLON] = ACTIONS(3408),
    [anon_sym_DASH_GT] = ACTIONS(3408),
    [anon_sym_EQ] = ACTIONS(3410),
    [anon_sym_COLON] = ACTIONS(3410),
    [anon_sym_PIPE] = ACTIONS(3410),
    [anon_sym_COLON_EQ] = ACTIONS(3408),
    [anon_sym_LPAREN] = ACTIONS(3408),
    [anon_sym_PLUS_EQ] = ACTIONS(3408),
    [anon_sym_DASH_EQ] = ACTIONS(3408),
    [anon_sym_STAR_EQ] = ACTIONS(3408),
    [anon_sym_SLASH_EQ] = ACTIONS(3408),
    [anon_sym_PERCENT_EQ] = ACTIONS(3408),
    [anon_sym_AMP_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_CARET_EQ] = ACTIONS(3408),
    [anon_sym_LT_LT_EQ] = ACTIONS(3408),
    [anon_sym_GT_GT_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_if] = ACTIONS(3408),
    [anon_sym_SEMI] = ACTIONS(3408),
    [anon_sym_else] = ACTIONS(3408),
    [anon_sym_when] = ACTIONS(3408),
    [anon_sym_in] = ACTIONS(3408),
    [anon_sym_case] = ACTIONS(3408),
    [anon_sym_QMARK] = ACTIONS(3408),
    [anon_sym_PLUS] = ACTIONS(3410),
    [anon_sym_DASH] = ACTIONS(3410),
    [anon_sym_TILDE] = ACTIONS(3410),
    [anon_sym_AMP] = ACTIONS(3410),
    [anon_sym_PIPE_PIPE] = ACTIONS(3410),
    [anon_sym_or_else] = ACTIONS(3408),
    [anon_sym_AMP_AMP] = ACTIONS(3410),
    [anon_sym_GT] = ACTIONS(3410),
    [anon_sym_GT_EQ] = ACTIONS(3408),
    [anon_sym_LT_EQ] = ACTIONS(3408),
    [anon_sym_LT] = ACTIONS(3410),
    [anon_sym_EQ_EQ] = ACTIONS(3408),
    [anon_sym_BANG_EQ] = ACTIONS(3408),
    [anon_sym_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE] = ACTIONS(3410),
    [anon_sym_LT_LT] = ACTIONS(3410),
    [anon_sym_GT_GT] = ACTIONS(3410),
    [anon_sym_STAR] = ACTIONS(3410),
    [anon_sym_SLASH] = ACTIONS(3410),
    [anon_sym_PERCENT] = ACTIONS(3410),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3408),
    [anon_sym_DOT] = ACTIONS(3410),
    [anon_sym_LBRACK] = ACTIONS(3408),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3408),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3408),
    [anon_sym_not_in] = ACTIONS(3408),
    [anon_sym_or_return] = ACTIONS(3408),
    [anon_sym_or_continue] = ACTIONS(3408),
    [anon_sym_or_break] = ACTIONS(3408),
    [anon_sym_CARET] = ACTIONS(3410),
    [anon_sym_DOT2] = ACTIONS(5904),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3408),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1269] = {
    [aux_sym_struct_type_repeat2] = STATE(1425),
    [ts_builtin_sym_end] = ACTIONS(4462),
    [anon_sym_LBRACE] = ACTIONS(4462),
    [anon_sym_RBRACE] = ACTIONS(4462),
    [anon_sym_COMMA] = ACTIONS(4462),
    [anon_sym_COLON_COLON] = ACTIONS(4462),
    [anon_sym_DASH_GT] = ACTIONS(4462),
    [anon_sym_EQ] = ACTIONS(4464),
    [anon_sym_COLON] = ACTIONS(4464),
    [anon_sym_PIPE] = ACTIONS(4464),
    [anon_sym_COLON_EQ] = ACTIONS(4462),
    [anon_sym_LPAREN] = ACTIONS(4462),
    [anon_sym_PLUS_EQ] = ACTIONS(4462),
    [anon_sym_DASH_EQ] = ACTIONS(4462),
    [anon_sym_STAR_EQ] = ACTIONS(4462),
    [anon_sym_SLASH_EQ] = ACTIONS(4462),
    [anon_sym_PERCENT_EQ] = ACTIONS(4462),
    [anon_sym_AMP_EQ] = ACTIONS(4462),
    [anon_sym_PIPE_EQ] = ACTIONS(4462),
    [anon_sym_CARET_EQ] = ACTIONS(4462),
    [anon_sym_LT_LT_EQ] = ACTIONS(4462),
    [anon_sym_GT_GT_EQ] = ACTIONS(4462),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4462),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4462),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4462),
    [anon_sym_if] = ACTIONS(4462),
    [anon_sym_SEMI] = ACTIONS(4462),
    [anon_sym_else] = ACTIONS(4462),
    [anon_sym_when] = ACTIONS(4462),
    [anon_sym_in] = ACTIONS(4462),
    [anon_sym_case] = ACTIONS(4462),
    [anon_sym_QMARK] = ACTIONS(4462),
    [anon_sym_PLUS] = ACTIONS(4464),
    [anon_sym_DASH] = ACTIONS(4464),
    [anon_sym_TILDE] = ACTIONS(4464),
    [anon_sym_AMP] = ACTIONS(4464),
    [anon_sym_PIPE_PIPE] = ACTIONS(4464),
    [anon_sym_or_else] = ACTIONS(4462),
    [anon_sym_AMP_AMP] = ACTIONS(4464),
    [anon_sym_GT] = ACTIONS(4464),
    [anon_sym_GT_EQ] = ACTIONS(4462),
    [anon_sym_LT_EQ] = ACTIONS(4462),
    [anon_sym_LT] = ACTIONS(4464),
    [anon_sym_EQ_EQ] = ACTIONS(4462),
    [anon_sym_BANG_EQ] = ACTIONS(4462),
    [anon_sym_TILDE_EQ] = ACTIONS(4462),
    [anon_sym_AMP_TILDE] = ACTIONS(4464),
    [anon_sym_LT_LT] = ACTIONS(4464),
    [anon_sym_GT_GT] = ACTIONS(4464),
    [anon_sym_STAR] = ACTIONS(4464),
    [anon_sym_SLASH] = ACTIONS(4464),
    [anon_sym_PERCENT] = ACTIONS(4464),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4462),
    [anon_sym_DOT] = ACTIONS(4464),
    [anon_sym_LBRACK] = ACTIONS(4462),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4462),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4462),
    [anon_sym_not_in] = ACTIONS(4462),
    [anon_sym_or_return] = ACTIONS(4462),
    [anon_sym_or_continue] = ACTIONS(4462),
    [anon_sym_or_break] = ACTIONS(4462),
    [anon_sym_CARET] = ACTIONS(4464),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4462),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1270] = {
    [aux_sym_struct_type_repeat2] = STATE(1425),
    [ts_builtin_sym_end] = ACTIONS(4475),
    [anon_sym_LBRACE] = ACTIONS(4475),
    [anon_sym_RBRACE] = ACTIONS(4475),
    [anon_sym_COMMA] = ACTIONS(4475),
    [anon_sym_COLON_COLON] = ACTIONS(4475),
    [anon_sym_DASH_GT] = ACTIONS(4475),
    [anon_sym_EQ] = ACTIONS(4477),
    [anon_sym_COLON] = ACTIONS(4477),
    [anon_sym_PIPE] = ACTIONS(4477),
    [anon_sym_COLON_EQ] = ACTIONS(4475),
    [anon_sym_LPAREN] = ACTIONS(4475),
    [anon_sym_PLUS_EQ] = ACTIONS(4475),
    [anon_sym_DASH_EQ] = ACTIONS(4475),
    [anon_sym_STAR_EQ] = ACTIONS(4475),
    [anon_sym_SLASH_EQ] = ACTIONS(4475),
    [anon_sym_PERCENT_EQ] = ACTIONS(4475),
    [anon_sym_AMP_EQ] = ACTIONS(4475),
    [anon_sym_PIPE_EQ] = ACTIONS(4475),
    [anon_sym_CARET_EQ] = ACTIONS(4475),
    [anon_sym_LT_LT_EQ] = ACTIONS(4475),
    [anon_sym_GT_GT_EQ] = ACTIONS(4475),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4475),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4475),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4475),
    [anon_sym_if] = ACTIONS(4475),
    [anon_sym_SEMI] = ACTIONS(4475),
    [anon_sym_else] = ACTIONS(4475),
    [anon_sym_when] = ACTIONS(4475),
    [anon_sym_in] = ACTIONS(4475),
    [anon_sym_case] = ACTIONS(4475),
    [anon_sym_QMARK] = ACTIONS(4475),
    [anon_sym_PLUS] = ACTIONS(4477),
    [anon_sym_DASH] = ACTIONS(4477),
    [anon_sym_TILDE] = ACTIONS(4477),
    [anon_sym_AMP] = ACTIONS(4477),
    [anon_sym_PIPE_PIPE] = ACTIONS(4477),
    [anon_sym_or_else] = ACTIONS(4475),
    [anon_sym_AMP_AMP] = ACTIONS(4477),
    [anon_sym_GT] = ACTIONS(4477),
    [anon_sym_GT_EQ] = ACTIONS(4475),
    [anon_sym_LT_EQ] = ACTIONS(4475),
    [anon_sym_LT] = ACTIONS(4477),
    [anon_sym_EQ_EQ] = ACTIONS(4475),
    [anon_sym_BANG_EQ] = ACTIONS(4475),
    [anon_sym_TILDE_EQ] = ACTIONS(4475),
    [anon_sym_AMP_TILDE] = ACTIONS(4477),
    [anon_sym_LT_LT] = ACTIONS(4477),
    [anon_sym_GT_GT] = ACTIONS(4477),
    [anon_sym_STAR] = ACTIONS(4477),
    [anon_sym_SLASH] = ACTIONS(4477),
    [anon_sym_PERCENT] = ACTIONS(4477),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4475),
    [anon_sym_DOT] = ACTIONS(4477),
    [anon_sym_LBRACK] = ACTIONS(4475),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4475),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4475),
    [anon_sym_not_in] = ACTIONS(4475),
    [anon_sym_or_return] = ACTIONS(4475),
    [anon_sym_or_continue] = ACTIONS(4475),
    [anon_sym_or_break] = ACTIONS(4475),
    [anon_sym_CARET] = ACTIONS(4477),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4475),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1271] = {
    [ts_builtin_sym_end] = ACTIONS(3408),
    [anon_sym_LBRACE] = ACTIONS(3408),
    [anon_sym_RBRACE] = ACTIONS(3408),
    [anon_sym_COMMA] = ACTIONS(3408),
    [anon_sym_COLON_COLON] = ACTIONS(3408),
    [anon_sym_DASH_GT] = ACTIONS(3408),
    [anon_sym_EQ] = ACTIONS(3410),
    [anon_sym_COLON] = ACTIONS(3410),
    [anon_sym_PIPE] = ACTIONS(3410),
    [anon_sym_COLON_EQ] = ACTIONS(3408),
    [anon_sym_LPAREN] = ACTIONS(3408),
    [anon_sym_PLUS_EQ] = ACTIONS(3408),
    [anon_sym_DASH_EQ] = ACTIONS(3408),
    [anon_sym_STAR_EQ] = ACTIONS(3408),
    [anon_sym_SLASH_EQ] = ACTIONS(3408),
    [anon_sym_PERCENT_EQ] = ACTIONS(3408),
    [anon_sym_AMP_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_CARET_EQ] = ACTIONS(3408),
    [anon_sym_LT_LT_EQ] = ACTIONS(3408),
    [anon_sym_GT_GT_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_if] = ACTIONS(3408),
    [anon_sym_SEMI] = ACTIONS(3408),
    [anon_sym_else] = ACTIONS(3408),
    [anon_sym_when] = ACTIONS(3408),
    [anon_sym_in] = ACTIONS(3408),
    [anon_sym_case] = ACTIONS(3408),
    [anon_sym_QMARK] = ACTIONS(3408),
    [anon_sym_PLUS] = ACTIONS(3410),
    [anon_sym_DASH] = ACTIONS(3410),
    [anon_sym_TILDE] = ACTIONS(3410),
    [anon_sym_AMP] = ACTIONS(3410),
    [anon_sym_PIPE_PIPE] = ACTIONS(3410),
    [anon_sym_or_else] = ACTIONS(3408),
    [anon_sym_AMP_AMP] = ACTIONS(3410),
    [anon_sym_GT] = ACTIONS(3410),
    [anon_sym_GT_EQ] = ACTIONS(3408),
    [anon_sym_LT_EQ] = ACTIONS(3408),
    [anon_sym_LT] = ACTIONS(3410),
    [anon_sym_EQ_EQ] = ACTIONS(3408),
    [anon_sym_BANG_EQ] = ACTIONS(3408),
    [anon_sym_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE] = ACTIONS(3410),
    [anon_sym_LT_LT] = ACTIONS(3410),
    [anon_sym_GT_GT] = ACTIONS(3410),
    [anon_sym_STAR] = ACTIONS(3410),
    [anon_sym_SLASH] = ACTIONS(3410),
    [anon_sym_PERCENT] = ACTIONS(3410),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3408),
    [anon_sym_DOT] = ACTIONS(3410),
    [anon_sym_LBRACK] = ACTIONS(3408),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3408),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3408),
    [anon_sym_not_in] = ACTIONS(3408),
    [anon_sym_or_return] = ACTIONS(3408),
    [anon_sym_or_continue] = ACTIONS(3408),
    [anon_sym_or_break] = ACTIONS(3408),
    [anon_sym_CARET] = ACTIONS(3410),
    [anon_sym_DOT2] = ACTIONS(3410),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3408),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1272] = {
    [aux_sym_struct_type_repeat2] = STATE(1425),
    [ts_builtin_sym_end] = ACTIONS(3547),
    [anon_sym_LBRACE] = ACTIONS(3547),
    [anon_sym_RBRACE] = ACTIONS(3547),
    [anon_sym_COMMA] = ACTIONS(3547),
    [anon_sym_COLON_COLON] = ACTIONS(3547),
    [anon_sym_DASH_GT] = ACTIONS(3547),
    [anon_sym_EQ] = ACTIONS(3549),
    [anon_sym_COLON] = ACTIONS(3549),
    [anon_sym_PIPE] = ACTIONS(3549),
    [anon_sym_COLON_EQ] = ACTIONS(3547),
    [anon_sym_LPAREN] = ACTIONS(3547),
    [anon_sym_PLUS_EQ] = ACTIONS(3547),
    [anon_sym_DASH_EQ] = ACTIONS(3547),
    [anon_sym_STAR_EQ] = ACTIONS(3547),
    [anon_sym_SLASH_EQ] = ACTIONS(3547),
    [anon_sym_PERCENT_EQ] = ACTIONS(3547),
    [anon_sym_AMP_EQ] = ACTIONS(3547),
    [anon_sym_PIPE_EQ] = ACTIONS(3547),
    [anon_sym_CARET_EQ] = ACTIONS(3547),
    [anon_sym_LT_LT_EQ] = ACTIONS(3547),
    [anon_sym_GT_GT_EQ] = ACTIONS(3547),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3547),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3547),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3547),
    [anon_sym_if] = ACTIONS(3547),
    [anon_sym_SEMI] = ACTIONS(3547),
    [anon_sym_else] = ACTIONS(3547),
    [anon_sym_when] = ACTIONS(3547),
    [anon_sym_in] = ACTIONS(3547),
    [anon_sym_case] = ACTIONS(3547),
    [anon_sym_QMARK] = ACTIONS(3547),
    [anon_sym_PLUS] = ACTIONS(3549),
    [anon_sym_DASH] = ACTIONS(3549),
    [anon_sym_TILDE] = ACTIONS(3549),
    [anon_sym_AMP] = ACTIONS(3549),
    [anon_sym_PIPE_PIPE] = ACTIONS(3549),
    [anon_sym_or_else] = ACTIONS(3547),
    [anon_sym_AMP_AMP] = ACTIONS(3549),
    [anon_sym_GT] = ACTIONS(3549),
    [anon_sym_GT_EQ] = ACTIONS(3547),
    [anon_sym_LT_EQ] = ACTIONS(3547),
    [anon_sym_LT] = ACTIONS(3549),
    [anon_sym_EQ_EQ] = ACTIONS(3547),
    [anon_sym_BANG_EQ] = ACTIONS(3547),
    [anon_sym_TILDE_EQ] = ACTIONS(3547),
    [anon_sym_AMP_TILDE] = ACTIONS(3549),
    [anon_sym_LT_LT] = ACTIONS(3549),
    [anon_sym_GT_GT] = ACTIONS(3549),
    [anon_sym_STAR] = ACTIONS(3549),
    [anon_sym_SLASH] = ACTIONS(3549),
    [anon_sym_PERCENT] = ACTIONS(3549),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3547),
    [anon_sym_DOT] = ACTIONS(3549),
    [anon_sym_LBRACK] = ACTIONS(3547),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3547),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3547),
    [anon_sym_not_in] = ACTIONS(3547),
    [anon_sym_or_return] = ACTIONS(3547),
    [anon_sym_or_continue] = ACTIONS(3547),
    [anon_sym_or_break] = ACTIONS(3547),
    [anon_sym_CARET] = ACTIONS(3549),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3547),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1273] = {
    [sym_expression] = STATE(6116),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5907),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1274] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5909),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1275] = {
    [sym_expression] = STATE(6382),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5911),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1276] = {
    [sym_expression] = STATE(6008),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5913),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1277] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5915),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1278] = {
    [aux_sym_field_type_repeat1] = STATE(1279),
    [anon_sym_LBRACE] = ACTIONS(3481),
    [anon_sym_COMMA] = ACTIONS(3481),
    [anon_sym_COLON_COLON] = ACTIONS(3481),
    [anon_sym_DASH_GT] = ACTIONS(3481),
    [anon_sym_where] = ACTIONS(3481),
    [anon_sym_EQ] = ACTIONS(3483),
    [anon_sym_COLON] = ACTIONS(3483),
    [anon_sym_PIPE] = ACTIONS(3483),
    [anon_sym_COLON_EQ] = ACTIONS(3481),
    [anon_sym_LPAREN] = ACTIONS(3481),
    [anon_sym_PLUS_EQ] = ACTIONS(3481),
    [anon_sym_DASH_EQ] = ACTIONS(3481),
    [anon_sym_STAR_EQ] = ACTIONS(3481),
    [anon_sym_SLASH_EQ] = ACTIONS(3481),
    [anon_sym_PERCENT_EQ] = ACTIONS(3481),
    [anon_sym_AMP_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_CARET_EQ] = ACTIONS(3481),
    [anon_sym_LT_LT_EQ] = ACTIONS(3481),
    [anon_sym_GT_GT_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(3481),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_do] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_in] = ACTIONS(3481),
    [anon_sym_QMARK] = ACTIONS(3481),
    [anon_sym_PLUS] = ACTIONS(3483),
    [anon_sym_DASH] = ACTIONS(3483),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_AMP] = ACTIONS(3483),
    [anon_sym_PIPE_PIPE] = ACTIONS(3483),
    [anon_sym_or_else] = ACTIONS(3481),
    [anon_sym_AMP_AMP] = ACTIONS(3483),
    [anon_sym_GT] = ACTIONS(3483),
    [anon_sym_GT_EQ] = ACTIONS(3481),
    [anon_sym_LT_EQ] = ACTIONS(3481),
    [anon_sym_LT] = ACTIONS(3483),
    [anon_sym_EQ_EQ] = ACTIONS(3481),
    [anon_sym_BANG_EQ] = ACTIONS(3481),
    [anon_sym_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE] = ACTIONS(3483),
    [anon_sym_LT_LT] = ACTIONS(3483),
    [anon_sym_GT_GT] = ACTIONS(3483),
    [anon_sym_STAR] = ACTIONS(3483),
    [anon_sym_SLASH] = ACTIONS(3483),
    [anon_sym_PERCENT] = ACTIONS(3483),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3481),
    [anon_sym_DOT] = ACTIONS(3483),
    [anon_sym_LBRACK] = ACTIONS(3481),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3481),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3481),
    [anon_sym_not_in] = ACTIONS(3481),
    [anon_sym_or_return] = ACTIONS(3481),
    [anon_sym_or_continue] = ACTIONS(3481),
    [anon_sym_or_break] = ACTIONS(3481),
    [anon_sym_CARET] = ACTIONS(3483),
    [anon_sym_DOT2] = ACTIONS(5917),
    [sym_uninitialized] = ACTIONS(3481),
    [sym_tag] = ACTIONS(3481),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1279] = {
    [aux_sym_field_type_repeat1] = STATE(1280),
    [anon_sym_LBRACE] = ACTIONS(3433),
    [anon_sym_COMMA] = ACTIONS(3433),
    [anon_sym_COLON_COLON] = ACTIONS(3433),
    [anon_sym_DASH_GT] = ACTIONS(3433),
    [anon_sym_where] = ACTIONS(3433),
    [anon_sym_EQ] = ACTIONS(3435),
    [anon_sym_COLON] = ACTIONS(3435),
    [anon_sym_PIPE] = ACTIONS(3435),
    [anon_sym_COLON_EQ] = ACTIONS(3433),
    [anon_sym_LPAREN] = ACTIONS(3433),
    [anon_sym_PLUS_EQ] = ACTIONS(3433),
    [anon_sym_DASH_EQ] = ACTIONS(3433),
    [anon_sym_STAR_EQ] = ACTIONS(3433),
    [anon_sym_SLASH_EQ] = ACTIONS(3433),
    [anon_sym_PERCENT_EQ] = ACTIONS(3433),
    [anon_sym_AMP_EQ] = ACTIONS(3433),
    [anon_sym_PIPE_EQ] = ACTIONS(3433),
    [anon_sym_CARET_EQ] = ACTIONS(3433),
    [anon_sym_LT_LT_EQ] = ACTIONS(3433),
    [anon_sym_GT_GT_EQ] = ACTIONS(3433),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3433),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3433),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3433),
    [anon_sym_if] = ACTIONS(3433),
    [anon_sym_SEMI] = ACTIONS(3433),
    [anon_sym_do] = ACTIONS(3433),
    [anon_sym_when] = ACTIONS(3433),
    [anon_sym_in] = ACTIONS(3433),
    [anon_sym_QMARK] = ACTIONS(3433),
    [anon_sym_PLUS] = ACTIONS(3435),
    [anon_sym_DASH] = ACTIONS(3435),
    [anon_sym_TILDE] = ACTIONS(3435),
    [anon_sym_AMP] = ACTIONS(3435),
    [anon_sym_PIPE_PIPE] = ACTIONS(3435),
    [anon_sym_or_else] = ACTIONS(3433),
    [anon_sym_AMP_AMP] = ACTIONS(3435),
    [anon_sym_GT] = ACTIONS(3435),
    [anon_sym_GT_EQ] = ACTIONS(3433),
    [anon_sym_LT_EQ] = ACTIONS(3433),
    [anon_sym_LT] = ACTIONS(3435),
    [anon_sym_EQ_EQ] = ACTIONS(3433),
    [anon_sym_BANG_EQ] = ACTIONS(3433),
    [anon_sym_TILDE_EQ] = ACTIONS(3433),
    [anon_sym_AMP_TILDE] = ACTIONS(3435),
    [anon_sym_LT_LT] = ACTIONS(3435),
    [anon_sym_GT_GT] = ACTIONS(3435),
    [anon_sym_STAR] = ACTIONS(3435),
    [anon_sym_SLASH] = ACTIONS(3435),
    [anon_sym_PERCENT] = ACTIONS(3435),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3433),
    [anon_sym_DOT] = ACTIONS(3435),
    [anon_sym_LBRACK] = ACTIONS(3433),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3433),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3433),
    [anon_sym_not_in] = ACTIONS(3433),
    [anon_sym_or_return] = ACTIONS(3433),
    [anon_sym_or_continue] = ACTIONS(3433),
    [anon_sym_or_break] = ACTIONS(3433),
    [anon_sym_CARET] = ACTIONS(3435),
    [anon_sym_DOT2] = ACTIONS(5917),
    [sym_uninitialized] = ACTIONS(3433),
    [sym_tag] = ACTIONS(3433),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1280] = {
    [aux_sym_field_type_repeat1] = STATE(1280),
    [anon_sym_LBRACE] = ACTIONS(3408),
    [anon_sym_COMMA] = ACTIONS(3408),
    [anon_sym_COLON_COLON] = ACTIONS(3408),
    [anon_sym_DASH_GT] = ACTIONS(3408),
    [anon_sym_where] = ACTIONS(3408),
    [anon_sym_EQ] = ACTIONS(3410),
    [anon_sym_COLON] = ACTIONS(3410),
    [anon_sym_PIPE] = ACTIONS(3410),
    [anon_sym_COLON_EQ] = ACTIONS(3408),
    [anon_sym_LPAREN] = ACTIONS(3408),
    [anon_sym_PLUS_EQ] = ACTIONS(3408),
    [anon_sym_DASH_EQ] = ACTIONS(3408),
    [anon_sym_STAR_EQ] = ACTIONS(3408),
    [anon_sym_SLASH_EQ] = ACTIONS(3408),
    [anon_sym_PERCENT_EQ] = ACTIONS(3408),
    [anon_sym_AMP_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_CARET_EQ] = ACTIONS(3408),
    [anon_sym_LT_LT_EQ] = ACTIONS(3408),
    [anon_sym_GT_GT_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_if] = ACTIONS(3408),
    [anon_sym_SEMI] = ACTIONS(3408),
    [anon_sym_do] = ACTIONS(3408),
    [anon_sym_when] = ACTIONS(3408),
    [anon_sym_in] = ACTIONS(3408),
    [anon_sym_QMARK] = ACTIONS(3408),
    [anon_sym_PLUS] = ACTIONS(3410),
    [anon_sym_DASH] = ACTIONS(3410),
    [anon_sym_TILDE] = ACTIONS(3410),
    [anon_sym_AMP] = ACTIONS(3410),
    [anon_sym_PIPE_PIPE] = ACTIONS(3410),
    [anon_sym_or_else] = ACTIONS(3408),
    [anon_sym_AMP_AMP] = ACTIONS(3410),
    [anon_sym_GT] = ACTIONS(3410),
    [anon_sym_GT_EQ] = ACTIONS(3408),
    [anon_sym_LT_EQ] = ACTIONS(3408),
    [anon_sym_LT] = ACTIONS(3410),
    [anon_sym_EQ_EQ] = ACTIONS(3408),
    [anon_sym_BANG_EQ] = ACTIONS(3408),
    [anon_sym_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE] = ACTIONS(3410),
    [anon_sym_LT_LT] = ACTIONS(3410),
    [anon_sym_GT_GT] = ACTIONS(3410),
    [anon_sym_STAR] = ACTIONS(3410),
    [anon_sym_SLASH] = ACTIONS(3410),
    [anon_sym_PERCENT] = ACTIONS(3410),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3408),
    [anon_sym_DOT] = ACTIONS(3410),
    [anon_sym_LBRACK] = ACTIONS(3408),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3408),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3408),
    [anon_sym_not_in] = ACTIONS(3408),
    [anon_sym_or_return] = ACTIONS(3408),
    [anon_sym_or_continue] = ACTIONS(3408),
    [anon_sym_or_break] = ACTIONS(3408),
    [anon_sym_CARET] = ACTIONS(3410),
    [anon_sym_DOT2] = ACTIONS(5919),
    [sym_uninitialized] = ACTIONS(3408),
    [sym_tag] = ACTIONS(3408),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1281] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5922),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1282] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5924),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1283] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5926),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1284] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5928),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1285] = {
    [aux_sym_struct_type_repeat2] = STATE(1425),
    [ts_builtin_sym_end] = ACTIONS(4475),
    [anon_sym_LBRACE] = ACTIONS(5930),
    [anon_sym_RBRACE] = ACTIONS(4475),
    [anon_sym_COMMA] = ACTIONS(4475),
    [anon_sym_COLON_COLON] = ACTIONS(4475),
    [anon_sym_DASH_GT] = ACTIONS(4475),
    [anon_sym_EQ] = ACTIONS(4477),
    [anon_sym_COLON] = ACTIONS(4477),
    [anon_sym_PIPE] = ACTIONS(4477),
    [anon_sym_COLON_EQ] = ACTIONS(4475),
    [anon_sym_LPAREN] = ACTIONS(4475),
    [anon_sym_PLUS_EQ] = ACTIONS(4475),
    [anon_sym_DASH_EQ] = ACTIONS(4475),
    [anon_sym_STAR_EQ] = ACTIONS(4475),
    [anon_sym_SLASH_EQ] = ACTIONS(4475),
    [anon_sym_PERCENT_EQ] = ACTIONS(4475),
    [anon_sym_AMP_EQ] = ACTIONS(4475),
    [anon_sym_PIPE_EQ] = ACTIONS(4475),
    [anon_sym_CARET_EQ] = ACTIONS(4475),
    [anon_sym_LT_LT_EQ] = ACTIONS(4475),
    [anon_sym_GT_GT_EQ] = ACTIONS(4475),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4475),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4475),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4475),
    [anon_sym_if] = ACTIONS(4475),
    [anon_sym_SEMI] = ACTIONS(4475),
    [anon_sym_else] = ACTIONS(4475),
    [anon_sym_when] = ACTIONS(4475),
    [anon_sym_in] = ACTIONS(4475),
    [anon_sym_case] = ACTIONS(4475),
    [anon_sym_QMARK] = ACTIONS(4475),
    [anon_sym_PLUS] = ACTIONS(4477),
    [anon_sym_DASH] = ACTIONS(4477),
    [anon_sym_TILDE] = ACTIONS(4477),
    [anon_sym_AMP] = ACTIONS(4477),
    [anon_sym_PIPE_PIPE] = ACTIONS(4477),
    [anon_sym_or_else] = ACTIONS(4475),
    [anon_sym_AMP_AMP] = ACTIONS(4477),
    [anon_sym_GT] = ACTIONS(4477),
    [anon_sym_GT_EQ] = ACTIONS(4475),
    [anon_sym_LT_EQ] = ACTIONS(4475),
    [anon_sym_LT] = ACTIONS(4477),
    [anon_sym_EQ_EQ] = ACTIONS(4475),
    [anon_sym_BANG_EQ] = ACTIONS(4475),
    [anon_sym_TILDE_EQ] = ACTIONS(4475),
    [anon_sym_AMP_TILDE] = ACTIONS(4477),
    [anon_sym_LT_LT] = ACTIONS(4477),
    [anon_sym_GT_GT] = ACTIONS(4477),
    [anon_sym_STAR] = ACTIONS(4477),
    [anon_sym_SLASH] = ACTIONS(4477),
    [anon_sym_PERCENT] = ACTIONS(4477),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4475),
    [anon_sym_DOT] = ACTIONS(4477),
    [anon_sym_LBRACK] = ACTIONS(4475),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4475),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4475),
    [anon_sym_not_in] = ACTIONS(4475),
    [anon_sym_or_return] = ACTIONS(4475),
    [anon_sym_or_continue] = ACTIONS(4475),
    [anon_sym_or_break] = ACTIONS(4475),
    [anon_sym_CARET] = ACTIONS(4477),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4475),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1286] = {
    [sym_expression] = STATE(6457),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5932),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1287] = {
    [sym_expression] = STATE(6567),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5934),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1288] = {
    [sym_expression] = STATE(6047),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5936),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1289] = {
    [sym_expression] = STATE(6376),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5938),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1290] = {
    [sym_expression] = STATE(6076),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5940),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1291] = {
    [sym_expression] = STATE(6104),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5942),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1292] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5944),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1293] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5946),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1294] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5948),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1295] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5950),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1296] = {
    [sym_expression] = STATE(6606),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5952),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1297] = {
    [sym_expression] = STATE(6540),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(5954),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1298] = {
    [sym_expression] = STATE(6093),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5956),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1299] = {
    [sym_expression] = STATE(6235),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5958),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1300] = {
    [sym_expression] = STATE(6124),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5960),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1301] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5962),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1302] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5964),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1303] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5966),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1304] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(5968),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1305] = {
    [sym_block] = STATE(2503),
    [sym_where_clause] = STATE(1525),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3439),
    [anon_sym_COLON_COLON] = ACTIONS(3439),
    [anon_sym_DASH_GT] = ACTIONS(5972),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3445),
    [anon_sym_COLON] = ACTIONS(3445),
    [anon_sym_PIPE] = ACTIONS(3445),
    [anon_sym_COLON_EQ] = ACTIONS(3439),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_PLUS_EQ] = ACTIONS(3439),
    [anon_sym_DASH_EQ] = ACTIONS(3439),
    [anon_sym_STAR_EQ] = ACTIONS(3439),
    [anon_sym_SLASH_EQ] = ACTIONS(3439),
    [anon_sym_PERCENT_EQ] = ACTIONS(3439),
    [anon_sym_AMP_EQ] = ACTIONS(3439),
    [anon_sym_PIPE_EQ] = ACTIONS(3439),
    [anon_sym_CARET_EQ] = ACTIONS(3439),
    [anon_sym_LT_LT_EQ] = ACTIONS(3439),
    [anon_sym_GT_GT_EQ] = ACTIONS(3439),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3439),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3439),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3439),
    [anon_sym_if] = ACTIONS(3439),
    [anon_sym_SEMI] = ACTIONS(3439),
    [anon_sym_do] = ACTIONS(3439),
    [anon_sym_when] = ACTIONS(3439),
    [anon_sym_in] = ACTIONS(3439),
    [anon_sym_QMARK] = ACTIONS(3439),
    [anon_sym_PLUS] = ACTIONS(3445),
    [anon_sym_DASH] = ACTIONS(3445),
    [anon_sym_TILDE] = ACTIONS(3445),
    [anon_sym_AMP] = ACTIONS(3445),
    [anon_sym_PIPE_PIPE] = ACTIONS(3445),
    [anon_sym_or_else] = ACTIONS(3439),
    [anon_sym_AMP_AMP] = ACTIONS(3445),
    [anon_sym_GT] = ACTIONS(3445),
    [anon_sym_GT_EQ] = ACTIONS(3439),
    [anon_sym_LT_EQ] = ACTIONS(3439),
    [anon_sym_LT] = ACTIONS(3445),
    [anon_sym_EQ_EQ] = ACTIONS(3439),
    [anon_sym_BANG_EQ] = ACTIONS(3439),
    [anon_sym_TILDE_EQ] = ACTIONS(3439),
    [anon_sym_AMP_TILDE] = ACTIONS(3445),
    [anon_sym_LT_LT] = ACTIONS(3445),
    [anon_sym_GT_GT] = ACTIONS(3445),
    [anon_sym_STAR] = ACTIONS(3445),
    [anon_sym_SLASH] = ACTIONS(3445),
    [anon_sym_PERCENT] = ACTIONS(3445),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3439),
    [anon_sym_DOT] = ACTIONS(3445),
    [anon_sym_LBRACK] = ACTIONS(3439),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3439),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3439),
    [anon_sym_not_in] = ACTIONS(3439),
    [anon_sym_or_return] = ACTIONS(3439),
    [anon_sym_or_continue] = ACTIONS(3439),
    [anon_sym_or_break] = ACTIONS(3439),
    [anon_sym_CARET] = ACTIONS(3445),
    [sym_uninitialized] = ACTIONS(5976),
    [sym_tag] = ACTIONS(5978),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1306] = {
    [sym_block] = STATE(2228),
    [sym_where_clause] = STATE(1527),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(5980),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_do] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(5982),
    [sym_tag] = ACTIONS(5984),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1307] = {
    [sym_block] = STATE(2277),
    [sym_where_clause] = STATE(1529),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(5986),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_do] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(5988),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(5990),
    [sym_tag] = ACTIONS(5992),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1308] = {
    [sym_block] = STATE(2277),
    [sym_where_clause] = STATE(1529),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_do] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(5990),
    [sym_tag] = ACTIONS(5992),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1309] = {
    [sym_block] = STATE(2293),
    [sym_where_clause] = STATE(1531),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(5986),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_do] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(5988),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(5994),
    [sym_tag] = ACTIONS(5996),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1310] = {
    [sym_block] = STATE(2293),
    [sym_where_clause] = STATE(1531),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_do] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(5994),
    [sym_tag] = ACTIONS(5996),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1311] = {
    [sym_block] = STATE(2293),
    [sym_where_clause] = STATE(1531),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_do] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(5994),
    [sym_tag] = ACTIONS(5998),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1312] = {
    [sym_block] = STATE(2370),
    [sym_where_clause] = STATE(1534),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(5986),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_do] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(5988),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(6000),
    [sym_tag] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1313] = {
    [sym_block] = STATE(2370),
    [sym_where_clause] = STATE(1534),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_do] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(6000),
    [sym_tag] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1314] = {
    [sym_block] = STATE(2370),
    [sym_where_clause] = STATE(1534),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_do] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(6000),
    [sym_tag] = ACTIONS(6004),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1315] = {
    [sym_block] = STATE(2530),
    [sym_where_clause] = STATE(1537),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_do] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(6006),
    [sym_tag] = ACTIONS(6008),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1316] = {
    [sym_expression] = STATE(6279),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6010),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1317] = {
    [sym_expression] = STATE(6225),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6012),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1318] = {
    [sym_expression] = STATE(6007),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6014),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1319] = {
    [sym_expression] = STATE(6249),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6016),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1320] = {
    [sym_expression] = STATE(5973),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6018),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1321] = {
    [sym_expression] = STATE(5976),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6020),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1322] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6022),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1323] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6024),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1324] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6026),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1325] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6028),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1326] = {
    [sym_expression] = STATE(6439),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6030),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1327] = {
    [sym_expression] = STATE(6468),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6032),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1328] = {
    [sym_expression] = STATE(6039),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6034),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1329] = {
    [sym_expression] = STATE(6263),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6036),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1330] = {
    [sym_expression] = STATE(6067),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6038),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1331] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6040),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1332] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6042),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1333] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6044),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1334] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6046),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1335] = {
    [sym_expression] = STATE(6595),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6048),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1336] = {
    [sym_expression] = STATE(6558),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6050),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1337] = {
    [sym_expression] = STATE(6058),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6052),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1338] = {
    [sym_expression] = STATE(6274),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6054),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1339] = {
    [sym_expression] = STATE(6044),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6056),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1340] = {
    [sym_expression] = STATE(6145),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6058),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1341] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6060),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1342] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6062),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1343] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6064),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1344] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6066),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1345] = {
    [sym_expression] = STATE(6373),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6068),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1346] = {
    [sym_expression] = STATE(6405),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6070),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1347] = {
    [sym_expression] = STATE(6018),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6072),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1348] = {
    [sym_expression] = STATE(6285),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6074),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1349] = {
    [sym_expression] = STATE(6005),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6076),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1350] = {
    [sym_expression] = STATE(6073),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6078),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1351] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6080),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1352] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6082),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1353] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6084),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1354] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6086),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1355] = {
    [sym_expression] = STATE(6292),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6088),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1356] = {
    [sym_expression] = STATE(6409),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6090),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1357] = {
    [sym_expression] = STATE(6128),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6092),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1358] = {
    [sym_expression] = STATE(6003),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6094),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1359] = {
    [sym_expression] = STATE(6296),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6096),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1360] = {
    [sym_expression] = STATE(5972),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6098),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1361] = {
    [sym_expression] = STATE(6020),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6100),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1362] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6102),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1363] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6104),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1364] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6106),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1365] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6108),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1366] = {
    [sym_expression] = STATE(6323),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6110),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1367] = {
    [sym_expression] = STATE(6433),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6112),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1368] = {
    [aux_sym_field_type_repeat1] = STATE(1268),
    [ts_builtin_sym_end] = ACTIONS(3433),
    [anon_sym_RBRACE] = ACTIONS(3433),
    [anon_sym_COMMA] = ACTIONS(3433),
    [anon_sym_COLON_COLON] = ACTIONS(3433),
    [anon_sym_DASH_GT] = ACTIONS(3433),
    [anon_sym_EQ] = ACTIONS(3435),
    [anon_sym_COLON] = ACTIONS(3435),
    [anon_sym_PIPE] = ACTIONS(3435),
    [anon_sym_COLON_EQ] = ACTIONS(3433),
    [anon_sym_LPAREN] = ACTIONS(3433),
    [anon_sym_PLUS_EQ] = ACTIONS(3433),
    [anon_sym_DASH_EQ] = ACTIONS(3433),
    [anon_sym_STAR_EQ] = ACTIONS(3433),
    [anon_sym_SLASH_EQ] = ACTIONS(3433),
    [anon_sym_PERCENT_EQ] = ACTIONS(3433),
    [anon_sym_AMP_EQ] = ACTIONS(3433),
    [anon_sym_PIPE_EQ] = ACTIONS(3433),
    [anon_sym_CARET_EQ] = ACTIONS(3433),
    [anon_sym_LT_LT_EQ] = ACTIONS(3433),
    [anon_sym_GT_GT_EQ] = ACTIONS(3433),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3433),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3433),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3433),
    [anon_sym_if] = ACTIONS(3433),
    [anon_sym_SEMI] = ACTIONS(3433),
    [anon_sym_else] = ACTIONS(3433),
    [anon_sym_when] = ACTIONS(3433),
    [anon_sym_in] = ACTIONS(3433),
    [anon_sym_case] = ACTIONS(3433),
    [anon_sym_QMARK] = ACTIONS(3433),
    [anon_sym_PLUS] = ACTIONS(3435),
    [anon_sym_DASH] = ACTIONS(3435),
    [anon_sym_TILDE] = ACTIONS(3435),
    [anon_sym_AMP] = ACTIONS(3435),
    [anon_sym_PIPE_PIPE] = ACTIONS(3435),
    [anon_sym_or_else] = ACTIONS(3433),
    [anon_sym_AMP_AMP] = ACTIONS(3435),
    [anon_sym_GT] = ACTIONS(3435),
    [anon_sym_GT_EQ] = ACTIONS(3433),
    [anon_sym_LT_EQ] = ACTIONS(3433),
    [anon_sym_LT] = ACTIONS(3435),
    [anon_sym_EQ_EQ] = ACTIONS(3433),
    [anon_sym_BANG_EQ] = ACTIONS(3433),
    [anon_sym_TILDE_EQ] = ACTIONS(3433),
    [anon_sym_AMP_TILDE] = ACTIONS(3435),
    [anon_sym_LT_LT] = ACTIONS(3435),
    [anon_sym_GT_GT] = ACTIONS(3435),
    [anon_sym_STAR] = ACTIONS(3435),
    [anon_sym_SLASH] = ACTIONS(3435),
    [anon_sym_PERCENT] = ACTIONS(3435),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3433),
    [anon_sym_DOT] = ACTIONS(3435),
    [anon_sym_LBRACK] = ACTIONS(3433),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3433),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3433),
    [anon_sym_not_in] = ACTIONS(3433),
    [anon_sym_or_return] = ACTIONS(3433),
    [anon_sym_or_continue] = ACTIONS(3433),
    [anon_sym_or_break] = ACTIONS(3433),
    [anon_sym_CARET] = ACTIONS(3435),
    [anon_sym_DOT2] = ACTIONS(6114),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3433),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1369] = {
    [sym_expression] = STATE(6304),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6116),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1370] = {
    [sym_expression] = STATE(6138),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6118),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1371] = {
    [sym_expression] = STATE(5981),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6120),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1372] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6122),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1373] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6124),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1374] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6126),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1375] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6128),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1376] = {
    [sym_expression] = STATE(6354),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6130),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1377] = {
    [sym_expression] = STATE(6481),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6132),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1378] = {
    [sym_expression] = STATE(6115),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6134),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1379] = {
    [sym_expression] = STATE(6312),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6136),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1380] = {
    [sym_expression] = STATE(6133),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6138),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1381] = {
    [sym_expression] = STATE(5979),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6140),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1382] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6142),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1383] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6144),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1384] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6146),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1385] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6148),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1386] = {
    [sym_expression] = STATE(6503),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6150),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1387] = {
    [sym_expression] = STATE(6229),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6152),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1388] = {
    [sym_expression] = STATE(6015),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6154),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1389] = {
    [sym_expression] = STATE(6320),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6156),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1390] = {
    [sym_expression] = STATE(6053),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6158),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1391] = {
    [sym_expression] = STATE(6080),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6160),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1392] = {
    [sym_expression] = STATE(6386),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6162),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1393] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6164),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1394] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6166),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1395] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6168),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1396] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6170),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1397] = {
    [sym_block] = STATE(2608),
    [sym_where_clause] = STATE(2428),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3439),
    [anon_sym_COLON_COLON] = ACTIONS(3439),
    [anon_sym_DASH_GT] = ACTIONS(6174),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3445),
    [anon_sym_COLON] = ACTIONS(3445),
    [anon_sym_PIPE] = ACTIONS(3445),
    [anon_sym_COLON_EQ] = ACTIONS(3439),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_PLUS_EQ] = ACTIONS(3439),
    [anon_sym_DASH_EQ] = ACTIONS(3439),
    [anon_sym_STAR_EQ] = ACTIONS(3439),
    [anon_sym_SLASH_EQ] = ACTIONS(3439),
    [anon_sym_PERCENT_EQ] = ACTIONS(3439),
    [anon_sym_AMP_EQ] = ACTIONS(3439),
    [anon_sym_PIPE_EQ] = ACTIONS(3439),
    [anon_sym_CARET_EQ] = ACTIONS(3439),
    [anon_sym_LT_LT_EQ] = ACTIONS(3439),
    [anon_sym_GT_GT_EQ] = ACTIONS(3439),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3439),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3439),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3439),
    [anon_sym_if] = ACTIONS(3439),
    [anon_sym_SEMI] = ACTIONS(3439),
    [anon_sym_do] = ACTIONS(3439),
    [anon_sym_when] = ACTIONS(3439),
    [anon_sym_in] = ACTIONS(3439),
    [anon_sym_QMARK] = ACTIONS(3439),
    [anon_sym_PLUS] = ACTIONS(3445),
    [anon_sym_DASH] = ACTIONS(3445),
    [anon_sym_TILDE] = ACTIONS(3445),
    [anon_sym_AMP] = ACTIONS(3445),
    [anon_sym_PIPE_PIPE] = ACTIONS(3445),
    [anon_sym_or_else] = ACTIONS(3439),
    [anon_sym_AMP_AMP] = ACTIONS(3445),
    [anon_sym_GT] = ACTIONS(3445),
    [anon_sym_GT_EQ] = ACTIONS(3439),
    [anon_sym_LT_EQ] = ACTIONS(3439),
    [anon_sym_LT] = ACTIONS(3445),
    [anon_sym_EQ_EQ] = ACTIONS(3439),
    [anon_sym_BANG_EQ] = ACTIONS(3439),
    [anon_sym_TILDE_EQ] = ACTIONS(3439),
    [anon_sym_AMP_TILDE] = ACTIONS(3445),
    [anon_sym_LT_LT] = ACTIONS(3445),
    [anon_sym_GT_GT] = ACTIONS(3445),
    [anon_sym_STAR] = ACTIONS(3445),
    [anon_sym_SLASH] = ACTIONS(3445),
    [anon_sym_PERCENT] = ACTIONS(3445),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3439),
    [anon_sym_DOT] = ACTIONS(3445),
    [anon_sym_LBRACK] = ACTIONS(3439),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3439),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3439),
    [anon_sym_not_in] = ACTIONS(3439),
    [anon_sym_or_return] = ACTIONS(3439),
    [anon_sym_or_continue] = ACTIONS(3439),
    [anon_sym_or_break] = ACTIONS(3439),
    [anon_sym_CARET] = ACTIONS(3445),
    [sym_uninitialized] = ACTIONS(6176),
    [sym_tag] = ACTIONS(6178),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1398] = {
    [sym_expression] = STATE(6228),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6180),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1399] = {
    [sym_block] = STATE(2616),
    [sym_where_clause] = STATE(2459),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(6182),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_do] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(6184),
    [sym_tag] = ACTIONS(6186),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1400] = {
    [sym_expression] = STATE(6335),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6188),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1401] = {
    [sym_expression] = STATE(6100),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6190),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1402] = {
    [sym_expression] = STATE(6330),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6192),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1403] = {
    [sym_expression] = STATE(6088),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6194),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1404] = {
    [aux_sym_field_type_repeat1] = STATE(1279),
    [anon_sym_LBRACE] = ACTIONS(3481),
    [anon_sym_COMMA] = ACTIONS(3481),
    [anon_sym_COLON_COLON] = ACTIONS(3481),
    [anon_sym_DASH_GT] = ACTIONS(3481),
    [anon_sym_where] = ACTIONS(3481),
    [anon_sym_EQ] = ACTIONS(3483),
    [anon_sym_COLON] = ACTIONS(6196),
    [anon_sym_PIPE] = ACTIONS(3483),
    [anon_sym_COLON_EQ] = ACTIONS(3481),
    [anon_sym_LPAREN] = ACTIONS(3481),
    [anon_sym_PLUS_EQ] = ACTIONS(3481),
    [anon_sym_DASH_EQ] = ACTIONS(3481),
    [anon_sym_STAR_EQ] = ACTIONS(3481),
    [anon_sym_SLASH_EQ] = ACTIONS(3481),
    [anon_sym_PERCENT_EQ] = ACTIONS(3481),
    [anon_sym_AMP_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_CARET_EQ] = ACTIONS(3481),
    [anon_sym_LT_LT_EQ] = ACTIONS(3481),
    [anon_sym_GT_GT_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(3481),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_do] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_in] = ACTIONS(3481),
    [anon_sym_QMARK] = ACTIONS(3481),
    [anon_sym_PLUS] = ACTIONS(3483),
    [anon_sym_DASH] = ACTIONS(3483),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_AMP] = ACTIONS(3483),
    [anon_sym_PIPE_PIPE] = ACTIONS(3483),
    [anon_sym_or_else] = ACTIONS(3481),
    [anon_sym_AMP_AMP] = ACTIONS(3483),
    [anon_sym_GT] = ACTIONS(3483),
    [anon_sym_GT_EQ] = ACTIONS(3481),
    [anon_sym_LT_EQ] = ACTIONS(3481),
    [anon_sym_LT] = ACTIONS(3483),
    [anon_sym_EQ_EQ] = ACTIONS(3481),
    [anon_sym_BANG_EQ] = ACTIONS(3481),
    [anon_sym_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE] = ACTIONS(3483),
    [anon_sym_LT_LT] = ACTIONS(3483),
    [anon_sym_GT_GT] = ACTIONS(3483),
    [anon_sym_STAR] = ACTIONS(3483),
    [anon_sym_SLASH] = ACTIONS(3483),
    [anon_sym_PERCENT] = ACTIONS(3483),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3481),
    [anon_sym_DOT] = ACTIONS(3483),
    [anon_sym_LBRACK] = ACTIONS(3481),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3481),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3481),
    [anon_sym_not_in] = ACTIONS(3481),
    [anon_sym_or_return] = ACTIONS(3481),
    [anon_sym_or_continue] = ACTIONS(3481),
    [anon_sym_or_break] = ACTIONS(3481),
    [anon_sym_CARET] = ACTIONS(3483),
    [anon_sym_DOT2] = ACTIONS(5917),
    [sym_uninitialized] = ACTIONS(3481),
    [sym_tag] = ACTIONS(3481),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1405] = {
    [sym_expression] = STATE(5978),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6198),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1406] = {
    [sym_block] = STATE(2625),
    [sym_where_clause] = STATE(2506),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(5986),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_do] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(5988),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(6200),
    [sym_tag] = ACTIONS(6202),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1407] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6204),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1408] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6206),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1409] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6208),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1410] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6210),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1411] = {
    [sym_block] = STATE(2625),
    [sym_where_clause] = STATE(2506),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_do] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(6200),
    [sym_tag] = ACTIONS(6202),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1412] = {
    [sym_expression] = STATE(6241),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6212),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1413] = {
    [sym_block] = STATE(2634),
    [sym_where_clause] = STATE(2227),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(5986),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_do] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(5988),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(6214),
    [sym_tag] = ACTIONS(6216),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1414] = {
    [sym_block] = STATE(2634),
    [sym_where_clause] = STATE(2227),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_do] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(6214),
    [sym_tag] = ACTIONS(6216),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1415] = {
    [sym_expression] = STATE(6300),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_RBRACK] = ACTIONS(6218),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1416] = {
    [sym_block] = STATE(2634),
    [sym_where_clause] = STATE(2227),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_do] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(6214),
    [sym_tag] = ACTIONS(6220),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1417] = {
    [sym_expression] = STATE(6141),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6222),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1418] = {
    [sym_expression] = STATE(6340),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6224),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1419] = {
    [sym_expression] = STATE(6146),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6226),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1420] = {
    [sym_expression] = STATE(6034),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6228),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1421] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6230),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1422] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6232),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1423] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6234),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1424] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6236),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1425] = {
    [aux_sym_struct_type_repeat2] = STATE(1425),
    [ts_builtin_sym_end] = ACTIONS(3701),
    [anon_sym_LBRACE] = ACTIONS(6238),
    [anon_sym_RBRACE] = ACTIONS(3701),
    [anon_sym_COMMA] = ACTIONS(3701),
    [anon_sym_COLON_COLON] = ACTIONS(3701),
    [anon_sym_DASH_GT] = ACTIONS(3701),
    [anon_sym_EQ] = ACTIONS(3706),
    [anon_sym_COLON] = ACTIONS(3706),
    [anon_sym_PIPE] = ACTIONS(3706),
    [anon_sym_COLON_EQ] = ACTIONS(3701),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_PLUS_EQ] = ACTIONS(3701),
    [anon_sym_DASH_EQ] = ACTIONS(3701),
    [anon_sym_STAR_EQ] = ACTIONS(3701),
    [anon_sym_SLASH_EQ] = ACTIONS(3701),
    [anon_sym_PERCENT_EQ] = ACTIONS(3701),
    [anon_sym_AMP_EQ] = ACTIONS(3701),
    [anon_sym_PIPE_EQ] = ACTIONS(3701),
    [anon_sym_CARET_EQ] = ACTIONS(3701),
    [anon_sym_LT_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT_GT_EQ] = ACTIONS(3701),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3701),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3701),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3701),
    [anon_sym_if] = ACTIONS(3701),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_else] = ACTIONS(3701),
    [anon_sym_when] = ACTIONS(3701),
    [anon_sym_in] = ACTIONS(3701),
    [anon_sym_case] = ACTIONS(3701),
    [anon_sym_QMARK] = ACTIONS(3701),
    [anon_sym_PLUS] = ACTIONS(3706),
    [anon_sym_DASH] = ACTIONS(3706),
    [anon_sym_TILDE] = ACTIONS(3706),
    [anon_sym_AMP] = ACTIONS(3706),
    [anon_sym_PIPE_PIPE] = ACTIONS(3706),
    [anon_sym_or_else] = ACTIONS(3701),
    [anon_sym_AMP_AMP] = ACTIONS(3706),
    [anon_sym_GT] = ACTIONS(3706),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_LT] = ACTIONS(3706),
    [anon_sym_EQ_EQ] = ACTIONS(3701),
    [anon_sym_BANG_EQ] = ACTIONS(3701),
    [anon_sym_TILDE_EQ] = ACTIONS(3701),
    [anon_sym_AMP_TILDE] = ACTIONS(3706),
    [anon_sym_LT_LT] = ACTIONS(3706),
    [anon_sym_GT_GT] = ACTIONS(3706),
    [anon_sym_STAR] = ACTIONS(3706),
    [anon_sym_SLASH] = ACTIONS(3706),
    [anon_sym_PERCENT] = ACTIONS(3706),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(3706),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3701),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3701),
    [anon_sym_not_in] = ACTIONS(3701),
    [anon_sym_or_return] = ACTIONS(3701),
    [anon_sym_or_continue] = ACTIONS(3701),
    [anon_sym_or_break] = ACTIONS(3701),
    [anon_sym_CARET] = ACTIONS(3706),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3701),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1426] = {
    [sym_block] = STATE(2667),
    [sym_where_clause] = STATE(2243),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(5986),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_do] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(5988),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(6241),
    [sym_tag] = ACTIONS(6243),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1427] = {
    [sym_expression] = STATE(6111),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6245),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1428] = {
    [sym_block] = STATE(2667),
    [sym_where_clause] = STATE(2243),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_do] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(6241),
    [sym_tag] = ACTIONS(6243),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1429] = {
    [sym_block] = STATE(2667),
    [sym_where_clause] = STATE(2243),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_do] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(6241),
    [sym_tag] = ACTIONS(6247),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1430] = {
    [sym_block] = STATE(2639),
    [sym_where_clause] = STATE(2244),
    [anon_sym_LBRACE] = ACTIONS(6172),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_where] = ACTIONS(5974),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_do] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(6249),
    [sym_tag] = ACTIONS(6251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1431] = {
    [sym_expression] = STATE(5985),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6253),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1432] = {
    [sym_expression] = STATE(6019),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6255),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1433] = {
    [sym_expression] = STATE(6010),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6257),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1434] = {
    [sym_expression] = STATE(6112),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6259),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1435] = {
    [sym_expression] = STATE(6006),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_struct_field] = STATE(8658),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1436] = {
    [sym_expression] = STATE(5984),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6261),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1437] = {
    [sym_expression] = STATE(6095),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6263),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1438] = {
    [sym_expression] = STATE(6022),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6265),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1439] = {
    [sym_expression] = STATE(6117),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6267),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1440] = {
    [sym_expression] = STATE(6094),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6269),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1441] = {
    [sym_expression] = STATE(6035),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6271),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1442] = {
    [sym_expression] = STATE(6065),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6273),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1443] = {
    [sym_expression] = STATE(6037),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_COLON] = ACTIONS(6275),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1444] = {
    [sym_expression] = STATE(6013),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6277),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1445] = {
    [sym_expression] = STATE(6016),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6279),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1446] = {
    [aux_sym_field_identifier_repeat1] = STATE(7617),
    [ts_builtin_sym_end] = ACTIONS(3912),
    [anon_sym_LBRACE] = ACTIONS(6281),
    [anon_sym_RBRACE] = ACTIONS(3912),
    [anon_sym_COMMA] = ACTIONS(3912),
    [anon_sym_COLON_COLON] = ACTIONS(3912),
    [anon_sym_DASH_GT] = ACTIONS(3912),
    [anon_sym_EQ] = ACTIONS(3917),
    [anon_sym_COLON] = ACTIONS(3917),
    [anon_sym_PIPE] = ACTIONS(3917),
    [anon_sym_COLON_EQ] = ACTIONS(3912),
    [anon_sym_LPAREN] = ACTIONS(6283),
    [anon_sym_PLUS_EQ] = ACTIONS(3912),
    [anon_sym_DASH_EQ] = ACTIONS(3912),
    [anon_sym_STAR_EQ] = ACTIONS(3912),
    [anon_sym_SLASH_EQ] = ACTIONS(3912),
    [anon_sym_PERCENT_EQ] = ACTIONS(3912),
    [anon_sym_AMP_EQ] = ACTIONS(3912),
    [anon_sym_PIPE_EQ] = ACTIONS(3912),
    [anon_sym_CARET_EQ] = ACTIONS(3912),
    [anon_sym_LT_LT_EQ] = ACTIONS(3912),
    [anon_sym_GT_GT_EQ] = ACTIONS(3912),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3912),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3912),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3912),
    [anon_sym_if] = ACTIONS(3912),
    [anon_sym_SEMI] = ACTIONS(3912),
    [anon_sym_else] = ACTIONS(3912),
    [anon_sym_when] = ACTIONS(3912),
    [anon_sym_in] = ACTIONS(3912),
    [anon_sym_case] = ACTIONS(3912),
    [anon_sym_QMARK] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3917),
    [anon_sym_DASH] = ACTIONS(3917),
    [anon_sym_TILDE] = ACTIONS(3917),
    [anon_sym_AMP] = ACTIONS(3917),
    [anon_sym_PIPE_PIPE] = ACTIONS(3917),
    [anon_sym_or_else] = ACTIONS(3912),
    [anon_sym_AMP_AMP] = ACTIONS(3917),
    [anon_sym_GT] = ACTIONS(3917),
    [anon_sym_GT_EQ] = ACTIONS(3912),
    [anon_sym_LT_EQ] = ACTIONS(3912),
    [anon_sym_LT] = ACTIONS(3917),
    [anon_sym_EQ_EQ] = ACTIONS(3912),
    [anon_sym_BANG_EQ] = ACTIONS(3912),
    [anon_sym_TILDE_EQ] = ACTIONS(3912),
    [anon_sym_AMP_TILDE] = ACTIONS(3917),
    [anon_sym_LT_LT] = ACTIONS(3917),
    [anon_sym_GT_GT] = ACTIONS(3917),
    [anon_sym_STAR] = ACTIONS(3917),
    [anon_sym_SLASH] = ACTIONS(3917),
    [anon_sym_PERCENT] = ACTIONS(3917),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3912),
    [anon_sym_DOT] = ACTIONS(3917),
    [anon_sym_LBRACK] = ACTIONS(3912),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3912),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3912),
    [anon_sym_not_in] = ACTIONS(3912),
    [anon_sym_or_return] = ACTIONS(3912),
    [anon_sym_or_continue] = ACTIONS(3912),
    [anon_sym_or_break] = ACTIONS(3912),
    [anon_sym_CARET] = ACTIONS(3917),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3912),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1447] = {
    [aux_sym_field_type_repeat1] = STATE(1368),
    [ts_builtin_sym_end] = ACTIONS(3481),
    [anon_sym_RBRACE] = ACTIONS(3481),
    [anon_sym_COMMA] = ACTIONS(3481),
    [anon_sym_COLON_COLON] = ACTIONS(3481),
    [anon_sym_DASH_GT] = ACTIONS(3481),
    [anon_sym_EQ] = ACTIONS(3483),
    [anon_sym_COLON] = ACTIONS(3483),
    [anon_sym_PIPE] = ACTIONS(3483),
    [anon_sym_COLON_EQ] = ACTIONS(3481),
    [anon_sym_LPAREN] = ACTIONS(3481),
    [anon_sym_PLUS_EQ] = ACTIONS(3481),
    [anon_sym_DASH_EQ] = ACTIONS(3481),
    [anon_sym_STAR_EQ] = ACTIONS(3481),
    [anon_sym_SLASH_EQ] = ACTIONS(3481),
    [anon_sym_PERCENT_EQ] = ACTIONS(3481),
    [anon_sym_AMP_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_CARET_EQ] = ACTIONS(3481),
    [anon_sym_LT_LT_EQ] = ACTIONS(3481),
    [anon_sym_GT_GT_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(3481),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_else] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_in] = ACTIONS(3481),
    [anon_sym_case] = ACTIONS(3481),
    [anon_sym_QMARK] = ACTIONS(3481),
    [anon_sym_PLUS] = ACTIONS(3483),
    [anon_sym_DASH] = ACTIONS(3483),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_AMP] = ACTIONS(3483),
    [anon_sym_PIPE_PIPE] = ACTIONS(3483),
    [anon_sym_or_else] = ACTIONS(3481),
    [anon_sym_AMP_AMP] = ACTIONS(3483),
    [anon_sym_GT] = ACTIONS(3483),
    [anon_sym_GT_EQ] = ACTIONS(3481),
    [anon_sym_LT_EQ] = ACTIONS(3481),
    [anon_sym_LT] = ACTIONS(3483),
    [anon_sym_EQ_EQ] = ACTIONS(3481),
    [anon_sym_BANG_EQ] = ACTIONS(3481),
    [anon_sym_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE] = ACTIONS(3483),
    [anon_sym_LT_LT] = ACTIONS(3483),
    [anon_sym_GT_GT] = ACTIONS(3483),
    [anon_sym_STAR] = ACTIONS(3483),
    [anon_sym_SLASH] = ACTIONS(3483),
    [anon_sym_PERCENT] = ACTIONS(3483),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3481),
    [anon_sym_DOT] = ACTIONS(3483),
    [anon_sym_LBRACK] = ACTIONS(3481),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3481),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3481),
    [anon_sym_not_in] = ACTIONS(3481),
    [anon_sym_or_return] = ACTIONS(3481),
    [anon_sym_or_continue] = ACTIONS(3481),
    [anon_sym_or_break] = ACTIONS(3481),
    [anon_sym_CARET] = ACTIONS(3483),
    [anon_sym_DOT2] = ACTIONS(6114),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3481),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1448] = {
    [aux_sym_struct_type_repeat2] = STATE(1425),
    [ts_builtin_sym_end] = ACTIONS(3547),
    [anon_sym_LBRACE] = ACTIONS(5930),
    [anon_sym_RBRACE] = ACTIONS(3547),
    [anon_sym_COMMA] = ACTIONS(3547),
    [anon_sym_COLON_COLON] = ACTIONS(3547),
    [anon_sym_DASH_GT] = ACTIONS(3547),
    [anon_sym_EQ] = ACTIONS(3549),
    [anon_sym_COLON] = ACTIONS(3549),
    [anon_sym_PIPE] = ACTIONS(3549),
    [anon_sym_COLON_EQ] = ACTIONS(3547),
    [anon_sym_LPAREN] = ACTIONS(3547),
    [anon_sym_PLUS_EQ] = ACTIONS(3547),
    [anon_sym_DASH_EQ] = ACTIONS(3547),
    [anon_sym_STAR_EQ] = ACTIONS(3547),
    [anon_sym_SLASH_EQ] = ACTIONS(3547),
    [anon_sym_PERCENT_EQ] = ACTIONS(3547),
    [anon_sym_AMP_EQ] = ACTIONS(3547),
    [anon_sym_PIPE_EQ] = ACTIONS(3547),
    [anon_sym_CARET_EQ] = ACTIONS(3547),
    [anon_sym_LT_LT_EQ] = ACTIONS(3547),
    [anon_sym_GT_GT_EQ] = ACTIONS(3547),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3547),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3547),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3547),
    [anon_sym_if] = ACTIONS(3547),
    [anon_sym_SEMI] = ACTIONS(3547),
    [anon_sym_else] = ACTIONS(3547),
    [anon_sym_when] = ACTIONS(3547),
    [anon_sym_in] = ACTIONS(3547),
    [anon_sym_case] = ACTIONS(3547),
    [anon_sym_QMARK] = ACTIONS(3547),
    [anon_sym_PLUS] = ACTIONS(3549),
    [anon_sym_DASH] = ACTIONS(3549),
    [anon_sym_TILDE] = ACTIONS(3549),
    [anon_sym_AMP] = ACTIONS(3549),
    [anon_sym_PIPE_PIPE] = ACTIONS(3549),
    [anon_sym_or_else] = ACTIONS(3547),
    [anon_sym_AMP_AMP] = ACTIONS(3549),
    [anon_sym_GT] = ACTIONS(3549),
    [anon_sym_GT_EQ] = ACTIONS(3547),
    [anon_sym_LT_EQ] = ACTIONS(3547),
    [anon_sym_LT] = ACTIONS(3549),
    [anon_sym_EQ_EQ] = ACTIONS(3547),
    [anon_sym_BANG_EQ] = ACTIONS(3547),
    [anon_sym_TILDE_EQ] = ACTIONS(3547),
    [anon_sym_AMP_TILDE] = ACTIONS(3549),
    [anon_sym_LT_LT] = ACTIONS(3549),
    [anon_sym_GT_GT] = ACTIONS(3549),
    [anon_sym_STAR] = ACTIONS(3549),
    [anon_sym_SLASH] = ACTIONS(3549),
    [anon_sym_PERCENT] = ACTIONS(3549),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3547),
    [anon_sym_DOT] = ACTIONS(3549),
    [anon_sym_LBRACK] = ACTIONS(3547),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3547),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3547),
    [anon_sym_not_in] = ACTIONS(3547),
    [anon_sym_or_return] = ACTIONS(3547),
    [anon_sym_or_continue] = ACTIONS(3547),
    [anon_sym_or_break] = ACTIONS(3547),
    [anon_sym_CARET] = ACTIONS(3549),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3547),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1449] = {
    [sym_expression] = STATE(6551),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6286),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1450] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6288),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1451] = {
    [aux_sym_struct_type_repeat2] = STATE(1425),
    [ts_builtin_sym_end] = ACTIONS(4462),
    [anon_sym_LBRACE] = ACTIONS(5930),
    [anon_sym_RBRACE] = ACTIONS(4462),
    [anon_sym_COMMA] = ACTIONS(4462),
    [anon_sym_COLON_COLON] = ACTIONS(4462),
    [anon_sym_DASH_GT] = ACTIONS(4462),
    [anon_sym_EQ] = ACTIONS(4464),
    [anon_sym_COLON] = ACTIONS(4464),
    [anon_sym_PIPE] = ACTIONS(4464),
    [anon_sym_COLON_EQ] = ACTIONS(4462),
    [anon_sym_LPAREN] = ACTIONS(4462),
    [anon_sym_PLUS_EQ] = ACTIONS(4462),
    [anon_sym_DASH_EQ] = ACTIONS(4462),
    [anon_sym_STAR_EQ] = ACTIONS(4462),
    [anon_sym_SLASH_EQ] = ACTIONS(4462),
    [anon_sym_PERCENT_EQ] = ACTIONS(4462),
    [anon_sym_AMP_EQ] = ACTIONS(4462),
    [anon_sym_PIPE_EQ] = ACTIONS(4462),
    [anon_sym_CARET_EQ] = ACTIONS(4462),
    [anon_sym_LT_LT_EQ] = ACTIONS(4462),
    [anon_sym_GT_GT_EQ] = ACTIONS(4462),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4462),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4462),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4462),
    [anon_sym_if] = ACTIONS(4462),
    [anon_sym_SEMI] = ACTIONS(4462),
    [anon_sym_else] = ACTIONS(4462),
    [anon_sym_when] = ACTIONS(4462),
    [anon_sym_in] = ACTIONS(4462),
    [anon_sym_case] = ACTIONS(4462),
    [anon_sym_QMARK] = ACTIONS(4462),
    [anon_sym_PLUS] = ACTIONS(4464),
    [anon_sym_DASH] = ACTIONS(4464),
    [anon_sym_TILDE] = ACTIONS(4464),
    [anon_sym_AMP] = ACTIONS(4464),
    [anon_sym_PIPE_PIPE] = ACTIONS(4464),
    [anon_sym_or_else] = ACTIONS(4462),
    [anon_sym_AMP_AMP] = ACTIONS(4464),
    [anon_sym_GT] = ACTIONS(4464),
    [anon_sym_GT_EQ] = ACTIONS(4462),
    [anon_sym_LT_EQ] = ACTIONS(4462),
    [anon_sym_LT] = ACTIONS(4464),
    [anon_sym_EQ_EQ] = ACTIONS(4462),
    [anon_sym_BANG_EQ] = ACTIONS(4462),
    [anon_sym_TILDE_EQ] = ACTIONS(4462),
    [anon_sym_AMP_TILDE] = ACTIONS(4464),
    [anon_sym_LT_LT] = ACTIONS(4464),
    [anon_sym_GT_GT] = ACTIONS(4464),
    [anon_sym_STAR] = ACTIONS(4464),
    [anon_sym_SLASH] = ACTIONS(4464),
    [anon_sym_PERCENT] = ACTIONS(4464),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4462),
    [anon_sym_DOT] = ACTIONS(4464),
    [anon_sym_LBRACK] = ACTIONS(4462),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4462),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4462),
    [anon_sym_not_in] = ACTIONS(4462),
    [anon_sym_or_return] = ACTIONS(4462),
    [anon_sym_or_continue] = ACTIONS(4462),
    [anon_sym_or_break] = ACTIONS(4462),
    [anon_sym_CARET] = ACTIONS(4464),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4462),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1452] = {
    [sym_expression] = STATE(6027),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_RBRACE] = ACTIONS(6290),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1453] = {
    [sym_expression] = STATE(2395),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1454] = {
    [sym_expression] = STATE(6191),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1455] = {
    [sym_expression] = STATE(6089),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1456] = {
    [ts_builtin_sym_end] = ACTIONS(5095),
    [anon_sym_LBRACE] = ACTIONS(5095),
    [anon_sym_RBRACE] = ACTIONS(5095),
    [anon_sym_COMMA] = ACTIONS(5095),
    [anon_sym_COLON_COLON] = ACTIONS(5095),
    [anon_sym_DASH_GT] = ACTIONS(5095),
    [anon_sym_EQ] = ACTIONS(5097),
    [anon_sym_COLON] = ACTIONS(5097),
    [anon_sym_PIPE] = ACTIONS(5097),
    [anon_sym_COLON_EQ] = ACTIONS(5095),
    [anon_sym_LPAREN] = ACTIONS(5095),
    [anon_sym_PLUS_EQ] = ACTIONS(5095),
    [anon_sym_DASH_EQ] = ACTIONS(5095),
    [anon_sym_STAR_EQ] = ACTIONS(5095),
    [anon_sym_SLASH_EQ] = ACTIONS(5095),
    [anon_sym_PERCENT_EQ] = ACTIONS(5095),
    [anon_sym_AMP_EQ] = ACTIONS(5095),
    [anon_sym_PIPE_EQ] = ACTIONS(5095),
    [anon_sym_CARET_EQ] = ACTIONS(5095),
    [anon_sym_LT_LT_EQ] = ACTIONS(5095),
    [anon_sym_GT_GT_EQ] = ACTIONS(5095),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5095),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5095),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5095),
    [anon_sym_if] = ACTIONS(5095),
    [anon_sym_SEMI] = ACTIONS(5095),
    [anon_sym_else] = ACTIONS(5095),
    [anon_sym_when] = ACTIONS(5095),
    [anon_sym_in] = ACTIONS(5095),
    [anon_sym_case] = ACTIONS(5095),
    [anon_sym_QMARK] = ACTIONS(5095),
    [anon_sym_PLUS] = ACTIONS(5097),
    [anon_sym_DASH] = ACTIONS(5097),
    [anon_sym_TILDE] = ACTIONS(5097),
    [anon_sym_AMP] = ACTIONS(5097),
    [anon_sym_PIPE_PIPE] = ACTIONS(5097),
    [anon_sym_or_else] = ACTIONS(5095),
    [anon_sym_AMP_AMP] = ACTIONS(5097),
    [anon_sym_GT] = ACTIONS(5097),
    [anon_sym_GT_EQ] = ACTIONS(5095),
    [anon_sym_LT_EQ] = ACTIONS(5095),
    [anon_sym_LT] = ACTIONS(5097),
    [anon_sym_EQ_EQ] = ACTIONS(5095),
    [anon_sym_BANG_EQ] = ACTIONS(5095),
    [anon_sym_TILDE_EQ] = ACTIONS(5095),
    [anon_sym_AMP_TILDE] = ACTIONS(5097),
    [anon_sym_LT_LT] = ACTIONS(5097),
    [anon_sym_GT_GT] = ACTIONS(5097),
    [anon_sym_STAR] = ACTIONS(5097),
    [anon_sym_SLASH] = ACTIONS(5097),
    [anon_sym_PERCENT] = ACTIONS(5097),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5095),
    [anon_sym_DOT] = ACTIONS(5097),
    [anon_sym_LBRACK] = ACTIONS(5095),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5095),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5095),
    [anon_sym_not_in] = ACTIONS(5095),
    [anon_sym_or_return] = ACTIONS(5095),
    [anon_sym_or_continue] = ACTIONS(5095),
    [anon_sym_or_break] = ACTIONS(5095),
    [anon_sym_CARET] = ACTIONS(5097),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5095),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1457] = {
    [sym_expression] = STATE(2396),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1458] = {
    [ts_builtin_sym_end] = ACTIONS(909),
    [anon_sym_LBRACE] = ACTIONS(909),
    [anon_sym_RBRACE] = ACTIONS(909),
    [anon_sym_COMMA] = ACTIONS(909),
    [anon_sym_COLON_COLON] = ACTIONS(909),
    [anon_sym_DASH_GT] = ACTIONS(909),
    [anon_sym_EQ] = ACTIONS(911),
    [anon_sym_COLON] = ACTIONS(911),
    [anon_sym_PIPE] = ACTIONS(911),
    [anon_sym_COLON_EQ] = ACTIONS(909),
    [anon_sym_LPAREN] = ACTIONS(909),
    [anon_sym_PLUS_EQ] = ACTIONS(909),
    [anon_sym_DASH_EQ] = ACTIONS(909),
    [anon_sym_STAR_EQ] = ACTIONS(909),
    [anon_sym_SLASH_EQ] = ACTIONS(909),
    [anon_sym_PERCENT_EQ] = ACTIONS(909),
    [anon_sym_AMP_EQ] = ACTIONS(909),
    [anon_sym_PIPE_EQ] = ACTIONS(909),
    [anon_sym_CARET_EQ] = ACTIONS(909),
    [anon_sym_LT_LT_EQ] = ACTIONS(909),
    [anon_sym_GT_GT_EQ] = ACTIONS(909),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(909),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(909),
    [anon_sym_if] = ACTIONS(909),
    [anon_sym_SEMI] = ACTIONS(909),
    [anon_sym_else] = ACTIONS(909),
    [anon_sym_when] = ACTIONS(909),
    [anon_sym_in] = ACTIONS(909),
    [anon_sym_case] = ACTIONS(909),
    [anon_sym_QMARK] = ACTIONS(909),
    [anon_sym_PLUS] = ACTIONS(911),
    [anon_sym_DASH] = ACTIONS(911),
    [anon_sym_TILDE] = ACTIONS(911),
    [anon_sym_AMP] = ACTIONS(911),
    [anon_sym_PIPE_PIPE] = ACTIONS(911),
    [anon_sym_or_else] = ACTIONS(909),
    [anon_sym_AMP_AMP] = ACTIONS(911),
    [anon_sym_GT] = ACTIONS(911),
    [anon_sym_GT_EQ] = ACTIONS(909),
    [anon_sym_LT_EQ] = ACTIONS(909),
    [anon_sym_LT] = ACTIONS(911),
    [anon_sym_EQ_EQ] = ACTIONS(909),
    [anon_sym_BANG_EQ] = ACTIONS(909),
    [anon_sym_TILDE_EQ] = ACTIONS(909),
    [anon_sym_AMP_TILDE] = ACTIONS(911),
    [anon_sym_LT_LT] = ACTIONS(911),
    [anon_sym_GT_GT] = ACTIONS(911),
    [anon_sym_STAR] = ACTIONS(911),
    [anon_sym_SLASH] = ACTIONS(911),
    [anon_sym_PERCENT] = ACTIONS(911),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(909),
    [anon_sym_DOT] = ACTIONS(911),
    [anon_sym_LBRACK] = ACTIONS(909),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(909),
    [anon_sym_DOT_DOT_LT] = ACTIONS(909),
    [anon_sym_not_in] = ACTIONS(909),
    [anon_sym_or_return] = ACTIONS(909),
    [anon_sym_or_continue] = ACTIONS(909),
    [anon_sym_or_break] = ACTIONS(909),
    [anon_sym_CARET] = ACTIONS(911),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(909),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1459] = {
    [ts_builtin_sym_end] = ACTIONS(809),
    [anon_sym_LBRACE] = ACTIONS(809),
    [anon_sym_RBRACE] = ACTIONS(809),
    [anon_sym_COMMA] = ACTIONS(809),
    [anon_sym_COLON_COLON] = ACTIONS(809),
    [anon_sym_DASH_GT] = ACTIONS(809),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_COLON_EQ] = ACTIONS(809),
    [anon_sym_LPAREN] = ACTIONS(809),
    [anon_sym_PLUS_EQ] = ACTIONS(809),
    [anon_sym_DASH_EQ] = ACTIONS(809),
    [anon_sym_STAR_EQ] = ACTIONS(809),
    [anon_sym_SLASH_EQ] = ACTIONS(809),
    [anon_sym_PERCENT_EQ] = ACTIONS(809),
    [anon_sym_AMP_EQ] = ACTIONS(809),
    [anon_sym_PIPE_EQ] = ACTIONS(809),
    [anon_sym_CARET_EQ] = ACTIONS(809),
    [anon_sym_LT_LT_EQ] = ACTIONS(809),
    [anon_sym_GT_GT_EQ] = ACTIONS(809),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(809),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(809),
    [anon_sym_SEMI] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(809),
    [anon_sym_when] = ACTIONS(809),
    [anon_sym_in] = ACTIONS(809),
    [anon_sym_case] = ACTIONS(809),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(812),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_TILDE] = ACTIONS(812),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(812),
    [anon_sym_or_else] = ACTIONS(809),
    [anon_sym_AMP_AMP] = ACTIONS(812),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(809),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_TILDE_EQ] = ACTIONS(809),
    [anon_sym_AMP_TILDE] = ACTIONS(812),
    [anon_sym_LT_LT] = ACTIONS(812),
    [anon_sym_GT_GT] = ACTIONS(812),
    [anon_sym_STAR] = ACTIONS(812),
    [anon_sym_SLASH] = ACTIONS(812),
    [anon_sym_PERCENT] = ACTIONS(812),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(809),
    [anon_sym_DOT] = ACTIONS(812),
    [anon_sym_LBRACK] = ACTIONS(809),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(809),
    [anon_sym_DOT_DOT_LT] = ACTIONS(809),
    [anon_sym_not_in] = ACTIONS(809),
    [anon_sym_or_return] = ACTIONS(809),
    [anon_sym_or_continue] = ACTIONS(809),
    [anon_sym_or_break] = ACTIONS(809),
    [anon_sym_CARET] = ACTIONS(812),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(809),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1460] = {
    [ts_builtin_sym_end] = ACTIONS(767),
    [anon_sym_LBRACE] = ACTIONS(767),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_COMMA] = ACTIONS(767),
    [anon_sym_COLON_COLON] = ACTIONS(767),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_EQ] = ACTIONS(773),
    [anon_sym_COLON] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(767),
    [anon_sym_LPAREN] = ACTIONS(767),
    [anon_sym_PLUS_EQ] = ACTIONS(767),
    [anon_sym_DASH_EQ] = ACTIONS(767),
    [anon_sym_STAR_EQ] = ACTIONS(767),
    [anon_sym_SLASH_EQ] = ACTIONS(767),
    [anon_sym_PERCENT_EQ] = ACTIONS(767),
    [anon_sym_AMP_EQ] = ACTIONS(767),
    [anon_sym_PIPE_EQ] = ACTIONS(767),
    [anon_sym_CARET_EQ] = ACTIONS(767),
    [anon_sym_LT_LT_EQ] = ACTIONS(767),
    [anon_sym_GT_GT_EQ] = ACTIONS(767),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(767),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(767),
    [anon_sym_SEMI] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(767),
    [anon_sym_when] = ACTIONS(767),
    [anon_sym_in] = ACTIONS(767),
    [anon_sym_case] = ACTIONS(767),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_AMP] = ACTIONS(773),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_or_else] = ACTIONS(767),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_GT] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(767),
    [anon_sym_LT] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_TILDE_EQ] = ACTIONS(767),
    [anon_sym_AMP_TILDE] = ACTIONS(773),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(773),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(767),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_LBRACK] = ACTIONS(767),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(767),
    [anon_sym_DOT_DOT_LT] = ACTIONS(767),
    [anon_sym_not_in] = ACTIONS(767),
    [anon_sym_or_return] = ACTIONS(767),
    [anon_sym_or_continue] = ACTIONS(767),
    [anon_sym_or_break] = ACTIONS(767),
    [anon_sym_CARET] = ACTIONS(773),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(767),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1461] = {
    [sym_expression] = STATE(5986),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1462] = {
    [ts_builtin_sym_end] = ACTIONS(871),
    [anon_sym_LBRACE] = ACTIONS(871),
    [anon_sym_RBRACE] = ACTIONS(871),
    [anon_sym_COMMA] = ACTIONS(871),
    [anon_sym_COLON_COLON] = ACTIONS(871),
    [anon_sym_DASH_GT] = ACTIONS(871),
    [anon_sym_EQ] = ACTIONS(874),
    [anon_sym_COLON] = ACTIONS(874),
    [anon_sym_PIPE] = ACTIONS(874),
    [anon_sym_COLON_EQ] = ACTIONS(871),
    [anon_sym_LPAREN] = ACTIONS(871),
    [anon_sym_PLUS_EQ] = ACTIONS(871),
    [anon_sym_DASH_EQ] = ACTIONS(871),
    [anon_sym_STAR_EQ] = ACTIONS(871),
    [anon_sym_SLASH_EQ] = ACTIONS(871),
    [anon_sym_PERCENT_EQ] = ACTIONS(871),
    [anon_sym_AMP_EQ] = ACTIONS(871),
    [anon_sym_PIPE_EQ] = ACTIONS(871),
    [anon_sym_CARET_EQ] = ACTIONS(871),
    [anon_sym_LT_LT_EQ] = ACTIONS(871),
    [anon_sym_GT_GT_EQ] = ACTIONS(871),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(871),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(871),
    [anon_sym_if] = ACTIONS(871),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(871),
    [anon_sym_when] = ACTIONS(871),
    [anon_sym_in] = ACTIONS(871),
    [anon_sym_case] = ACTIONS(871),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_PLUS] = ACTIONS(874),
    [anon_sym_DASH] = ACTIONS(874),
    [anon_sym_TILDE] = ACTIONS(874),
    [anon_sym_AMP] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(874),
    [anon_sym_or_else] = ACTIONS(871),
    [anon_sym_AMP_AMP] = ACTIONS(874),
    [anon_sym_GT] = ACTIONS(874),
    [anon_sym_GT_EQ] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(871),
    [anon_sym_LT] = ACTIONS(874),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_TILDE_EQ] = ACTIONS(871),
    [anon_sym_AMP_TILDE] = ACTIONS(874),
    [anon_sym_LT_LT] = ACTIONS(874),
    [anon_sym_GT_GT] = ACTIONS(874),
    [anon_sym_STAR] = ACTIONS(874),
    [anon_sym_SLASH] = ACTIONS(874),
    [anon_sym_PERCENT] = ACTIONS(874),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(871),
    [anon_sym_DOT] = ACTIONS(874),
    [anon_sym_LBRACK] = ACTIONS(871),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(871),
    [anon_sym_DOT_DOT_LT] = ACTIONS(871),
    [anon_sym_not_in] = ACTIONS(871),
    [anon_sym_or_return] = ACTIONS(871),
    [anon_sym_or_continue] = ACTIONS(871),
    [anon_sym_or_break] = ACTIONS(871),
    [anon_sym_CARET] = ACTIONS(874),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(871),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1463] = {
    [sym_expression] = STATE(6391),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1464] = {
    [sym_expression] = STATE(2398),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1465] = {
    [sym_expression] = STATE(6009),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1466] = {
    [ts_builtin_sym_end] = ACTIONS(5081),
    [anon_sym_LBRACE] = ACTIONS(5081),
    [anon_sym_RBRACE] = ACTIONS(5081),
    [anon_sym_COMMA] = ACTIONS(5081),
    [anon_sym_COLON_COLON] = ACTIONS(5081),
    [anon_sym_DASH_GT] = ACTIONS(5081),
    [anon_sym_EQ] = ACTIONS(5084),
    [anon_sym_COLON] = ACTIONS(5084),
    [anon_sym_PIPE] = ACTIONS(5084),
    [anon_sym_COLON_EQ] = ACTIONS(5081),
    [anon_sym_LPAREN] = ACTIONS(5081),
    [anon_sym_PLUS_EQ] = ACTIONS(5081),
    [anon_sym_DASH_EQ] = ACTIONS(5081),
    [anon_sym_STAR_EQ] = ACTIONS(5081),
    [anon_sym_SLASH_EQ] = ACTIONS(5081),
    [anon_sym_PERCENT_EQ] = ACTIONS(5081),
    [anon_sym_AMP_EQ] = ACTIONS(5081),
    [anon_sym_PIPE_EQ] = ACTIONS(5081),
    [anon_sym_CARET_EQ] = ACTIONS(5081),
    [anon_sym_LT_LT_EQ] = ACTIONS(5081),
    [anon_sym_GT_GT_EQ] = ACTIONS(5081),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5081),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5081),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5081),
    [anon_sym_if] = ACTIONS(5081),
    [anon_sym_SEMI] = ACTIONS(5081),
    [anon_sym_else] = ACTIONS(5081),
    [anon_sym_when] = ACTIONS(5081),
    [anon_sym_in] = ACTIONS(5081),
    [anon_sym_case] = ACTIONS(5081),
    [anon_sym_QMARK] = ACTIONS(5081),
    [anon_sym_PLUS] = ACTIONS(5084),
    [anon_sym_DASH] = ACTIONS(5084),
    [anon_sym_TILDE] = ACTIONS(5084),
    [anon_sym_AMP] = ACTIONS(5084),
    [anon_sym_PIPE_PIPE] = ACTIONS(5084),
    [anon_sym_or_else] = ACTIONS(5081),
    [anon_sym_AMP_AMP] = ACTIONS(5084),
    [anon_sym_GT] = ACTIONS(5084),
    [anon_sym_GT_EQ] = ACTIONS(5081),
    [anon_sym_LT_EQ] = ACTIONS(5081),
    [anon_sym_LT] = ACTIONS(5084),
    [anon_sym_EQ_EQ] = ACTIONS(5081),
    [anon_sym_BANG_EQ] = ACTIONS(5081),
    [anon_sym_TILDE_EQ] = ACTIONS(5081),
    [anon_sym_AMP_TILDE] = ACTIONS(5084),
    [anon_sym_LT_LT] = ACTIONS(5084),
    [anon_sym_GT_GT] = ACTIONS(5084),
    [anon_sym_STAR] = ACTIONS(5084),
    [anon_sym_SLASH] = ACTIONS(5084),
    [anon_sym_PERCENT] = ACTIONS(5084),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5081),
    [anon_sym_DOT] = ACTIONS(5084),
    [anon_sym_LBRACK] = ACTIONS(5081),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5081),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5081),
    [anon_sym_not_in] = ACTIONS(5081),
    [anon_sym_or_return] = ACTIONS(5081),
    [anon_sym_or_continue] = ACTIONS(5081),
    [anon_sym_or_break] = ACTIONS(5081),
    [anon_sym_CARET] = ACTIONS(5084),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5081),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1467] = {
    [sym_expression] = STATE(2399),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1468] = {
    [aux_sym_struct_type_repeat2] = STATE(2102),
    [anon_sym_LBRACE] = ACTIONS(4462),
    [anon_sym_COMMA] = ACTIONS(4462),
    [anon_sym_COLON_COLON] = ACTIONS(4462),
    [anon_sym_DASH_GT] = ACTIONS(4462),
    [anon_sym_where] = ACTIONS(4462),
    [anon_sym_EQ] = ACTIONS(4464),
    [anon_sym_COLON] = ACTIONS(4464),
    [anon_sym_PIPE] = ACTIONS(4464),
    [anon_sym_COLON_EQ] = ACTIONS(4462),
    [anon_sym_LPAREN] = ACTIONS(4462),
    [anon_sym_PLUS_EQ] = ACTIONS(4462),
    [anon_sym_DASH_EQ] = ACTIONS(4462),
    [anon_sym_STAR_EQ] = ACTIONS(4462),
    [anon_sym_SLASH_EQ] = ACTIONS(4462),
    [anon_sym_PERCENT_EQ] = ACTIONS(4462),
    [anon_sym_AMP_EQ] = ACTIONS(4462),
    [anon_sym_PIPE_EQ] = ACTIONS(4462),
    [anon_sym_CARET_EQ] = ACTIONS(4462),
    [anon_sym_LT_LT_EQ] = ACTIONS(4462),
    [anon_sym_GT_GT_EQ] = ACTIONS(4462),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4462),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4462),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4462),
    [anon_sym_if] = ACTIONS(4462),
    [anon_sym_SEMI] = ACTIONS(4462),
    [anon_sym_do] = ACTIONS(4462),
    [anon_sym_when] = ACTIONS(4462),
    [anon_sym_in] = ACTIONS(4462),
    [anon_sym_QMARK] = ACTIONS(4462),
    [anon_sym_PLUS] = ACTIONS(4464),
    [anon_sym_DASH] = ACTIONS(4464),
    [anon_sym_TILDE] = ACTIONS(4464),
    [anon_sym_AMP] = ACTIONS(4464),
    [anon_sym_PIPE_PIPE] = ACTIONS(4464),
    [anon_sym_or_else] = ACTIONS(4462),
    [anon_sym_AMP_AMP] = ACTIONS(4464),
    [anon_sym_GT] = ACTIONS(4464),
    [anon_sym_GT_EQ] = ACTIONS(4462),
    [anon_sym_LT_EQ] = ACTIONS(4462),
    [anon_sym_LT] = ACTIONS(4464),
    [anon_sym_EQ_EQ] = ACTIONS(4462),
    [anon_sym_BANG_EQ] = ACTIONS(4462),
    [anon_sym_TILDE_EQ] = ACTIONS(4462),
    [anon_sym_AMP_TILDE] = ACTIONS(4464),
    [anon_sym_LT_LT] = ACTIONS(4464),
    [anon_sym_GT_GT] = ACTIONS(4464),
    [anon_sym_STAR] = ACTIONS(4464),
    [anon_sym_SLASH] = ACTIONS(4464),
    [anon_sym_PERCENT] = ACTIONS(4464),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4462),
    [anon_sym_DOT] = ACTIONS(4464),
    [anon_sym_LBRACK] = ACTIONS(4462),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4462),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4462),
    [anon_sym_not_in] = ACTIONS(4462),
    [anon_sym_or_return] = ACTIONS(4462),
    [anon_sym_or_continue] = ACTIONS(4462),
    [anon_sym_or_break] = ACTIONS(4462),
    [anon_sym_CARET] = ACTIONS(4464),
    [sym_uninitialized] = ACTIONS(4462),
    [sym_tag] = ACTIONS(4462),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1469] = {
    [sym_expression] = STATE(2404),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1470] = {
    [aux_sym_struct_type_repeat2] = STATE(2102),
    [anon_sym_LBRACE] = ACTIONS(4475),
    [anon_sym_COMMA] = ACTIONS(4475),
    [anon_sym_COLON_COLON] = ACTIONS(4475),
    [anon_sym_DASH_GT] = ACTIONS(4475),
    [anon_sym_where] = ACTIONS(4475),
    [anon_sym_EQ] = ACTIONS(4477),
    [anon_sym_COLON] = ACTIONS(4477),
    [anon_sym_PIPE] = ACTIONS(4477),
    [anon_sym_COLON_EQ] = ACTIONS(4475),
    [anon_sym_LPAREN] = ACTIONS(4475),
    [anon_sym_PLUS_EQ] = ACTIONS(4475),
    [anon_sym_DASH_EQ] = ACTIONS(4475),
    [anon_sym_STAR_EQ] = ACTIONS(4475),
    [anon_sym_SLASH_EQ] = ACTIONS(4475),
    [anon_sym_PERCENT_EQ] = ACTIONS(4475),
    [anon_sym_AMP_EQ] = ACTIONS(4475),
    [anon_sym_PIPE_EQ] = ACTIONS(4475),
    [anon_sym_CARET_EQ] = ACTIONS(4475),
    [anon_sym_LT_LT_EQ] = ACTIONS(4475),
    [anon_sym_GT_GT_EQ] = ACTIONS(4475),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4475),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4475),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4475),
    [anon_sym_if] = ACTIONS(4475),
    [anon_sym_SEMI] = ACTIONS(4475),
    [anon_sym_do] = ACTIONS(4475),
    [anon_sym_when] = ACTIONS(4475),
    [anon_sym_in] = ACTIONS(4475),
    [anon_sym_QMARK] = ACTIONS(4475),
    [anon_sym_PLUS] = ACTIONS(4477),
    [anon_sym_DASH] = ACTIONS(4477),
    [anon_sym_TILDE] = ACTIONS(4477),
    [anon_sym_AMP] = ACTIONS(4477),
    [anon_sym_PIPE_PIPE] = ACTIONS(4477),
    [anon_sym_or_else] = ACTIONS(4475),
    [anon_sym_AMP_AMP] = ACTIONS(4477),
    [anon_sym_GT] = ACTIONS(4477),
    [anon_sym_GT_EQ] = ACTIONS(4475),
    [anon_sym_LT_EQ] = ACTIONS(4475),
    [anon_sym_LT] = ACTIONS(4477),
    [anon_sym_EQ_EQ] = ACTIONS(4475),
    [anon_sym_BANG_EQ] = ACTIONS(4475),
    [anon_sym_TILDE_EQ] = ACTIONS(4475),
    [anon_sym_AMP_TILDE] = ACTIONS(4477),
    [anon_sym_LT_LT] = ACTIONS(4477),
    [anon_sym_GT_GT] = ACTIONS(4477),
    [anon_sym_STAR] = ACTIONS(4477),
    [anon_sym_SLASH] = ACTIONS(4477),
    [anon_sym_PERCENT] = ACTIONS(4477),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4475),
    [anon_sym_DOT] = ACTIONS(4477),
    [anon_sym_LBRACK] = ACTIONS(4475),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4475),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4475),
    [anon_sym_not_in] = ACTIONS(4475),
    [anon_sym_or_return] = ACTIONS(4475),
    [anon_sym_or_continue] = ACTIONS(4475),
    [anon_sym_or_break] = ACTIONS(4475),
    [anon_sym_CARET] = ACTIONS(4477),
    [sym_uninitialized] = ACTIONS(4475),
    [sym_tag] = ACTIONS(4475),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1471] = {
    [anon_sym_LBRACE] = ACTIONS(3408),
    [anon_sym_COMMA] = ACTIONS(3408),
    [anon_sym_COLON_COLON] = ACTIONS(3408),
    [anon_sym_DASH_GT] = ACTIONS(3408),
    [anon_sym_where] = ACTIONS(3408),
    [anon_sym_EQ] = ACTIONS(3410),
    [anon_sym_COLON] = ACTIONS(3410),
    [anon_sym_PIPE] = ACTIONS(3410),
    [anon_sym_COLON_EQ] = ACTIONS(3408),
    [anon_sym_LPAREN] = ACTIONS(3408),
    [anon_sym_PLUS_EQ] = ACTIONS(3408),
    [anon_sym_DASH_EQ] = ACTIONS(3408),
    [anon_sym_STAR_EQ] = ACTIONS(3408),
    [anon_sym_SLASH_EQ] = ACTIONS(3408),
    [anon_sym_PERCENT_EQ] = ACTIONS(3408),
    [anon_sym_AMP_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_CARET_EQ] = ACTIONS(3408),
    [anon_sym_LT_LT_EQ] = ACTIONS(3408),
    [anon_sym_GT_GT_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_if] = ACTIONS(3408),
    [anon_sym_SEMI] = ACTIONS(3408),
    [anon_sym_do] = ACTIONS(3408),
    [anon_sym_when] = ACTIONS(3408),
    [anon_sym_in] = ACTIONS(3408),
    [anon_sym_QMARK] = ACTIONS(3408),
    [anon_sym_PLUS] = ACTIONS(3410),
    [anon_sym_DASH] = ACTIONS(3410),
    [anon_sym_TILDE] = ACTIONS(3410),
    [anon_sym_AMP] = ACTIONS(3410),
    [anon_sym_PIPE_PIPE] = ACTIONS(3410),
    [anon_sym_or_else] = ACTIONS(3408),
    [anon_sym_AMP_AMP] = ACTIONS(3410),
    [anon_sym_GT] = ACTIONS(3410),
    [anon_sym_GT_EQ] = ACTIONS(3408),
    [anon_sym_LT_EQ] = ACTIONS(3408),
    [anon_sym_LT] = ACTIONS(3410),
    [anon_sym_EQ_EQ] = ACTIONS(3408),
    [anon_sym_BANG_EQ] = ACTIONS(3408),
    [anon_sym_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE] = ACTIONS(3410),
    [anon_sym_LT_LT] = ACTIONS(3410),
    [anon_sym_GT_GT] = ACTIONS(3410),
    [anon_sym_STAR] = ACTIONS(3410),
    [anon_sym_SLASH] = ACTIONS(3410),
    [anon_sym_PERCENT] = ACTIONS(3410),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3408),
    [anon_sym_DOT] = ACTIONS(3410),
    [anon_sym_LBRACK] = ACTIONS(3408),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3408),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3408),
    [anon_sym_not_in] = ACTIONS(3408),
    [anon_sym_or_return] = ACTIONS(3408),
    [anon_sym_or_continue] = ACTIONS(3408),
    [anon_sym_or_break] = ACTIONS(3408),
    [anon_sym_CARET] = ACTIONS(3410),
    [anon_sym_DOT2] = ACTIONS(3410),
    [sym_uninitialized] = ACTIONS(3408),
    [sym_tag] = ACTIONS(3408),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1472] = {
    [sym_expression] = STATE(2406),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1473] = {
    [sym_expression] = STATE(6173),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1474] = {
    [aux_sym_struct_type_repeat2] = STATE(2102),
    [anon_sym_LBRACE] = ACTIONS(3547),
    [anon_sym_COMMA] = ACTIONS(3547),
    [anon_sym_COLON_COLON] = ACTIONS(3547),
    [anon_sym_DASH_GT] = ACTIONS(3547),
    [anon_sym_where] = ACTIONS(3547),
    [anon_sym_EQ] = ACTIONS(3549),
    [anon_sym_COLON] = ACTIONS(3549),
    [anon_sym_PIPE] = ACTIONS(3549),
    [anon_sym_COLON_EQ] = ACTIONS(3547),
    [anon_sym_LPAREN] = ACTIONS(3547),
    [anon_sym_PLUS_EQ] = ACTIONS(3547),
    [anon_sym_DASH_EQ] = ACTIONS(3547),
    [anon_sym_STAR_EQ] = ACTIONS(3547),
    [anon_sym_SLASH_EQ] = ACTIONS(3547),
    [anon_sym_PERCENT_EQ] = ACTIONS(3547),
    [anon_sym_AMP_EQ] = ACTIONS(3547),
    [anon_sym_PIPE_EQ] = ACTIONS(3547),
    [anon_sym_CARET_EQ] = ACTIONS(3547),
    [anon_sym_LT_LT_EQ] = ACTIONS(3547),
    [anon_sym_GT_GT_EQ] = ACTIONS(3547),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3547),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3547),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3547),
    [anon_sym_if] = ACTIONS(3547),
    [anon_sym_SEMI] = ACTIONS(3547),
    [anon_sym_do] = ACTIONS(3547),
    [anon_sym_when] = ACTIONS(3547),
    [anon_sym_in] = ACTIONS(3547),
    [anon_sym_QMARK] = ACTIONS(3547),
    [anon_sym_PLUS] = ACTIONS(3549),
    [anon_sym_DASH] = ACTIONS(3549),
    [anon_sym_TILDE] = ACTIONS(3549),
    [anon_sym_AMP] = ACTIONS(3549),
    [anon_sym_PIPE_PIPE] = ACTIONS(3549),
    [anon_sym_or_else] = ACTIONS(3547),
    [anon_sym_AMP_AMP] = ACTIONS(3549),
    [anon_sym_GT] = ACTIONS(3549),
    [anon_sym_GT_EQ] = ACTIONS(3547),
    [anon_sym_LT_EQ] = ACTIONS(3547),
    [anon_sym_LT] = ACTIONS(3549),
    [anon_sym_EQ_EQ] = ACTIONS(3547),
    [anon_sym_BANG_EQ] = ACTIONS(3547),
    [anon_sym_TILDE_EQ] = ACTIONS(3547),
    [anon_sym_AMP_TILDE] = ACTIONS(3549),
    [anon_sym_LT_LT] = ACTIONS(3549),
    [anon_sym_GT_GT] = ACTIONS(3549),
    [anon_sym_STAR] = ACTIONS(3549),
    [anon_sym_SLASH] = ACTIONS(3549),
    [anon_sym_PERCENT] = ACTIONS(3549),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3547),
    [anon_sym_DOT] = ACTIONS(3549),
    [anon_sym_LBRACK] = ACTIONS(3547),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3547),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3547),
    [anon_sym_not_in] = ACTIONS(3547),
    [anon_sym_or_return] = ACTIONS(3547),
    [anon_sym_or_continue] = ACTIONS(3547),
    [anon_sym_or_break] = ACTIONS(3547),
    [anon_sym_CARET] = ACTIONS(3549),
    [sym_uninitialized] = ACTIONS(3547),
    [sym_tag] = ACTIONS(3547),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1475] = {
    [sym_expression] = STATE(6147),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1476] = {
    [sym_expression] = STATE(6122),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1477] = {
    [sym_expression] = STATE(2411),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1478] = {
    [sym_expression] = STATE(2412),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1479] = {
    [sym_expression] = STATE(6397),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1480] = {
    [sym_expression] = STATE(6050),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1481] = {
    [sym_expression] = STATE(2413),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1482] = {
    [sym_expression] = STATE(6175),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1483] = {
    [sym_expression] = STATE(6298),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1484] = {
    [sym_expression] = STATE(6195),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1485] = {
    [sym_expression] = STATE(4055),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1486] = {
    [sym_expression] = STATE(4058),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1487] = {
    [sym_expression] = STATE(4079),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1488] = {
    [sym_expression] = STATE(4090),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1489] = {
    [sym_expression] = STATE(6189),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1490] = {
    [sym_identifier] = ACTIONS(6296),
    [anon_sym_LBRACE] = ACTIONS(4450),
    [anon_sym_COMMA] = ACTIONS(4450),
    [anon_sym_COLON_COLON] = ACTIONS(4450),
    [anon_sym_DASH_GT] = ACTIONS(4450),
    [anon_sym_where] = ACTIONS(4454),
    [anon_sym_EQ] = ACTIONS(4454),
    [anon_sym_COLON] = ACTIONS(4454),
    [anon_sym_PIPE] = ACTIONS(4454),
    [anon_sym_COLON_EQ] = ACTIONS(4450),
    [anon_sym_LPAREN] = ACTIONS(4450),
    [anon_sym_PLUS_EQ] = ACTIONS(4450),
    [anon_sym_DASH_EQ] = ACTIONS(4450),
    [anon_sym_STAR_EQ] = ACTIONS(4450),
    [anon_sym_SLASH_EQ] = ACTIONS(4450),
    [anon_sym_PERCENT_EQ] = ACTIONS(4450),
    [anon_sym_AMP_EQ] = ACTIONS(4450),
    [anon_sym_PIPE_EQ] = ACTIONS(4450),
    [anon_sym_CARET_EQ] = ACTIONS(4450),
    [anon_sym_LT_LT_EQ] = ACTIONS(4450),
    [anon_sym_GT_GT_EQ] = ACTIONS(4450),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4450),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4450),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4450),
    [anon_sym_if] = ACTIONS(4454),
    [anon_sym_SEMI] = ACTIONS(4450),
    [anon_sym_do] = ACTIONS(4454),
    [anon_sym_when] = ACTIONS(4454),
    [anon_sym_in] = ACTIONS(4454),
    [anon_sym_QMARK] = ACTIONS(4450),
    [anon_sym_PLUS] = ACTIONS(4454),
    [anon_sym_DASH] = ACTIONS(4454),
    [anon_sym_TILDE] = ACTIONS(4454),
    [anon_sym_AMP] = ACTIONS(4454),
    [anon_sym_PIPE_PIPE] = ACTIONS(4454),
    [anon_sym_or_else] = ACTIONS(4454),
    [anon_sym_AMP_AMP] = ACTIONS(4454),
    [anon_sym_GT] = ACTIONS(4454),
    [anon_sym_GT_EQ] = ACTIONS(4450),
    [anon_sym_LT_EQ] = ACTIONS(4450),
    [anon_sym_LT] = ACTIONS(4454),
    [anon_sym_EQ_EQ] = ACTIONS(4450),
    [anon_sym_BANG_EQ] = ACTIONS(4450),
    [anon_sym_TILDE_EQ] = ACTIONS(4450),
    [anon_sym_AMP_TILDE] = ACTIONS(4454),
    [anon_sym_LT_LT] = ACTIONS(4454),
    [anon_sym_GT_GT] = ACTIONS(4454),
    [anon_sym_STAR] = ACTIONS(4454),
    [anon_sym_SLASH] = ACTIONS(4454),
    [anon_sym_PERCENT] = ACTIONS(4454),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4450),
    [anon_sym_DOT] = ACTIONS(4454),
    [anon_sym_LBRACK] = ACTIONS(4450),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4450),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4450),
    [anon_sym_not_in] = ACTIONS(4454),
    [anon_sym_or_return] = ACTIONS(4454),
    [anon_sym_or_continue] = ACTIONS(4454),
    [anon_sym_or_break] = ACTIONS(4454),
    [anon_sym_CARET] = ACTIONS(4454),
    [sym_uninitialized] = ACTIONS(4450),
    [sym_tag] = ACTIONS(4450),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1491] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4130),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1492] = {
    [sym_expression] = STATE(6454),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1493] = {
    [sym_expression] = STATE(3474),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1494] = {
    [sym_expression] = STATE(4134),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1495] = {
    [sym_expression] = STATE(3031),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1496] = {
    [sym_expression] = STATE(4117),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1497] = {
    [sym_expression] = STATE(4135),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1498] = {
    [sym_expression] = STATE(4137),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1499] = {
    [sym_expression] = STATE(4145),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1500] = {
    [sym_expression] = STATE(4169),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1501] = {
    [sym_expression] = STATE(4176),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1502] = {
    [sym_expression] = STATE(3369),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1503] = {
    [sym_expression] = STATE(4211),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1504] = {
    [sym_expression] = STATE(4219),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1505] = {
    [sym_expression] = STATE(4220),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1506] = {
    [sym_expression] = STATE(4238),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1507] = {
    [sym_expression] = STATE(4240),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1508] = {
    [sym_expression] = STATE(4243),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1509] = {
    [sym_expression] = STATE(4245),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1510] = {
    [sym_expression] = STATE(4249),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1511] = {
    [sym_expression] = STATE(3685),
    [sym__expression_no_tag] = STATE(2807),
    [sym_unary_expression] = STATE(2807),
    [sym_binary_expression] = STATE(2807),
    [sym_ternary_expression] = STATE(2807),
    [sym_call_expression] = STATE(2807),
    [sym_selector_call_expression] = STATE(2807),
    [sym_member_expression] = STATE(2807),
    [sym_index_expression] = STATE(2807),
    [sym_slice_expression] = STATE(2807),
    [sym_range_expression] = STATE(2807),
    [sym_cast_expression] = STATE(2807),
    [sym_in_expression] = STATE(2807),
    [sym_variadic_expression] = STATE(2807),
    [sym_parenthesized_expression] = STATE(2807),
    [sym_or_return_expression] = STATE(2807),
    [sym_or_continue_expression] = STATE(2807),
    [sym_or_break_expression] = STATE(2807),
    [sym_address] = STATE(2807),
    [sym_map_type] = STATE(2807),
    [sym_matrix_type] = STATE(2807),
    [sym_distinct_type] = STATE(2807),
    [sym_literal] = STATE(2807),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(3294),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1512] = {
    [sym_expression] = STATE(6021),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(6300),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1513] = {
    [sym_expression] = STATE(5901),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6302),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1514] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5927),
    [sym_unary_expression] = STATE(5927),
    [sym_binary_expression] = STATE(5927),
    [sym_ternary_expression] = STATE(5927),
    [sym_call_expression] = STATE(4857),
    [sym_selector_call_expression] = STATE(5927),
    [sym_member_expression] = STATE(5927),
    [sym_index_expression] = STATE(5927),
    [sym_slice_expression] = STATE(5927),
    [sym_range_expression] = STATE(5927),
    [sym_cast_expression] = STATE(5927),
    [sym_in_expression] = STATE(5927),
    [sym_variadic_expression] = STATE(5927),
    [sym_parenthesized_expression] = STATE(5927),
    [sym_or_return_expression] = STATE(5927),
    [sym_or_continue_expression] = STATE(5927),
    [sym_or_break_expression] = STATE(5927),
    [sym_address] = STATE(5927),
    [sym_map_type] = STATE(5927),
    [sym_matrix_type] = STATE(5927),
    [sym_distinct_type] = STATE(5927),
    [sym_literal] = STATE(5927),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6304),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6306),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1515] = {
    [sym_expression] = STATE(6107),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1516] = {
    [sym_expression] = STATE(6081),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1517] = {
    [ts_builtin_sym_end] = ACTIONS(3408),
    [anon_sym_RBRACE] = ACTIONS(3408),
    [anon_sym_COMMA] = ACTIONS(3408),
    [anon_sym_COLON_COLON] = ACTIONS(3408),
    [anon_sym_DASH_GT] = ACTIONS(3408),
    [anon_sym_EQ] = ACTIONS(3410),
    [anon_sym_COLON] = ACTIONS(3410),
    [anon_sym_PIPE] = ACTIONS(3410),
    [anon_sym_COLON_EQ] = ACTIONS(3408),
    [anon_sym_LPAREN] = ACTIONS(3408),
    [anon_sym_PLUS_EQ] = ACTIONS(3408),
    [anon_sym_DASH_EQ] = ACTIONS(3408),
    [anon_sym_STAR_EQ] = ACTIONS(3408),
    [anon_sym_SLASH_EQ] = ACTIONS(3408),
    [anon_sym_PERCENT_EQ] = ACTIONS(3408),
    [anon_sym_AMP_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_CARET_EQ] = ACTIONS(3408),
    [anon_sym_LT_LT_EQ] = ACTIONS(3408),
    [anon_sym_GT_GT_EQ] = ACTIONS(3408),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_if] = ACTIONS(3408),
    [anon_sym_SEMI] = ACTIONS(3408),
    [anon_sym_else] = ACTIONS(3408),
    [anon_sym_when] = ACTIONS(3408),
    [anon_sym_in] = ACTIONS(3408),
    [anon_sym_case] = ACTIONS(3408),
    [anon_sym_QMARK] = ACTIONS(3408),
    [anon_sym_PLUS] = ACTIONS(3410),
    [anon_sym_DASH] = ACTIONS(3410),
    [anon_sym_TILDE] = ACTIONS(3410),
    [anon_sym_AMP] = ACTIONS(3410),
    [anon_sym_PIPE_PIPE] = ACTIONS(3410),
    [anon_sym_or_else] = ACTIONS(3408),
    [anon_sym_AMP_AMP] = ACTIONS(3410),
    [anon_sym_GT] = ACTIONS(3410),
    [anon_sym_GT_EQ] = ACTIONS(3408),
    [anon_sym_LT_EQ] = ACTIONS(3408),
    [anon_sym_LT] = ACTIONS(3410),
    [anon_sym_EQ_EQ] = ACTIONS(3408),
    [anon_sym_BANG_EQ] = ACTIONS(3408),
    [anon_sym_TILDE_EQ] = ACTIONS(3408),
    [anon_sym_AMP_TILDE] = ACTIONS(3410),
    [anon_sym_LT_LT] = ACTIONS(3410),
    [anon_sym_GT_GT] = ACTIONS(3410),
    [anon_sym_STAR] = ACTIONS(3410),
    [anon_sym_SLASH] = ACTIONS(3410),
    [anon_sym_PERCENT] = ACTIONS(3410),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3408),
    [anon_sym_DOT] = ACTIONS(3410),
    [anon_sym_LBRACK] = ACTIONS(3408),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3408),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3408),
    [anon_sym_not_in] = ACTIONS(3408),
    [anon_sym_or_return] = ACTIONS(3408),
    [anon_sym_or_continue] = ACTIONS(3408),
    [anon_sym_or_break] = ACTIONS(3408),
    [anon_sym_CARET] = ACTIONS(3410),
    [anon_sym_DOT2] = ACTIONS(3410),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3408),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1518] = {
    [sym_expression] = STATE(6183),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1519] = {
    [ts_builtin_sym_end] = ACTIONS(4725),
    [anon_sym_LBRACE] = ACTIONS(6308),
    [anon_sym_RBRACE] = ACTIONS(4725),
    [anon_sym_COMMA] = ACTIONS(4725),
    [anon_sym_COLON_COLON] = ACTIONS(4725),
    [anon_sym_DASH_GT] = ACTIONS(4725),
    [anon_sym_EQ] = ACTIONS(4727),
    [anon_sym_COLON] = ACTIONS(4727),
    [anon_sym_PIPE] = ACTIONS(4727),
    [anon_sym_COLON_EQ] = ACTIONS(4725),
    [anon_sym_LPAREN] = ACTIONS(4725),
    [anon_sym_PLUS_EQ] = ACTIONS(4725),
    [anon_sym_DASH_EQ] = ACTIONS(4725),
    [anon_sym_STAR_EQ] = ACTIONS(4725),
    [anon_sym_SLASH_EQ] = ACTIONS(4725),
    [anon_sym_PERCENT_EQ] = ACTIONS(4725),
    [anon_sym_AMP_EQ] = ACTIONS(4725),
    [anon_sym_PIPE_EQ] = ACTIONS(4725),
    [anon_sym_CARET_EQ] = ACTIONS(4725),
    [anon_sym_LT_LT_EQ] = ACTIONS(4725),
    [anon_sym_GT_GT_EQ] = ACTIONS(4725),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4725),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4725),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4725),
    [anon_sym_if] = ACTIONS(4725),
    [anon_sym_SEMI] = ACTIONS(4725),
    [anon_sym_else] = ACTIONS(4725),
    [anon_sym_when] = ACTIONS(4725),
    [anon_sym_in] = ACTIONS(4725),
    [anon_sym_case] = ACTIONS(4725),
    [anon_sym_QMARK] = ACTIONS(4725),
    [anon_sym_PLUS] = ACTIONS(4727),
    [anon_sym_DASH] = ACTIONS(4727),
    [anon_sym_TILDE] = ACTIONS(4727),
    [anon_sym_AMP] = ACTIONS(4727),
    [anon_sym_PIPE_PIPE] = ACTIONS(4727),
    [anon_sym_or_else] = ACTIONS(4725),
    [anon_sym_AMP_AMP] = ACTIONS(4727),
    [anon_sym_GT] = ACTIONS(4727),
    [anon_sym_GT_EQ] = ACTIONS(4725),
    [anon_sym_LT_EQ] = ACTIONS(4725),
    [anon_sym_LT] = ACTIONS(4727),
    [anon_sym_EQ_EQ] = ACTIONS(4725),
    [anon_sym_BANG_EQ] = ACTIONS(4725),
    [anon_sym_TILDE_EQ] = ACTIONS(4725),
    [anon_sym_AMP_TILDE] = ACTIONS(4727),
    [anon_sym_LT_LT] = ACTIONS(4727),
    [anon_sym_GT_GT] = ACTIONS(4727),
    [anon_sym_STAR] = ACTIONS(4727),
    [anon_sym_SLASH] = ACTIONS(4727),
    [anon_sym_PERCENT] = ACTIONS(4727),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4725),
    [anon_sym_DOT] = ACTIONS(4727),
    [anon_sym_LBRACK] = ACTIONS(4725),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4725),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4725),
    [anon_sym_not_in] = ACTIONS(4725),
    [anon_sym_or_return] = ACTIONS(4725),
    [anon_sym_or_continue] = ACTIONS(4725),
    [anon_sym_or_break] = ACTIONS(4725),
    [anon_sym_CARET] = ACTIONS(4727),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4725),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1520] = {
    [ts_builtin_sym_end] = ACTIONS(4683),
    [anon_sym_LBRACE] = ACTIONS(4713),
    [anon_sym_RBRACE] = ACTIONS(4683),
    [anon_sym_COMMA] = ACTIONS(4713),
    [anon_sym_DASH_GT] = ACTIONS(4713),
    [anon_sym_EQ] = ACTIONS(4715),
    [anon_sym_COLON] = ACTIONS(4715),
    [anon_sym_PIPE] = ACTIONS(4715),
    [anon_sym_COLON_EQ] = ACTIONS(4713),
    [anon_sym_LPAREN] = ACTIONS(4713),
    [anon_sym_PLUS_EQ] = ACTIONS(4713),
    [anon_sym_DASH_EQ] = ACTIONS(4713),
    [anon_sym_STAR_EQ] = ACTIONS(4713),
    [anon_sym_SLASH_EQ] = ACTIONS(4713),
    [anon_sym_PERCENT_EQ] = ACTIONS(4713),
    [anon_sym_AMP_EQ] = ACTIONS(4713),
    [anon_sym_PIPE_EQ] = ACTIONS(4713),
    [anon_sym_CARET_EQ] = ACTIONS(4713),
    [anon_sym_LT_LT_EQ] = ACTIONS(4713),
    [anon_sym_GT_GT_EQ] = ACTIONS(4713),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4713),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4713),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4713),
    [anon_sym_if] = ACTIONS(4713),
    [anon_sym_SEMI] = ACTIONS(4683),
    [anon_sym_do] = ACTIONS(4713),
    [anon_sym_else] = ACTIONS(4683),
    [anon_sym_when] = ACTIONS(4713),
    [anon_sym_in] = ACTIONS(4713),
    [anon_sym_case] = ACTIONS(4683),
    [anon_sym_QMARK] = ACTIONS(4713),
    [anon_sym_PLUS] = ACTIONS(4715),
    [anon_sym_DASH] = ACTIONS(4715),
    [anon_sym_TILDE] = ACTIONS(4715),
    [anon_sym_AMP] = ACTIONS(4715),
    [anon_sym_PIPE_PIPE] = ACTIONS(4715),
    [anon_sym_or_else] = ACTIONS(4713),
    [anon_sym_AMP_AMP] = ACTIONS(4715),
    [anon_sym_GT] = ACTIONS(4715),
    [anon_sym_GT_EQ] = ACTIONS(4713),
    [anon_sym_LT_EQ] = ACTIONS(4713),
    [anon_sym_LT] = ACTIONS(4715),
    [anon_sym_EQ_EQ] = ACTIONS(4713),
    [anon_sym_BANG_EQ] = ACTIONS(4713),
    [anon_sym_TILDE_EQ] = ACTIONS(4713),
    [anon_sym_AMP_TILDE] = ACTIONS(4715),
    [anon_sym_LT_LT] = ACTIONS(4715),
    [anon_sym_GT_GT] = ACTIONS(4715),
    [anon_sym_STAR] = ACTIONS(4715),
    [anon_sym_SLASH] = ACTIONS(4715),
    [anon_sym_PERCENT] = ACTIONS(4715),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4713),
    [anon_sym_DOT] = ACTIONS(4715),
    [anon_sym_LBRACK] = ACTIONS(4713),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4713),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4713),
    [anon_sym_not_in] = ACTIONS(4713),
    [anon_sym_or_return] = ACTIONS(4713),
    [anon_sym_or_continue] = ACTIONS(4713),
    [anon_sym_or_break] = ACTIONS(4713),
    [anon_sym_CARET] = ACTIONS(4715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4683),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1521] = {
    [sym_expression] = STATE(6043),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1522] = {
    [sym_expression] = STATE(4144),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1523] = {
    [sym_expression] = STATE(5992),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1524] = {
    [sym_block] = STATE(2228),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3451),
    [anon_sym_where] = ACTIONS(3451),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_do] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(5982),
    [sym_tag] = ACTIONS(3451),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1525] = {
    [sym_block] = STATE(2228),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3451),
    [anon_sym_where] = ACTIONS(3451),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_do] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_uninitialized] = ACTIONS(5982),
    [sym_tag] = ACTIONS(5984),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1526] = {
    [sym_block] = STATE(2277),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3425),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_do] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(5990),
    [sym_tag] = ACTIONS(3425),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1527] = {
    [sym_block] = STATE(2277),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3425),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_do] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_uninitialized] = ACTIONS(5990),
    [sym_tag] = ACTIONS(6310),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1528] = {
    [sym_block] = STATE(2293),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3368),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_do] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(5994),
    [sym_tag] = ACTIONS(3368),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1529] = {
    [sym_block] = STATE(2293),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_where] = ACTIONS(3368),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_do] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_uninitialized] = ACTIONS(5994),
    [sym_tag] = ACTIONS(5998),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1530] = {
    [ts_builtin_sym_end] = ACTIONS(3451),
    [anon_sym_LBRACE] = ACTIONS(3451),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_COMMA] = ACTIONS(3451),
    [anon_sym_COLON_COLON] = ACTIONS(3451),
    [anon_sym_DASH_GT] = ACTIONS(3451),
    [anon_sym_EQ] = ACTIONS(3455),
    [anon_sym_COLON] = ACTIONS(3455),
    [anon_sym_PIPE] = ACTIONS(3455),
    [anon_sym_COLON_EQ] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_PLUS_EQ] = ACTIONS(3451),
    [anon_sym_DASH_EQ] = ACTIONS(3451),
    [anon_sym_STAR_EQ] = ACTIONS(3451),
    [anon_sym_SLASH_EQ] = ACTIONS(3451),
    [anon_sym_PERCENT_EQ] = ACTIONS(3451),
    [anon_sym_AMP_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_CARET_EQ] = ACTIONS(3451),
    [anon_sym_LT_LT_EQ] = ACTIONS(3451),
    [anon_sym_GT_GT_EQ] = ACTIONS(3451),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_if] = ACTIONS(3451),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_else] = ACTIONS(3451),
    [anon_sym_when] = ACTIONS(3451),
    [anon_sym_in] = ACTIONS(3451),
    [anon_sym_case] = ACTIONS(3451),
    [anon_sym_QMARK] = ACTIONS(3451),
    [anon_sym_PLUS] = ACTIONS(3455),
    [anon_sym_DASH] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_PIPE_PIPE] = ACTIONS(3455),
    [anon_sym_or_else] = ACTIONS(3451),
    [anon_sym_AMP_AMP] = ACTIONS(3455),
    [anon_sym_GT] = ACTIONS(3455),
    [anon_sym_GT_EQ] = ACTIONS(3451),
    [anon_sym_LT_EQ] = ACTIONS(3451),
    [anon_sym_LT] = ACTIONS(3455),
    [anon_sym_EQ_EQ] = ACTIONS(3451),
    [anon_sym_BANG_EQ] = ACTIONS(3451),
    [anon_sym_TILDE_EQ] = ACTIONS(3451),
    [anon_sym_AMP_TILDE] = ACTIONS(3455),
    [anon_sym_LT_LT] = ACTIONS(3455),
    [anon_sym_GT_GT] = ACTIONS(3455),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_SLASH] = ACTIONS(3455),
    [anon_sym_PERCENT] = ACTIONS(3455),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3451),
    [anon_sym_DOT] = ACTIONS(3455),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3451),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3451),
    [anon_sym_not_in] = ACTIONS(3451),
    [anon_sym_or_return] = ACTIONS(3451),
    [anon_sym_or_continue] = ACTIONS(3451),
    [anon_sym_or_break] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3455),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3451),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1531] = {
    [sym_block] = STATE(2370),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3384),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_do] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(6000),
    [sym_tag] = ACTIONS(6004),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1532] = {
    [sym_block] = STATE(2370),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_where] = ACTIONS(3384),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_do] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_uninitialized] = ACTIONS(6000),
    [sym_tag] = ACTIONS(3384),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1533] = {
    [sym_expression] = STATE(2507),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1534] = {
    [sym_block] = STATE(2530),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_where] = ACTIONS(3400),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_do] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(6006),
    [sym_tag] = ACTIONS(6008),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1535] = {
    [sym_block] = STATE(2530),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_where] = ACTIONS(3400),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_do] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_uninitialized] = ACTIONS(6006),
    [sym_tag] = ACTIONS(3400),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1536] = {
    [sym_block] = STATE(2401),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(4577),
    [anon_sym_COLON_COLON] = ACTIONS(4577),
    [anon_sym_DASH_GT] = ACTIONS(4577),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_EQ] = ACTIONS(4579),
    [anon_sym_COLON] = ACTIONS(4579),
    [anon_sym_PIPE] = ACTIONS(4579),
    [anon_sym_COLON_EQ] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4577),
    [anon_sym_PLUS_EQ] = ACTIONS(4577),
    [anon_sym_DASH_EQ] = ACTIONS(4577),
    [anon_sym_STAR_EQ] = ACTIONS(4577),
    [anon_sym_SLASH_EQ] = ACTIONS(4577),
    [anon_sym_PERCENT_EQ] = ACTIONS(4577),
    [anon_sym_AMP_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_CARET_EQ] = ACTIONS(4577),
    [anon_sym_LT_LT_EQ] = ACTIONS(4577),
    [anon_sym_GT_GT_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4577),
    [anon_sym_do] = ACTIONS(4577),
    [anon_sym_when] = ACTIONS(4577),
    [anon_sym_in] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [anon_sym_TILDE] = ACTIONS(4579),
    [anon_sym_AMP] = ACTIONS(4579),
    [anon_sym_PIPE_PIPE] = ACTIONS(4579),
    [anon_sym_or_else] = ACTIONS(4577),
    [anon_sym_AMP_AMP] = ACTIONS(4579),
    [anon_sym_GT] = ACTIONS(4579),
    [anon_sym_GT_EQ] = ACTIONS(4577),
    [anon_sym_LT_EQ] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4579),
    [anon_sym_EQ_EQ] = ACTIONS(4577),
    [anon_sym_BANG_EQ] = ACTIONS(4577),
    [anon_sym_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE] = ACTIONS(4579),
    [anon_sym_LT_LT] = ACTIONS(4579),
    [anon_sym_GT_GT] = ACTIONS(4579),
    [anon_sym_STAR] = ACTIONS(4579),
    [anon_sym_SLASH] = ACTIONS(4579),
    [anon_sym_PERCENT] = ACTIONS(4579),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4577),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4577),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4577),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4577),
    [anon_sym_not_in] = ACTIONS(4577),
    [anon_sym_or_return] = ACTIONS(4577),
    [anon_sym_or_continue] = ACTIONS(4577),
    [anon_sym_or_break] = ACTIONS(4577),
    [anon_sym_CARET] = ACTIONS(4579),
    [sym_uninitialized] = ACTIONS(6312),
    [sym_tag] = ACTIONS(4577),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1537] = {
    [sym_block] = STATE(2401),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(4577),
    [anon_sym_COLON_COLON] = ACTIONS(4577),
    [anon_sym_DASH_GT] = ACTIONS(4577),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_EQ] = ACTIONS(4579),
    [anon_sym_COLON] = ACTIONS(4579),
    [anon_sym_PIPE] = ACTIONS(4579),
    [anon_sym_COLON_EQ] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4577),
    [anon_sym_PLUS_EQ] = ACTIONS(4577),
    [anon_sym_DASH_EQ] = ACTIONS(4577),
    [anon_sym_STAR_EQ] = ACTIONS(4577),
    [anon_sym_SLASH_EQ] = ACTIONS(4577),
    [anon_sym_PERCENT_EQ] = ACTIONS(4577),
    [anon_sym_AMP_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_CARET_EQ] = ACTIONS(4577),
    [anon_sym_LT_LT_EQ] = ACTIONS(4577),
    [anon_sym_GT_GT_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4577),
    [anon_sym_do] = ACTIONS(4577),
    [anon_sym_when] = ACTIONS(4577),
    [anon_sym_in] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [anon_sym_TILDE] = ACTIONS(4579),
    [anon_sym_AMP] = ACTIONS(4579),
    [anon_sym_PIPE_PIPE] = ACTIONS(4579),
    [anon_sym_or_else] = ACTIONS(4577),
    [anon_sym_AMP_AMP] = ACTIONS(4579),
    [anon_sym_GT] = ACTIONS(4579),
    [anon_sym_GT_EQ] = ACTIONS(4577),
    [anon_sym_LT_EQ] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4579),
    [anon_sym_EQ_EQ] = ACTIONS(4577),
    [anon_sym_BANG_EQ] = ACTIONS(4577),
    [anon_sym_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE] = ACTIONS(4579),
    [anon_sym_LT_LT] = ACTIONS(4579),
    [anon_sym_GT_GT] = ACTIONS(4579),
    [anon_sym_STAR] = ACTIONS(4579),
    [anon_sym_SLASH] = ACTIONS(4579),
    [anon_sym_PERCENT] = ACTIONS(4579),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4577),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4577),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4577),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4577),
    [anon_sym_not_in] = ACTIONS(4577),
    [anon_sym_or_return] = ACTIONS(4577),
    [anon_sym_or_continue] = ACTIONS(4577),
    [anon_sym_or_break] = ACTIONS(4577),
    [anon_sym_CARET] = ACTIONS(4579),
    [sym_uninitialized] = ACTIONS(6312),
    [sym_tag] = ACTIONS(6314),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1538] = {
    [sym_block] = STATE(2407),
    [anon_sym_LBRACE] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_COLON_COLON] = ACTIONS(4585),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_where] = ACTIONS(4585),
    [anon_sym_EQ] = ACTIONS(4587),
    [anon_sym_COLON] = ACTIONS(4587),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_COLON_EQ] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_PLUS_EQ] = ACTIONS(4585),
    [anon_sym_DASH_EQ] = ACTIONS(4585),
    [anon_sym_STAR_EQ] = ACTIONS(4585),
    [anon_sym_SLASH_EQ] = ACTIONS(4585),
    [anon_sym_PERCENT_EQ] = ACTIONS(4585),
    [anon_sym_AMP_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_CARET_EQ] = ACTIONS(4585),
    [anon_sym_LT_LT_EQ] = ACTIONS(4585),
    [anon_sym_GT_GT_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_if] = ACTIONS(4585),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_do] = ACTIONS(4585),
    [anon_sym_when] = ACTIONS(4585),
    [anon_sym_in] = ACTIONS(4585),
    [anon_sym_QMARK] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_TILDE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_PIPE_PIPE] = ACTIONS(4587),
    [anon_sym_or_else] = ACTIONS(4585),
    [anon_sym_AMP_AMP] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4587),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4587),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4587),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4585),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4585),
    [anon_sym_not_in] = ACTIONS(4585),
    [anon_sym_or_return] = ACTIONS(4585),
    [anon_sym_or_continue] = ACTIONS(4585),
    [anon_sym_or_break] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4587),
    [sym_uninitialized] = ACTIONS(6316),
    [sym_tag] = ACTIONS(4585),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1539] = {
    [sym_expression] = STATE(4093),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1540] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5907),
    [sym_unary_expression] = STATE(5907),
    [sym_binary_expression] = STATE(5907),
    [sym_ternary_expression] = STATE(5907),
    [sym_call_expression] = STATE(2522),
    [sym_selector_call_expression] = STATE(5907),
    [sym_member_expression] = STATE(5907),
    [sym_index_expression] = STATE(5907),
    [sym_slice_expression] = STATE(5907),
    [sym_range_expression] = STATE(5907),
    [sym_cast_expression] = STATE(5907),
    [sym_in_expression] = STATE(5907),
    [sym_variadic_expression] = STATE(5907),
    [sym_parenthesized_expression] = STATE(5907),
    [sym_or_return_expression] = STATE(5907),
    [sym_or_continue_expression] = STATE(5907),
    [sym_or_break_expression] = STATE(5907),
    [sym_address] = STATE(5907),
    [sym_map_type] = STATE(5907),
    [sym_matrix_type] = STATE(5907),
    [sym_distinct_type] = STATE(5907),
    [sym_literal] = STATE(5907),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6318),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6320),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1541] = {
    [sym_expression] = STATE(4106),
    [sym__expression_no_tag] = STATE(4129),
    [sym_unary_expression] = STATE(4129),
    [sym_binary_expression] = STATE(4129),
    [sym_ternary_expression] = STATE(4129),
    [sym_call_expression] = STATE(4129),
    [sym_selector_call_expression] = STATE(4129),
    [sym_member_expression] = STATE(4129),
    [sym_index_expression] = STATE(4129),
    [sym_slice_expression] = STATE(4129),
    [sym_range_expression] = STATE(4129),
    [sym_cast_expression] = STATE(4129),
    [sym_in_expression] = STATE(4129),
    [sym_variadic_expression] = STATE(4129),
    [sym_parenthesized_expression] = STATE(4129),
    [sym_or_return_expression] = STATE(4129),
    [sym_or_continue_expression] = STATE(4129),
    [sym_or_break_expression] = STATE(4129),
    [sym_address] = STATE(4129),
    [sym_map_type] = STATE(4129),
    [sym_matrix_type] = STATE(4129),
    [sym_distinct_type] = STATE(4129),
    [sym_literal] = STATE(4129),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(663),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1542] = {
    [sym_expression] = STATE(3101),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1543] = {
    [sym_expression] = STATE(6200),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1544] = {
    [sym_expression] = STATE(5983),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1545] = {
    [sym_expression] = STATE(4127),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1546] = {
    [sym_expression] = STATE(6590),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1547] = {
    [sym_expression] = STATE(3234),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1548] = {
    [sym_expression] = STATE(2225),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1549] = {
    [sym_expression] = STATE(2226),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1550] = {
    [sym_expression] = STATE(5951),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1551] = {
    [ts_builtin_sym_end] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3425),
    [anon_sym_RBRACE] = ACTIONS(3425),
    [anon_sym_COMMA] = ACTIONS(3425),
    [anon_sym_COLON_COLON] = ACTIONS(3425),
    [anon_sym_DASH_GT] = ACTIONS(3425),
    [anon_sym_EQ] = ACTIONS(3427),
    [anon_sym_COLON] = ACTIONS(3427),
    [anon_sym_PIPE] = ACTIONS(3427),
    [anon_sym_COLON_EQ] = ACTIONS(3425),
    [anon_sym_LPAREN] = ACTIONS(3425),
    [anon_sym_PLUS_EQ] = ACTIONS(3425),
    [anon_sym_DASH_EQ] = ACTIONS(3425),
    [anon_sym_STAR_EQ] = ACTIONS(3425),
    [anon_sym_SLASH_EQ] = ACTIONS(3425),
    [anon_sym_PERCENT_EQ] = ACTIONS(3425),
    [anon_sym_AMP_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_CARET_EQ] = ACTIONS(3425),
    [anon_sym_LT_LT_EQ] = ACTIONS(3425),
    [anon_sym_GT_GT_EQ] = ACTIONS(3425),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3425),
    [anon_sym_else] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_in] = ACTIONS(3425),
    [anon_sym_case] = ACTIONS(3425),
    [anon_sym_QMARK] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3427),
    [anon_sym_DASH] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_PIPE_PIPE] = ACTIONS(3427),
    [anon_sym_or_else] = ACTIONS(3425),
    [anon_sym_AMP_AMP] = ACTIONS(3427),
    [anon_sym_GT] = ACTIONS(3427),
    [anon_sym_GT_EQ] = ACTIONS(3425),
    [anon_sym_LT_EQ] = ACTIONS(3425),
    [anon_sym_LT] = ACTIONS(3427),
    [anon_sym_EQ_EQ] = ACTIONS(3425),
    [anon_sym_BANG_EQ] = ACTIONS(3425),
    [anon_sym_TILDE_EQ] = ACTIONS(3425),
    [anon_sym_AMP_TILDE] = ACTIONS(3427),
    [anon_sym_LT_LT] = ACTIONS(3427),
    [anon_sym_GT_GT] = ACTIONS(3427),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_SLASH] = ACTIONS(3427),
    [anon_sym_PERCENT] = ACTIONS(3427),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3425),
    [anon_sym_DOT] = ACTIONS(3427),
    [anon_sym_LBRACK] = ACTIONS(3425),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3425),
    [anon_sym_not_in] = ACTIONS(3425),
    [anon_sym_or_return] = ACTIONS(3425),
    [anon_sym_or_continue] = ACTIONS(3425),
    [anon_sym_or_break] = ACTIONS(3425),
    [anon_sym_CARET] = ACTIONS(3427),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3425),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1552] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5914),
    [sym_unary_expression] = STATE(5914),
    [sym_binary_expression] = STATE(5914),
    [sym_ternary_expression] = STATE(5914),
    [sym_call_expression] = STATE(2727),
    [sym_selector_call_expression] = STATE(5914),
    [sym_member_expression] = STATE(5914),
    [sym_index_expression] = STATE(5914),
    [sym_slice_expression] = STATE(5914),
    [sym_range_expression] = STATE(5914),
    [sym_cast_expression] = STATE(5914),
    [sym_in_expression] = STATE(5914),
    [sym_variadic_expression] = STATE(5914),
    [sym_parenthesized_expression] = STATE(5914),
    [sym_or_return_expression] = STATE(5914),
    [sym_or_continue_expression] = STATE(5914),
    [sym_or_break_expression] = STATE(5914),
    [sym_address] = STATE(5914),
    [sym_map_type] = STATE(5914),
    [sym_matrix_type] = STATE(5914),
    [sym_distinct_type] = STATE(5914),
    [sym_literal] = STATE(5914),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6324),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6326),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1553] = {
    [sym_expression] = STATE(4173),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1554] = {
    [sym_expression] = STATE(4847),
    [sym__expression_no_tag] = STATE(4737),
    [sym_unary_expression] = STATE(4737),
    [sym_binary_expression] = STATE(4737),
    [sym_ternary_expression] = STATE(4737),
    [sym_call_expression] = STATE(4737),
    [sym_selector_call_expression] = STATE(4737),
    [sym_member_expression] = STATE(4737),
    [sym_index_expression] = STATE(4737),
    [sym_slice_expression] = STATE(4737),
    [sym_range_expression] = STATE(4737),
    [sym_cast_expression] = STATE(4737),
    [sym_in_expression] = STATE(4737),
    [sym_variadic_expression] = STATE(4737),
    [sym_parenthesized_expression] = STATE(4737),
    [sym_or_return_expression] = STATE(4737),
    [sym_or_continue_expression] = STATE(4737),
    [sym_or_break_expression] = STATE(4737),
    [sym_address] = STATE(4737),
    [sym_map_type] = STATE(4737),
    [sym_matrix_type] = STATE(4737),
    [sym_distinct_type] = STATE(4737),
    [sym_literal] = STATE(4737),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(6328),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1555] = {
    [sym_expression] = STATE(4132),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1556] = {
    [sym_expression] = STATE(4412),
    [sym__expression_no_tag] = STATE(4737),
    [sym_unary_expression] = STATE(4737),
    [sym_binary_expression] = STATE(4737),
    [sym_ternary_expression] = STATE(4737),
    [sym_call_expression] = STATE(4737),
    [sym_selector_call_expression] = STATE(4737),
    [sym_member_expression] = STATE(4737),
    [sym_index_expression] = STATE(4737),
    [sym_slice_expression] = STATE(4737),
    [sym_range_expression] = STATE(4737),
    [sym_cast_expression] = STATE(4737),
    [sym_in_expression] = STATE(4737),
    [sym_variadic_expression] = STATE(4737),
    [sym_parenthesized_expression] = STATE(4737),
    [sym_or_return_expression] = STATE(4737),
    [sym_or_continue_expression] = STATE(4737),
    [sym_or_break_expression] = STATE(4737),
    [sym_address] = STATE(4737),
    [sym_map_type] = STATE(4737),
    [sym_matrix_type] = STATE(4737),
    [sym_distinct_type] = STATE(4737),
    [sym_literal] = STATE(4737),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(6328),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1557] = {
    [sym_expression] = STATE(6032),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1558] = {
    [ts_builtin_sym_end] = ACTIONS(3368),
    [anon_sym_LBRACE] = ACTIONS(3368),
    [anon_sym_RBRACE] = ACTIONS(3368),
    [anon_sym_COMMA] = ACTIONS(3368),
    [anon_sym_COLON_COLON] = ACTIONS(3368),
    [anon_sym_DASH_GT] = ACTIONS(3368),
    [anon_sym_EQ] = ACTIONS(3374),
    [anon_sym_COLON] = ACTIONS(3374),
    [anon_sym_PIPE] = ACTIONS(3374),
    [anon_sym_COLON_EQ] = ACTIONS(3368),
    [anon_sym_LPAREN] = ACTIONS(3368),
    [anon_sym_PLUS_EQ] = ACTIONS(3368),
    [anon_sym_DASH_EQ] = ACTIONS(3368),
    [anon_sym_STAR_EQ] = ACTIONS(3368),
    [anon_sym_SLASH_EQ] = ACTIONS(3368),
    [anon_sym_PERCENT_EQ] = ACTIONS(3368),
    [anon_sym_AMP_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_CARET_EQ] = ACTIONS(3368),
    [anon_sym_LT_LT_EQ] = ACTIONS(3368),
    [anon_sym_GT_GT_EQ] = ACTIONS(3368),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_if] = ACTIONS(3368),
    [anon_sym_SEMI] = ACTIONS(3368),
    [anon_sym_else] = ACTIONS(3368),
    [anon_sym_when] = ACTIONS(3368),
    [anon_sym_in] = ACTIONS(3368),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_QMARK] = ACTIONS(3368),
    [anon_sym_PLUS] = ACTIONS(3374),
    [anon_sym_DASH] = ACTIONS(3374),
    [anon_sym_TILDE] = ACTIONS(3374),
    [anon_sym_AMP] = ACTIONS(3374),
    [anon_sym_PIPE_PIPE] = ACTIONS(3374),
    [anon_sym_or_else] = ACTIONS(3368),
    [anon_sym_AMP_AMP] = ACTIONS(3374),
    [anon_sym_GT] = ACTIONS(3374),
    [anon_sym_GT_EQ] = ACTIONS(3368),
    [anon_sym_LT_EQ] = ACTIONS(3368),
    [anon_sym_LT] = ACTIONS(3374),
    [anon_sym_EQ_EQ] = ACTIONS(3368),
    [anon_sym_BANG_EQ] = ACTIONS(3368),
    [anon_sym_TILDE_EQ] = ACTIONS(3368),
    [anon_sym_AMP_TILDE] = ACTIONS(3374),
    [anon_sym_LT_LT] = ACTIONS(3374),
    [anon_sym_GT_GT] = ACTIONS(3374),
    [anon_sym_STAR] = ACTIONS(3374),
    [anon_sym_SLASH] = ACTIONS(3374),
    [anon_sym_PERCENT] = ACTIONS(3374),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3368),
    [anon_sym_DOT] = ACTIONS(3374),
    [anon_sym_LBRACK] = ACTIONS(3368),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3368),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3368),
    [anon_sym_not_in] = ACTIONS(3368),
    [anon_sym_or_return] = ACTIONS(3368),
    [anon_sym_or_continue] = ACTIONS(3368),
    [anon_sym_or_break] = ACTIONS(3368),
    [anon_sym_CARET] = ACTIONS(3374),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3368),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1559] = {
    [sym_expression] = STATE(5925),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(4785),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1560] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5957),
    [sym_unary_expression] = STATE(5957),
    [sym_binary_expression] = STATE(5957),
    [sym_ternary_expression] = STATE(5957),
    [sym_call_expression] = STATE(4585),
    [sym_selector_call_expression] = STATE(5957),
    [sym_member_expression] = STATE(5957),
    [sym_index_expression] = STATE(5957),
    [sym_slice_expression] = STATE(5957),
    [sym_range_expression] = STATE(5957),
    [sym_cast_expression] = STATE(5957),
    [sym_in_expression] = STATE(5957),
    [sym_variadic_expression] = STATE(5957),
    [sym_parenthesized_expression] = STATE(5957),
    [sym_or_return_expression] = STATE(5957),
    [sym_or_continue_expression] = STATE(5957),
    [sym_or_break_expression] = STATE(5957),
    [sym_address] = STATE(5957),
    [sym_map_type] = STATE(5957),
    [sym_matrix_type] = STATE(5957),
    [sym_distinct_type] = STATE(5957),
    [sym_literal] = STATE(5957),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6330),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6332),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1561] = {
    [sym_expression] = STATE(3895),
    [sym__expression_no_tag] = STATE(3668),
    [sym_unary_expression] = STATE(3668),
    [sym_binary_expression] = STATE(3668),
    [sym_ternary_expression] = STATE(3668),
    [sym_call_expression] = STATE(3668),
    [sym_selector_call_expression] = STATE(3668),
    [sym_member_expression] = STATE(3668),
    [sym_index_expression] = STATE(3668),
    [sym_slice_expression] = STATE(3668),
    [sym_range_expression] = STATE(3668),
    [sym_cast_expression] = STATE(3668),
    [sym_in_expression] = STATE(3668),
    [sym_variadic_expression] = STATE(3668),
    [sym_parenthesized_expression] = STATE(3668),
    [sym_or_return_expression] = STATE(3668),
    [sym_or_continue_expression] = STATE(3668),
    [sym_or_break_expression] = STATE(3668),
    [sym_address] = STATE(3668),
    [sym_map_type] = STATE(3668),
    [sym_matrix_type] = STATE(3668),
    [sym_distinct_type] = STATE(3668),
    [sym_literal] = STATE(3668),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(6334),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1562] = {
    [sym_expression] = STATE(4083),
    [sym__expression_no_tag] = STATE(3668),
    [sym_unary_expression] = STATE(3668),
    [sym_binary_expression] = STATE(3668),
    [sym_ternary_expression] = STATE(3668),
    [sym_call_expression] = STATE(3668),
    [sym_selector_call_expression] = STATE(3668),
    [sym_member_expression] = STATE(3668),
    [sym_index_expression] = STATE(3668),
    [sym_slice_expression] = STATE(3668),
    [sym_range_expression] = STATE(3668),
    [sym_cast_expression] = STATE(3668),
    [sym_in_expression] = STATE(3668),
    [sym_variadic_expression] = STATE(3668),
    [sym_parenthesized_expression] = STATE(3668),
    [sym_or_return_expression] = STATE(3668),
    [sym_or_continue_expression] = STATE(3668),
    [sym_or_break_expression] = STATE(3668),
    [sym_address] = STATE(3668),
    [sym_map_type] = STATE(3668),
    [sym_matrix_type] = STATE(3668),
    [sym_distinct_type] = STATE(3668),
    [sym_literal] = STATE(3668),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(6334),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1563] = {
    [sym_expression] = STATE(2780),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1564] = {
    [sym_expression] = STATE(2708),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1565] = {
    [sym_expression] = STATE(2801),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1566] = {
    [sym_expression] = STATE(2709),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1567] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5903),
    [sym_unary_expression] = STATE(5903),
    [sym_binary_expression] = STATE(5903),
    [sym_ternary_expression] = STATE(5903),
    [sym_call_expression] = STATE(2884),
    [sym_selector_call_expression] = STATE(5903),
    [sym_member_expression] = STATE(5903),
    [sym_index_expression] = STATE(5903),
    [sym_slice_expression] = STATE(5903),
    [sym_range_expression] = STATE(5903),
    [sym_cast_expression] = STATE(5903),
    [sym_in_expression] = STATE(5903),
    [sym_variadic_expression] = STATE(5903),
    [sym_parenthesized_expression] = STATE(5903),
    [sym_or_return_expression] = STATE(5903),
    [sym_or_continue_expression] = STATE(5903),
    [sym_or_break_expression] = STATE(5903),
    [sym_address] = STATE(5903),
    [sym_map_type] = STATE(5903),
    [sym_matrix_type] = STATE(5903),
    [sym_distinct_type] = STATE(5903),
    [sym_literal] = STATE(5903),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6336),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6338),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1568] = {
    [ts_builtin_sym_end] = ACTIONS(3384),
    [anon_sym_LBRACE] = ACTIONS(3384),
    [anon_sym_RBRACE] = ACTIONS(3384),
    [anon_sym_COMMA] = ACTIONS(3384),
    [anon_sym_COLON_COLON] = ACTIONS(3384),
    [anon_sym_DASH_GT] = ACTIONS(3384),
    [anon_sym_EQ] = ACTIONS(3388),
    [anon_sym_COLON] = ACTIONS(3388),
    [anon_sym_PIPE] = ACTIONS(3388),
    [anon_sym_COLON_EQ] = ACTIONS(3384),
    [anon_sym_LPAREN] = ACTIONS(3384),
    [anon_sym_PLUS_EQ] = ACTIONS(3384),
    [anon_sym_DASH_EQ] = ACTIONS(3384),
    [anon_sym_STAR_EQ] = ACTIONS(3384),
    [anon_sym_SLASH_EQ] = ACTIONS(3384),
    [anon_sym_PERCENT_EQ] = ACTIONS(3384),
    [anon_sym_AMP_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_CARET_EQ] = ACTIONS(3384),
    [anon_sym_LT_LT_EQ] = ACTIONS(3384),
    [anon_sym_GT_GT_EQ] = ACTIONS(3384),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_if] = ACTIONS(3384),
    [anon_sym_SEMI] = ACTIONS(3384),
    [anon_sym_else] = ACTIONS(3384),
    [anon_sym_when] = ACTIONS(3384),
    [anon_sym_in] = ACTIONS(3384),
    [anon_sym_case] = ACTIONS(3384),
    [anon_sym_QMARK] = ACTIONS(3384),
    [anon_sym_PLUS] = ACTIONS(3388),
    [anon_sym_DASH] = ACTIONS(3388),
    [anon_sym_TILDE] = ACTIONS(3388),
    [anon_sym_AMP] = ACTIONS(3388),
    [anon_sym_PIPE_PIPE] = ACTIONS(3388),
    [anon_sym_or_else] = ACTIONS(3384),
    [anon_sym_AMP_AMP] = ACTIONS(3388),
    [anon_sym_GT] = ACTIONS(3388),
    [anon_sym_GT_EQ] = ACTIONS(3384),
    [anon_sym_LT_EQ] = ACTIONS(3384),
    [anon_sym_LT] = ACTIONS(3388),
    [anon_sym_EQ_EQ] = ACTIONS(3384),
    [anon_sym_BANG_EQ] = ACTIONS(3384),
    [anon_sym_TILDE_EQ] = ACTIONS(3384),
    [anon_sym_AMP_TILDE] = ACTIONS(3388),
    [anon_sym_LT_LT] = ACTIONS(3388),
    [anon_sym_GT_GT] = ACTIONS(3388),
    [anon_sym_STAR] = ACTIONS(3388),
    [anon_sym_SLASH] = ACTIONS(3388),
    [anon_sym_PERCENT] = ACTIONS(3388),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3384),
    [anon_sym_DOT] = ACTIONS(3388),
    [anon_sym_LBRACK] = ACTIONS(3384),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3384),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3384),
    [anon_sym_not_in] = ACTIONS(3384),
    [anon_sym_or_return] = ACTIONS(3384),
    [anon_sym_or_continue] = ACTIONS(3384),
    [anon_sym_or_break] = ACTIONS(3384),
    [anon_sym_CARET] = ACTIONS(3388),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3384),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1569] = {
    [sym_expression] = STATE(2781),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1570] = {
    [sym_expression] = STATE(3818),
    [sym__expression_no_tag] = STATE(3682),
    [sym_unary_expression] = STATE(3682),
    [sym_binary_expression] = STATE(3682),
    [sym_ternary_expression] = STATE(3682),
    [sym_call_expression] = STATE(3682),
    [sym_selector_call_expression] = STATE(3682),
    [sym_member_expression] = STATE(3682),
    [sym_index_expression] = STATE(3682),
    [sym_slice_expression] = STATE(3682),
    [sym_range_expression] = STATE(3682),
    [sym_cast_expression] = STATE(3682),
    [sym_in_expression] = STATE(3682),
    [sym_variadic_expression] = STATE(3682),
    [sym_parenthesized_expression] = STATE(3682),
    [sym_or_return_expression] = STATE(3682),
    [sym_or_continue_expression] = STATE(3682),
    [sym_or_break_expression] = STATE(3682),
    [sym_address] = STATE(3682),
    [sym_map_type] = STATE(3682),
    [sym_matrix_type] = STATE(3682),
    [sym_distinct_type] = STATE(3682),
    [sym_literal] = STATE(3682),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(6340),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1571] = {
    [sym_expression] = STATE(2782),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1572] = {
    [sym_expression] = STATE(2783),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1573] = {
    [sym_expression] = STATE(6090),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1574] = {
    [sym_expression] = STATE(2769),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1575] = {
    [sym_expression] = STATE(4124),
    [sym__expression_no_tag] = STATE(3682),
    [sym_unary_expression] = STATE(3682),
    [sym_binary_expression] = STATE(3682),
    [sym_ternary_expression] = STATE(3682),
    [sym_call_expression] = STATE(3682),
    [sym_selector_call_expression] = STATE(3682),
    [sym_member_expression] = STATE(3682),
    [sym_index_expression] = STATE(3682),
    [sym_slice_expression] = STATE(3682),
    [sym_range_expression] = STATE(3682),
    [sym_cast_expression] = STATE(3682),
    [sym_in_expression] = STATE(3682),
    [sym_variadic_expression] = STATE(3682),
    [sym_parenthesized_expression] = STATE(3682),
    [sym_or_return_expression] = STATE(3682),
    [sym_or_continue_expression] = STATE(3682),
    [sym_or_break_expression] = STATE(3682),
    [sym_address] = STATE(3682),
    [sym_map_type] = STATE(3682),
    [sym_matrix_type] = STATE(3682),
    [sym_distinct_type] = STATE(3682),
    [sym_literal] = STATE(3682),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(6340),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1576] = {
    [sym_expression] = STATE(2803),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1577] = {
    [sym_expression] = STATE(6302),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1578] = {
    [sym_expression] = STATE(2789),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1579] = {
    [sym_expression] = STATE(2790),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1580] = {
    [sym_expression] = STATE(2791),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1581] = {
    [sym_expression] = STATE(2793),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1582] = {
    [sym_expression] = STATE(2794),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1583] = {
    [sym_expression] = STATE(2796),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1584] = {
    [sym_expression] = STATE(2798),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1585] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5930),
    [sym_unary_expression] = STATE(5930),
    [sym_binary_expression] = STATE(5930),
    [sym_ternary_expression] = STATE(5930),
    [sym_call_expression] = STATE(3039),
    [sym_selector_call_expression] = STATE(5930),
    [sym_member_expression] = STATE(5930),
    [sym_index_expression] = STATE(5930),
    [sym_slice_expression] = STATE(5930),
    [sym_range_expression] = STATE(5930),
    [sym_cast_expression] = STATE(5930),
    [sym_in_expression] = STATE(5930),
    [sym_variadic_expression] = STATE(5930),
    [sym_parenthesized_expression] = STATE(5930),
    [sym_or_return_expression] = STATE(5930),
    [sym_or_continue_expression] = STATE(5930),
    [sym_or_break_expression] = STATE(5930),
    [sym_address] = STATE(5930),
    [sym_map_type] = STATE(5930),
    [sym_matrix_type] = STATE(5930),
    [sym_distinct_type] = STATE(5930),
    [sym_literal] = STATE(5930),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6346),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1586] = {
    [sym_expression] = STATE(2733),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1587] = {
    [ts_builtin_sym_end] = ACTIONS(3400),
    [anon_sym_LBRACE] = ACTIONS(3400),
    [anon_sym_RBRACE] = ACTIONS(3400),
    [anon_sym_COMMA] = ACTIONS(3400),
    [anon_sym_COLON_COLON] = ACTIONS(3400),
    [anon_sym_DASH_GT] = ACTIONS(3400),
    [anon_sym_EQ] = ACTIONS(3402),
    [anon_sym_COLON] = ACTIONS(3402),
    [anon_sym_PIPE] = ACTIONS(3402),
    [anon_sym_COLON_EQ] = ACTIONS(3400),
    [anon_sym_LPAREN] = ACTIONS(3400),
    [anon_sym_PLUS_EQ] = ACTIONS(3400),
    [anon_sym_DASH_EQ] = ACTIONS(3400),
    [anon_sym_STAR_EQ] = ACTIONS(3400),
    [anon_sym_SLASH_EQ] = ACTIONS(3400),
    [anon_sym_PERCENT_EQ] = ACTIONS(3400),
    [anon_sym_AMP_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_CARET_EQ] = ACTIONS(3400),
    [anon_sym_LT_LT_EQ] = ACTIONS(3400),
    [anon_sym_GT_GT_EQ] = ACTIONS(3400),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_if] = ACTIONS(3400),
    [anon_sym_SEMI] = ACTIONS(3400),
    [anon_sym_else] = ACTIONS(3400),
    [anon_sym_when] = ACTIONS(3400),
    [anon_sym_in] = ACTIONS(3400),
    [anon_sym_case] = ACTIONS(3400),
    [anon_sym_QMARK] = ACTIONS(3400),
    [anon_sym_PLUS] = ACTIONS(3402),
    [anon_sym_DASH] = ACTIONS(3402),
    [anon_sym_TILDE] = ACTIONS(3402),
    [anon_sym_AMP] = ACTIONS(3402),
    [anon_sym_PIPE_PIPE] = ACTIONS(3402),
    [anon_sym_or_else] = ACTIONS(3400),
    [anon_sym_AMP_AMP] = ACTIONS(3402),
    [anon_sym_GT] = ACTIONS(3402),
    [anon_sym_GT_EQ] = ACTIONS(3400),
    [anon_sym_LT_EQ] = ACTIONS(3400),
    [anon_sym_LT] = ACTIONS(3402),
    [anon_sym_EQ_EQ] = ACTIONS(3400),
    [anon_sym_BANG_EQ] = ACTIONS(3400),
    [anon_sym_TILDE_EQ] = ACTIONS(3400),
    [anon_sym_AMP_TILDE] = ACTIONS(3402),
    [anon_sym_LT_LT] = ACTIONS(3402),
    [anon_sym_GT_GT] = ACTIONS(3402),
    [anon_sym_STAR] = ACTIONS(3402),
    [anon_sym_SLASH] = ACTIONS(3402),
    [anon_sym_PERCENT] = ACTIONS(3402),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3400),
    [anon_sym_DOT] = ACTIONS(3402),
    [anon_sym_LBRACK] = ACTIONS(3400),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3400),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3400),
    [anon_sym_not_in] = ACTIONS(3400),
    [anon_sym_or_return] = ACTIONS(3400),
    [anon_sym_or_continue] = ACTIONS(3400),
    [anon_sym_or_break] = ACTIONS(3400),
    [anon_sym_CARET] = ACTIONS(3402),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3400),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1588] = {
    [sym_expression] = STATE(2734),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1589] = {
    [sym_expression] = STATE(673),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1590] = {
    [sym_expression] = STATE(831),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1591] = {
    [sym_expression] = STATE(2774),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1592] = {
    [sym_expression] = STATE(4141),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1593] = {
    [sym_expression] = STATE(2565),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [1594] = {
    [ts_builtin_sym_end] = ACTIONS(4577),
    [anon_sym_LBRACE] = ACTIONS(4577),
    [anon_sym_RBRACE] = ACTIONS(4577),
    [anon_sym_COMMA] = ACTIONS(4577),
    [anon_sym_COLON_COLON] = ACTIONS(4577),
    [anon_sym_DASH_GT] = ACTIONS(4577),
    [anon_sym_EQ] = ACTIONS(4579),
    [anon_sym_COLON] = ACTIONS(4579),
    [anon_sym_PIPE] = ACTIONS(4579),
    [anon_sym_COLON_EQ] = ACTIONS(4577),
    [anon_sym_LPAREN] = ACTIONS(4577),
    [anon_sym_PLUS_EQ] = ACTIONS(4577),
    [anon_sym_DASH_EQ] = ACTIONS(4577),
    [anon_sym_STAR_EQ] = ACTIONS(4577),
    [anon_sym_SLASH_EQ] = ACTIONS(4577),
    [anon_sym_PERCENT_EQ] = ACTIONS(4577),
    [anon_sym_AMP_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_CARET_EQ] = ACTIONS(4577),
    [anon_sym_LT_LT_EQ] = ACTIONS(4577),
    [anon_sym_GT_GT_EQ] = ACTIONS(4577),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_if] = ACTIONS(4577),
    [anon_sym_SEMI] = ACTIONS(4577),
    [anon_sym_else] = ACTIONS(4577),
    [anon_sym_when] = ACTIONS(4577),
    [anon_sym_in] = ACTIONS(4577),
    [anon_sym_case] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4577),
    [anon_sym_PLUS] = ACTIONS(4579),
    [anon_sym_DASH] = ACTIONS(4579),
    [anon_sym_TILDE] = ACTIONS(4579),
    [anon_sym_AMP] = ACTIONS(4579),
    [anon_sym_PIPE_PIPE] = ACTIONS(4579),
    [anon_sym_or_else] = ACTIONS(4577),
    [anon_sym_AMP_AMP] = ACTIONS(4579),
    [anon_sym_GT] = ACTIONS(4579),
    [anon_sym_GT_EQ] = ACTIONS(4577),
    [anon_sym_LT_EQ] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4579),
    [anon_sym_EQ_EQ] = ACTIONS(4577),
    [anon_sym_BANG_EQ] = ACTIONS(4577),
    [anon_sym_TILDE_EQ] = ACTIONS(4577),
    [anon_sym_AMP_TILDE] = ACTIONS(4579),
    [anon_sym_LT_LT] = ACTIONS(4579),
    [anon_sym_GT_GT] = ACTIONS(4579),
    [anon_sym_STAR] = ACTIONS(4579),
    [anon_sym_SLASH] = ACTIONS(4579),
    [anon_sym_PERCENT] = ACTIONS(4579),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4577),
    [anon_sym_DOT] = ACTIONS(4579),
    [anon_sym_LBRACK] = ACTIONS(4577),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4577),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4577),
    [anon_sym_not_in] = ACTIONS(4577),
    [anon_sym_or_return] = ACTIONS(4577),
    [anon_sym_or_continue] = ACTIONS(4577),
    [anon_sym_or_break] = ACTIONS(4577),
    [anon_sym_CARET] = ACTIONS(4579),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4577),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1595] = {
    [sym_expression] = STATE(2787),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1596] = {
    [sym_expression] = STATE(2792),
    [sym__expression_no_tag] = STATE(2797),
    [sym_unary_expression] = STATE(2797),
    [sym_binary_expression] = STATE(2797),
    [sym_ternary_expression] = STATE(2797),
    [sym_call_expression] = STATE(2797),
    [sym_selector_call_expression] = STATE(2797),
    [sym_member_expression] = STATE(2797),
    [sym_index_expression] = STATE(2797),
    [sym_slice_expression] = STATE(2797),
    [sym_range_expression] = STATE(2797),
    [sym_cast_expression] = STATE(2797),
    [sym_in_expression] = STATE(2797),
    [sym_variadic_expression] = STATE(2797),
    [sym_parenthesized_expression] = STATE(2797),
    [sym_or_return_expression] = STATE(2797),
    [sym_or_continue_expression] = STATE(2797),
    [sym_or_break_expression] = STATE(2797),
    [sym_address] = STATE(2797),
    [sym_map_type] = STATE(2797),
    [sym_matrix_type] = STATE(2797),
    [sym_distinct_type] = STATE(2797),
    [sym_literal] = STATE(2797),
    [sym_struct] = STATE(2778),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_PLUS] = ACTIONS(3344),
    [anon_sym_DASH] = ACTIONS(295),
    [anon_sym_TILDE] = ACTIONS(3344),
    [anon_sym_BANG] = ACTIONS(3344),
    [anon_sym_AMP] = ACTIONS(3344),
    [anon_sym_DOT] = ACTIONS(383),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(297),
    [anon_sym_transmute] = ACTIONS(297),
    [anon_sym_auto_cast] = ACTIONS(299),
    [anon_sym_DOT_DOT] = ACTIONS(3346),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(303),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1597] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5952),
    [sym_unary_expression] = STATE(5952),
    [sym_binary_expression] = STATE(5952),
    [sym_ternary_expression] = STATE(5952),
    [sym_call_expression] = STATE(3271),
    [sym_selector_call_expression] = STATE(5952),
    [sym_member_expression] = STATE(5952),
    [sym_index_expression] = STATE(5952),
    [sym_slice_expression] = STATE(5952),
    [sym_range_expression] = STATE(5952),
    [sym_cast_expression] = STATE(5952),
    [sym_in_expression] = STATE(5952),
    [sym_variadic_expression] = STATE(5952),
    [sym_parenthesized_expression] = STATE(5952),
    [sym_or_return_expression] = STATE(5952),
    [sym_or_continue_expression] = STATE(5952),
    [sym_or_break_expression] = STATE(5952),
    [sym_address] = STATE(5952),
    [sym_map_type] = STATE(5952),
    [sym_matrix_type] = STATE(5952),
    [sym_distinct_type] = STATE(5952),
    [sym_literal] = STATE(5952),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6352),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6354),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1598] = {
    [sym_expression] = STATE(4188),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1599] = {
    [sym_expression] = STATE(1866),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1600] = {
    [ts_builtin_sym_end] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(4585),
    [anon_sym_RBRACE] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_COLON_COLON] = ACTIONS(4585),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_EQ] = ACTIONS(4587),
    [anon_sym_COLON] = ACTIONS(4587),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_COLON_EQ] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_PLUS_EQ] = ACTIONS(4585),
    [anon_sym_DASH_EQ] = ACTIONS(4585),
    [anon_sym_STAR_EQ] = ACTIONS(4585),
    [anon_sym_SLASH_EQ] = ACTIONS(4585),
    [anon_sym_PERCENT_EQ] = ACTIONS(4585),
    [anon_sym_AMP_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_CARET_EQ] = ACTIONS(4585),
    [anon_sym_LT_LT_EQ] = ACTIONS(4585),
    [anon_sym_GT_GT_EQ] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_if] = ACTIONS(4585),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_else] = ACTIONS(4585),
    [anon_sym_when] = ACTIONS(4585),
    [anon_sym_in] = ACTIONS(4585),
    [anon_sym_case] = ACTIONS(4585),
    [anon_sym_QMARK] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_TILDE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_PIPE_PIPE] = ACTIONS(4587),
    [anon_sym_or_else] = ACTIONS(4585),
    [anon_sym_AMP_AMP] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_TILDE_EQ] = ACTIONS(4585),
    [anon_sym_AMP_TILDE] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4587),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4587),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4587),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4585),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4585),
    [anon_sym_not_in] = ACTIONS(4585),
    [anon_sym_or_return] = ACTIONS(4585),
    [anon_sym_or_continue] = ACTIONS(4585),
    [anon_sym_or_break] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4587),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4585),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1601] = {
    [sym_expression] = STATE(4954),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1602] = {
    [sym_expression] = STATE(6036),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1603] = {
    [sym_expression] = STATE(5759),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1604] = {
    [sym_expression] = STATE(5897),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1605] = {
    [sym_expression] = STATE(2405),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1606] = {
    [sym_expression] = STATE(4190),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1607] = {
    [sym_expression] = STATE(6400),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1608] = {
    [ts_builtin_sym_end] = ACTIONS(4949),
    [anon_sym_LBRACE] = ACTIONS(4949),
    [anon_sym_RBRACE] = ACTIONS(4949),
    [anon_sym_COMMA] = ACTIONS(4949),
    [anon_sym_COLON_COLON] = ACTIONS(4949),
    [anon_sym_DASH_GT] = ACTIONS(4949),
    [anon_sym_EQ] = ACTIONS(4951),
    [anon_sym_COLON] = ACTIONS(4951),
    [anon_sym_PIPE] = ACTIONS(4951),
    [anon_sym_COLON_EQ] = ACTIONS(4949),
    [anon_sym_LPAREN] = ACTIONS(4949),
    [anon_sym_PLUS_EQ] = ACTIONS(4949),
    [anon_sym_DASH_EQ] = ACTIONS(4949),
    [anon_sym_STAR_EQ] = ACTIONS(4949),
    [anon_sym_SLASH_EQ] = ACTIONS(4949),
    [anon_sym_PERCENT_EQ] = ACTIONS(4949),
    [anon_sym_AMP_EQ] = ACTIONS(4949),
    [anon_sym_PIPE_EQ] = ACTIONS(4949),
    [anon_sym_CARET_EQ] = ACTIONS(4949),
    [anon_sym_LT_LT_EQ] = ACTIONS(4949),
    [anon_sym_GT_GT_EQ] = ACTIONS(4949),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4949),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4949),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4949),
    [anon_sym_if] = ACTIONS(4949),
    [anon_sym_SEMI] = ACTIONS(4949),
    [anon_sym_else] = ACTIONS(4949),
    [anon_sym_when] = ACTIONS(4949),
    [anon_sym_in] = ACTIONS(4949),
    [anon_sym_case] = ACTIONS(4949),
    [anon_sym_QMARK] = ACTIONS(4949),
    [anon_sym_PLUS] = ACTIONS(4951),
    [anon_sym_DASH] = ACTIONS(4951),
    [anon_sym_TILDE] = ACTIONS(4951),
    [anon_sym_AMP] = ACTIONS(4951),
    [anon_sym_PIPE_PIPE] = ACTIONS(4951),
    [anon_sym_or_else] = ACTIONS(4949),
    [anon_sym_AMP_AMP] = ACTIONS(4951),
    [anon_sym_GT] = ACTIONS(4951),
    [anon_sym_GT_EQ] = ACTIONS(4949),
    [anon_sym_LT_EQ] = ACTIONS(4949),
    [anon_sym_LT] = ACTIONS(4951),
    [anon_sym_EQ_EQ] = ACTIONS(4949),
    [anon_sym_BANG_EQ] = ACTIONS(4949),
    [anon_sym_TILDE_EQ] = ACTIONS(4949),
    [anon_sym_AMP_TILDE] = ACTIONS(4951),
    [anon_sym_LT_LT] = ACTIONS(4951),
    [anon_sym_GT_GT] = ACTIONS(4951),
    [anon_sym_STAR] = ACTIONS(4951),
    [anon_sym_SLASH] = ACTIONS(4951),
    [anon_sym_PERCENT] = ACTIONS(4951),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4949),
    [anon_sym_DOT] = ACTIONS(4951),
    [anon_sym_LBRACK] = ACTIONS(4949),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4949),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4949),
    [anon_sym_not_in] = ACTIONS(4949),
    [anon_sym_or_return] = ACTIONS(4949),
    [anon_sym_or_continue] = ACTIONS(4949),
    [anon_sym_or_break] = ACTIONS(4949),
    [anon_sym_CARET] = ACTIONS(4951),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4949),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1609] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5905),
    [sym_unary_expression] = STATE(5905),
    [sym_binary_expression] = STATE(5905),
    [sym_ternary_expression] = STATE(5905),
    [sym_call_expression] = STATE(3632),
    [sym_selector_call_expression] = STATE(5905),
    [sym_member_expression] = STATE(5905),
    [sym_index_expression] = STATE(5905),
    [sym_slice_expression] = STATE(5905),
    [sym_range_expression] = STATE(5905),
    [sym_cast_expression] = STATE(5905),
    [sym_in_expression] = STATE(5905),
    [sym_variadic_expression] = STATE(5905),
    [sym_parenthesized_expression] = STATE(5905),
    [sym_or_return_expression] = STATE(5905),
    [sym_or_continue_expression] = STATE(5905),
    [sym_or_break_expression] = STATE(5905),
    [sym_address] = STATE(5905),
    [sym_map_type] = STATE(5905),
    [sym_matrix_type] = STATE(5905),
    [sym_distinct_type] = STATE(5905),
    [sym_literal] = STATE(5905),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6356),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6358),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1610] = {
    [sym_expression] = STATE(3459),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1611] = {
    [sym_expression] = STATE(4563),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1612] = {
    [sym_expression] = STATE(4421),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1613] = {
    [sym_expression] = STATE(4564),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1614] = {
    [sym_expression] = STATE(4422),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1615] = {
    [sym_expression] = STATE(4565),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1616] = {
    [sym_expression] = STATE(3532),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1617] = {
    [sym_expression] = STATE(4566),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1618] = {
    [sym_expression] = STATE(4423),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1619] = {
    [sym_expression] = STATE(4586),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1620] = {
    [sym_expression] = STATE(4424),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1621] = {
    [sym_expression] = STATE(4587),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1622] = {
    [ts_builtin_sym_end] = ACTIONS(4953),
    [anon_sym_LBRACE] = ACTIONS(4953),
    [anon_sym_RBRACE] = ACTIONS(4953),
    [anon_sym_COMMA] = ACTIONS(4953),
    [anon_sym_COLON_COLON] = ACTIONS(4953),
    [anon_sym_DASH_GT] = ACTIONS(4953),
    [anon_sym_EQ] = ACTIONS(4955),
    [anon_sym_COLON] = ACTIONS(4955),
    [anon_sym_PIPE] = ACTIONS(4955),
    [anon_sym_COLON_EQ] = ACTIONS(4953),
    [anon_sym_LPAREN] = ACTIONS(4953),
    [anon_sym_PLUS_EQ] = ACTIONS(4953),
    [anon_sym_DASH_EQ] = ACTIONS(4953),
    [anon_sym_STAR_EQ] = ACTIONS(4953),
    [anon_sym_SLASH_EQ] = ACTIONS(4953),
    [anon_sym_PERCENT_EQ] = ACTIONS(4953),
    [anon_sym_AMP_EQ] = ACTIONS(4953),
    [anon_sym_PIPE_EQ] = ACTIONS(4953),
    [anon_sym_CARET_EQ] = ACTIONS(4953),
    [anon_sym_LT_LT_EQ] = ACTIONS(4953),
    [anon_sym_GT_GT_EQ] = ACTIONS(4953),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4953),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4953),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4953),
    [anon_sym_if] = ACTIONS(4953),
    [anon_sym_SEMI] = ACTIONS(4953),
    [anon_sym_else] = ACTIONS(4953),
    [anon_sym_when] = ACTIONS(4953),
    [anon_sym_in] = ACTIONS(4953),
    [anon_sym_case] = ACTIONS(4953),
    [anon_sym_QMARK] = ACTIONS(4953),
    [anon_sym_PLUS] = ACTIONS(4955),
    [anon_sym_DASH] = ACTIONS(4955),
    [anon_sym_TILDE] = ACTIONS(4955),
    [anon_sym_AMP] = ACTIONS(4955),
    [anon_sym_PIPE_PIPE] = ACTIONS(4955),
    [anon_sym_or_else] = ACTIONS(4953),
    [anon_sym_AMP_AMP] = ACTIONS(4955),
    [anon_sym_GT] = ACTIONS(4955),
    [anon_sym_GT_EQ] = ACTIONS(4953),
    [anon_sym_LT_EQ] = ACTIONS(4953),
    [anon_sym_LT] = ACTIONS(4955),
    [anon_sym_EQ_EQ] = ACTIONS(4953),
    [anon_sym_BANG_EQ] = ACTIONS(4953),
    [anon_sym_TILDE_EQ] = ACTIONS(4953),
    [anon_sym_AMP_TILDE] = ACTIONS(4955),
    [anon_sym_LT_LT] = ACTIONS(4955),
    [anon_sym_GT_GT] = ACTIONS(4955),
    [anon_sym_STAR] = ACTIONS(4955),
    [anon_sym_SLASH] = ACTIONS(4955),
    [anon_sym_PERCENT] = ACTIONS(4955),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4953),
    [anon_sym_DOT] = ACTIONS(4955),
    [anon_sym_LBRACK] = ACTIONS(4953),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4953),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4953),
    [anon_sym_not_in] = ACTIONS(4953),
    [anon_sym_or_return] = ACTIONS(4953),
    [anon_sym_or_continue] = ACTIONS(4953),
    [anon_sym_or_break] = ACTIONS(4953),
    [anon_sym_CARET] = ACTIONS(4955),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4953),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1623] = {
    [sym_expression] = STATE(4588),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1624] = {
    [ts_builtin_sym_end] = ACTIONS(3481),
    [anon_sym_LBRACE] = ACTIONS(3481),
    [anon_sym_RBRACE] = ACTIONS(3481),
    [anon_sym_COMMA] = ACTIONS(3481),
    [anon_sym_COLON_COLON] = ACTIONS(3481),
    [anon_sym_DASH_GT] = ACTIONS(3481),
    [anon_sym_EQ] = ACTIONS(3483),
    [anon_sym_COLON] = ACTIONS(3483),
    [anon_sym_PIPE] = ACTIONS(3483),
    [anon_sym_COLON_EQ] = ACTIONS(3481),
    [anon_sym_LPAREN] = ACTIONS(3481),
    [anon_sym_PLUS_EQ] = ACTIONS(3481),
    [anon_sym_DASH_EQ] = ACTIONS(3481),
    [anon_sym_STAR_EQ] = ACTIONS(3481),
    [anon_sym_SLASH_EQ] = ACTIONS(3481),
    [anon_sym_PERCENT_EQ] = ACTIONS(3481),
    [anon_sym_AMP_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_CARET_EQ] = ACTIONS(3481),
    [anon_sym_LT_LT_EQ] = ACTIONS(3481),
    [anon_sym_GT_GT_EQ] = ACTIONS(3481),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(3481),
    [anon_sym_SEMI] = ACTIONS(3481),
    [anon_sym_else] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_in] = ACTIONS(3481),
    [anon_sym_case] = ACTIONS(3481),
    [anon_sym_QMARK] = ACTIONS(3481),
    [anon_sym_PLUS] = ACTIONS(3483),
    [anon_sym_DASH] = ACTIONS(3483),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_AMP] = ACTIONS(3483),
    [anon_sym_PIPE_PIPE] = ACTIONS(3483),
    [anon_sym_or_else] = ACTIONS(3481),
    [anon_sym_AMP_AMP] = ACTIONS(3483),
    [anon_sym_GT] = ACTIONS(3483),
    [anon_sym_GT_EQ] = ACTIONS(3481),
    [anon_sym_LT_EQ] = ACTIONS(3481),
    [anon_sym_LT] = ACTIONS(3483),
    [anon_sym_EQ_EQ] = ACTIONS(3481),
    [anon_sym_BANG_EQ] = ACTIONS(3481),
    [anon_sym_TILDE_EQ] = ACTIONS(3481),
    [anon_sym_AMP_TILDE] = ACTIONS(3483),
    [anon_sym_LT_LT] = ACTIONS(3483),
    [anon_sym_GT_GT] = ACTIONS(3483),
    [anon_sym_STAR] = ACTIONS(3483),
    [anon_sym_SLASH] = ACTIONS(3483),
    [anon_sym_PERCENT] = ACTIONS(3483),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3481),
    [anon_sym_DOT] = ACTIONS(3483),
    [anon_sym_LBRACK] = ACTIONS(3481),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3481),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3481),
    [anon_sym_not_in] = ACTIONS(3481),
    [anon_sym_or_return] = ACTIONS(3481),
    [anon_sym_or_continue] = ACTIONS(3481),
    [anon_sym_or_break] = ACTIONS(3481),
    [anon_sym_CARET] = ACTIONS(3483),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3481),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1625] = {
    [ts_builtin_sym_end] = ACTIONS(4961),
    [anon_sym_LBRACE] = ACTIONS(4961),
    [anon_sym_RBRACE] = ACTIONS(4961),
    [anon_sym_COMMA] = ACTIONS(4961),
    [anon_sym_COLON_COLON] = ACTIONS(4961),
    [anon_sym_DASH_GT] = ACTIONS(4961),
    [anon_sym_EQ] = ACTIONS(4963),
    [anon_sym_COLON] = ACTIONS(4963),
    [anon_sym_PIPE] = ACTIONS(4963),
    [anon_sym_COLON_EQ] = ACTIONS(4961),
    [anon_sym_LPAREN] = ACTIONS(6362),
    [anon_sym_PLUS_EQ] = ACTIONS(4961),
    [anon_sym_DASH_EQ] = ACTIONS(4961),
    [anon_sym_STAR_EQ] = ACTIONS(4961),
    [anon_sym_SLASH_EQ] = ACTIONS(4961),
    [anon_sym_PERCENT_EQ] = ACTIONS(4961),
    [anon_sym_AMP_EQ] = ACTIONS(4961),
    [anon_sym_PIPE_EQ] = ACTIONS(4961),
    [anon_sym_CARET_EQ] = ACTIONS(4961),
    [anon_sym_LT_LT_EQ] = ACTIONS(4961),
    [anon_sym_GT_GT_EQ] = ACTIONS(4961),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4961),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4961),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4961),
    [anon_sym_if] = ACTIONS(4961),
    [anon_sym_SEMI] = ACTIONS(4961),
    [anon_sym_else] = ACTIONS(4961),
    [anon_sym_when] = ACTIONS(4961),
    [anon_sym_in] = ACTIONS(4961),
    [anon_sym_case] = ACTIONS(4961),
    [anon_sym_QMARK] = ACTIONS(4961),
    [anon_sym_PLUS] = ACTIONS(4963),
    [anon_sym_DASH] = ACTIONS(4963),
    [anon_sym_TILDE] = ACTIONS(4963),
    [anon_sym_AMP] = ACTIONS(4963),
    [anon_sym_PIPE_PIPE] = ACTIONS(4963),
    [anon_sym_or_else] = ACTIONS(4961),
    [anon_sym_AMP_AMP] = ACTIONS(4963),
    [anon_sym_GT] = ACTIONS(4963),
    [anon_sym_GT_EQ] = ACTIONS(4961),
    [anon_sym_LT_EQ] = ACTIONS(4961),
    [anon_sym_LT] = ACTIONS(4963),
    [anon_sym_EQ_EQ] = ACTIONS(4961),
    [anon_sym_BANG_EQ] = ACTIONS(4961),
    [anon_sym_TILDE_EQ] = ACTIONS(4961),
    [anon_sym_AMP_TILDE] = ACTIONS(4963),
    [anon_sym_LT_LT] = ACTIONS(4963),
    [anon_sym_GT_GT] = ACTIONS(4963),
    [anon_sym_STAR] = ACTIONS(4963),
    [anon_sym_SLASH] = ACTIONS(6364),
    [anon_sym_PERCENT] = ACTIONS(4963),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4961),
    [anon_sym_DOT] = ACTIONS(4963),
    [anon_sym_LBRACK] = ACTIONS(4961),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4961),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4961),
    [anon_sym_not_in] = ACTIONS(4961),
    [anon_sym_or_return] = ACTIONS(4961),
    [anon_sym_or_continue] = ACTIONS(4961),
    [anon_sym_or_break] = ACTIONS(4961),
    [anon_sym_CARET] = ACTIONS(4963),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4961),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1626] = {
    [sym_expression] = STATE(4439),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1627] = {
    [sym_expression] = STATE(4440),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1628] = {
    [sym_expression] = STATE(4589),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1629] = {
    [sym_expression] = STATE(4590),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1630] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5911),
    [sym_unary_expression] = STATE(5911),
    [sym_binary_expression] = STATE(5911),
    [sym_ternary_expression] = STATE(5911),
    [sym_call_expression] = STATE(782),
    [sym_selector_call_expression] = STATE(5911),
    [sym_member_expression] = STATE(5911),
    [sym_index_expression] = STATE(5911),
    [sym_slice_expression] = STATE(5911),
    [sym_range_expression] = STATE(5911),
    [sym_cast_expression] = STATE(5911),
    [sym_in_expression] = STATE(5911),
    [sym_variadic_expression] = STATE(5911),
    [sym_parenthesized_expression] = STATE(5911),
    [sym_or_return_expression] = STATE(5911),
    [sym_or_continue_expression] = STATE(5911),
    [sym_or_break_expression] = STATE(5911),
    [sym_address] = STATE(5911),
    [sym_map_type] = STATE(5911),
    [sym_matrix_type] = STATE(5911),
    [sym_distinct_type] = STATE(5911),
    [sym_literal] = STATE(5911),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6366),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6368),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1631] = {
    [sym_expression] = STATE(4591),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1632] = {
    [sym_expression] = STATE(4446),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1633] = {
    [sym_expression] = STATE(4592),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1634] = {
    [sym_expression] = STATE(4714),
    [sym__expression_no_tag] = STATE(4386),
    [sym_unary_expression] = STATE(4386),
    [sym_binary_expression] = STATE(4386),
    [sym_ternary_expression] = STATE(4386),
    [sym_call_expression] = STATE(4386),
    [sym_selector_call_expression] = STATE(4386),
    [sym_member_expression] = STATE(4386),
    [sym_index_expression] = STATE(4386),
    [sym_slice_expression] = STATE(4386),
    [sym_range_expression] = STATE(4386),
    [sym_cast_expression] = STATE(4386),
    [sym_in_expression] = STATE(4386),
    [sym_variadic_expression] = STATE(4386),
    [sym_parenthesized_expression] = STATE(4386),
    [sym_or_return_expression] = STATE(4386),
    [sym_or_continue_expression] = STATE(4386),
    [sym_or_break_expression] = STATE(4386),
    [sym_address] = STATE(4386),
    [sym_map_type] = STATE(4386),
    [sym_matrix_type] = STATE(4386),
    [sym_distinct_type] = STATE(4386),
    [sym_literal] = STATE(4386),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(6370),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1635] = {
    [sym_expression] = STATE(4593),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1636] = {
    [sym_expression] = STATE(4447),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1637] = {
    [sym_expression] = STATE(4594),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1638] = {
    [sym_expression] = STATE(4448),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1639] = {
    [sym_expression] = STATE(4505),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1640] = {
    [sym_expression] = STATE(4819),
    [sym__expression_no_tag] = STATE(4386),
    [sym_unary_expression] = STATE(4386),
    [sym_binary_expression] = STATE(4386),
    [sym_ternary_expression] = STATE(4386),
    [sym_call_expression] = STATE(4386),
    [sym_selector_call_expression] = STATE(4386),
    [sym_member_expression] = STATE(4386),
    [sym_index_expression] = STATE(4386),
    [sym_slice_expression] = STATE(4386),
    [sym_range_expression] = STATE(4386),
    [sym_cast_expression] = STATE(4386),
    [sym_in_expression] = STATE(4386),
    [sym_variadic_expression] = STATE(4386),
    [sym_parenthesized_expression] = STATE(4386),
    [sym_or_return_expression] = STATE(4386),
    [sym_or_continue_expression] = STATE(4386),
    [sym_or_break_expression] = STATE(4386),
    [sym_address] = STATE(4386),
    [sym_map_type] = STATE(4386),
    [sym_matrix_type] = STATE(4386),
    [sym_distinct_type] = STATE(4386),
    [sym_literal] = STATE(4386),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(6370),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1641] = {
    [sym_expression] = STATE(4695),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1642] = {
    [sym_expression] = STATE(4449),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1643] = {
    [sym_expression] = STATE(4596),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1644] = {
    [sym_expression] = STATE(4597),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1645] = {
    [sym_expression] = STATE(4450),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1646] = {
    [sym_expression] = STATE(4599),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1647] = {
    [sym_expression] = STATE(4451),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1648] = {
    [sym_expression] = STATE(4809),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1649] = {
    [sym_expression] = STATE(4452),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1650] = {
    [sym_expression] = STATE(4455),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1651] = {
    [sym_expression] = STATE(4456),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1652] = {
    [sym_expression] = STATE(4457),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1653] = {
    [sym_expression] = STATE(4458),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1654] = {
    [sym_expression] = STATE(4459),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1655] = {
    [sym_expression] = STATE(4810),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1656] = {
    [sym_expression] = STATE(4811),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1657] = {
    [sym_expression] = STATE(4812),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1658] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5916),
    [sym_unary_expression] = STATE(5916),
    [sym_binary_expression] = STATE(5916),
    [sym_ternary_expression] = STATE(5916),
    [sym_call_expression] = STATE(2317),
    [sym_selector_call_expression] = STATE(5916),
    [sym_member_expression] = STATE(5916),
    [sym_index_expression] = STATE(5916),
    [sym_slice_expression] = STATE(5916),
    [sym_range_expression] = STATE(5916),
    [sym_cast_expression] = STATE(5916),
    [sym_in_expression] = STATE(5916),
    [sym_variadic_expression] = STATE(5916),
    [sym_parenthesized_expression] = STATE(5916),
    [sym_or_return_expression] = STATE(5916),
    [sym_or_continue_expression] = STATE(5916),
    [sym_or_break_expression] = STATE(5916),
    [sym_address] = STATE(5916),
    [sym_map_type] = STATE(5916),
    [sym_matrix_type] = STATE(5916),
    [sym_distinct_type] = STATE(5916),
    [sym_literal] = STATE(5916),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6372),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6374),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1659] = {
    [ts_builtin_sym_end] = ACTIONS(4989),
    [anon_sym_LBRACE] = ACTIONS(4989),
    [anon_sym_RBRACE] = ACTIONS(4989),
    [anon_sym_COMMA] = ACTIONS(4989),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_DASH_GT] = ACTIONS(4989),
    [anon_sym_EQ] = ACTIONS(4991),
    [anon_sym_COLON] = ACTIONS(4991),
    [anon_sym_PIPE] = ACTIONS(4991),
    [anon_sym_COLON_EQ] = ACTIONS(4989),
    [anon_sym_LPAREN] = ACTIONS(4989),
    [anon_sym_PLUS_EQ] = ACTIONS(4989),
    [anon_sym_DASH_EQ] = ACTIONS(4989),
    [anon_sym_STAR_EQ] = ACTIONS(4989),
    [anon_sym_SLASH_EQ] = ACTIONS(4989),
    [anon_sym_PERCENT_EQ] = ACTIONS(4989),
    [anon_sym_AMP_EQ] = ACTIONS(4989),
    [anon_sym_PIPE_EQ] = ACTIONS(4989),
    [anon_sym_CARET_EQ] = ACTIONS(4989),
    [anon_sym_LT_LT_EQ] = ACTIONS(4989),
    [anon_sym_GT_GT_EQ] = ACTIONS(4989),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4989),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4989),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4989),
    [anon_sym_if] = ACTIONS(4989),
    [anon_sym_SEMI] = ACTIONS(4989),
    [anon_sym_else] = ACTIONS(4989),
    [anon_sym_when] = ACTIONS(4989),
    [anon_sym_in] = ACTIONS(4989),
    [anon_sym_case] = ACTIONS(4989),
    [anon_sym_QMARK] = ACTIONS(4989),
    [anon_sym_PLUS] = ACTIONS(4991),
    [anon_sym_DASH] = ACTIONS(4991),
    [anon_sym_TILDE] = ACTIONS(4991),
    [anon_sym_AMP] = ACTIONS(4991),
    [anon_sym_PIPE_PIPE] = ACTIONS(4991),
    [anon_sym_or_else] = ACTIONS(4989),
    [anon_sym_AMP_AMP] = ACTIONS(4991),
    [anon_sym_GT] = ACTIONS(4991),
    [anon_sym_GT_EQ] = ACTIONS(4989),
    [anon_sym_LT_EQ] = ACTIONS(4989),
    [anon_sym_LT] = ACTIONS(4991),
    [anon_sym_EQ_EQ] = ACTIONS(4989),
    [anon_sym_BANG_EQ] = ACTIONS(4989),
    [anon_sym_TILDE_EQ] = ACTIONS(4989),
    [anon_sym_AMP_TILDE] = ACTIONS(4991),
    [anon_sym_LT_LT] = ACTIONS(4991),
    [anon_sym_GT_GT] = ACTIONS(4991),
    [anon_sym_STAR] = ACTIONS(4991),
    [anon_sym_SLASH] = ACTIONS(4991),
    [anon_sym_PERCENT] = ACTIONS(4991),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4989),
    [anon_sym_DOT] = ACTIONS(4991),
    [anon_sym_LBRACK] = ACTIONS(4989),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4989),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4989),
    [anon_sym_not_in] = ACTIONS(4989),
    [anon_sym_or_return] = ACTIONS(4989),
    [anon_sym_or_continue] = ACTIONS(4989),
    [anon_sym_or_break] = ACTIONS(4989),
    [anon_sym_CARET] = ACTIONS(4991),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4989),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1660] = {
    [sym_expression] = STATE(4133),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1661] = {
    [ts_builtin_sym_end] = ACTIONS(5001),
    [anon_sym_LBRACE] = ACTIONS(5001),
    [anon_sym_RBRACE] = ACTIONS(5001),
    [anon_sym_COMMA] = ACTIONS(5001),
    [anon_sym_COLON_COLON] = ACTIONS(5001),
    [anon_sym_DASH_GT] = ACTIONS(5001),
    [anon_sym_EQ] = ACTIONS(5003),
    [anon_sym_COLON] = ACTIONS(5003),
    [anon_sym_PIPE] = ACTIONS(5003),
    [anon_sym_COLON_EQ] = ACTIONS(5001),
    [anon_sym_LPAREN] = ACTIONS(6362),
    [anon_sym_PLUS_EQ] = ACTIONS(5001),
    [anon_sym_DASH_EQ] = ACTIONS(5001),
    [anon_sym_STAR_EQ] = ACTIONS(5001),
    [anon_sym_SLASH_EQ] = ACTIONS(5001),
    [anon_sym_PERCENT_EQ] = ACTIONS(5001),
    [anon_sym_AMP_EQ] = ACTIONS(5001),
    [anon_sym_PIPE_EQ] = ACTIONS(5001),
    [anon_sym_CARET_EQ] = ACTIONS(5001),
    [anon_sym_LT_LT_EQ] = ACTIONS(5001),
    [anon_sym_GT_GT_EQ] = ACTIONS(5001),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5001),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5001),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5001),
    [anon_sym_if] = ACTIONS(5001),
    [anon_sym_SEMI] = ACTIONS(5001),
    [anon_sym_else] = ACTIONS(5001),
    [anon_sym_when] = ACTIONS(5001),
    [anon_sym_in] = ACTIONS(5001),
    [anon_sym_case] = ACTIONS(5001),
    [anon_sym_QMARK] = ACTIONS(5001),
    [anon_sym_PLUS] = ACTIONS(5003),
    [anon_sym_DASH] = ACTIONS(5003),
    [anon_sym_TILDE] = ACTIONS(5003),
    [anon_sym_AMP] = ACTIONS(5003),
    [anon_sym_PIPE_PIPE] = ACTIONS(5003),
    [anon_sym_or_else] = ACTIONS(5001),
    [anon_sym_AMP_AMP] = ACTIONS(5003),
    [anon_sym_GT] = ACTIONS(5003),
    [anon_sym_GT_EQ] = ACTIONS(5001),
    [anon_sym_LT_EQ] = ACTIONS(5001),
    [anon_sym_LT] = ACTIONS(5003),
    [anon_sym_EQ_EQ] = ACTIONS(5001),
    [anon_sym_BANG_EQ] = ACTIONS(5001),
    [anon_sym_TILDE_EQ] = ACTIONS(5001),
    [anon_sym_AMP_TILDE] = ACTIONS(5003),
    [anon_sym_LT_LT] = ACTIONS(5003),
    [anon_sym_GT_GT] = ACTIONS(5003),
    [anon_sym_STAR] = ACTIONS(5003),
    [anon_sym_SLASH] = ACTIONS(6364),
    [anon_sym_PERCENT] = ACTIONS(5003),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5001),
    [anon_sym_DOT] = ACTIONS(5003),
    [anon_sym_LBRACK] = ACTIONS(5001),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5001),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5001),
    [anon_sym_not_in] = ACTIONS(5001),
    [anon_sym_or_return] = ACTIONS(5001),
    [anon_sym_or_continue] = ACTIONS(5001),
    [anon_sym_or_break] = ACTIONS(5001),
    [anon_sym_CARET] = ACTIONS(5003),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5001),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1662] = {
    [sym_expression] = STATE(4660),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1663] = {
    [sym_expression] = STATE(4155),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1664] = {
    [sym_expression] = STATE(4688),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1665] = {
    [sym_expression] = STATE(4399),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1666] = {
    [sym_expression] = STATE(4689),
    [sym__expression_no_tag] = STATE(4533),
    [sym_unary_expression] = STATE(4533),
    [sym_binary_expression] = STATE(4533),
    [sym_ternary_expression] = STATE(4533),
    [sym_call_expression] = STATE(4533),
    [sym_selector_call_expression] = STATE(4533),
    [sym_member_expression] = STATE(4533),
    [sym_index_expression] = STATE(4533),
    [sym_slice_expression] = STATE(4533),
    [sym_range_expression] = STATE(4533),
    [sym_cast_expression] = STATE(4533),
    [sym_in_expression] = STATE(4533),
    [sym_variadic_expression] = STATE(4533),
    [sym_parenthesized_expression] = STATE(4533),
    [sym_or_return_expression] = STATE(4533),
    [sym_or_continue_expression] = STATE(4533),
    [sym_or_break_expression] = STATE(4533),
    [sym_address] = STATE(4533),
    [sym_map_type] = STATE(4533),
    [sym_matrix_type] = STATE(4533),
    [sym_distinct_type] = STATE(4533),
    [sym_literal] = STATE(4533),
    [sym_struct] = STATE(4561),
    [sym_map] = STATE(4558),
    [sym_bit_set] = STATE(4558),
    [sym_matrix] = STATE(4558),
    [sym_string] = STATE(4558),
    [sym__string_literal] = STATE(4562),
    [sym__raw_string_literal] = STATE(4562),
    [sym_character] = STATE(4558),
    [sym_boolean] = STATE(4558),
    [sym_field_identifier] = STATE(8766),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_TILDE] = ACTIONS(731),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_DOT] = ACTIONS(735),
    [anon_sym_LBRACK] = ACTIONS(737),
    [anon_sym_cast] = ACTIONS(739),
    [anon_sym_transmute] = ACTIONS(739),
    [anon_sym_auto_cast] = ACTIONS(741),
    [anon_sym_DOT_DOT] = ACTIONS(2918),
    [anon_sym_map] = ACTIONS(745),
    [anon_sym_bit_set] = ACTIONS(747),
    [anon_sym_matrix] = ACTIONS(749),
    [anon_sym_distinct] = ACTIONS(751),
    [sym_number] = ACTIONS(753),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [anon_sym_BQUOTE] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_true] = ACTIONS(761),
    [anon_sym_false] = ACTIONS(761),
    [sym_nil] = ACTIONS(763),
    [sym_uninitialized] = ACTIONS(753),
    [sym_tag] = ACTIONS(765),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(753),
    [sym_block_comment] = ACTIONS(3),
  },
  [1667] = {
    [ts_builtin_sym_end] = ACTIONS(5011),
    [anon_sym_LBRACE] = ACTIONS(5011),
    [anon_sym_RBRACE] = ACTIONS(5011),
    [anon_sym_COMMA] = ACTIONS(5011),
    [anon_sym_COLON_COLON] = ACTIONS(5011),
    [anon_sym_DASH_GT] = ACTIONS(5011),
    [anon_sym_EQ] = ACTIONS(5013),
    [anon_sym_COLON] = ACTIONS(5013),
    [anon_sym_PIPE] = ACTIONS(5013),
    [anon_sym_COLON_EQ] = ACTIONS(5011),
    [anon_sym_LPAREN] = ACTIONS(6362),
    [anon_sym_PLUS_EQ] = ACTIONS(5011),
    [anon_sym_DASH_EQ] = ACTIONS(5011),
    [anon_sym_STAR_EQ] = ACTIONS(5011),
    [anon_sym_SLASH_EQ] = ACTIONS(5011),
    [anon_sym_PERCENT_EQ] = ACTIONS(5011),
    [anon_sym_AMP_EQ] = ACTIONS(5011),
    [anon_sym_PIPE_EQ] = ACTIONS(5011),
    [anon_sym_CARET_EQ] = ACTIONS(5011),
    [anon_sym_LT_LT_EQ] = ACTIONS(5011),
    [anon_sym_GT_GT_EQ] = ACTIONS(5011),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5011),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5011),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5011),
    [anon_sym_if] = ACTIONS(5011),
    [anon_sym_SEMI] = ACTIONS(5011),
    [anon_sym_else] = ACTIONS(5011),
    [anon_sym_when] = ACTIONS(5011),
    [anon_sym_in] = ACTIONS(5011),
    [anon_sym_case] = ACTIONS(5011),
    [anon_sym_QMARK] = ACTIONS(5011),
    [anon_sym_PLUS] = ACTIONS(5013),
    [anon_sym_DASH] = ACTIONS(5013),
    [anon_sym_TILDE] = ACTIONS(5013),
    [anon_sym_AMP] = ACTIONS(5013),
    [anon_sym_PIPE_PIPE] = ACTIONS(5013),
    [anon_sym_or_else] = ACTIONS(5011),
    [anon_sym_AMP_AMP] = ACTIONS(5013),
    [anon_sym_GT] = ACTIONS(5013),
    [anon_sym_GT_EQ] = ACTIONS(5011),
    [anon_sym_LT_EQ] = ACTIONS(5011),
    [anon_sym_LT] = ACTIONS(5013),
    [anon_sym_EQ_EQ] = ACTIONS(5011),
    [anon_sym_BANG_EQ] = ACTIONS(5011),
    [anon_sym_TILDE_EQ] = ACTIONS(5011),
    [anon_sym_AMP_TILDE] = ACTIONS(5013),
    [anon_sym_LT_LT] = ACTIONS(5013),
    [anon_sym_GT_GT] = ACTIONS(5013),
    [anon_sym_STAR] = ACTIONS(5013),
    [anon_sym_SLASH] = ACTIONS(6364),
    [anon_sym_PERCENT] = ACTIONS(5013),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5011),
    [anon_sym_DOT] = ACTIONS(5013),
    [anon_sym_LBRACK] = ACTIONS(5011),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5011),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5011),
    [anon_sym_not_in] = ACTIONS(5011),
    [anon_sym_or_return] = ACTIONS(5011),
    [anon_sym_or_continue] = ACTIONS(5011),
    [anon_sym_or_break] = ACTIONS(5011),
    [anon_sym_CARET] = ACTIONS(5013),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5011),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1668] = {
    [sym_expression] = STATE(5110),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1669] = {
    [sym_expression] = STATE(4858),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1670] = {
    [sym_expression] = STATE(4859),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1671] = {
    [sym_expression] = STATE(4862),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1672] = {
    [sym_expression] = STATE(4863),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1673] = {
    [sym_expression] = STATE(4472),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1674] = {
    [sym_expression] = STATE(4864),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1675] = {
    [sym_expression] = STATE(2374),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1676] = {
    [ts_builtin_sym_end] = ACTIONS(5035),
    [anon_sym_LBRACE] = ACTIONS(5035),
    [anon_sym_RBRACE] = ACTIONS(5035),
    [anon_sym_COMMA] = ACTIONS(5035),
    [anon_sym_COLON_COLON] = ACTIONS(5035),
    [anon_sym_DASH_GT] = ACTIONS(5035),
    [anon_sym_EQ] = ACTIONS(5037),
    [anon_sym_COLON] = ACTIONS(5037),
    [anon_sym_PIPE] = ACTIONS(5037),
    [anon_sym_COLON_EQ] = ACTIONS(5035),
    [anon_sym_LPAREN] = ACTIONS(5035),
    [anon_sym_PLUS_EQ] = ACTIONS(5035),
    [anon_sym_DASH_EQ] = ACTIONS(5035),
    [anon_sym_STAR_EQ] = ACTIONS(5035),
    [anon_sym_SLASH_EQ] = ACTIONS(5035),
    [anon_sym_PERCENT_EQ] = ACTIONS(5035),
    [anon_sym_AMP_EQ] = ACTIONS(5035),
    [anon_sym_PIPE_EQ] = ACTIONS(5035),
    [anon_sym_CARET_EQ] = ACTIONS(5035),
    [anon_sym_LT_LT_EQ] = ACTIONS(5035),
    [anon_sym_GT_GT_EQ] = ACTIONS(5035),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5035),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5035),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5035),
    [anon_sym_if] = ACTIONS(5035),
    [anon_sym_SEMI] = ACTIONS(5035),
    [anon_sym_else] = ACTIONS(5035),
    [anon_sym_when] = ACTIONS(5035),
    [anon_sym_in] = ACTIONS(5035),
    [anon_sym_case] = ACTIONS(5035),
    [anon_sym_QMARK] = ACTIONS(5035),
    [anon_sym_PLUS] = ACTIONS(5037),
    [anon_sym_DASH] = ACTIONS(5037),
    [anon_sym_TILDE] = ACTIONS(5037),
    [anon_sym_AMP] = ACTIONS(5037),
    [anon_sym_PIPE_PIPE] = ACTIONS(5037),
    [anon_sym_or_else] = ACTIONS(5035),
    [anon_sym_AMP_AMP] = ACTIONS(5037),
    [anon_sym_GT] = ACTIONS(5037),
    [anon_sym_GT_EQ] = ACTIONS(5035),
    [anon_sym_LT_EQ] = ACTIONS(5035),
    [anon_sym_LT] = ACTIONS(5037),
    [anon_sym_EQ_EQ] = ACTIONS(5035),
    [anon_sym_BANG_EQ] = ACTIONS(5035),
    [anon_sym_TILDE_EQ] = ACTIONS(5035),
    [anon_sym_AMP_TILDE] = ACTIONS(5037),
    [anon_sym_LT_LT] = ACTIONS(5037),
    [anon_sym_GT_GT] = ACTIONS(5037),
    [anon_sym_STAR] = ACTIONS(5037),
    [anon_sym_SLASH] = ACTIONS(5037),
    [anon_sym_PERCENT] = ACTIONS(5037),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5035),
    [anon_sym_DOT] = ACTIONS(5037),
    [anon_sym_LBRACK] = ACTIONS(5035),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5035),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5035),
    [anon_sym_not_in] = ACTIONS(5035),
    [anon_sym_or_return] = ACTIONS(5035),
    [anon_sym_or_continue] = ACTIONS(5035),
    [anon_sym_or_break] = ACTIONS(5035),
    [anon_sym_CARET] = ACTIONS(5037),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5035),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1677] = {
    [sym_expression] = STATE(2378),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1678] = {
    [ts_builtin_sym_end] = ACTIONS(5103),
    [anon_sym_LBRACE] = ACTIONS(5103),
    [anon_sym_RBRACE] = ACTIONS(5103),
    [anon_sym_COMMA] = ACTIONS(5103),
    [anon_sym_COLON_COLON] = ACTIONS(5103),
    [anon_sym_DASH_GT] = ACTIONS(5103),
    [anon_sym_EQ] = ACTIONS(5105),
    [anon_sym_COLON] = ACTIONS(5105),
    [anon_sym_PIPE] = ACTIONS(5105),
    [anon_sym_COLON_EQ] = ACTIONS(5103),
    [anon_sym_LPAREN] = ACTIONS(6362),
    [anon_sym_PLUS_EQ] = ACTIONS(5103),
    [anon_sym_DASH_EQ] = ACTIONS(5103),
    [anon_sym_STAR_EQ] = ACTIONS(5103),
    [anon_sym_SLASH_EQ] = ACTIONS(5103),
    [anon_sym_PERCENT_EQ] = ACTIONS(5103),
    [anon_sym_AMP_EQ] = ACTIONS(5103),
    [anon_sym_PIPE_EQ] = ACTIONS(5103),
    [anon_sym_CARET_EQ] = ACTIONS(5103),
    [anon_sym_LT_LT_EQ] = ACTIONS(5103),
    [anon_sym_GT_GT_EQ] = ACTIONS(5103),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5103),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5103),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5103),
    [anon_sym_if] = ACTIONS(5103),
    [anon_sym_SEMI] = ACTIONS(5103),
    [anon_sym_else] = ACTIONS(5103),
    [anon_sym_when] = ACTIONS(5103),
    [anon_sym_in] = ACTIONS(5103),
    [anon_sym_case] = ACTIONS(5103),
    [anon_sym_QMARK] = ACTIONS(5103),
    [anon_sym_PLUS] = ACTIONS(5105),
    [anon_sym_DASH] = ACTIONS(5105),
    [anon_sym_TILDE] = ACTIONS(5105),
    [anon_sym_AMP] = ACTIONS(5105),
    [anon_sym_PIPE_PIPE] = ACTIONS(5105),
    [anon_sym_or_else] = ACTIONS(5103),
    [anon_sym_AMP_AMP] = ACTIONS(5105),
    [anon_sym_GT] = ACTIONS(5105),
    [anon_sym_GT_EQ] = ACTIONS(5103),
    [anon_sym_LT_EQ] = ACTIONS(5103),
    [anon_sym_LT] = ACTIONS(5105),
    [anon_sym_EQ_EQ] = ACTIONS(5103),
    [anon_sym_BANG_EQ] = ACTIONS(5103),
    [anon_sym_TILDE_EQ] = ACTIONS(5103),
    [anon_sym_AMP_TILDE] = ACTIONS(5105),
    [anon_sym_LT_LT] = ACTIONS(5105),
    [anon_sym_GT_GT] = ACTIONS(5105),
    [anon_sym_STAR] = ACTIONS(5105),
    [anon_sym_SLASH] = ACTIONS(6364),
    [anon_sym_PERCENT] = ACTIONS(5105),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5103),
    [anon_sym_DOT] = ACTIONS(5105),
    [anon_sym_LBRACK] = ACTIONS(5103),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5103),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5103),
    [anon_sym_not_in] = ACTIONS(5103),
    [anon_sym_or_return] = ACTIONS(5103),
    [anon_sym_or_continue] = ACTIONS(5103),
    [anon_sym_or_break] = ACTIONS(5103),
    [anon_sym_CARET] = ACTIONS(5105),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5103),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1679] = {
    [sym_expression] = STATE(4479),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1680] = {
    [sym_expression] = STATE(4480),
    [sym__expression_no_tag] = STATE(4387),
    [sym_unary_expression] = STATE(4387),
    [sym_binary_expression] = STATE(4387),
    [sym_ternary_expression] = STATE(4387),
    [sym_call_expression] = STATE(4387),
    [sym_selector_call_expression] = STATE(4387),
    [sym_member_expression] = STATE(4387),
    [sym_index_expression] = STATE(4387),
    [sym_slice_expression] = STATE(4387),
    [sym_range_expression] = STATE(4387),
    [sym_cast_expression] = STATE(4387),
    [sym_in_expression] = STATE(4387),
    [sym_variadic_expression] = STATE(4387),
    [sym_parenthesized_expression] = STATE(4387),
    [sym_or_return_expression] = STATE(4387),
    [sym_or_continue_expression] = STATE(4387),
    [sym_or_break_expression] = STATE(4387),
    [sym_address] = STATE(4387),
    [sym_map_type] = STATE(4387),
    [sym_matrix_type] = STATE(4387),
    [sym_distinct_type] = STATE(4387),
    [sym_literal] = STATE(4387),
    [sym_struct] = STATE(4417),
    [sym_map] = STATE(4415),
    [sym_bit_set] = STATE(4415),
    [sym_matrix] = STATE(4415),
    [sym_string] = STATE(4415),
    [sym__string_literal] = STATE(4418),
    [sym__raw_string_literal] = STATE(4418),
    [sym_character] = STATE(4415),
    [sym_boolean] = STATE(4415),
    [sym_field_identifier] = STATE(8653),
    [sym_identifier] = ACTIONS(1315),
    [anon_sym_LBRACE] = ACTIONS(1317),
    [anon_sym_LPAREN] = ACTIONS(1319),
    [anon_sym_QMARK] = ACTIONS(1321),
    [anon_sym_PLUS] = ACTIONS(1323),
    [anon_sym_DASH] = ACTIONS(1325),
    [anon_sym_TILDE] = ACTIONS(1323),
    [anon_sym_BANG] = ACTIONS(1323),
    [anon_sym_AMP] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1327),
    [anon_sym_LBRACK] = ACTIONS(1329),
    [anon_sym_cast] = ACTIONS(1331),
    [anon_sym_transmute] = ACTIONS(1331),
    [anon_sym_auto_cast] = ACTIONS(1333),
    [anon_sym_DOT_DOT] = ACTIONS(6360),
    [anon_sym_map] = ACTIONS(1337),
    [anon_sym_bit_set] = ACTIONS(1339),
    [anon_sym_matrix] = ACTIONS(1341),
    [anon_sym_distinct] = ACTIONS(1343),
    [sym_number] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1347),
    [anon_sym_BQUOTE] = ACTIONS(1349),
    [anon_sym_SQUOTE] = ACTIONS(1351),
    [anon_sym_true] = ACTIONS(1353),
    [anon_sym_false] = ACTIONS(1353),
    [sym_nil] = ACTIONS(1355),
    [sym_uninitialized] = ACTIONS(1345),
    [sym_tag] = ACTIONS(1357),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(1345),
    [sym_block_comment] = ACTIONS(3),
  },
  [1681] = {
    [sym_expression] = STATE(4865),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1682] = {
    [sym_expression] = STATE(4866),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1683] = {
    [sym_expression] = STATE(4867),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1684] = {
    [sym_expression] = STATE(4199),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1685] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5920),
    [sym_unary_expression] = STATE(5920),
    [sym_binary_expression] = STATE(5920),
    [sym_ternary_expression] = STATE(5920),
    [sym_call_expression] = STATE(4438),
    [sym_selector_call_expression] = STATE(5920),
    [sym_member_expression] = STATE(5920),
    [sym_index_expression] = STATE(5920),
    [sym_slice_expression] = STATE(5920),
    [sym_range_expression] = STATE(5920),
    [sym_cast_expression] = STATE(5920),
    [sym_in_expression] = STATE(5920),
    [sym_variadic_expression] = STATE(5920),
    [sym_parenthesized_expression] = STATE(5920),
    [sym_or_return_expression] = STATE(5920),
    [sym_or_continue_expression] = STATE(5920),
    [sym_or_break_expression] = STATE(5920),
    [sym_address] = STATE(5920),
    [sym_map_type] = STATE(5920),
    [sym_matrix_type] = STATE(5920),
    [sym_distinct_type] = STATE(5920),
    [sym_literal] = STATE(5920),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6376),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6378),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1686] = {
    [sym_expression] = STATE(4868),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1687] = {
    [sym_expression] = STATE(4869),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1688] = {
    [sym_expression] = STATE(4870),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1689] = {
    [sym_expression] = STATE(2382),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1690] = {
    [ts_builtin_sym_end] = ACTIONS(5127),
    [anon_sym_LBRACE] = ACTIONS(5127),
    [anon_sym_RBRACE] = ACTIONS(5127),
    [anon_sym_COMMA] = ACTIONS(5127),
    [anon_sym_COLON_COLON] = ACTIONS(5127),
    [anon_sym_DASH_GT] = ACTIONS(5127),
    [anon_sym_EQ] = ACTIONS(5129),
    [anon_sym_COLON] = ACTIONS(5129),
    [anon_sym_PIPE] = ACTIONS(5129),
    [anon_sym_COLON_EQ] = ACTIONS(5127),
    [anon_sym_LPAREN] = ACTIONS(5127),
    [anon_sym_PLUS_EQ] = ACTIONS(5127),
    [anon_sym_DASH_EQ] = ACTIONS(5127),
    [anon_sym_STAR_EQ] = ACTIONS(5127),
    [anon_sym_SLASH_EQ] = ACTIONS(5127),
    [anon_sym_PERCENT_EQ] = ACTIONS(5127),
    [anon_sym_AMP_EQ] = ACTIONS(5127),
    [anon_sym_PIPE_EQ] = ACTIONS(5127),
    [anon_sym_CARET_EQ] = ACTIONS(5127),
    [anon_sym_LT_LT_EQ] = ACTIONS(5127),
    [anon_sym_GT_GT_EQ] = ACTIONS(5127),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5127),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5127),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5127),
    [anon_sym_if] = ACTIONS(5127),
    [anon_sym_SEMI] = ACTIONS(5127),
    [anon_sym_else] = ACTIONS(5127),
    [anon_sym_when] = ACTIONS(5127),
    [anon_sym_in] = ACTIONS(5127),
    [anon_sym_case] = ACTIONS(5127),
    [anon_sym_QMARK] = ACTIONS(5127),
    [anon_sym_PLUS] = ACTIONS(5129),
    [anon_sym_DASH] = ACTIONS(5129),
    [anon_sym_TILDE] = ACTIONS(5129),
    [anon_sym_AMP] = ACTIONS(5129),
    [anon_sym_PIPE_PIPE] = ACTIONS(5129),
    [anon_sym_or_else] = ACTIONS(5127),
    [anon_sym_AMP_AMP] = ACTIONS(5129),
    [anon_sym_GT] = ACTIONS(5129),
    [anon_sym_GT_EQ] = ACTIONS(5127),
    [anon_sym_LT_EQ] = ACTIONS(5127),
    [anon_sym_LT] = ACTIONS(5129),
    [anon_sym_EQ_EQ] = ACTIONS(5127),
    [anon_sym_BANG_EQ] = ACTIONS(5127),
    [anon_sym_TILDE_EQ] = ACTIONS(5127),
    [anon_sym_AMP_TILDE] = ACTIONS(5129),
    [anon_sym_LT_LT] = ACTIONS(5129),
    [anon_sym_GT_GT] = ACTIONS(5129),
    [anon_sym_STAR] = ACTIONS(5129),
    [anon_sym_SLASH] = ACTIONS(5129),
    [anon_sym_PERCENT] = ACTIONS(5129),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5127),
    [anon_sym_DOT] = ACTIONS(5129),
    [anon_sym_LBRACK] = ACTIONS(5127),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5127),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5127),
    [anon_sym_not_in] = ACTIONS(5127),
    [anon_sym_or_return] = ACTIONS(5127),
    [anon_sym_or_continue] = ACTIONS(5127),
    [anon_sym_or_break] = ACTIONS(5127),
    [anon_sym_CARET] = ACTIONS(5129),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5127),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1691] = {
    [ts_builtin_sym_end] = ACTIONS(5131),
    [anon_sym_LBRACE] = ACTIONS(5131),
    [anon_sym_RBRACE] = ACTIONS(5131),
    [anon_sym_COMMA] = ACTIONS(5131),
    [anon_sym_COLON_COLON] = ACTIONS(5131),
    [anon_sym_DASH_GT] = ACTIONS(5131),
    [anon_sym_EQ] = ACTIONS(5133),
    [anon_sym_COLON] = ACTIONS(5133),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_COLON_EQ] = ACTIONS(5131),
    [anon_sym_LPAREN] = ACTIONS(5131),
    [anon_sym_PLUS_EQ] = ACTIONS(5131),
    [anon_sym_DASH_EQ] = ACTIONS(5131),
    [anon_sym_STAR_EQ] = ACTIONS(5131),
    [anon_sym_SLASH_EQ] = ACTIONS(5131),
    [anon_sym_PERCENT_EQ] = ACTIONS(5131),
    [anon_sym_AMP_EQ] = ACTIONS(5131),
    [anon_sym_PIPE_EQ] = ACTIONS(5131),
    [anon_sym_CARET_EQ] = ACTIONS(5131),
    [anon_sym_LT_LT_EQ] = ACTIONS(5131),
    [anon_sym_GT_GT_EQ] = ACTIONS(5131),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5131),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5131),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5131),
    [anon_sym_if] = ACTIONS(5131),
    [anon_sym_SEMI] = ACTIONS(5131),
    [anon_sym_else] = ACTIONS(5131),
    [anon_sym_when] = ACTIONS(5131),
    [anon_sym_in] = ACTIONS(5131),
    [anon_sym_case] = ACTIONS(5131),
    [anon_sym_QMARK] = ACTIONS(5131),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_TILDE] = ACTIONS(5133),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_PIPE_PIPE] = ACTIONS(5133),
    [anon_sym_or_else] = ACTIONS(5131),
    [anon_sym_AMP_AMP] = ACTIONS(5133),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5131),
    [anon_sym_LT_EQ] = ACTIONS(5131),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5131),
    [anon_sym_BANG_EQ] = ACTIONS(5131),
    [anon_sym_TILDE_EQ] = ACTIONS(5131),
    [anon_sym_AMP_TILDE] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5133),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5133),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5131),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_LBRACK] = ACTIONS(5131),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5131),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5131),
    [anon_sym_not_in] = ACTIONS(5131),
    [anon_sym_or_return] = ACTIONS(5131),
    [anon_sym_or_continue] = ACTIONS(5131),
    [anon_sym_or_break] = ACTIONS(5131),
    [anon_sym_CARET] = ACTIONS(5133),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5131),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1692] = {
    [sym_expression] = STATE(4871),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1693] = {
    [ts_builtin_sym_end] = ACTIONS(5135),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_RBRACE] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_COLON_COLON] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [anon_sym_EQ] = ACTIONS(5137),
    [anon_sym_COLON] = ACTIONS(5137),
    [anon_sym_PIPE] = ACTIONS(5137),
    [anon_sym_COLON_EQ] = ACTIONS(5135),
    [anon_sym_LPAREN] = ACTIONS(5135),
    [anon_sym_PLUS_EQ] = ACTIONS(5135),
    [anon_sym_DASH_EQ] = ACTIONS(5135),
    [anon_sym_STAR_EQ] = ACTIONS(5135),
    [anon_sym_SLASH_EQ] = ACTIONS(5135),
    [anon_sym_PERCENT_EQ] = ACTIONS(5135),
    [anon_sym_AMP_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_CARET_EQ] = ACTIONS(5135),
    [anon_sym_LT_LT_EQ] = ACTIONS(5135),
    [anon_sym_GT_GT_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5135),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5135),
    [anon_sym_if] = ACTIONS(5135),
    [anon_sym_SEMI] = ACTIONS(5135),
    [anon_sym_else] = ACTIONS(5135),
    [anon_sym_when] = ACTIONS(5135),
    [anon_sym_in] = ACTIONS(5135),
    [anon_sym_case] = ACTIONS(5135),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_PLUS] = ACTIONS(5137),
    [anon_sym_DASH] = ACTIONS(5137),
    [anon_sym_TILDE] = ACTIONS(5137),
    [anon_sym_AMP] = ACTIONS(5137),
    [anon_sym_PIPE_PIPE] = ACTIONS(5137),
    [anon_sym_or_else] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5137),
    [anon_sym_GT] = ACTIONS(5137),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5135),
    [anon_sym_LT] = ACTIONS(5137),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_TILDE_EQ] = ACTIONS(5135),
    [anon_sym_AMP_TILDE] = ACTIONS(5137),
    [anon_sym_LT_LT] = ACTIONS(5137),
    [anon_sym_GT_GT] = ACTIONS(5137),
    [anon_sym_STAR] = ACTIONS(5137),
    [anon_sym_SLASH] = ACTIONS(5137),
    [anon_sym_PERCENT] = ACTIONS(5137),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5137),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5135),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5135),
    [anon_sym_not_in] = ACTIONS(5135),
    [anon_sym_or_return] = ACTIONS(5135),
    [anon_sym_or_continue] = ACTIONS(5135),
    [anon_sym_or_break] = ACTIONS(5135),
    [anon_sym_CARET] = ACTIONS(5137),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5135),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1694] = {
    [ts_builtin_sym_end] = ACTIONS(5139),
    [anon_sym_LBRACE] = ACTIONS(5139),
    [anon_sym_RBRACE] = ACTIONS(5139),
    [anon_sym_COMMA] = ACTIONS(5139),
    [anon_sym_COLON_COLON] = ACTIONS(5139),
    [anon_sym_DASH_GT] = ACTIONS(5139),
    [anon_sym_EQ] = ACTIONS(5141),
    [anon_sym_COLON] = ACTIONS(5141),
    [anon_sym_PIPE] = ACTIONS(5141),
    [anon_sym_COLON_EQ] = ACTIONS(5139),
    [anon_sym_LPAREN] = ACTIONS(5139),
    [anon_sym_PLUS_EQ] = ACTIONS(5139),
    [anon_sym_DASH_EQ] = ACTIONS(5139),
    [anon_sym_STAR_EQ] = ACTIONS(5139),
    [anon_sym_SLASH_EQ] = ACTIONS(5139),
    [anon_sym_PERCENT_EQ] = ACTIONS(5139),
    [anon_sym_AMP_EQ] = ACTIONS(5139),
    [anon_sym_PIPE_EQ] = ACTIONS(5139),
    [anon_sym_CARET_EQ] = ACTIONS(5139),
    [anon_sym_LT_LT_EQ] = ACTIONS(5139),
    [anon_sym_GT_GT_EQ] = ACTIONS(5139),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5139),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5139),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5139),
    [anon_sym_if] = ACTIONS(5139),
    [anon_sym_SEMI] = ACTIONS(5139),
    [anon_sym_else] = ACTIONS(5139),
    [anon_sym_when] = ACTIONS(5139),
    [anon_sym_in] = ACTIONS(5139),
    [anon_sym_case] = ACTIONS(5139),
    [anon_sym_QMARK] = ACTIONS(5139),
    [anon_sym_PLUS] = ACTIONS(5141),
    [anon_sym_DASH] = ACTIONS(5141),
    [anon_sym_TILDE] = ACTIONS(5141),
    [anon_sym_AMP] = ACTIONS(5141),
    [anon_sym_PIPE_PIPE] = ACTIONS(5141),
    [anon_sym_or_else] = ACTIONS(5139),
    [anon_sym_AMP_AMP] = ACTIONS(5141),
    [anon_sym_GT] = ACTIONS(5141),
    [anon_sym_GT_EQ] = ACTIONS(5139),
    [anon_sym_LT_EQ] = ACTIONS(5139),
    [anon_sym_LT] = ACTIONS(5141),
    [anon_sym_EQ_EQ] = ACTIONS(5139),
    [anon_sym_BANG_EQ] = ACTIONS(5139),
    [anon_sym_TILDE_EQ] = ACTIONS(5139),
    [anon_sym_AMP_TILDE] = ACTIONS(5141),
    [anon_sym_LT_LT] = ACTIONS(5141),
    [anon_sym_GT_GT] = ACTIONS(5141),
    [anon_sym_STAR] = ACTIONS(5141),
    [anon_sym_SLASH] = ACTIONS(5141),
    [anon_sym_PERCENT] = ACTIONS(5141),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5139),
    [anon_sym_DOT] = ACTIONS(5141),
    [anon_sym_LBRACK] = ACTIONS(5139),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5139),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5139),
    [anon_sym_not_in] = ACTIONS(5139),
    [anon_sym_or_return] = ACTIONS(5139),
    [anon_sym_or_continue] = ACTIONS(5139),
    [anon_sym_or_break] = ACTIONS(5139),
    [anon_sym_CARET] = ACTIONS(5141),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5139),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1695] = {
    [ts_builtin_sym_end] = ACTIONS(5237),
    [anon_sym_LBRACE] = ACTIONS(5237),
    [anon_sym_RBRACE] = ACTIONS(5237),
    [anon_sym_COMMA] = ACTIONS(5237),
    [anon_sym_COLON_COLON] = ACTIONS(5237),
    [anon_sym_DASH_GT] = ACTIONS(5237),
    [anon_sym_EQ] = ACTIONS(5239),
    [anon_sym_COLON] = ACTIONS(5239),
    [anon_sym_PIPE] = ACTIONS(5239),
    [anon_sym_COLON_EQ] = ACTIONS(5237),
    [anon_sym_LPAREN] = ACTIONS(5237),
    [anon_sym_PLUS_EQ] = ACTIONS(5237),
    [anon_sym_DASH_EQ] = ACTIONS(5237),
    [anon_sym_STAR_EQ] = ACTIONS(5237),
    [anon_sym_SLASH_EQ] = ACTIONS(5237),
    [anon_sym_PERCENT_EQ] = ACTIONS(5237),
    [anon_sym_AMP_EQ] = ACTIONS(5237),
    [anon_sym_PIPE_EQ] = ACTIONS(5237),
    [anon_sym_CARET_EQ] = ACTIONS(5237),
    [anon_sym_LT_LT_EQ] = ACTIONS(5237),
    [anon_sym_GT_GT_EQ] = ACTIONS(5237),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5237),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5237),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5237),
    [anon_sym_if] = ACTIONS(5237),
    [anon_sym_SEMI] = ACTIONS(5237),
    [anon_sym_else] = ACTIONS(5237),
    [anon_sym_when] = ACTIONS(5237),
    [anon_sym_in] = ACTIONS(5237),
    [anon_sym_case] = ACTIONS(5237),
    [anon_sym_QMARK] = ACTIONS(5237),
    [anon_sym_PLUS] = ACTIONS(5239),
    [anon_sym_DASH] = ACTIONS(5239),
    [anon_sym_TILDE] = ACTIONS(5239),
    [anon_sym_AMP] = ACTIONS(5239),
    [anon_sym_PIPE_PIPE] = ACTIONS(5239),
    [anon_sym_or_else] = ACTIONS(5237),
    [anon_sym_AMP_AMP] = ACTIONS(5239),
    [anon_sym_GT] = ACTIONS(5239),
    [anon_sym_GT_EQ] = ACTIONS(5237),
    [anon_sym_LT_EQ] = ACTIONS(5237),
    [anon_sym_LT] = ACTIONS(5239),
    [anon_sym_EQ_EQ] = ACTIONS(5237),
    [anon_sym_BANG_EQ] = ACTIONS(5237),
    [anon_sym_TILDE_EQ] = ACTIONS(5237),
    [anon_sym_AMP_TILDE] = ACTIONS(5239),
    [anon_sym_LT_LT] = ACTIONS(5239),
    [anon_sym_GT_GT] = ACTIONS(5239),
    [anon_sym_STAR] = ACTIONS(5239),
    [anon_sym_SLASH] = ACTIONS(5239),
    [anon_sym_PERCENT] = ACTIONS(5239),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5237),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_LBRACK] = ACTIONS(5237),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5237),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5237),
    [anon_sym_not_in] = ACTIONS(5237),
    [anon_sym_or_return] = ACTIONS(5237),
    [anon_sym_or_continue] = ACTIONS(5237),
    [anon_sym_or_break] = ACTIONS(5237),
    [anon_sym_CARET] = ACTIONS(5239),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5237),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1696] = {
    [sym_expression] = STATE(4873),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1697] = {
    [sym_expression] = STATE(4874),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1698] = {
    [aux_sym_where_clause_repeat1] = STATE(1726),
    [anon_sym_LBRACE] = ACTIONS(4456),
    [anon_sym_COMMA] = ACTIONS(6380),
    [anon_sym_COLON_COLON] = ACTIONS(4456),
    [anon_sym_DASH_GT] = ACTIONS(4456),
    [anon_sym_where] = ACTIONS(4456),
    [anon_sym_EQ] = ACTIONS(4460),
    [anon_sym_COLON] = ACTIONS(4460),
    [anon_sym_PIPE] = ACTIONS(4460),
    [anon_sym_COLON_EQ] = ACTIONS(4456),
    [anon_sym_LPAREN] = ACTIONS(4456),
    [anon_sym_PLUS_EQ] = ACTIONS(4456),
    [anon_sym_DASH_EQ] = ACTIONS(4456),
    [anon_sym_STAR_EQ] = ACTIONS(4456),
    [anon_sym_SLASH_EQ] = ACTIONS(4456),
    [anon_sym_PERCENT_EQ] = ACTIONS(4456),
    [anon_sym_AMP_EQ] = ACTIONS(4456),
    [anon_sym_PIPE_EQ] = ACTIONS(4456),
    [anon_sym_CARET_EQ] = ACTIONS(4456),
    [anon_sym_LT_LT_EQ] = ACTIONS(4456),
    [anon_sym_GT_GT_EQ] = ACTIONS(4456),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4456),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4456),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4456),
    [anon_sym_if] = ACTIONS(4456),
    [anon_sym_SEMI] = ACTIONS(4456),
    [anon_sym_do] = ACTIONS(4456),
    [anon_sym_when] = ACTIONS(4456),
    [anon_sym_in] = ACTIONS(4456),
    [anon_sym_QMARK] = ACTIONS(4456),
    [anon_sym_PLUS] = ACTIONS(4460),
    [anon_sym_DASH] = ACTIONS(4460),
    [anon_sym_TILDE] = ACTIONS(4460),
    [anon_sym_AMP] = ACTIONS(4460),
    [anon_sym_PIPE_PIPE] = ACTIONS(4460),
    [anon_sym_or_else] = ACTIONS(4456),
    [anon_sym_AMP_AMP] = ACTIONS(4460),
    [anon_sym_GT] = ACTIONS(4460),
    [anon_sym_GT_EQ] = ACTIONS(4456),
    [anon_sym_LT_EQ] = ACTIONS(4456),
    [anon_sym_LT] = ACTIONS(4460),
    [anon_sym_EQ_EQ] = ACTIONS(4456),
    [anon_sym_BANG_EQ] = ACTIONS(4456),
    [anon_sym_TILDE_EQ] = ACTIONS(4456),
    [anon_sym_AMP_TILDE] = ACTIONS(4460),
    [anon_sym_LT_LT] = ACTIONS(4460),
    [anon_sym_GT_GT] = ACTIONS(4460),
    [anon_sym_STAR] = ACTIONS(4460),
    [anon_sym_SLASH] = ACTIONS(4460),
    [anon_sym_PERCENT] = ACTIONS(4460),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4456),
    [anon_sym_DOT] = ACTIONS(4460),
    [anon_sym_LBRACK] = ACTIONS(4456),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4456),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4456),
    [anon_sym_not_in] = ACTIONS(4456),
    [anon_sym_or_return] = ACTIONS(4456),
    [anon_sym_or_continue] = ACTIONS(4456),
    [anon_sym_or_break] = ACTIONS(4456),
    [anon_sym_CARET] = ACTIONS(4460),
    [sym_uninitialized] = ACTIONS(4456),
    [sym_tag] = ACTIONS(4456),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1699] = {
    [ts_builtin_sym_end] = ACTIONS(5241),
    [anon_sym_LBRACE] = ACTIONS(5241),
    [anon_sym_RBRACE] = ACTIONS(5241),
    [anon_sym_COMMA] = ACTIONS(5241),
    [anon_sym_COLON_COLON] = ACTIONS(5241),
    [anon_sym_DASH_GT] = ACTIONS(5241),
    [anon_sym_EQ] = ACTIONS(5243),
    [anon_sym_COLON] = ACTIONS(5243),
    [anon_sym_PIPE] = ACTIONS(5243),
    [anon_sym_COLON_EQ] = ACTIONS(5241),
    [anon_sym_LPAREN] = ACTIONS(5241),
    [anon_sym_PLUS_EQ] = ACTIONS(5241),
    [anon_sym_DASH_EQ] = ACTIONS(5241),
    [anon_sym_STAR_EQ] = ACTIONS(5241),
    [anon_sym_SLASH_EQ] = ACTIONS(5241),
    [anon_sym_PERCENT_EQ] = ACTIONS(5241),
    [anon_sym_AMP_EQ] = ACTIONS(5241),
    [anon_sym_PIPE_EQ] = ACTIONS(5241),
    [anon_sym_CARET_EQ] = ACTIONS(5241),
    [anon_sym_LT_LT_EQ] = ACTIONS(5241),
    [anon_sym_GT_GT_EQ] = ACTIONS(5241),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5241),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5241),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5241),
    [anon_sym_if] = ACTIONS(5241),
    [anon_sym_SEMI] = ACTIONS(5241),
    [anon_sym_else] = ACTIONS(5241),
    [anon_sym_when] = ACTIONS(5241),
    [anon_sym_in] = ACTIONS(5241),
    [anon_sym_case] = ACTIONS(5241),
    [anon_sym_QMARK] = ACTIONS(5241),
    [anon_sym_PLUS] = ACTIONS(5243),
    [anon_sym_DASH] = ACTIONS(5243),
    [anon_sym_TILDE] = ACTIONS(5243),
    [anon_sym_AMP] = ACTIONS(5243),
    [anon_sym_PIPE_PIPE] = ACTIONS(5243),
    [anon_sym_or_else] = ACTIONS(5241),
    [anon_sym_AMP_AMP] = ACTIONS(5243),
    [anon_sym_GT] = ACTIONS(5243),
    [anon_sym_GT_EQ] = ACTIONS(5241),
    [anon_sym_LT_EQ] = ACTIONS(5241),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_EQ_EQ] = ACTIONS(5241),
    [anon_sym_BANG_EQ] = ACTIONS(5241),
    [anon_sym_TILDE_EQ] = ACTIONS(5241),
    [anon_sym_AMP_TILDE] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(5243),
    [anon_sym_GT_GT] = ACTIONS(5243),
    [anon_sym_STAR] = ACTIONS(5243),
    [anon_sym_SLASH] = ACTIONS(5243),
    [anon_sym_PERCENT] = ACTIONS(5243),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5241),
    [anon_sym_DOT] = ACTIONS(5243),
    [anon_sym_LBRACK] = ACTIONS(5241),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5241),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5241),
    [anon_sym_not_in] = ACTIONS(5241),
    [anon_sym_or_return] = ACTIONS(5241),
    [anon_sym_or_continue] = ACTIONS(5241),
    [anon_sym_or_break] = ACTIONS(5241),
    [anon_sym_CARET] = ACTIONS(5243),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5241),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1700] = {
    [sym_expression] = STATE(4047),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1701] = {
    [ts_builtin_sym_end] = ACTIONS(5245),
    [anon_sym_LBRACE] = ACTIONS(5245),
    [anon_sym_RBRACE] = ACTIONS(5245),
    [anon_sym_COMMA] = ACTIONS(5245),
    [anon_sym_COLON_COLON] = ACTIONS(5245),
    [anon_sym_DASH_GT] = ACTIONS(5245),
    [anon_sym_EQ] = ACTIONS(5247),
    [anon_sym_COLON] = ACTIONS(5247),
    [anon_sym_PIPE] = ACTIONS(5247),
    [anon_sym_COLON_EQ] = ACTIONS(5245),
    [anon_sym_LPAREN] = ACTIONS(5245),
    [anon_sym_PLUS_EQ] = ACTIONS(5245),
    [anon_sym_DASH_EQ] = ACTIONS(5245),
    [anon_sym_STAR_EQ] = ACTIONS(5245),
    [anon_sym_SLASH_EQ] = ACTIONS(5245),
    [anon_sym_PERCENT_EQ] = ACTIONS(5245),
    [anon_sym_AMP_EQ] = ACTIONS(5245),
    [anon_sym_PIPE_EQ] = ACTIONS(5245),
    [anon_sym_CARET_EQ] = ACTIONS(5245),
    [anon_sym_LT_LT_EQ] = ACTIONS(5245),
    [anon_sym_GT_GT_EQ] = ACTIONS(5245),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5245),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5245),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5245),
    [anon_sym_if] = ACTIONS(5245),
    [anon_sym_SEMI] = ACTIONS(5245),
    [anon_sym_else] = ACTIONS(5245),
    [anon_sym_when] = ACTIONS(5245),
    [anon_sym_in] = ACTIONS(5245),
    [anon_sym_case] = ACTIONS(5245),
    [anon_sym_QMARK] = ACTIONS(5245),
    [anon_sym_PLUS] = ACTIONS(5247),
    [anon_sym_DASH] = ACTIONS(5247),
    [anon_sym_TILDE] = ACTIONS(5247),
    [anon_sym_AMP] = ACTIONS(5247),
    [anon_sym_PIPE_PIPE] = ACTIONS(5247),
    [anon_sym_or_else] = ACTIONS(5245),
    [anon_sym_AMP_AMP] = ACTIONS(5247),
    [anon_sym_GT] = ACTIONS(5247),
    [anon_sym_GT_EQ] = ACTIONS(5245),
    [anon_sym_LT_EQ] = ACTIONS(5245),
    [anon_sym_LT] = ACTIONS(5247),
    [anon_sym_EQ_EQ] = ACTIONS(5245),
    [anon_sym_BANG_EQ] = ACTIONS(5245),
    [anon_sym_TILDE_EQ] = ACTIONS(5245),
    [anon_sym_AMP_TILDE] = ACTIONS(5247),
    [anon_sym_LT_LT] = ACTIONS(5247),
    [anon_sym_GT_GT] = ACTIONS(5247),
    [anon_sym_STAR] = ACTIONS(5247),
    [anon_sym_SLASH] = ACTIONS(5247),
    [anon_sym_PERCENT] = ACTIONS(5247),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5245),
    [anon_sym_DOT] = ACTIONS(5247),
    [anon_sym_LBRACK] = ACTIONS(5245),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5245),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5245),
    [anon_sym_not_in] = ACTIONS(5245),
    [anon_sym_or_return] = ACTIONS(5245),
    [anon_sym_or_continue] = ACTIONS(5245),
    [anon_sym_or_break] = ACTIONS(5245),
    [anon_sym_CARET] = ACTIONS(5247),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5245),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1702] = {
    [sym_expression] = STATE(4053),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1703] = {
    [ts_builtin_sym_end] = ACTIONS(5249),
    [anon_sym_LBRACE] = ACTIONS(5249),
    [anon_sym_RBRACE] = ACTIONS(5249),
    [anon_sym_COMMA] = ACTIONS(5249),
    [anon_sym_COLON_COLON] = ACTIONS(5249),
    [anon_sym_DASH_GT] = ACTIONS(5249),
    [anon_sym_EQ] = ACTIONS(5251),
    [anon_sym_COLON] = ACTIONS(5251),
    [anon_sym_PIPE] = ACTIONS(5251),
    [anon_sym_COLON_EQ] = ACTIONS(5249),
    [anon_sym_LPAREN] = ACTIONS(5249),
    [anon_sym_PLUS_EQ] = ACTIONS(5249),
    [anon_sym_DASH_EQ] = ACTIONS(5249),
    [anon_sym_STAR_EQ] = ACTIONS(5249),
    [anon_sym_SLASH_EQ] = ACTIONS(5249),
    [anon_sym_PERCENT_EQ] = ACTIONS(5249),
    [anon_sym_AMP_EQ] = ACTIONS(5249),
    [anon_sym_PIPE_EQ] = ACTIONS(5249),
    [anon_sym_CARET_EQ] = ACTIONS(5249),
    [anon_sym_LT_LT_EQ] = ACTIONS(5249),
    [anon_sym_GT_GT_EQ] = ACTIONS(5249),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5249),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5249),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5249),
    [anon_sym_if] = ACTIONS(5249),
    [anon_sym_SEMI] = ACTIONS(5249),
    [anon_sym_else] = ACTIONS(5249),
    [anon_sym_when] = ACTIONS(5249),
    [anon_sym_in] = ACTIONS(5249),
    [anon_sym_case] = ACTIONS(5249),
    [anon_sym_QMARK] = ACTIONS(5249),
    [anon_sym_PLUS] = ACTIONS(5251),
    [anon_sym_DASH] = ACTIONS(5251),
    [anon_sym_TILDE] = ACTIONS(5251),
    [anon_sym_AMP] = ACTIONS(5251),
    [anon_sym_PIPE_PIPE] = ACTIONS(5251),
    [anon_sym_or_else] = ACTIONS(5249),
    [anon_sym_AMP_AMP] = ACTIONS(5251),
    [anon_sym_GT] = ACTIONS(5251),
    [anon_sym_GT_EQ] = ACTIONS(5249),
    [anon_sym_LT_EQ] = ACTIONS(5249),
    [anon_sym_LT] = ACTIONS(5251),
    [anon_sym_EQ_EQ] = ACTIONS(5249),
    [anon_sym_BANG_EQ] = ACTIONS(5249),
    [anon_sym_TILDE_EQ] = ACTIONS(5249),
    [anon_sym_AMP_TILDE] = ACTIONS(5251),
    [anon_sym_LT_LT] = ACTIONS(5251),
    [anon_sym_GT_GT] = ACTIONS(5251),
    [anon_sym_STAR] = ACTIONS(5251),
    [anon_sym_SLASH] = ACTIONS(5251),
    [anon_sym_PERCENT] = ACTIONS(5251),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5249),
    [anon_sym_DOT] = ACTIONS(5251),
    [anon_sym_LBRACK] = ACTIONS(5249),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5249),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5249),
    [anon_sym_not_in] = ACTIONS(5249),
    [anon_sym_or_return] = ACTIONS(5249),
    [anon_sym_or_continue] = ACTIONS(5249),
    [anon_sym_or_break] = ACTIONS(5249),
    [anon_sym_CARET] = ACTIONS(5251),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5249),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1704] = {
    [ts_builtin_sym_end] = ACTIONS(5253),
    [anon_sym_LBRACE] = ACTIONS(5253),
    [anon_sym_RBRACE] = ACTIONS(5253),
    [anon_sym_COMMA] = ACTIONS(5253),
    [anon_sym_COLON_COLON] = ACTIONS(5253),
    [anon_sym_DASH_GT] = ACTIONS(5253),
    [anon_sym_EQ] = ACTIONS(5255),
    [anon_sym_COLON] = ACTIONS(5255),
    [anon_sym_PIPE] = ACTIONS(5255),
    [anon_sym_COLON_EQ] = ACTIONS(5253),
    [anon_sym_LPAREN] = ACTIONS(5253),
    [anon_sym_PLUS_EQ] = ACTIONS(5253),
    [anon_sym_DASH_EQ] = ACTIONS(5253),
    [anon_sym_STAR_EQ] = ACTIONS(5253),
    [anon_sym_SLASH_EQ] = ACTIONS(5253),
    [anon_sym_PERCENT_EQ] = ACTIONS(5253),
    [anon_sym_AMP_EQ] = ACTIONS(5253),
    [anon_sym_PIPE_EQ] = ACTIONS(5253),
    [anon_sym_CARET_EQ] = ACTIONS(5253),
    [anon_sym_LT_LT_EQ] = ACTIONS(5253),
    [anon_sym_GT_GT_EQ] = ACTIONS(5253),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5253),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5253),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5253),
    [anon_sym_if] = ACTIONS(5253),
    [anon_sym_SEMI] = ACTIONS(5253),
    [anon_sym_else] = ACTIONS(5253),
    [anon_sym_when] = ACTIONS(5253),
    [anon_sym_in] = ACTIONS(5253),
    [anon_sym_case] = ACTIONS(5253),
    [anon_sym_QMARK] = ACTIONS(5253),
    [anon_sym_PLUS] = ACTIONS(5255),
    [anon_sym_DASH] = ACTIONS(5255),
    [anon_sym_TILDE] = ACTIONS(5255),
    [anon_sym_AMP] = ACTIONS(5255),
    [anon_sym_PIPE_PIPE] = ACTIONS(5255),
    [anon_sym_or_else] = ACTIONS(5253),
    [anon_sym_AMP_AMP] = ACTIONS(5255),
    [anon_sym_GT] = ACTIONS(5255),
    [anon_sym_GT_EQ] = ACTIONS(5253),
    [anon_sym_LT_EQ] = ACTIONS(5253),
    [anon_sym_LT] = ACTIONS(5255),
    [anon_sym_EQ_EQ] = ACTIONS(5253),
    [anon_sym_BANG_EQ] = ACTIONS(5253),
    [anon_sym_TILDE_EQ] = ACTIONS(5253),
    [anon_sym_AMP_TILDE] = ACTIONS(5255),
    [anon_sym_LT_LT] = ACTIONS(5255),
    [anon_sym_GT_GT] = ACTIONS(5255),
    [anon_sym_STAR] = ACTIONS(5255),
    [anon_sym_SLASH] = ACTIONS(5255),
    [anon_sym_PERCENT] = ACTIONS(5255),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5253),
    [anon_sym_DOT] = ACTIONS(5255),
    [anon_sym_LBRACK] = ACTIONS(5253),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5253),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5253),
    [anon_sym_not_in] = ACTIONS(5253),
    [anon_sym_or_return] = ACTIONS(5253),
    [anon_sym_or_continue] = ACTIONS(5253),
    [anon_sym_or_break] = ACTIONS(5253),
    [anon_sym_CARET] = ACTIONS(5255),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5253),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1705] = {
    [ts_builtin_sym_end] = ACTIONS(4751),
    [anon_sym_LBRACE] = ACTIONS(4751),
    [anon_sym_RBRACE] = ACTIONS(4751),
    [anon_sym_COMMA] = ACTIONS(4751),
    [anon_sym_COLON_COLON] = ACTIONS(4751),
    [anon_sym_DASH_GT] = ACTIONS(4751),
    [anon_sym_EQ] = ACTIONS(4753),
    [anon_sym_COLON] = ACTIONS(4753),
    [anon_sym_PIPE] = ACTIONS(4753),
    [anon_sym_COLON_EQ] = ACTIONS(4751),
    [anon_sym_LPAREN] = ACTIONS(6362),
    [anon_sym_PLUS_EQ] = ACTIONS(4751),
    [anon_sym_DASH_EQ] = ACTIONS(4751),
    [anon_sym_STAR_EQ] = ACTIONS(4751),
    [anon_sym_SLASH_EQ] = ACTIONS(4751),
    [anon_sym_PERCENT_EQ] = ACTIONS(4751),
    [anon_sym_AMP_EQ] = ACTIONS(4751),
    [anon_sym_PIPE_EQ] = ACTIONS(4751),
    [anon_sym_CARET_EQ] = ACTIONS(4751),
    [anon_sym_LT_LT_EQ] = ACTIONS(4751),
    [anon_sym_GT_GT_EQ] = ACTIONS(4751),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4751),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4751),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4751),
    [anon_sym_if] = ACTIONS(4751),
    [anon_sym_SEMI] = ACTIONS(4751),
    [anon_sym_else] = ACTIONS(4751),
    [anon_sym_when] = ACTIONS(4751),
    [anon_sym_in] = ACTIONS(4751),
    [anon_sym_case] = ACTIONS(4751),
    [anon_sym_QMARK] = ACTIONS(4751),
    [anon_sym_PLUS] = ACTIONS(4753),
    [anon_sym_DASH] = ACTIONS(4753),
    [anon_sym_TILDE] = ACTIONS(4753),
    [anon_sym_AMP] = ACTIONS(4753),
    [anon_sym_PIPE_PIPE] = ACTIONS(4753),
    [anon_sym_or_else] = ACTIONS(4751),
    [anon_sym_AMP_AMP] = ACTIONS(4753),
    [anon_sym_GT] = ACTIONS(4753),
    [anon_sym_GT_EQ] = ACTIONS(4751),
    [anon_sym_LT_EQ] = ACTIONS(4751),
    [anon_sym_LT] = ACTIONS(4753),
    [anon_sym_EQ_EQ] = ACTIONS(4751),
    [anon_sym_BANG_EQ] = ACTIONS(4751),
    [anon_sym_TILDE_EQ] = ACTIONS(4751),
    [anon_sym_AMP_TILDE] = ACTIONS(4753),
    [anon_sym_LT_LT] = ACTIONS(4753),
    [anon_sym_GT_GT] = ACTIONS(4753),
    [anon_sym_STAR] = ACTIONS(4753),
    [anon_sym_SLASH] = ACTIONS(6364),
    [anon_sym_PERCENT] = ACTIONS(4753),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4751),
    [anon_sym_DOT] = ACTIONS(4753),
    [anon_sym_LBRACK] = ACTIONS(4751),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4751),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4751),
    [anon_sym_not_in] = ACTIONS(4751),
    [anon_sym_or_return] = ACTIONS(4751),
    [anon_sym_or_continue] = ACTIONS(4751),
    [anon_sym_or_break] = ACTIONS(4751),
    [anon_sym_CARET] = ACTIONS(4753),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4751),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1706] = {
    [ts_builtin_sym_end] = ACTIONS(5059),
    [anon_sym_LBRACE] = ACTIONS(5059),
    [anon_sym_RBRACE] = ACTIONS(5059),
    [anon_sym_COMMA] = ACTIONS(5059),
    [anon_sym_COLON_COLON] = ACTIONS(5059),
    [anon_sym_DASH_GT] = ACTIONS(5059),
    [anon_sym_EQ] = ACTIONS(5061),
    [anon_sym_COLON] = ACTIONS(5061),
    [anon_sym_PIPE] = ACTIONS(5061),
    [anon_sym_COLON_EQ] = ACTIONS(5059),
    [anon_sym_LPAREN] = ACTIONS(5059),
    [anon_sym_PLUS_EQ] = ACTIONS(5059),
    [anon_sym_DASH_EQ] = ACTIONS(5059),
    [anon_sym_STAR_EQ] = ACTIONS(5059),
    [anon_sym_SLASH_EQ] = ACTIONS(5059),
    [anon_sym_PERCENT_EQ] = ACTIONS(5059),
    [anon_sym_AMP_EQ] = ACTIONS(5059),
    [anon_sym_PIPE_EQ] = ACTIONS(5059),
    [anon_sym_CARET_EQ] = ACTIONS(5059),
    [anon_sym_LT_LT_EQ] = ACTIONS(5059),
    [anon_sym_GT_GT_EQ] = ACTIONS(5059),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5059),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5059),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5059),
    [anon_sym_if] = ACTIONS(5059),
    [anon_sym_SEMI] = ACTIONS(5059),
    [anon_sym_else] = ACTIONS(5059),
    [anon_sym_when] = ACTIONS(5059),
    [anon_sym_in] = ACTIONS(5059),
    [anon_sym_case] = ACTIONS(5059),
    [anon_sym_QMARK] = ACTIONS(5059),
    [anon_sym_PLUS] = ACTIONS(5061),
    [anon_sym_DASH] = ACTIONS(5061),
    [anon_sym_TILDE] = ACTIONS(5061),
    [anon_sym_AMP] = ACTIONS(5061),
    [anon_sym_PIPE_PIPE] = ACTIONS(5061),
    [anon_sym_or_else] = ACTIONS(5059),
    [anon_sym_AMP_AMP] = ACTIONS(5061),
    [anon_sym_GT] = ACTIONS(5061),
    [anon_sym_GT_EQ] = ACTIONS(5059),
    [anon_sym_LT_EQ] = ACTIONS(5059),
    [anon_sym_LT] = ACTIONS(5061),
    [anon_sym_EQ_EQ] = ACTIONS(5059),
    [anon_sym_BANG_EQ] = ACTIONS(5059),
    [anon_sym_TILDE_EQ] = ACTIONS(5059),
    [anon_sym_AMP_TILDE] = ACTIONS(5061),
    [anon_sym_LT_LT] = ACTIONS(5061),
    [anon_sym_GT_GT] = ACTIONS(5061),
    [anon_sym_STAR] = ACTIONS(5061),
    [anon_sym_SLASH] = ACTIONS(5061),
    [anon_sym_PERCENT] = ACTIONS(5061),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5059),
    [anon_sym_DOT] = ACTIONS(5061),
    [anon_sym_LBRACK] = ACTIONS(5059),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5059),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5059),
    [anon_sym_not_in] = ACTIONS(5059),
    [anon_sym_or_return] = ACTIONS(5059),
    [anon_sym_or_continue] = ACTIONS(5059),
    [anon_sym_or_break] = ACTIONS(5059),
    [anon_sym_CARET] = ACTIONS(5061),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5059),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1707] = {
    [sym_expression] = STATE(5944),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1708] = {
    [sym_expression] = STATE(4746),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1709] = {
    [ts_builtin_sym_end] = ACTIONS(3701),
    [anon_sym_LBRACE] = ACTIONS(3701),
    [anon_sym_RBRACE] = ACTIONS(3701),
    [anon_sym_COMMA] = ACTIONS(3701),
    [anon_sym_COLON_COLON] = ACTIONS(3701),
    [anon_sym_DASH_GT] = ACTIONS(3701),
    [anon_sym_EQ] = ACTIONS(3706),
    [anon_sym_COLON] = ACTIONS(3706),
    [anon_sym_PIPE] = ACTIONS(3706),
    [anon_sym_COLON_EQ] = ACTIONS(3701),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_PLUS_EQ] = ACTIONS(3701),
    [anon_sym_DASH_EQ] = ACTIONS(3701),
    [anon_sym_STAR_EQ] = ACTIONS(3701),
    [anon_sym_SLASH_EQ] = ACTIONS(3701),
    [anon_sym_PERCENT_EQ] = ACTIONS(3701),
    [anon_sym_AMP_EQ] = ACTIONS(3701),
    [anon_sym_PIPE_EQ] = ACTIONS(3701),
    [anon_sym_CARET_EQ] = ACTIONS(3701),
    [anon_sym_LT_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT_GT_EQ] = ACTIONS(3701),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3701),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3701),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3701),
    [anon_sym_if] = ACTIONS(3701),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_else] = ACTIONS(3701),
    [anon_sym_when] = ACTIONS(3701),
    [anon_sym_in] = ACTIONS(3701),
    [anon_sym_case] = ACTIONS(3701),
    [anon_sym_QMARK] = ACTIONS(3701),
    [anon_sym_PLUS] = ACTIONS(3706),
    [anon_sym_DASH] = ACTIONS(3706),
    [anon_sym_TILDE] = ACTIONS(3706),
    [anon_sym_AMP] = ACTIONS(3706),
    [anon_sym_PIPE_PIPE] = ACTIONS(3706),
    [anon_sym_or_else] = ACTIONS(3701),
    [anon_sym_AMP_AMP] = ACTIONS(3706),
    [anon_sym_GT] = ACTIONS(3706),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_LT] = ACTIONS(3706),
    [anon_sym_EQ_EQ] = ACTIONS(3701),
    [anon_sym_BANG_EQ] = ACTIONS(3701),
    [anon_sym_TILDE_EQ] = ACTIONS(3701),
    [anon_sym_AMP_TILDE] = ACTIONS(3706),
    [anon_sym_LT_LT] = ACTIONS(3706),
    [anon_sym_GT_GT] = ACTIONS(3706),
    [anon_sym_STAR] = ACTIONS(3706),
    [anon_sym_SLASH] = ACTIONS(3706),
    [anon_sym_PERCENT] = ACTIONS(3706),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(3706),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3701),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3701),
    [anon_sym_not_in] = ACTIONS(3701),
    [anon_sym_or_return] = ACTIONS(3701),
    [anon_sym_or_continue] = ACTIONS(3701),
    [anon_sym_or_break] = ACTIONS(3701),
    [anon_sym_CARET] = ACTIONS(3706),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(3701),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1710] = {
    [ts_builtin_sym_end] = ACTIONS(4725),
    [anon_sym_LBRACE] = ACTIONS(4725),
    [anon_sym_RBRACE] = ACTIONS(4725),
    [anon_sym_COMMA] = ACTIONS(4725),
    [anon_sym_COLON_COLON] = ACTIONS(4725),
    [anon_sym_DASH_GT] = ACTIONS(4725),
    [anon_sym_EQ] = ACTIONS(4727),
    [anon_sym_COLON] = ACTIONS(4727),
    [anon_sym_PIPE] = ACTIONS(4727),
    [anon_sym_COLON_EQ] = ACTIONS(4725),
    [anon_sym_LPAREN] = ACTIONS(4725),
    [anon_sym_PLUS_EQ] = ACTIONS(4725),
    [anon_sym_DASH_EQ] = ACTIONS(4725),
    [anon_sym_STAR_EQ] = ACTIONS(4725),
    [anon_sym_SLASH_EQ] = ACTIONS(4725),
    [anon_sym_PERCENT_EQ] = ACTIONS(4725),
    [anon_sym_AMP_EQ] = ACTIONS(4725),
    [anon_sym_PIPE_EQ] = ACTIONS(4725),
    [anon_sym_CARET_EQ] = ACTIONS(4725),
    [anon_sym_LT_LT_EQ] = ACTIONS(4725),
    [anon_sym_GT_GT_EQ] = ACTIONS(4725),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4725),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4725),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4725),
    [anon_sym_if] = ACTIONS(4725),
    [anon_sym_SEMI] = ACTIONS(4725),
    [anon_sym_else] = ACTIONS(4725),
    [anon_sym_when] = ACTIONS(4725),
    [anon_sym_in] = ACTIONS(4725),
    [anon_sym_case] = ACTIONS(4725),
    [anon_sym_QMARK] = ACTIONS(4725),
    [anon_sym_PLUS] = ACTIONS(4727),
    [anon_sym_DASH] = ACTIONS(4727),
    [anon_sym_TILDE] = ACTIONS(4727),
    [anon_sym_AMP] = ACTIONS(4727),
    [anon_sym_PIPE_PIPE] = ACTIONS(4727),
    [anon_sym_or_else] = ACTIONS(4725),
    [anon_sym_AMP_AMP] = ACTIONS(4727),
    [anon_sym_GT] = ACTIONS(4727),
    [anon_sym_GT_EQ] = ACTIONS(4725),
    [anon_sym_LT_EQ] = ACTIONS(4725),
    [anon_sym_LT] = ACTIONS(4727),
    [anon_sym_EQ_EQ] = ACTIONS(4725),
    [anon_sym_BANG_EQ] = ACTIONS(4725),
    [anon_sym_TILDE_EQ] = ACTIONS(4725),
    [anon_sym_AMP_TILDE] = ACTIONS(4727),
    [anon_sym_LT_LT] = ACTIONS(4727),
    [anon_sym_GT_GT] = ACTIONS(4727),
    [anon_sym_STAR] = ACTIONS(4727),
    [anon_sym_SLASH] = ACTIONS(4727),
    [anon_sym_PERCENT] = ACTIONS(4727),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4725),
    [anon_sym_DOT] = ACTIONS(4727),
    [anon_sym_LBRACK] = ACTIONS(4725),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4725),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4725),
    [anon_sym_not_in] = ACTIONS(4725),
    [anon_sym_or_return] = ACTIONS(4725),
    [anon_sym_or_continue] = ACTIONS(4725),
    [anon_sym_or_break] = ACTIONS(4725),
    [anon_sym_CARET] = ACTIONS(4727),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4725),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1711] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5918),
    [sym_unary_expression] = STATE(5918),
    [sym_binary_expression] = STATE(5918),
    [sym_ternary_expression] = STATE(5918),
    [sym_call_expression] = STATE(4111),
    [sym_selector_call_expression] = STATE(5918),
    [sym_member_expression] = STATE(5918),
    [sym_index_expression] = STATE(5918),
    [sym_slice_expression] = STATE(5918),
    [sym_range_expression] = STATE(5918),
    [sym_cast_expression] = STATE(5918),
    [sym_in_expression] = STATE(5918),
    [sym_variadic_expression] = STATE(5918),
    [sym_parenthesized_expression] = STATE(5918),
    [sym_or_return_expression] = STATE(5918),
    [sym_or_continue_expression] = STATE(5918),
    [sym_or_break_expression] = STATE(5918),
    [sym_address] = STATE(5918),
    [sym_map_type] = STATE(5918),
    [sym_matrix_type] = STATE(5918),
    [sym_distinct_type] = STATE(5918),
    [sym_literal] = STATE(5918),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6382),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(63),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1712] = {
    [sym_expression] = STATE(4757),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1713] = {
    [sym_expression] = STATE(4758),
    [sym__expression_no_tag] = STATE(4856),
    [sym_unary_expression] = STATE(4856),
    [sym_binary_expression] = STATE(4856),
    [sym_ternary_expression] = STATE(4856),
    [sym_call_expression] = STATE(4856),
    [sym_selector_call_expression] = STATE(4856),
    [sym_member_expression] = STATE(4856),
    [sym_index_expression] = STATE(4856),
    [sym_slice_expression] = STATE(4856),
    [sym_range_expression] = STATE(4856),
    [sym_cast_expression] = STATE(4856),
    [sym_in_expression] = STATE(4856),
    [sym_variadic_expression] = STATE(4856),
    [sym_parenthesized_expression] = STATE(4856),
    [sym_or_return_expression] = STATE(4856),
    [sym_or_continue_expression] = STATE(4856),
    [sym_or_break_expression] = STATE(4856),
    [sym_address] = STATE(4856),
    [sym_map_type] = STATE(4856),
    [sym_matrix_type] = STATE(4856),
    [sym_distinct_type] = STATE(4856),
    [sym_literal] = STATE(4856),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(1215),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1714] = {
    [sym_expression] = STATE(5962),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1715] = {
    [ts_builtin_sym_end] = ACTIONS(4735),
    [anon_sym_LBRACE] = ACTIONS(4735),
    [anon_sym_RBRACE] = ACTIONS(4735),
    [anon_sym_COMMA] = ACTIONS(4735),
    [anon_sym_COLON_COLON] = ACTIONS(4735),
    [anon_sym_DASH_GT] = ACTIONS(4735),
    [anon_sym_EQ] = ACTIONS(4737),
    [anon_sym_COLON] = ACTIONS(4737),
    [anon_sym_PIPE] = ACTIONS(4737),
    [anon_sym_COLON_EQ] = ACTIONS(4735),
    [anon_sym_LPAREN] = ACTIONS(4735),
    [anon_sym_PLUS_EQ] = ACTIONS(4735),
    [anon_sym_DASH_EQ] = ACTIONS(4735),
    [anon_sym_STAR_EQ] = ACTIONS(4735),
    [anon_sym_SLASH_EQ] = ACTIONS(4735),
    [anon_sym_PERCENT_EQ] = ACTIONS(4735),
    [anon_sym_AMP_EQ] = ACTIONS(4735),
    [anon_sym_PIPE_EQ] = ACTIONS(4735),
    [anon_sym_CARET_EQ] = ACTIONS(4735),
    [anon_sym_LT_LT_EQ] = ACTIONS(4735),
    [anon_sym_GT_GT_EQ] = ACTIONS(4735),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4735),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4735),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4735),
    [anon_sym_if] = ACTIONS(4735),
    [anon_sym_SEMI] = ACTIONS(4735),
    [anon_sym_else] = ACTIONS(4735),
    [anon_sym_when] = ACTIONS(4735),
    [anon_sym_in] = ACTIONS(4735),
    [anon_sym_case] = ACTIONS(4735),
    [anon_sym_QMARK] = ACTIONS(4735),
    [anon_sym_PLUS] = ACTIONS(4737),
    [anon_sym_DASH] = ACTIONS(4737),
    [anon_sym_TILDE] = ACTIONS(4737),
    [anon_sym_AMP] = ACTIONS(4737),
    [anon_sym_PIPE_PIPE] = ACTIONS(4737),
    [anon_sym_or_else] = ACTIONS(4735),
    [anon_sym_AMP_AMP] = ACTIONS(4737),
    [anon_sym_GT] = ACTIONS(4737),
    [anon_sym_GT_EQ] = ACTIONS(4735),
    [anon_sym_LT_EQ] = ACTIONS(4735),
    [anon_sym_LT] = ACTIONS(4737),
    [anon_sym_EQ_EQ] = ACTIONS(4735),
    [anon_sym_BANG_EQ] = ACTIONS(4735),
    [anon_sym_TILDE_EQ] = ACTIONS(4735),
    [anon_sym_AMP_TILDE] = ACTIONS(4737),
    [anon_sym_LT_LT] = ACTIONS(4737),
    [anon_sym_GT_GT] = ACTIONS(4737),
    [anon_sym_STAR] = ACTIONS(4737),
    [anon_sym_SLASH] = ACTIONS(4737),
    [anon_sym_PERCENT] = ACTIONS(4737),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4735),
    [anon_sym_DOT] = ACTIONS(4737),
    [anon_sym_LBRACK] = ACTIONS(4735),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4735),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4735),
    [anon_sym_not_in] = ACTIONS(4735),
    [anon_sym_or_return] = ACTIONS(4735),
    [anon_sym_or_continue] = ACTIONS(4735),
    [anon_sym_or_break] = ACTIONS(4735),
    [anon_sym_CARET] = ACTIONS(4737),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4735),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1716] = {
    [ts_builtin_sym_end] = ACTIONS(4751),
    [anon_sym_LBRACE] = ACTIONS(6384),
    [anon_sym_RBRACE] = ACTIONS(4751),
    [anon_sym_COMMA] = ACTIONS(4751),
    [anon_sym_COLON_COLON] = ACTIONS(4751),
    [anon_sym_DASH_GT] = ACTIONS(4751),
    [anon_sym_EQ] = ACTIONS(4753),
    [anon_sym_COLON] = ACTIONS(4753),
    [anon_sym_PIPE] = ACTIONS(4753),
    [anon_sym_COLON_EQ] = ACTIONS(4751),
    [anon_sym_LPAREN] = ACTIONS(6362),
    [anon_sym_PLUS_EQ] = ACTIONS(4751),
    [anon_sym_DASH_EQ] = ACTIONS(4751),
    [anon_sym_STAR_EQ] = ACTIONS(4751),
    [anon_sym_SLASH_EQ] = ACTIONS(4751),
    [anon_sym_PERCENT_EQ] = ACTIONS(4751),
    [anon_sym_AMP_EQ] = ACTIONS(4751),
    [anon_sym_PIPE_EQ] = ACTIONS(4751),
    [anon_sym_CARET_EQ] = ACTIONS(4751),
    [anon_sym_LT_LT_EQ] = ACTIONS(4751),
    [anon_sym_GT_GT_EQ] = ACTIONS(4751),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4751),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4751),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4751),
    [anon_sym_if] = ACTIONS(4751),
    [anon_sym_SEMI] = ACTIONS(4751),
    [anon_sym_else] = ACTIONS(4751),
    [anon_sym_when] = ACTIONS(4751),
    [anon_sym_in] = ACTIONS(4751),
    [anon_sym_case] = ACTIONS(4751),
    [anon_sym_QMARK] = ACTIONS(4751),
    [anon_sym_PLUS] = ACTIONS(4753),
    [anon_sym_DASH] = ACTIONS(4753),
    [anon_sym_TILDE] = ACTIONS(4753),
    [anon_sym_AMP] = ACTIONS(4753),
    [anon_sym_PIPE_PIPE] = ACTIONS(4753),
    [anon_sym_or_else] = ACTIONS(4751),
    [anon_sym_AMP_AMP] = ACTIONS(4753),
    [anon_sym_GT] = ACTIONS(4753),
    [anon_sym_GT_EQ] = ACTIONS(4751),
    [anon_sym_LT_EQ] = ACTIONS(4751),
    [anon_sym_LT] = ACTIONS(4753),
    [anon_sym_EQ_EQ] = ACTIONS(4751),
    [anon_sym_BANG_EQ] = ACTIONS(4751),
    [anon_sym_TILDE_EQ] = ACTIONS(4751),
    [anon_sym_AMP_TILDE] = ACTIONS(4753),
    [anon_sym_LT_LT] = ACTIONS(4753),
    [anon_sym_GT_GT] = ACTIONS(4753),
    [anon_sym_STAR] = ACTIONS(4753),
    [anon_sym_SLASH] = ACTIONS(6364),
    [anon_sym_PERCENT] = ACTIONS(4753),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4751),
    [anon_sym_DOT] = ACTIONS(4753),
    [anon_sym_LBRACK] = ACTIONS(4751),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4751),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4751),
    [anon_sym_not_in] = ACTIONS(4751),
    [anon_sym_or_return] = ACTIONS(4751),
    [anon_sym_or_continue] = ACTIONS(4751),
    [anon_sym_or_break] = ACTIONS(4751),
    [anon_sym_CARET] = ACTIONS(4753),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4751),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1717] = {
    [ts_builtin_sym_end] = ACTIONS(4839),
    [anon_sym_LBRACE] = ACTIONS(4839),
    [anon_sym_RBRACE] = ACTIONS(4839),
    [anon_sym_COMMA] = ACTIONS(4839),
    [anon_sym_COLON_COLON] = ACTIONS(4839),
    [anon_sym_DASH_GT] = ACTIONS(4839),
    [anon_sym_EQ] = ACTIONS(4841),
    [anon_sym_COLON] = ACTIONS(4841),
    [anon_sym_PIPE] = ACTIONS(4841),
    [anon_sym_COLON_EQ] = ACTIONS(4839),
    [anon_sym_LPAREN] = ACTIONS(4839),
    [anon_sym_PLUS_EQ] = ACTIONS(4839),
    [anon_sym_DASH_EQ] = ACTIONS(4839),
    [anon_sym_STAR_EQ] = ACTIONS(4839),
    [anon_sym_SLASH_EQ] = ACTIONS(4839),
    [anon_sym_PERCENT_EQ] = ACTIONS(4839),
    [anon_sym_AMP_EQ] = ACTIONS(4839),
    [anon_sym_PIPE_EQ] = ACTIONS(4839),
    [anon_sym_CARET_EQ] = ACTIONS(4839),
    [anon_sym_LT_LT_EQ] = ACTIONS(4839),
    [anon_sym_GT_GT_EQ] = ACTIONS(4839),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4839),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4839),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4839),
    [anon_sym_if] = ACTIONS(4839),
    [anon_sym_SEMI] = ACTIONS(4839),
    [anon_sym_else] = ACTIONS(4839),
    [anon_sym_when] = ACTIONS(4839),
    [anon_sym_in] = ACTIONS(4839),
    [anon_sym_case] = ACTIONS(4839),
    [anon_sym_QMARK] = ACTIONS(4839),
    [anon_sym_PLUS] = ACTIONS(4841),
    [anon_sym_DASH] = ACTIONS(4841),
    [anon_sym_TILDE] = ACTIONS(4841),
    [anon_sym_AMP] = ACTIONS(4841),
    [anon_sym_PIPE_PIPE] = ACTIONS(4841),
    [anon_sym_or_else] = ACTIONS(4839),
    [anon_sym_AMP_AMP] = ACTIONS(4841),
    [anon_sym_GT] = ACTIONS(4841),
    [anon_sym_GT_EQ] = ACTIONS(4839),
    [anon_sym_LT_EQ] = ACTIONS(4839),
    [anon_sym_LT] = ACTIONS(4841),
    [anon_sym_EQ_EQ] = ACTIONS(4839),
    [anon_sym_BANG_EQ] = ACTIONS(4839),
    [anon_sym_TILDE_EQ] = ACTIONS(4839),
    [anon_sym_AMP_TILDE] = ACTIONS(4841),
    [anon_sym_LT_LT] = ACTIONS(4841),
    [anon_sym_GT_GT] = ACTIONS(4841),
    [anon_sym_STAR] = ACTIONS(4841),
    [anon_sym_SLASH] = ACTIONS(4841),
    [anon_sym_PERCENT] = ACTIONS(4841),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4839),
    [anon_sym_DOT] = ACTIONS(4841),
    [anon_sym_LBRACK] = ACTIONS(4839),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4839),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4839),
    [anon_sym_not_in] = ACTIONS(4839),
    [anon_sym_or_return] = ACTIONS(4839),
    [anon_sym_or_continue] = ACTIONS(4839),
    [anon_sym_or_break] = ACTIONS(4839),
    [anon_sym_CARET] = ACTIONS(4841),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4839),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1718] = {
    [sym_expression] = STATE(4968),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1719] = {
    [ts_builtin_sym_end] = ACTIONS(4739),
    [anon_sym_LBRACE] = ACTIONS(4739),
    [anon_sym_RBRACE] = ACTIONS(4739),
    [anon_sym_COMMA] = ACTIONS(4739),
    [anon_sym_COLON_COLON] = ACTIONS(4739),
    [anon_sym_DASH_GT] = ACTIONS(4739),
    [anon_sym_EQ] = ACTIONS(4741),
    [anon_sym_COLON] = ACTIONS(4741),
    [anon_sym_PIPE] = ACTIONS(4741),
    [anon_sym_COLON_EQ] = ACTIONS(4739),
    [anon_sym_LPAREN] = ACTIONS(4739),
    [anon_sym_PLUS_EQ] = ACTIONS(4739),
    [anon_sym_DASH_EQ] = ACTIONS(4739),
    [anon_sym_STAR_EQ] = ACTIONS(4739),
    [anon_sym_SLASH_EQ] = ACTIONS(4739),
    [anon_sym_PERCENT_EQ] = ACTIONS(4739),
    [anon_sym_AMP_EQ] = ACTIONS(4739),
    [anon_sym_PIPE_EQ] = ACTIONS(4739),
    [anon_sym_CARET_EQ] = ACTIONS(4739),
    [anon_sym_LT_LT_EQ] = ACTIONS(4739),
    [anon_sym_GT_GT_EQ] = ACTIONS(4739),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4739),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4739),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4739),
    [anon_sym_if] = ACTIONS(4739),
    [anon_sym_SEMI] = ACTIONS(4739),
    [anon_sym_else] = ACTIONS(4739),
    [anon_sym_when] = ACTIONS(4739),
    [anon_sym_in] = ACTIONS(4739),
    [anon_sym_case] = ACTIONS(4739),
    [anon_sym_QMARK] = ACTIONS(4739),
    [anon_sym_PLUS] = ACTIONS(4741),
    [anon_sym_DASH] = ACTIONS(4741),
    [anon_sym_TILDE] = ACTIONS(4741),
    [anon_sym_AMP] = ACTIONS(4741),
    [anon_sym_PIPE_PIPE] = ACTIONS(4741),
    [anon_sym_or_else] = ACTIONS(4739),
    [anon_sym_AMP_AMP] = ACTIONS(4741),
    [anon_sym_GT] = ACTIONS(4741),
    [anon_sym_GT_EQ] = ACTIONS(4739),
    [anon_sym_LT_EQ] = ACTIONS(4739),
    [anon_sym_LT] = ACTIONS(4741),
    [anon_sym_EQ_EQ] = ACTIONS(4739),
    [anon_sym_BANG_EQ] = ACTIONS(4739),
    [anon_sym_TILDE_EQ] = ACTIONS(4739),
    [anon_sym_AMP_TILDE] = ACTIONS(4741),
    [anon_sym_LT_LT] = ACTIONS(4741),
    [anon_sym_GT_GT] = ACTIONS(4741),
    [anon_sym_STAR] = ACTIONS(4741),
    [anon_sym_SLASH] = ACTIONS(4741),
    [anon_sym_PERCENT] = ACTIONS(4741),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4739),
    [anon_sym_DOT] = ACTIONS(4741),
    [anon_sym_LBRACK] = ACTIONS(4739),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4739),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4739),
    [anon_sym_not_in] = ACTIONS(4739),
    [anon_sym_or_return] = ACTIONS(4739),
    [anon_sym_or_continue] = ACTIONS(4739),
    [anon_sym_or_break] = ACTIONS(4739),
    [anon_sym_CARET] = ACTIONS(4741),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4739),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1720] = {
    [sym_expression] = STATE(6599),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1721] = {
    [sym_expression] = STATE(6236),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1722] = {
    [ts_builtin_sym_end] = ACTIONS(4743),
    [anon_sym_LBRACE] = ACTIONS(4743),
    [anon_sym_RBRACE] = ACTIONS(4743),
    [anon_sym_COMMA] = ACTIONS(4743),
    [anon_sym_COLON_COLON] = ACTIONS(4743),
    [anon_sym_DASH_GT] = ACTIONS(4743),
    [anon_sym_EQ] = ACTIONS(4745),
    [anon_sym_COLON] = ACTIONS(4745),
    [anon_sym_PIPE] = ACTIONS(4745),
    [anon_sym_COLON_EQ] = ACTIONS(4743),
    [anon_sym_LPAREN] = ACTIONS(4743),
    [anon_sym_PLUS_EQ] = ACTIONS(4743),
    [anon_sym_DASH_EQ] = ACTIONS(4743),
    [anon_sym_STAR_EQ] = ACTIONS(4743),
    [anon_sym_SLASH_EQ] = ACTIONS(4743),
    [anon_sym_PERCENT_EQ] = ACTIONS(4743),
    [anon_sym_AMP_EQ] = ACTIONS(4743),
    [anon_sym_PIPE_EQ] = ACTIONS(4743),
    [anon_sym_CARET_EQ] = ACTIONS(4743),
    [anon_sym_LT_LT_EQ] = ACTIONS(4743),
    [anon_sym_GT_GT_EQ] = ACTIONS(4743),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4743),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4743),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4743),
    [anon_sym_if] = ACTIONS(4743),
    [anon_sym_SEMI] = ACTIONS(4743),
    [anon_sym_else] = ACTIONS(4743),
    [anon_sym_when] = ACTIONS(4743),
    [anon_sym_in] = ACTIONS(4743),
    [anon_sym_case] = ACTIONS(4743),
    [anon_sym_QMARK] = ACTIONS(4743),
    [anon_sym_PLUS] = ACTIONS(4745),
    [anon_sym_DASH] = ACTIONS(4745),
    [anon_sym_TILDE] = ACTIONS(4745),
    [anon_sym_AMP] = ACTIONS(4745),
    [anon_sym_PIPE_PIPE] = ACTIONS(4745),
    [anon_sym_or_else] = ACTIONS(4743),
    [anon_sym_AMP_AMP] = ACTIONS(4745),
    [anon_sym_GT] = ACTIONS(4745),
    [anon_sym_GT_EQ] = ACTIONS(4743),
    [anon_sym_LT_EQ] = ACTIONS(4743),
    [anon_sym_LT] = ACTIONS(4745),
    [anon_sym_EQ_EQ] = ACTIONS(4743),
    [anon_sym_BANG_EQ] = ACTIONS(4743),
    [anon_sym_TILDE_EQ] = ACTIONS(4743),
    [anon_sym_AMP_TILDE] = ACTIONS(4745),
    [anon_sym_LT_LT] = ACTIONS(4745),
    [anon_sym_GT_GT] = ACTIONS(4745),
    [anon_sym_STAR] = ACTIONS(4745),
    [anon_sym_SLASH] = ACTIONS(4745),
    [anon_sym_PERCENT] = ACTIONS(4745),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4743),
    [anon_sym_DOT] = ACTIONS(4745),
    [anon_sym_LBRACK] = ACTIONS(4743),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4743),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4743),
    [anon_sym_not_in] = ACTIONS(4743),
    [anon_sym_or_return] = ACTIONS(4743),
    [anon_sym_or_continue] = ACTIONS(4743),
    [anon_sym_or_break] = ACTIONS(4743),
    [anon_sym_CARET] = ACTIONS(4745),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4743),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1723] = {
    [ts_builtin_sym_end] = ACTIONS(4759),
    [anon_sym_LBRACE] = ACTIONS(4759),
    [anon_sym_RBRACE] = ACTIONS(4759),
    [anon_sym_COMMA] = ACTIONS(4759),
    [anon_sym_COLON_COLON] = ACTIONS(4759),
    [anon_sym_DASH_GT] = ACTIONS(4759),
    [anon_sym_EQ] = ACTIONS(4761),
    [anon_sym_COLON] = ACTIONS(4761),
    [anon_sym_PIPE] = ACTIONS(4761),
    [anon_sym_COLON_EQ] = ACTIONS(4759),
    [anon_sym_LPAREN] = ACTIONS(4759),
    [anon_sym_PLUS_EQ] = ACTIONS(4759),
    [anon_sym_DASH_EQ] = ACTIONS(4759),
    [anon_sym_STAR_EQ] = ACTIONS(4759),
    [anon_sym_SLASH_EQ] = ACTIONS(4759),
    [anon_sym_PERCENT_EQ] = ACTIONS(4759),
    [anon_sym_AMP_EQ] = ACTIONS(4759),
    [anon_sym_PIPE_EQ] = ACTIONS(4759),
    [anon_sym_CARET_EQ] = ACTIONS(4759),
    [anon_sym_LT_LT_EQ] = ACTIONS(4759),
    [anon_sym_GT_GT_EQ] = ACTIONS(4759),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4759),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4759),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4759),
    [anon_sym_if] = ACTIONS(4759),
    [anon_sym_SEMI] = ACTIONS(4759),
    [anon_sym_else] = ACTIONS(4759),
    [anon_sym_when] = ACTIONS(4759),
    [anon_sym_in] = ACTIONS(4759),
    [anon_sym_case] = ACTIONS(4759),
    [anon_sym_QMARK] = ACTIONS(4759),
    [anon_sym_PLUS] = ACTIONS(4761),
    [anon_sym_DASH] = ACTIONS(4761),
    [anon_sym_TILDE] = ACTIONS(4761),
    [anon_sym_AMP] = ACTIONS(4761),
    [anon_sym_PIPE_PIPE] = ACTIONS(4761),
    [anon_sym_or_else] = ACTIONS(4759),
    [anon_sym_AMP_AMP] = ACTIONS(4761),
    [anon_sym_GT] = ACTIONS(4761),
    [anon_sym_GT_EQ] = ACTIONS(4759),
    [anon_sym_LT_EQ] = ACTIONS(4759),
    [anon_sym_LT] = ACTIONS(4761),
    [anon_sym_EQ_EQ] = ACTIONS(4759),
    [anon_sym_BANG_EQ] = ACTIONS(4759),
    [anon_sym_TILDE_EQ] = ACTIONS(4759),
    [anon_sym_AMP_TILDE] = ACTIONS(4761),
    [anon_sym_LT_LT] = ACTIONS(4761),
    [anon_sym_GT_GT] = ACTIONS(4761),
    [anon_sym_STAR] = ACTIONS(4761),
    [anon_sym_SLASH] = ACTIONS(4761),
    [anon_sym_PERCENT] = ACTIONS(4761),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4759),
    [anon_sym_DOT] = ACTIONS(4761),
    [anon_sym_LBRACK] = ACTIONS(4759),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4759),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4759),
    [anon_sym_not_in] = ACTIONS(4759),
    [anon_sym_or_return] = ACTIONS(4759),
    [anon_sym_or_continue] = ACTIONS(4759),
    [anon_sym_or_break] = ACTIONS(4759),
    [anon_sym_CARET] = ACTIONS(4761),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4759),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1724] = {
    [sym_expression] = STATE(5912),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6302),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1725] = {
    [sym_expression] = STATE(6040),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1726] = {
    [aux_sym_where_clause_repeat1] = STATE(1726),
    [anon_sym_LBRACE] = ACTIONS(4466),
    [anon_sym_COMMA] = ACTIONS(6386),
    [anon_sym_COLON_COLON] = ACTIONS(4466),
    [anon_sym_DASH_GT] = ACTIONS(4466),
    [anon_sym_where] = ACTIONS(4466),
    [anon_sym_EQ] = ACTIONS(4471),
    [anon_sym_COLON] = ACTIONS(4471),
    [anon_sym_PIPE] = ACTIONS(4471),
    [anon_sym_COLON_EQ] = ACTIONS(4466),
    [anon_sym_LPAREN] = ACTIONS(4466),
    [anon_sym_PLUS_EQ] = ACTIONS(4466),
    [anon_sym_DASH_EQ] = ACTIONS(4466),
    [anon_sym_STAR_EQ] = ACTIONS(4466),
    [anon_sym_SLASH_EQ] = ACTIONS(4466),
    [anon_sym_PERCENT_EQ] = ACTIONS(4466),
    [anon_sym_AMP_EQ] = ACTIONS(4466),
    [anon_sym_PIPE_EQ] = ACTIONS(4466),
    [anon_sym_CARET_EQ] = ACTIONS(4466),
    [anon_sym_LT_LT_EQ] = ACTIONS(4466),
    [anon_sym_GT_GT_EQ] = ACTIONS(4466),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4466),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4466),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4466),
    [anon_sym_if] = ACTIONS(4466),
    [anon_sym_SEMI] = ACTIONS(4466),
    [anon_sym_do] = ACTIONS(4466),
    [anon_sym_when] = ACTIONS(4466),
    [anon_sym_in] = ACTIONS(4466),
    [anon_sym_QMARK] = ACTIONS(4466),
    [anon_sym_PLUS] = ACTIONS(4471),
    [anon_sym_DASH] = ACTIONS(4471),
    [anon_sym_TILDE] = ACTIONS(4471),
    [anon_sym_AMP] = ACTIONS(4471),
    [anon_sym_PIPE_PIPE] = ACTIONS(4471),
    [anon_sym_or_else] = ACTIONS(4466),
    [anon_sym_AMP_AMP] = ACTIONS(4471),
    [anon_sym_GT] = ACTIONS(4471),
    [anon_sym_GT_EQ] = ACTIONS(4466),
    [anon_sym_LT_EQ] = ACTIONS(4466),
    [anon_sym_LT] = ACTIONS(4471),
    [anon_sym_EQ_EQ] = ACTIONS(4466),
    [anon_sym_BANG_EQ] = ACTIONS(4466),
    [anon_sym_TILDE_EQ] = ACTIONS(4466),
    [anon_sym_AMP_TILDE] = ACTIONS(4471),
    [anon_sym_LT_LT] = ACTIONS(4471),
    [anon_sym_GT_GT] = ACTIONS(4471),
    [anon_sym_STAR] = ACTIONS(4471),
    [anon_sym_SLASH] = ACTIONS(4471),
    [anon_sym_PERCENT] = ACTIONS(4471),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4466),
    [anon_sym_DOT] = ACTIONS(4471),
    [anon_sym_LBRACK] = ACTIONS(4466),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4466),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4466),
    [anon_sym_not_in] = ACTIONS(4466),
    [anon_sym_or_return] = ACTIONS(4466),
    [anon_sym_or_continue] = ACTIONS(4466),
    [anon_sym_or_break] = ACTIONS(4466),
    [anon_sym_CARET] = ACTIONS(4471),
    [sym_uninitialized] = ACTIONS(4466),
    [sym_tag] = ACTIONS(4466),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1727] = {
    [ts_builtin_sym_end] = ACTIONS(4787),
    [anon_sym_LBRACE] = ACTIONS(4787),
    [anon_sym_RBRACE] = ACTIONS(4787),
    [anon_sym_COMMA] = ACTIONS(4787),
    [anon_sym_COLON_COLON] = ACTIONS(4787),
    [anon_sym_DASH_GT] = ACTIONS(4787),
    [anon_sym_EQ] = ACTIONS(4789),
    [anon_sym_COLON] = ACTIONS(4789),
    [anon_sym_PIPE] = ACTIONS(4789),
    [anon_sym_COLON_EQ] = ACTIONS(4787),
    [anon_sym_LPAREN] = ACTIONS(4787),
    [anon_sym_PLUS_EQ] = ACTIONS(4787),
    [anon_sym_DASH_EQ] = ACTIONS(4787),
    [anon_sym_STAR_EQ] = ACTIONS(4787),
    [anon_sym_SLASH_EQ] = ACTIONS(4787),
    [anon_sym_PERCENT_EQ] = ACTIONS(4787),
    [anon_sym_AMP_EQ] = ACTIONS(4787),
    [anon_sym_PIPE_EQ] = ACTIONS(4787),
    [anon_sym_CARET_EQ] = ACTIONS(4787),
    [anon_sym_LT_LT_EQ] = ACTIONS(4787),
    [anon_sym_GT_GT_EQ] = ACTIONS(4787),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4787),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4787),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4787),
    [anon_sym_if] = ACTIONS(4787),
    [anon_sym_SEMI] = ACTIONS(4787),
    [anon_sym_else] = ACTIONS(4787),
    [anon_sym_when] = ACTIONS(4787),
    [anon_sym_in] = ACTIONS(4787),
    [anon_sym_case] = ACTIONS(4787),
    [anon_sym_QMARK] = ACTIONS(4787),
    [anon_sym_PLUS] = ACTIONS(4789),
    [anon_sym_DASH] = ACTIONS(4789),
    [anon_sym_TILDE] = ACTIONS(4789),
    [anon_sym_AMP] = ACTIONS(4789),
    [anon_sym_PIPE_PIPE] = ACTIONS(4789),
    [anon_sym_or_else] = ACTIONS(4787),
    [anon_sym_AMP_AMP] = ACTIONS(4789),
    [anon_sym_GT] = ACTIONS(4789),
    [anon_sym_GT_EQ] = ACTIONS(4787),
    [anon_sym_LT_EQ] = ACTIONS(4787),
    [anon_sym_LT] = ACTIONS(4789),
    [anon_sym_EQ_EQ] = ACTIONS(4787),
    [anon_sym_BANG_EQ] = ACTIONS(4787),
    [anon_sym_TILDE_EQ] = ACTIONS(4787),
    [anon_sym_AMP_TILDE] = ACTIONS(4789),
    [anon_sym_LT_LT] = ACTIONS(4789),
    [anon_sym_GT_GT] = ACTIONS(4789),
    [anon_sym_STAR] = ACTIONS(4789),
    [anon_sym_SLASH] = ACTIONS(4789),
    [anon_sym_PERCENT] = ACTIONS(4789),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4787),
    [anon_sym_DOT] = ACTIONS(4789),
    [anon_sym_LBRACK] = ACTIONS(4787),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4787),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4787),
    [anon_sym_not_in] = ACTIONS(4787),
    [anon_sym_or_return] = ACTIONS(4787),
    [anon_sym_or_continue] = ACTIONS(4787),
    [anon_sym_or_break] = ACTIONS(4787),
    [anon_sym_CARET] = ACTIONS(4789),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4787),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1728] = {
    [sym_expression] = STATE(6113),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1729] = {
    [sym_expression] = STATE(6554),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1730] = {
    [sym_expression] = STATE(6106),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1731] = {
    [sym_expression] = STATE(5969),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1732] = {
    [sym_expression] = STATE(6052),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1733] = {
    [sym_expression] = STATE(6103),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1734] = {
    [sym_expression] = STATE(6126),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1735] = {
    [ts_builtin_sym_end] = ACTIONS(4795),
    [anon_sym_LBRACE] = ACTIONS(4795),
    [anon_sym_RBRACE] = ACTIONS(4795),
    [anon_sym_COMMA] = ACTIONS(4795),
    [anon_sym_COLON_COLON] = ACTIONS(4795),
    [anon_sym_DASH_GT] = ACTIONS(4795),
    [anon_sym_EQ] = ACTIONS(4797),
    [anon_sym_COLON] = ACTIONS(4797),
    [anon_sym_PIPE] = ACTIONS(4797),
    [anon_sym_COLON_EQ] = ACTIONS(4795),
    [anon_sym_LPAREN] = ACTIONS(4795),
    [anon_sym_PLUS_EQ] = ACTIONS(4795),
    [anon_sym_DASH_EQ] = ACTIONS(4795),
    [anon_sym_STAR_EQ] = ACTIONS(4795),
    [anon_sym_SLASH_EQ] = ACTIONS(4795),
    [anon_sym_PERCENT_EQ] = ACTIONS(4795),
    [anon_sym_AMP_EQ] = ACTIONS(4795),
    [anon_sym_PIPE_EQ] = ACTIONS(4795),
    [anon_sym_CARET_EQ] = ACTIONS(4795),
    [anon_sym_LT_LT_EQ] = ACTIONS(4795),
    [anon_sym_GT_GT_EQ] = ACTIONS(4795),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4795),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4795),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4795),
    [anon_sym_if] = ACTIONS(4795),
    [anon_sym_SEMI] = ACTIONS(4795),
    [anon_sym_else] = ACTIONS(4795),
    [anon_sym_when] = ACTIONS(4795),
    [anon_sym_in] = ACTIONS(4795),
    [anon_sym_case] = ACTIONS(4795),
    [anon_sym_QMARK] = ACTIONS(4795),
    [anon_sym_PLUS] = ACTIONS(4797),
    [anon_sym_DASH] = ACTIONS(4797),
    [anon_sym_TILDE] = ACTIONS(4797),
    [anon_sym_AMP] = ACTIONS(4797),
    [anon_sym_PIPE_PIPE] = ACTIONS(4797),
    [anon_sym_or_else] = ACTIONS(4795),
    [anon_sym_AMP_AMP] = ACTIONS(4797),
    [anon_sym_GT] = ACTIONS(4797),
    [anon_sym_GT_EQ] = ACTIONS(4795),
    [anon_sym_LT_EQ] = ACTIONS(4795),
    [anon_sym_LT] = ACTIONS(4797),
    [anon_sym_EQ_EQ] = ACTIONS(4795),
    [anon_sym_BANG_EQ] = ACTIONS(4795),
    [anon_sym_TILDE_EQ] = ACTIONS(4795),
    [anon_sym_AMP_TILDE] = ACTIONS(4797),
    [anon_sym_LT_LT] = ACTIONS(4797),
    [anon_sym_GT_GT] = ACTIONS(4797),
    [anon_sym_STAR] = ACTIONS(4797),
    [anon_sym_SLASH] = ACTIONS(4797),
    [anon_sym_PERCENT] = ACTIONS(4797),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4795),
    [anon_sym_DOT] = ACTIONS(4797),
    [anon_sym_LBRACK] = ACTIONS(4795),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4795),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4795),
    [anon_sym_not_in] = ACTIONS(4795),
    [anon_sym_or_return] = ACTIONS(4795),
    [anon_sym_or_continue] = ACTIONS(4795),
    [anon_sym_or_break] = ACTIONS(4795),
    [anon_sym_CARET] = ACTIONS(4797),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4795),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1736] = {
    [sym_expression] = STATE(6556),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1737] = {
    [sym_expression] = STATE(6559),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1738] = {
    [sym_expression] = STATE(2848),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1739] = {
    [sym_expression] = STATE(2804),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1740] = {
    [sym_expression] = STATE(2850),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1741] = {
    [sym_expression] = STATE(2851),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1742] = {
    [sym_expression] = STATE(6075),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1743] = {
    [sym_expression] = STATE(6535),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1744] = {
    [sym_expression] = STATE(6097),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1745] = {
    [sym_expression] = STATE(6098),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1746] = {
    [sym_expression] = STATE(6119),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1747] = {
    [sym_expression] = STATE(6132),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1748] = {
    [sym_expression] = STATE(6143),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1749] = {
    [ts_builtin_sym_end] = ACTIONS(4803),
    [anon_sym_LBRACE] = ACTIONS(4803),
    [anon_sym_RBRACE] = ACTIONS(4803),
    [anon_sym_COMMA] = ACTIONS(4803),
    [anon_sym_COLON_COLON] = ACTIONS(4803),
    [anon_sym_DASH_GT] = ACTIONS(4803),
    [anon_sym_EQ] = ACTIONS(4805),
    [anon_sym_COLON] = ACTIONS(4805),
    [anon_sym_PIPE] = ACTIONS(4805),
    [anon_sym_COLON_EQ] = ACTIONS(4803),
    [anon_sym_LPAREN] = ACTIONS(4803),
    [anon_sym_PLUS_EQ] = ACTIONS(4803),
    [anon_sym_DASH_EQ] = ACTIONS(4803),
    [anon_sym_STAR_EQ] = ACTIONS(4803),
    [anon_sym_SLASH_EQ] = ACTIONS(4803),
    [anon_sym_PERCENT_EQ] = ACTIONS(4803),
    [anon_sym_AMP_EQ] = ACTIONS(4803),
    [anon_sym_PIPE_EQ] = ACTIONS(4803),
    [anon_sym_CARET_EQ] = ACTIONS(4803),
    [anon_sym_LT_LT_EQ] = ACTIONS(4803),
    [anon_sym_GT_GT_EQ] = ACTIONS(4803),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4803),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4803),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4803),
    [anon_sym_if] = ACTIONS(4803),
    [anon_sym_SEMI] = ACTIONS(4803),
    [anon_sym_else] = ACTIONS(4803),
    [anon_sym_when] = ACTIONS(4803),
    [anon_sym_in] = ACTIONS(4803),
    [anon_sym_case] = ACTIONS(4803),
    [anon_sym_QMARK] = ACTIONS(4803),
    [anon_sym_PLUS] = ACTIONS(4805),
    [anon_sym_DASH] = ACTIONS(4805),
    [anon_sym_TILDE] = ACTIONS(4805),
    [anon_sym_AMP] = ACTIONS(4805),
    [anon_sym_PIPE_PIPE] = ACTIONS(4805),
    [anon_sym_or_else] = ACTIONS(4803),
    [anon_sym_AMP_AMP] = ACTIONS(4805),
    [anon_sym_GT] = ACTIONS(4805),
    [anon_sym_GT_EQ] = ACTIONS(4803),
    [anon_sym_LT_EQ] = ACTIONS(4803),
    [anon_sym_LT] = ACTIONS(4805),
    [anon_sym_EQ_EQ] = ACTIONS(4803),
    [anon_sym_BANG_EQ] = ACTIONS(4803),
    [anon_sym_TILDE_EQ] = ACTIONS(4803),
    [anon_sym_AMP_TILDE] = ACTIONS(4805),
    [anon_sym_LT_LT] = ACTIONS(4805),
    [anon_sym_GT_GT] = ACTIONS(4805),
    [anon_sym_STAR] = ACTIONS(4805),
    [anon_sym_SLASH] = ACTIONS(4805),
    [anon_sym_PERCENT] = ACTIONS(4805),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4803),
    [anon_sym_DOT] = ACTIONS(4805),
    [anon_sym_LBRACK] = ACTIONS(4803),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4803),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4803),
    [anon_sym_not_in] = ACTIONS(4803),
    [anon_sym_or_return] = ACTIONS(4803),
    [anon_sym_or_continue] = ACTIONS(4803),
    [anon_sym_or_break] = ACTIONS(4803),
    [anon_sym_CARET] = ACTIONS(4805),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4803),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1750] = {
    [sym_expression] = STATE(6600),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1751] = {
    [sym_expression] = STATE(6601),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1752] = {
    [sym_expression] = STATE(2955),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1753] = {
    [sym_expression] = STATE(2886),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1754] = {
    [sym_expression] = STATE(2888),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1755] = {
    [sym_expression] = STATE(2889),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1756] = {
    [sym_expression] = STATE(2890),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1757] = {
    [sym_expression] = STATE(2891),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1758] = {
    [sym_expression] = STATE(6120),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1759] = {
    [sym_expression] = STATE(6223),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1760] = {
    [sym_expression] = STATE(6142),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1761] = {
    [sym_expression] = STATE(6049),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1762] = {
    [sym_expression] = STATE(5970),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1763] = {
    [sym_expression] = STATE(5975),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1764] = {
    [sym_expression] = STATE(5977),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1765] = {
    [sym_expression] = STATE(5982),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1766] = {
    [sym_expression] = STATE(6421),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1767] = {
    [sym_expression] = STATE(6422),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1768] = {
    [sym_expression] = STATE(2892),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1769] = {
    [sym_expression] = STATE(2893),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1770] = {
    [sym_expression] = STATE(2894),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1771] = {
    [sym_expression] = STATE(2895),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1772] = {
    [sym_expression] = STATE(2896),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1773] = {
    [sym_expression] = STATE(2897),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1774] = {
    [sym_expression] = STATE(6029),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1775] = {
    [sym_expression] = STATE(6466),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1776] = {
    [sym_expression] = STATE(5967),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1777] = {
    [sym_expression] = STATE(6048),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1778] = {
    [sym_expression] = STATE(6062),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1779] = {
    [sym_expression] = STATE(6070),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1780] = {
    [sym_expression] = STATE(6074),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1781] = {
    [ts_builtin_sym_end] = ACTIONS(4807),
    [anon_sym_LBRACE] = ACTIONS(4807),
    [anon_sym_RBRACE] = ACTIONS(4807),
    [anon_sym_COMMA] = ACTIONS(4807),
    [anon_sym_COLON_COLON] = ACTIONS(4807),
    [anon_sym_DASH_GT] = ACTIONS(4807),
    [anon_sym_EQ] = ACTIONS(4809),
    [anon_sym_COLON] = ACTIONS(4809),
    [anon_sym_PIPE] = ACTIONS(4809),
    [anon_sym_COLON_EQ] = ACTIONS(4807),
    [anon_sym_LPAREN] = ACTIONS(4807),
    [anon_sym_PLUS_EQ] = ACTIONS(4807),
    [anon_sym_DASH_EQ] = ACTIONS(4807),
    [anon_sym_STAR_EQ] = ACTIONS(4807),
    [anon_sym_SLASH_EQ] = ACTIONS(4807),
    [anon_sym_PERCENT_EQ] = ACTIONS(4807),
    [anon_sym_AMP_EQ] = ACTIONS(4807),
    [anon_sym_PIPE_EQ] = ACTIONS(4807),
    [anon_sym_CARET_EQ] = ACTIONS(4807),
    [anon_sym_LT_LT_EQ] = ACTIONS(4807),
    [anon_sym_GT_GT_EQ] = ACTIONS(4807),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4807),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4807),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4807),
    [anon_sym_if] = ACTIONS(4807),
    [anon_sym_SEMI] = ACTIONS(4807),
    [anon_sym_else] = ACTIONS(4807),
    [anon_sym_when] = ACTIONS(4807),
    [anon_sym_in] = ACTIONS(4807),
    [anon_sym_case] = ACTIONS(4807),
    [anon_sym_QMARK] = ACTIONS(4807),
    [anon_sym_PLUS] = ACTIONS(4809),
    [anon_sym_DASH] = ACTIONS(4809),
    [anon_sym_TILDE] = ACTIONS(4809),
    [anon_sym_AMP] = ACTIONS(4809),
    [anon_sym_PIPE_PIPE] = ACTIONS(4809),
    [anon_sym_or_else] = ACTIONS(4807),
    [anon_sym_AMP_AMP] = ACTIONS(4809),
    [anon_sym_GT] = ACTIONS(4809),
    [anon_sym_GT_EQ] = ACTIONS(4807),
    [anon_sym_LT_EQ] = ACTIONS(4807),
    [anon_sym_LT] = ACTIONS(4809),
    [anon_sym_EQ_EQ] = ACTIONS(4807),
    [anon_sym_BANG_EQ] = ACTIONS(4807),
    [anon_sym_TILDE_EQ] = ACTIONS(4807),
    [anon_sym_AMP_TILDE] = ACTIONS(4809),
    [anon_sym_LT_LT] = ACTIONS(4809),
    [anon_sym_GT_GT] = ACTIONS(4809),
    [anon_sym_STAR] = ACTIONS(4809),
    [anon_sym_SLASH] = ACTIONS(4809),
    [anon_sym_PERCENT] = ACTIONS(4809),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4807),
    [anon_sym_DOT] = ACTIONS(4809),
    [anon_sym_LBRACK] = ACTIONS(4807),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4807),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4807),
    [anon_sym_not_in] = ACTIONS(4807),
    [anon_sym_or_return] = ACTIONS(4807),
    [anon_sym_or_continue] = ACTIONS(4807),
    [anon_sym_or_break] = ACTIONS(4807),
    [anon_sym_CARET] = ACTIONS(4809),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4807),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1782] = {
    [sym_expression] = STATE(6568),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1783] = {
    [sym_expression] = STATE(6570),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1784] = {
    [sym_expression] = STATE(2898),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1785] = {
    [sym_expression] = STATE(2899),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1786] = {
    [ts_builtin_sym_end] = ACTIONS(4811),
    [anon_sym_LBRACE] = ACTIONS(4811),
    [anon_sym_RBRACE] = ACTIONS(4811),
    [anon_sym_COMMA] = ACTIONS(4811),
    [anon_sym_COLON_COLON] = ACTIONS(4811),
    [anon_sym_DASH_GT] = ACTIONS(4811),
    [anon_sym_EQ] = ACTIONS(4813),
    [anon_sym_COLON] = ACTIONS(4813),
    [anon_sym_PIPE] = ACTIONS(4813),
    [anon_sym_COLON_EQ] = ACTIONS(4811),
    [anon_sym_LPAREN] = ACTIONS(4811),
    [anon_sym_PLUS_EQ] = ACTIONS(4811),
    [anon_sym_DASH_EQ] = ACTIONS(4811),
    [anon_sym_STAR_EQ] = ACTIONS(4811),
    [anon_sym_SLASH_EQ] = ACTIONS(4811),
    [anon_sym_PERCENT_EQ] = ACTIONS(4811),
    [anon_sym_AMP_EQ] = ACTIONS(4811),
    [anon_sym_PIPE_EQ] = ACTIONS(4811),
    [anon_sym_CARET_EQ] = ACTIONS(4811),
    [anon_sym_LT_LT_EQ] = ACTIONS(4811),
    [anon_sym_GT_GT_EQ] = ACTIONS(4811),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4811),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4811),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4811),
    [anon_sym_if] = ACTIONS(4811),
    [anon_sym_SEMI] = ACTIONS(4811),
    [anon_sym_else] = ACTIONS(4811),
    [anon_sym_when] = ACTIONS(4811),
    [anon_sym_in] = ACTIONS(4811),
    [anon_sym_case] = ACTIONS(4811),
    [anon_sym_QMARK] = ACTIONS(4811),
    [anon_sym_PLUS] = ACTIONS(4813),
    [anon_sym_DASH] = ACTIONS(4813),
    [anon_sym_TILDE] = ACTIONS(4813),
    [anon_sym_AMP] = ACTIONS(4813),
    [anon_sym_PIPE_PIPE] = ACTIONS(4813),
    [anon_sym_or_else] = ACTIONS(4811),
    [anon_sym_AMP_AMP] = ACTIONS(4813),
    [anon_sym_GT] = ACTIONS(4813),
    [anon_sym_GT_EQ] = ACTIONS(4811),
    [anon_sym_LT_EQ] = ACTIONS(4811),
    [anon_sym_LT] = ACTIONS(4813),
    [anon_sym_EQ_EQ] = ACTIONS(4811),
    [anon_sym_BANG_EQ] = ACTIONS(4811),
    [anon_sym_TILDE_EQ] = ACTIONS(4811),
    [anon_sym_AMP_TILDE] = ACTIONS(4813),
    [anon_sym_LT_LT] = ACTIONS(4813),
    [anon_sym_GT_GT] = ACTIONS(4813),
    [anon_sym_STAR] = ACTIONS(4813),
    [anon_sym_SLASH] = ACTIONS(4813),
    [anon_sym_PERCENT] = ACTIONS(4813),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4811),
    [anon_sym_DOT] = ACTIONS(4813),
    [anon_sym_LBRACK] = ACTIONS(4811),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4811),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4811),
    [anon_sym_not_in] = ACTIONS(4811),
    [anon_sym_or_return] = ACTIONS(4811),
    [anon_sym_or_continue] = ACTIONS(4811),
    [anon_sym_or_break] = ACTIONS(4811),
    [anon_sym_CARET] = ACTIONS(4813),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4811),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1787] = {
    [sym_expression] = STATE(4201),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1788] = {
    [sym_expression] = STATE(2910),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1789] = {
    [sym_expression] = STATE(2917),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1790] = {
    [sym_expression] = STATE(6071),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1791] = {
    [sym_expression] = STATE(6530),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1792] = {
    [sym_expression] = STATE(6083),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1793] = {
    [sym_expression] = STATE(5988),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1794] = {
    [sym_expression] = STATE(6096),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1795] = {
    [sym_expression] = STATE(6060),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1796] = {
    [sym_expression] = STATE(6085),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1797] = {
    [sym_expression] = STATE(6201),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1798] = {
    [sym_expression] = STATE(6379),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1799] = {
    [sym_expression] = STATE(6610),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1800] = {
    [sym_expression] = STATE(2918),
    [sym__expression_no_tag] = STATE(2954),
    [sym_unary_expression] = STATE(2954),
    [sym_binary_expression] = STATE(2954),
    [sym_ternary_expression] = STATE(2954),
    [sym_call_expression] = STATE(2954),
    [sym_selector_call_expression] = STATE(2954),
    [sym_member_expression] = STATE(2954),
    [sym_index_expression] = STATE(2954),
    [sym_slice_expression] = STATE(2954),
    [sym_range_expression] = STATE(2954),
    [sym_cast_expression] = STATE(2954),
    [sym_in_expression] = STATE(2954),
    [sym_variadic_expression] = STATE(2954),
    [sym_parenthesized_expression] = STATE(2954),
    [sym_or_return_expression] = STATE(2954),
    [sym_or_continue_expression] = STATE(2954),
    [sym_or_break_expression] = STATE(2954),
    [sym_address] = STATE(2954),
    [sym_map_type] = STATE(2954),
    [sym_matrix_type] = STATE(2954),
    [sym_distinct_type] = STATE(2954),
    [sym_literal] = STATE(2954),
    [sym_struct] = STATE(2844),
    [sym_map] = STATE(2836),
    [sym_bit_set] = STATE(2836),
    [sym_matrix] = STATE(2836),
    [sym_string] = STATE(2836),
    [sym__string_literal] = STATE(2845),
    [sym__raw_string_literal] = STATE(2845),
    [sym_character] = STATE(2836),
    [sym_boolean] = STATE(2836),
    [sym_field_identifier] = STATE(8789),
    [sym_identifier] = ACTIONS(305),
    [anon_sym_LBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(339),
    [anon_sym_QMARK] = ACTIONS(341),
    [anon_sym_PLUS] = ACTIONS(3296),
    [anon_sym_DASH] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(3296),
    [anon_sym_BANG] = ACTIONS(3296),
    [anon_sym_AMP] = ACTIONS(3296),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_cast] = ACTIONS(311),
    [anon_sym_transmute] = ACTIONS(311),
    [anon_sym_auto_cast] = ACTIONS(313),
    [anon_sym_DOT_DOT] = ACTIONS(3298),
    [anon_sym_map] = ACTIONS(317),
    [anon_sym_bit_set] = ACTIONS(319),
    [anon_sym_matrix] = ACTIONS(321),
    [anon_sym_distinct] = ACTIONS(323),
    [sym_number] = ACTIONS(325),
    [anon_sym_DQUOTE] = ACTIONS(327),
    [anon_sym_BQUOTE] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [sym_nil] = ACTIONS(335),
    [sym_uninitialized] = ACTIONS(325),
    [sym_tag] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(325),
    [sym_block_comment] = ACTIONS(3),
  },
  [1801] = {
    [sym_expression] = STATE(4205),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1802] = {
    [sym_expression] = STATE(6127),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(6389),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1803] = {
    [sym_expression] = STATE(3325),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1804] = {
    [sym_expression] = STATE(6025),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1805] = {
    [sym_expression] = STATE(6404),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1806] = {
    [sym_expression] = STATE(6030),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1807] = {
    [sym_expression] = STATE(6139),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1808] = {
    [sym_expression] = STATE(6078),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1809] = {
    [sym_expression] = STATE(6057),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1810] = {
    [ts_builtin_sym_end] = ACTIONS(4815),
    [anon_sym_LBRACE] = ACTIONS(4815),
    [anon_sym_RBRACE] = ACTIONS(4815),
    [anon_sym_COMMA] = ACTIONS(4815),
    [anon_sym_COLON_COLON] = ACTIONS(4815),
    [anon_sym_DASH_GT] = ACTIONS(4815),
    [anon_sym_EQ] = ACTIONS(4817),
    [anon_sym_COLON] = ACTIONS(4817),
    [anon_sym_PIPE] = ACTIONS(4817),
    [anon_sym_COLON_EQ] = ACTIONS(4815),
    [anon_sym_LPAREN] = ACTIONS(4815),
    [anon_sym_PLUS_EQ] = ACTIONS(4815),
    [anon_sym_DASH_EQ] = ACTIONS(4815),
    [anon_sym_STAR_EQ] = ACTIONS(4815),
    [anon_sym_SLASH_EQ] = ACTIONS(4815),
    [anon_sym_PERCENT_EQ] = ACTIONS(4815),
    [anon_sym_AMP_EQ] = ACTIONS(4815),
    [anon_sym_PIPE_EQ] = ACTIONS(4815),
    [anon_sym_CARET_EQ] = ACTIONS(4815),
    [anon_sym_LT_LT_EQ] = ACTIONS(4815),
    [anon_sym_GT_GT_EQ] = ACTIONS(4815),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4815),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4815),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4815),
    [anon_sym_if] = ACTIONS(4815),
    [anon_sym_SEMI] = ACTIONS(4815),
    [anon_sym_else] = ACTIONS(4815),
    [anon_sym_when] = ACTIONS(4815),
    [anon_sym_in] = ACTIONS(4815),
    [anon_sym_case] = ACTIONS(4815),
    [anon_sym_QMARK] = ACTIONS(4815),
    [anon_sym_PLUS] = ACTIONS(4817),
    [anon_sym_DASH] = ACTIONS(4817),
    [anon_sym_TILDE] = ACTIONS(4817),
    [anon_sym_AMP] = ACTIONS(4817),
    [anon_sym_PIPE_PIPE] = ACTIONS(4817),
    [anon_sym_or_else] = ACTIONS(4815),
    [anon_sym_AMP_AMP] = ACTIONS(4817),
    [anon_sym_GT] = ACTIONS(4817),
    [anon_sym_GT_EQ] = ACTIONS(4815),
    [anon_sym_LT_EQ] = ACTIONS(4815),
    [anon_sym_LT] = ACTIONS(4817),
    [anon_sym_EQ_EQ] = ACTIONS(4815),
    [anon_sym_BANG_EQ] = ACTIONS(4815),
    [anon_sym_TILDE_EQ] = ACTIONS(4815),
    [anon_sym_AMP_TILDE] = ACTIONS(4817),
    [anon_sym_LT_LT] = ACTIONS(4817),
    [anon_sym_GT_GT] = ACTIONS(4817),
    [anon_sym_STAR] = ACTIONS(4817),
    [anon_sym_SLASH] = ACTIONS(4817),
    [anon_sym_PERCENT] = ACTIONS(4817),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4815),
    [anon_sym_DOT] = ACTIONS(4817),
    [anon_sym_LBRACK] = ACTIONS(4815),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4815),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4815),
    [anon_sym_not_in] = ACTIONS(4815),
    [anon_sym_or_return] = ACTIONS(4815),
    [anon_sym_or_continue] = ACTIONS(4815),
    [anon_sym_or_break] = ACTIONS(4815),
    [anon_sym_CARET] = ACTIONS(4817),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4815),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1811] = {
    [sym_expression] = STATE(6371),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1812] = {
    [sym_expression] = STATE(6375),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1813] = {
    [sym_expression] = STATE(3115),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1814] = {
    [sym_expression] = STATE(3333),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1815] = {
    [sym_expression] = STATE(3123),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1816] = {
    [sym_expression] = STATE(3314),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1817] = {
    [sym_expression] = STATE(3317),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1818] = {
    [sym_expression] = STATE(3320),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1819] = {
    [sym_expression] = STATE(6023),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1820] = {
    [sym_expression] = STATE(6336),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1821] = {
    [sym_expression] = STATE(5989),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1822] = {
    [sym_expression] = STATE(5993),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1823] = {
    [sym_expression] = STATE(6091),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1824] = {
    [sym_expression] = STATE(6102),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1825] = {
    [sym_expression] = STATE(6011),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1826] = {
    [ts_builtin_sym_end] = ACTIONS(4855),
    [anon_sym_LBRACE] = ACTIONS(4855),
    [anon_sym_RBRACE] = ACTIONS(4855),
    [anon_sym_COMMA] = ACTIONS(4855),
    [anon_sym_COLON_COLON] = ACTIONS(4855),
    [anon_sym_DASH_GT] = ACTIONS(4855),
    [anon_sym_EQ] = ACTIONS(4857),
    [anon_sym_COLON] = ACTIONS(4857),
    [anon_sym_PIPE] = ACTIONS(4857),
    [anon_sym_COLON_EQ] = ACTIONS(4855),
    [anon_sym_LPAREN] = ACTIONS(4855),
    [anon_sym_PLUS_EQ] = ACTIONS(4855),
    [anon_sym_DASH_EQ] = ACTIONS(4855),
    [anon_sym_STAR_EQ] = ACTIONS(4855),
    [anon_sym_SLASH_EQ] = ACTIONS(4855),
    [anon_sym_PERCENT_EQ] = ACTIONS(4855),
    [anon_sym_AMP_EQ] = ACTIONS(4855),
    [anon_sym_PIPE_EQ] = ACTIONS(4855),
    [anon_sym_CARET_EQ] = ACTIONS(4855),
    [anon_sym_LT_LT_EQ] = ACTIONS(4855),
    [anon_sym_GT_GT_EQ] = ACTIONS(4855),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4855),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4855),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4855),
    [anon_sym_if] = ACTIONS(4855),
    [anon_sym_SEMI] = ACTIONS(4855),
    [anon_sym_else] = ACTIONS(4855),
    [anon_sym_when] = ACTIONS(4855),
    [anon_sym_in] = ACTIONS(4855),
    [anon_sym_case] = ACTIONS(4855),
    [anon_sym_QMARK] = ACTIONS(4855),
    [anon_sym_PLUS] = ACTIONS(4857),
    [anon_sym_DASH] = ACTIONS(4857),
    [anon_sym_TILDE] = ACTIONS(4857),
    [anon_sym_AMP] = ACTIONS(4857),
    [anon_sym_PIPE_PIPE] = ACTIONS(4857),
    [anon_sym_or_else] = ACTIONS(4855),
    [anon_sym_AMP_AMP] = ACTIONS(4857),
    [anon_sym_GT] = ACTIONS(4857),
    [anon_sym_GT_EQ] = ACTIONS(4855),
    [anon_sym_LT_EQ] = ACTIONS(4855),
    [anon_sym_LT] = ACTIONS(4857),
    [anon_sym_EQ_EQ] = ACTIONS(4855),
    [anon_sym_BANG_EQ] = ACTIONS(4855),
    [anon_sym_TILDE_EQ] = ACTIONS(4855),
    [anon_sym_AMP_TILDE] = ACTIONS(4857),
    [anon_sym_LT_LT] = ACTIONS(4857),
    [anon_sym_GT_GT] = ACTIONS(4857),
    [anon_sym_STAR] = ACTIONS(4857),
    [anon_sym_SLASH] = ACTIONS(4857),
    [anon_sym_PERCENT] = ACTIONS(4857),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4855),
    [anon_sym_DOT] = ACTIONS(4857),
    [anon_sym_LBRACK] = ACTIONS(4855),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4855),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4855),
    [anon_sym_not_in] = ACTIONS(4855),
    [anon_sym_or_return] = ACTIONS(4855),
    [anon_sym_or_continue] = ACTIONS(4855),
    [anon_sym_or_break] = ACTIONS(4855),
    [anon_sym_CARET] = ACTIONS(4857),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4855),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1827] = {
    [sym_expression] = STATE(6514),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1828] = {
    [sym_expression] = STATE(6560),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1829] = {
    [sym_expression] = STATE(3208),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1830] = {
    [sym_expression] = STATE(3331),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1831] = {
    [sym_expression] = STATE(3336),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1832] = {
    [sym_expression] = STATE(3217),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1833] = {
    [sym_expression] = STATE(3219),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1834] = {
    [sym_expression] = STATE(3220),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1835] = {
    [sym_expression] = STATE(6109),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1836] = {
    [sym_expression] = STATE(6428),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1837] = {
    [sym_expression] = STATE(6045),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1838] = {
    [sym_expression] = STATE(6068),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1839] = {
    [sym_expression] = STATE(5974),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1840] = {
    [sym_expression] = STATE(5980),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1841] = {
    [sym_expression] = STATE(5995),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1842] = {
    [ts_builtin_sym_end] = ACTIONS(4859),
    [anon_sym_LBRACE] = ACTIONS(4859),
    [anon_sym_RBRACE] = ACTIONS(4859),
    [anon_sym_COMMA] = ACTIONS(4859),
    [anon_sym_COLON_COLON] = ACTIONS(4859),
    [anon_sym_DASH_GT] = ACTIONS(4859),
    [anon_sym_EQ] = ACTIONS(4861),
    [anon_sym_COLON] = ACTIONS(4861),
    [anon_sym_PIPE] = ACTIONS(4861),
    [anon_sym_COLON_EQ] = ACTIONS(4859),
    [anon_sym_LPAREN] = ACTIONS(4859),
    [anon_sym_PLUS_EQ] = ACTIONS(4859),
    [anon_sym_DASH_EQ] = ACTIONS(4859),
    [anon_sym_STAR_EQ] = ACTIONS(4859),
    [anon_sym_SLASH_EQ] = ACTIONS(4859),
    [anon_sym_PERCENT_EQ] = ACTIONS(4859),
    [anon_sym_AMP_EQ] = ACTIONS(4859),
    [anon_sym_PIPE_EQ] = ACTIONS(4859),
    [anon_sym_CARET_EQ] = ACTIONS(4859),
    [anon_sym_LT_LT_EQ] = ACTIONS(4859),
    [anon_sym_GT_GT_EQ] = ACTIONS(4859),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4859),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4859),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4859),
    [anon_sym_if] = ACTIONS(4859),
    [anon_sym_SEMI] = ACTIONS(4859),
    [anon_sym_else] = ACTIONS(4859),
    [anon_sym_when] = ACTIONS(4859),
    [anon_sym_in] = ACTIONS(4859),
    [anon_sym_case] = ACTIONS(4859),
    [anon_sym_QMARK] = ACTIONS(4859),
    [anon_sym_PLUS] = ACTIONS(4861),
    [anon_sym_DASH] = ACTIONS(4861),
    [anon_sym_TILDE] = ACTIONS(4861),
    [anon_sym_AMP] = ACTIONS(4861),
    [anon_sym_PIPE_PIPE] = ACTIONS(4861),
    [anon_sym_or_else] = ACTIONS(4859),
    [anon_sym_AMP_AMP] = ACTIONS(4861),
    [anon_sym_GT] = ACTIONS(4861),
    [anon_sym_GT_EQ] = ACTIONS(4859),
    [anon_sym_LT_EQ] = ACTIONS(4859),
    [anon_sym_LT] = ACTIONS(4861),
    [anon_sym_EQ_EQ] = ACTIONS(4859),
    [anon_sym_BANG_EQ] = ACTIONS(4859),
    [anon_sym_TILDE_EQ] = ACTIONS(4859),
    [anon_sym_AMP_TILDE] = ACTIONS(4861),
    [anon_sym_LT_LT] = ACTIONS(4861),
    [anon_sym_GT_GT] = ACTIONS(4861),
    [anon_sym_STAR] = ACTIONS(4861),
    [anon_sym_SLASH] = ACTIONS(4861),
    [anon_sym_PERCENT] = ACTIONS(4861),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4859),
    [anon_sym_DOT] = ACTIONS(4861),
    [anon_sym_LBRACK] = ACTIONS(4859),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4859),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4859),
    [anon_sym_not_in] = ACTIONS(4859),
    [anon_sym_or_return] = ACTIONS(4859),
    [anon_sym_or_continue] = ACTIONS(4859),
    [anon_sym_or_break] = ACTIONS(4859),
    [anon_sym_CARET] = ACTIONS(4861),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4859),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1843] = {
    [sym_expression] = STATE(6268),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1844] = {
    [sym_expression] = STATE(6286),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1845] = {
    [sym_expression] = STATE(3222),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1846] = {
    [sym_expression] = STATE(3223),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1847] = {
    [sym_expression] = STATE(3224),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1848] = {
    [sym_expression] = STATE(3054),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1849] = {
    [sym_expression] = STATE(3055),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1850] = {
    [sym_expression] = STATE(4206),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1851] = {
    [sym_expression] = STATE(6114),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1852] = {
    [sym_expression] = STATE(6411),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1853] = {
    [sym_expression] = STATE(6054),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1854] = {
    [sym_expression] = STATE(6061),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1855] = {
    [sym_expression] = STATE(6002),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1856] = {
    [sym_expression] = STATE(6024),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1857] = {
    [sym_expression] = STATE(6099),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1858] = {
    [ts_builtin_sym_end] = ACTIONS(4863),
    [anon_sym_LBRACE] = ACTIONS(4863),
    [anon_sym_RBRACE] = ACTIONS(4863),
    [anon_sym_COMMA] = ACTIONS(4863),
    [anon_sym_COLON_COLON] = ACTIONS(4863),
    [anon_sym_DASH_GT] = ACTIONS(4863),
    [anon_sym_EQ] = ACTIONS(4865),
    [anon_sym_COLON] = ACTIONS(4865),
    [anon_sym_PIPE] = ACTIONS(4865),
    [anon_sym_COLON_EQ] = ACTIONS(4863),
    [anon_sym_LPAREN] = ACTIONS(4863),
    [anon_sym_PLUS_EQ] = ACTIONS(4863),
    [anon_sym_DASH_EQ] = ACTIONS(4863),
    [anon_sym_STAR_EQ] = ACTIONS(4863),
    [anon_sym_SLASH_EQ] = ACTIONS(4863),
    [anon_sym_PERCENT_EQ] = ACTIONS(4863),
    [anon_sym_AMP_EQ] = ACTIONS(4863),
    [anon_sym_PIPE_EQ] = ACTIONS(4863),
    [anon_sym_CARET_EQ] = ACTIONS(4863),
    [anon_sym_LT_LT_EQ] = ACTIONS(4863),
    [anon_sym_GT_GT_EQ] = ACTIONS(4863),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4863),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4863),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4863),
    [anon_sym_if] = ACTIONS(4863),
    [anon_sym_SEMI] = ACTIONS(4863),
    [anon_sym_else] = ACTIONS(4863),
    [anon_sym_when] = ACTIONS(4863),
    [anon_sym_in] = ACTIONS(4863),
    [anon_sym_case] = ACTIONS(4863),
    [anon_sym_QMARK] = ACTIONS(4863),
    [anon_sym_PLUS] = ACTIONS(4865),
    [anon_sym_DASH] = ACTIONS(4865),
    [anon_sym_TILDE] = ACTIONS(4865),
    [anon_sym_AMP] = ACTIONS(4865),
    [anon_sym_PIPE_PIPE] = ACTIONS(4865),
    [anon_sym_or_else] = ACTIONS(4863),
    [anon_sym_AMP_AMP] = ACTIONS(4865),
    [anon_sym_GT] = ACTIONS(4865),
    [anon_sym_GT_EQ] = ACTIONS(4863),
    [anon_sym_LT_EQ] = ACTIONS(4863),
    [anon_sym_LT] = ACTIONS(4865),
    [anon_sym_EQ_EQ] = ACTIONS(4863),
    [anon_sym_BANG_EQ] = ACTIONS(4863),
    [anon_sym_TILDE_EQ] = ACTIONS(4863),
    [anon_sym_AMP_TILDE] = ACTIONS(4865),
    [anon_sym_LT_LT] = ACTIONS(4865),
    [anon_sym_GT_GT] = ACTIONS(4865),
    [anon_sym_STAR] = ACTIONS(4865),
    [anon_sym_SLASH] = ACTIONS(4865),
    [anon_sym_PERCENT] = ACTIONS(4865),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4863),
    [anon_sym_DOT] = ACTIONS(4865),
    [anon_sym_LBRACK] = ACTIONS(4863),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4863),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4863),
    [anon_sym_not_in] = ACTIONS(4863),
    [anon_sym_or_return] = ACTIONS(4863),
    [anon_sym_or_continue] = ACTIONS(4863),
    [anon_sym_or_break] = ACTIONS(4863),
    [anon_sym_CARET] = ACTIONS(4865),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4863),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1859] = {
    [sym_expression] = STATE(6276),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1860] = {
    [sym_expression] = STATE(6278),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1861] = {
    [sym_expression] = STATE(4207),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1862] = {
    [sym_expression] = STATE(4208),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1863] = {
    [sym_expression] = STATE(3276),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1864] = {
    [sym_expression] = STATE(3294),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1865] = {
    [sym_expression] = STATE(3295),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [1866] = {
    [aux_sym_where_clause_repeat1] = STATE(1698),
    [anon_sym_LBRACE] = ACTIONS(4479),
    [anon_sym_COMMA] = ACTIONS(6380),
    [anon_sym_COLON_COLON] = ACTIONS(4479),
    [anon_sym_DASH_GT] = ACTIONS(6391),
    [anon_sym_where] = ACTIONS(4479),
    [anon_sym_EQ] = ACTIONS(4483),
    [anon_sym_COLON] = ACTIONS(4483),
    [anon_sym_PIPE] = ACTIONS(6393),
    [anon_sym_COLON_EQ] = ACTIONS(4479),
    [anon_sym_LPAREN] = ACTIONS(4479),
    [anon_sym_PLUS_EQ] = ACTIONS(4479),
    [anon_sym_DASH_EQ] = ACTIONS(4479),
    [anon_sym_STAR_EQ] = ACTIONS(4479),
    [anon_sym_SLASH_EQ] = ACTIONS(4479),
    [anon_sym_PERCENT_EQ] = ACTIONS(4479),
    [anon_sym_AMP_EQ] = ACTIONS(4479),
    [anon_sym_PIPE_EQ] = ACTIONS(4479),
    [anon_sym_CARET_EQ] = ACTIONS(4479),
    [anon_sym_LT_LT_EQ] = ACTIONS(4479),
    [anon_sym_GT_GT_EQ] = ACTIONS(4479),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4479),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4479),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4479),
    [anon_sym_if] = ACTIONS(4479),
    [anon_sym_SEMI] = ACTIONS(4479),
    [anon_sym_do] = ACTIONS(4479),
    [anon_sym_when] = ACTIONS(4479),
    [anon_sym_in] = ACTIONS(4479),
    [anon_sym_QMARK] = ACTIONS(4479),
    [anon_sym_PLUS] = ACTIONS(6395),
    [anon_sym_DASH] = ACTIONS(6395),
    [anon_sym_TILDE] = ACTIONS(6397),
    [anon_sym_AMP] = ACTIONS(6399),
    [anon_sym_PIPE_PIPE] = ACTIONS(6401),
    [anon_sym_or_else] = ACTIONS(6403),
    [anon_sym_AMP_AMP] = ACTIONS(6405),
    [anon_sym_GT] = ACTIONS(6407),
    [anon_sym_GT_EQ] = ACTIONS(6409),
    [anon_sym_LT_EQ] = ACTIONS(6409),
    [anon_sym_LT] = ACTIONS(6407),
    [anon_sym_EQ_EQ] = ACTIONS(6411),
    [anon_sym_BANG_EQ] = ACTIONS(6411),
    [anon_sym_TILDE_EQ] = ACTIONS(6411),
    [anon_sym_AMP_TILDE] = ACTIONS(6413),
    [anon_sym_LT_LT] = ACTIONS(6415),
    [anon_sym_GT_GT] = ACTIONS(6415),
    [anon_sym_STAR] = ACTIONS(6417),
    [anon_sym_SLASH] = ACTIONS(6417),
    [anon_sym_PERCENT] = ACTIONS(6417),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(6419),
    [anon_sym_DOT] = ACTIONS(6421),
    [anon_sym_LBRACK] = ACTIONS(6423),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(6425),
    [anon_sym_DOT_DOT_LT] = ACTIONS(6425),
    [anon_sym_not_in] = ACTIONS(4479),
    [anon_sym_or_return] = ACTIONS(6427),
    [anon_sym_or_continue] = ACTIONS(6429),
    [anon_sym_or_break] = ACTIONS(6431),
    [anon_sym_CARET] = ACTIONS(6433),
    [sym_uninitialized] = ACTIONS(4479),
    [sym_tag] = ACTIONS(4479),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1867] = {
    [sym_expression] = STATE(6004),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1868] = {
    [sym_expression] = STATE(6594),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1869] = {
    [sym_expression] = STATE(6131),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1870] = {
    [sym_expression] = STATE(5987),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1871] = {
    [sym_expression] = STATE(6012),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1872] = {
    [sym_expression] = STATE(6079),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1873] = {
    [sym_expression] = STATE(6084),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1874] = {
    [sym_expression] = STATE(6205),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1875] = {
    [sym_expression] = STATE(6608),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1876] = {
    [sym_expression] = STATE(6611),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1877] = {
    [sym_expression] = STATE(3246),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1878] = {
    [sym_expression] = STATE(3263),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1879] = {
    [sym_expression] = STATE(3297),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1880] = {
    [sym_expression] = STATE(3301),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1881] = {
    [sym_expression] = STATE(3272),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1882] = {
    [sym_expression] = STATE(6038),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1883] = {
    [sym_expression] = STATE(6333),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1884] = {
    [sym_expression] = STATE(6118),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1885] = {
    [sym_expression] = STATE(6063),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1886] = {
    [sym_expression] = STATE(6140),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1887] = {
    [sym_expression] = STATE(5968),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1888] = {
    [sym_expression] = STATE(5990),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1889] = {
    [sym_expression] = STATE(6407),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1890] = {
    [sym_expression] = STATE(6516),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1891] = {
    [sym_expression] = STATE(3278),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1892] = {
    [sym_expression] = STATE(3279),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1893] = {
    [sym_expression] = STATE(3280),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1894] = {
    [sym_expression] = STATE(3282),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1895] = {
    [sym_expression] = STATE(3283),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1896] = {
    [sym_expression] = STATE(3284),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1897] = {
    [sym_expression] = STATE(6137),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1898] = {
    [sym_expression] = STATE(6299),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1899] = {
    [sym_expression] = STATE(6144),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1900] = {
    [sym_expression] = STATE(6086),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1901] = {
    [sym_expression] = STATE(6042),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1902] = {
    [sym_expression] = STATE(6014),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1903] = {
    [sym_expression] = STATE(6066),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1904] = {
    [sym_expression] = STATE(3286),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1905] = {
    [sym_expression] = STATE(3289),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1906] = {
    [sym_expression] = STATE(3291),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1907] = {
    [sym_expression] = STATE(3292),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1908] = {
    [sym_expression] = STATE(3298),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1909] = {
    [sym_expression] = STATE(3299),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1910] = {
    [sym_expression] = STATE(6026),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1911] = {
    [sym_expression] = STATE(6028),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1912] = {
    [sym_expression] = STATE(6031),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1913] = {
    [sym_expression] = STATE(3300),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1914] = {
    [sym_expression] = STATE(5924),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1915] = {
    [sym_expression] = STATE(4209),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1916] = {
    [sym_expression] = STATE(3338),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1917] = {
    [ts_builtin_sym_end] = ACTIONS(4945),
    [anon_sym_LBRACE] = ACTIONS(4945),
    [anon_sym_RBRACE] = ACTIONS(4945),
    [anon_sym_COMMA] = ACTIONS(4945),
    [anon_sym_COLON_COLON] = ACTIONS(4945),
    [anon_sym_DASH_GT] = ACTIONS(4945),
    [anon_sym_EQ] = ACTIONS(4947),
    [anon_sym_COLON] = ACTIONS(4947),
    [anon_sym_PIPE] = ACTIONS(4947),
    [anon_sym_COLON_EQ] = ACTIONS(4945),
    [anon_sym_LPAREN] = ACTIONS(4945),
    [anon_sym_PLUS_EQ] = ACTIONS(4945),
    [anon_sym_DASH_EQ] = ACTIONS(4945),
    [anon_sym_STAR_EQ] = ACTIONS(4945),
    [anon_sym_SLASH_EQ] = ACTIONS(4945),
    [anon_sym_PERCENT_EQ] = ACTIONS(4945),
    [anon_sym_AMP_EQ] = ACTIONS(4945),
    [anon_sym_PIPE_EQ] = ACTIONS(4945),
    [anon_sym_CARET_EQ] = ACTIONS(4945),
    [anon_sym_LT_LT_EQ] = ACTIONS(4945),
    [anon_sym_GT_GT_EQ] = ACTIONS(4945),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4945),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4945),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4945),
    [anon_sym_if] = ACTIONS(4945),
    [anon_sym_SEMI] = ACTIONS(4945),
    [anon_sym_else] = ACTIONS(4945),
    [anon_sym_when] = ACTIONS(4945),
    [anon_sym_in] = ACTIONS(4945),
    [anon_sym_case] = ACTIONS(4945),
    [anon_sym_QMARK] = ACTIONS(4945),
    [anon_sym_PLUS] = ACTIONS(4947),
    [anon_sym_DASH] = ACTIONS(4947),
    [anon_sym_TILDE] = ACTIONS(4947),
    [anon_sym_AMP] = ACTIONS(4947),
    [anon_sym_PIPE_PIPE] = ACTIONS(4947),
    [anon_sym_or_else] = ACTIONS(4945),
    [anon_sym_AMP_AMP] = ACTIONS(4947),
    [anon_sym_GT] = ACTIONS(4947),
    [anon_sym_GT_EQ] = ACTIONS(4945),
    [anon_sym_LT_EQ] = ACTIONS(4945),
    [anon_sym_LT] = ACTIONS(4947),
    [anon_sym_EQ_EQ] = ACTIONS(4945),
    [anon_sym_BANG_EQ] = ACTIONS(4945),
    [anon_sym_TILDE_EQ] = ACTIONS(4945),
    [anon_sym_AMP_TILDE] = ACTIONS(4947),
    [anon_sym_LT_LT] = ACTIONS(4947),
    [anon_sym_GT_GT] = ACTIONS(4947),
    [anon_sym_STAR] = ACTIONS(4947),
    [anon_sym_SLASH] = ACTIONS(4947),
    [anon_sym_PERCENT] = ACTIONS(4947),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4945),
    [anon_sym_DOT] = ACTIONS(4947),
    [anon_sym_LBRACK] = ACTIONS(4945),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4945),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4945),
    [anon_sym_not_in] = ACTIONS(4945),
    [anon_sym_or_return] = ACTIONS(4945),
    [anon_sym_or_continue] = ACTIONS(4945),
    [anon_sym_or_break] = ACTIONS(4945),
    [anon_sym_CARET] = ACTIONS(4947),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4945),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1918] = {
    [sym_expression] = STATE(3353),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1919] = {
    [sym_expression] = STATE(6136),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1920] = {
    [sym_expression] = STATE(5998),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1921] = {
    [sym_expression] = STATE(6017),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1922] = {
    [sym_expression] = STATE(3355),
    [sym__expression_no_tag] = STATE(3414),
    [sym_unary_expression] = STATE(3414),
    [sym_binary_expression] = STATE(3414),
    [sym_ternary_expression] = STATE(3414),
    [sym_call_expression] = STATE(3414),
    [sym_selector_call_expression] = STATE(3414),
    [sym_member_expression] = STATE(3414),
    [sym_index_expression] = STATE(3414),
    [sym_slice_expression] = STATE(3414),
    [sym_range_expression] = STATE(3414),
    [sym_cast_expression] = STATE(3414),
    [sym_in_expression] = STATE(3414),
    [sym_variadic_expression] = STATE(3414),
    [sym_parenthesized_expression] = STATE(3414),
    [sym_or_return_expression] = STATE(3414),
    [sym_or_continue_expression] = STATE(3414),
    [sym_or_break_expression] = STATE(3414),
    [sym_address] = STATE(3414),
    [sym_map_type] = STATE(3414),
    [sym_matrix_type] = STATE(3414),
    [sym_distinct_type] = STATE(3414),
    [sym_literal] = STATE(3414),
    [sym_struct] = STATE(3361),
    [sym_map] = STATE(3315),
    [sym_bit_set] = STATE(3315),
    [sym_matrix] = STATE(3315),
    [sym_string] = STATE(3315),
    [sym__string_literal] = STATE(3374),
    [sym__raw_string_literal] = STATE(3374),
    [sym_character] = STATE(3315),
    [sym_boolean] = STATE(3315),
    [sym_field_identifier] = STATE(8759),
    [sym_identifier] = ACTIONS(553),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_DOT] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_cast] = ACTIONS(569),
    [anon_sym_transmute] = ACTIONS(569),
    [anon_sym_auto_cast] = ACTIONS(571),
    [anon_sym_DOT_DOT] = ACTIONS(6298),
    [anon_sym_map] = ACTIONS(575),
    [anon_sym_bit_set] = ACTIONS(577),
    [anon_sym_matrix] = ACTIONS(579),
    [anon_sym_distinct] = ACTIONS(581),
    [sym_number] = ACTIONS(583),
    [anon_sym_DQUOTE] = ACTIONS(585),
    [anon_sym_BQUOTE] = ACTIONS(587),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(591),
    [anon_sym_false] = ACTIONS(591),
    [sym_nil] = ACTIONS(593),
    [sym_uninitialized] = ACTIONS(583),
    [sym_tag] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(583),
    [sym_block_comment] = ACTIONS(3),
  },
  [1923] = {
    [sym_expression] = STATE(4213),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1924] = {
    [sym_expression] = STATE(2711),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [1925] = {
    [sym_expression] = STATE(3587),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1926] = {
    [sym_expression] = STATE(3591),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1927] = {
    [sym_expression] = STATE(5991),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1928] = {
    [sym_expression] = STATE(5997),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1929] = {
    [sym_expression] = STATE(5999),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1930] = {
    [sym_expression] = STATE(3592),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1931] = {
    [sym_expression] = STATE(3593),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1932] = {
    [sym_expression] = STATE(3633),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1933] = {
    [sym_expression] = STATE(3634),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1934] = {
    [sym_expression] = STATE(3637),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1935] = {
    [sym_expression] = STATE(6082),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1936] = {
    [sym_expression] = STATE(6087),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1937] = {
    [sym_expression] = STATE(6108),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1938] = {
    [sym_expression] = STATE(3639),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1939] = {
    [sym_expression] = STATE(3640),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1940] = {
    [sym_expression] = STATE(3646),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1941] = {
    [sym_expression] = STATE(3648),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1942] = {
    [sym_expression] = STATE(3649),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1943] = {
    [sym_expression] = STATE(3650),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1944] = {
    [sym_expression] = STATE(3651),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1945] = {
    [sym_expression] = STATE(3652),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1946] = {
    [sym_expression] = STATE(3653),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1947] = {
    [sym_expression] = STATE(3654),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1948] = {
    [sym_expression] = STATE(3655),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1949] = {
    [sym_expression] = STATE(6508),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(6435),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1950] = {
    [sym_expression] = STATE(3680),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1951] = {
    [sym_expression] = STATE(2566),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [1952] = {
    [sym_expression] = STATE(6498),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1953] = {
    [sym_expression] = STATE(3701),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1954] = {
    [sym_expression] = STATE(3702),
    [sym__expression_no_tag] = STATE(3622),
    [sym_unary_expression] = STATE(3622),
    [sym_binary_expression] = STATE(3622),
    [sym_ternary_expression] = STATE(3622),
    [sym_call_expression] = STATE(3622),
    [sym_selector_call_expression] = STATE(3622),
    [sym_member_expression] = STATE(3622),
    [sym_index_expression] = STATE(3622),
    [sym_slice_expression] = STATE(3622),
    [sym_range_expression] = STATE(3622),
    [sym_cast_expression] = STATE(3622),
    [sym_in_expression] = STATE(3622),
    [sym_variadic_expression] = STATE(3622),
    [sym_parenthesized_expression] = STATE(3622),
    [sym_or_return_expression] = STATE(3622),
    [sym_or_continue_expression] = STATE(3622),
    [sym_or_break_expression] = STATE(3622),
    [sym_address] = STATE(3622),
    [sym_map_type] = STATE(3622),
    [sym_matrix_type] = STATE(3622),
    [sym_distinct_type] = STATE(3622),
    [sym_literal] = STATE(3622),
    [sym_struct] = STATE(3583),
    [sym_map] = STATE(3577),
    [sym_bit_set] = STATE(3577),
    [sym_matrix] = STATE(3577),
    [sym_string] = STATE(3577),
    [sym__string_literal] = STATE(3584),
    [sym__raw_string_literal] = STATE(3584),
    [sym_character] = STATE(3577),
    [sym_boolean] = STATE(3577),
    [sym_field_identifier] = STATE(8824),
    [sym_identifier] = ACTIONS(623),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_cast] = ACTIONS(627),
    [anon_sym_transmute] = ACTIONS(627),
    [anon_sym_auto_cast] = ACTIONS(629),
    [anon_sym_DOT_DOT] = ACTIONS(6342),
    [anon_sym_map] = ACTIONS(633),
    [anon_sym_bit_set] = ACTIONS(635),
    [anon_sym_matrix] = ACTIONS(637),
    [anon_sym_distinct] = ACTIONS(639),
    [sym_number] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(643),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [sym_nil] = ACTIONS(651),
    [sym_uninitialized] = ACTIONS(641),
    [sym_tag] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(641),
    [sym_block_comment] = ACTIONS(3),
  },
  [1955] = {
    [sym_expression] = STATE(6408),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1956] = {
    [sym_expression] = STATE(4956),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1957] = {
    [sym_expression] = STATE(6149),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1958] = {
    [ts_builtin_sym_end] = ACTIONS(5055),
    [anon_sym_LBRACE] = ACTIONS(5055),
    [anon_sym_RBRACE] = ACTIONS(5055),
    [anon_sym_COMMA] = ACTIONS(5055),
    [anon_sym_COLON_COLON] = ACTIONS(5055),
    [anon_sym_DASH_GT] = ACTIONS(5055),
    [anon_sym_EQ] = ACTIONS(5057),
    [anon_sym_COLON] = ACTIONS(5057),
    [anon_sym_PIPE] = ACTIONS(5057),
    [anon_sym_COLON_EQ] = ACTIONS(5055),
    [anon_sym_LPAREN] = ACTIONS(5055),
    [anon_sym_PLUS_EQ] = ACTIONS(5055),
    [anon_sym_DASH_EQ] = ACTIONS(5055),
    [anon_sym_STAR_EQ] = ACTIONS(5055),
    [anon_sym_SLASH_EQ] = ACTIONS(5055),
    [anon_sym_PERCENT_EQ] = ACTIONS(5055),
    [anon_sym_AMP_EQ] = ACTIONS(5055),
    [anon_sym_PIPE_EQ] = ACTIONS(5055),
    [anon_sym_CARET_EQ] = ACTIONS(5055),
    [anon_sym_LT_LT_EQ] = ACTIONS(5055),
    [anon_sym_GT_GT_EQ] = ACTIONS(5055),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(5055),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(5055),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(5055),
    [anon_sym_if] = ACTIONS(5055),
    [anon_sym_SEMI] = ACTIONS(5055),
    [anon_sym_else] = ACTIONS(5055),
    [anon_sym_when] = ACTIONS(5055),
    [anon_sym_in] = ACTIONS(5055),
    [anon_sym_case] = ACTIONS(5055),
    [anon_sym_QMARK] = ACTIONS(5055),
    [anon_sym_PLUS] = ACTIONS(5057),
    [anon_sym_DASH] = ACTIONS(5057),
    [anon_sym_TILDE] = ACTIONS(5057),
    [anon_sym_AMP] = ACTIONS(5057),
    [anon_sym_PIPE_PIPE] = ACTIONS(5057),
    [anon_sym_or_else] = ACTIONS(5055),
    [anon_sym_AMP_AMP] = ACTIONS(5057),
    [anon_sym_GT] = ACTIONS(5057),
    [anon_sym_GT_EQ] = ACTIONS(5055),
    [anon_sym_LT_EQ] = ACTIONS(5055),
    [anon_sym_LT] = ACTIONS(5057),
    [anon_sym_EQ_EQ] = ACTIONS(5055),
    [anon_sym_BANG_EQ] = ACTIONS(5055),
    [anon_sym_TILDE_EQ] = ACTIONS(5055),
    [anon_sym_AMP_TILDE] = ACTIONS(5057),
    [anon_sym_LT_LT] = ACTIONS(5057),
    [anon_sym_GT_GT] = ACTIONS(5057),
    [anon_sym_STAR] = ACTIONS(5057),
    [anon_sym_SLASH] = ACTIONS(5057),
    [anon_sym_PERCENT] = ACTIONS(5057),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(5055),
    [anon_sym_DOT] = ACTIONS(5057),
    [anon_sym_LBRACK] = ACTIONS(5055),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(5055),
    [anon_sym_DOT_DOT_LT] = ACTIONS(5055),
    [anon_sym_not_in] = ACTIONS(5055),
    [anon_sym_or_return] = ACTIONS(5055),
    [anon_sym_or_continue] = ACTIONS(5055),
    [anon_sym_or_break] = ACTIONS(5055),
    [anon_sym_CARET] = ACTIONS(5057),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(5055),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1959] = {
    [sym_expression] = STATE(725),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1960] = {
    [sym_expression] = STATE(780),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1961] = {
    [sym_expression] = STATE(784),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1962] = {
    [sym_expression] = STATE(785),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1963] = {
    [sym_expression] = STATE(6101),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1964] = {
    [sym_expression] = STATE(6212),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [1965] = {
    [sym_expression] = STATE(2386),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [1966] = {
    [sym_expression] = STATE(6059),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1967] = {
    [sym_expression] = STATE(834),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1968] = {
    [sym_expression] = STATE(838),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1969] = {
    [sym_expression] = STATE(690),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1970] = {
    [sym_expression] = STATE(692),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1971] = {
    [sym_expression] = STATE(693),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1972] = {
    [sym_expression] = STATE(705),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1973] = {
    [sym_expression] = STATE(708),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1974] = {
    [sym_expression] = STATE(711),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1975] = {
    [sym_expression] = STATE(722),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1976] = {
    [sym_expression] = STATE(727),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1977] = {
    [sym_expression] = STATE(731),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1978] = {
    [sym_expression] = STATE(732),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1979] = {
    [sym_expression] = STATE(736),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1980] = {
    [sym_expression] = STATE(738),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [1981] = {
    [ts_builtin_sym_end] = ACTIONS(4683),
    [anon_sym_LBRACE] = ACTIONS(4683),
    [anon_sym_RBRACE] = ACTIONS(4683),
    [anon_sym_COMMA] = ACTIONS(4683),
    [anon_sym_COLON_COLON] = ACTIONS(4683),
    [anon_sym_DASH_GT] = ACTIONS(4683),
    [anon_sym_EQ] = ACTIONS(4685),
    [anon_sym_COLON] = ACTIONS(4685),
    [anon_sym_PIPE] = ACTIONS(4685),
    [anon_sym_COLON_EQ] = ACTIONS(4683),
    [anon_sym_LPAREN] = ACTIONS(4683),
    [anon_sym_PLUS_EQ] = ACTIONS(4683),
    [anon_sym_DASH_EQ] = ACTIONS(4683),
    [anon_sym_STAR_EQ] = ACTIONS(4683),
    [anon_sym_SLASH_EQ] = ACTIONS(4683),
    [anon_sym_PERCENT_EQ] = ACTIONS(4683),
    [anon_sym_AMP_EQ] = ACTIONS(4683),
    [anon_sym_PIPE_EQ] = ACTIONS(4683),
    [anon_sym_CARET_EQ] = ACTIONS(4683),
    [anon_sym_LT_LT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4683),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4683),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4683),
    [anon_sym_if] = ACTIONS(4683),
    [anon_sym_SEMI] = ACTIONS(4683),
    [anon_sym_else] = ACTIONS(4683),
    [anon_sym_when] = ACTIONS(4683),
    [anon_sym_in] = ACTIONS(4683),
    [anon_sym_case] = ACTIONS(4683),
    [anon_sym_QMARK] = ACTIONS(4683),
    [anon_sym_PLUS] = ACTIONS(4685),
    [anon_sym_DASH] = ACTIONS(4685),
    [anon_sym_TILDE] = ACTIONS(4685),
    [anon_sym_AMP] = ACTIONS(4685),
    [anon_sym_PIPE_PIPE] = ACTIONS(4685),
    [anon_sym_or_else] = ACTIONS(4683),
    [anon_sym_AMP_AMP] = ACTIONS(4685),
    [anon_sym_GT] = ACTIONS(4685),
    [anon_sym_GT_EQ] = ACTIONS(4683),
    [anon_sym_LT_EQ] = ACTIONS(4683),
    [anon_sym_LT] = ACTIONS(4685),
    [anon_sym_EQ_EQ] = ACTIONS(4683),
    [anon_sym_BANG_EQ] = ACTIONS(4683),
    [anon_sym_TILDE_EQ] = ACTIONS(4683),
    [anon_sym_AMP_TILDE] = ACTIONS(4685),
    [anon_sym_LT_LT] = ACTIONS(4685),
    [anon_sym_GT_GT] = ACTIONS(4685),
    [anon_sym_STAR] = ACTIONS(4685),
    [anon_sym_SLASH] = ACTIONS(4685),
    [anon_sym_PERCENT] = ACTIONS(4685),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4683),
    [anon_sym_DOT] = ACTIONS(4685),
    [anon_sym_LBRACK] = ACTIONS(4683),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4683),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4683),
    [anon_sym_not_in] = ACTIONS(4683),
    [anon_sym_or_return] = ACTIONS(4683),
    [anon_sym_or_continue] = ACTIONS(4683),
    [anon_sym_or_break] = ACTIONS(4683),
    [anon_sym_CARET] = ACTIONS(4685),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4683),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [1982] = {
    [sym_expression] = STATE(6129),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1983] = {
    [sym_expression] = STATE(4702),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1984] = {
    [sym_expression] = STATE(4149),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1985] = {
    [sym_expression] = STATE(4703),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1986] = {
    [sym_expression] = STATE(4173),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1987] = {
    [sym_expression] = STATE(5629),
    [sym__expression_no_tag] = STATE(4804),
    [sym_unary_expression] = STATE(4804),
    [sym_binary_expression] = STATE(4804),
    [sym_ternary_expression] = STATE(4804),
    [sym_call_expression] = STATE(4804),
    [sym_selector_call_expression] = STATE(4804),
    [sym_member_expression] = STATE(4804),
    [sym_index_expression] = STATE(4804),
    [sym_slice_expression] = STATE(4804),
    [sym_range_expression] = STATE(4804),
    [sym_cast_expression] = STATE(4804),
    [sym_in_expression] = STATE(4804),
    [sym_variadic_expression] = STATE(4804),
    [sym_parenthesized_expression] = STATE(4804),
    [sym_or_return_expression] = STATE(4804),
    [sym_or_continue_expression] = STATE(4804),
    [sym_or_break_expression] = STATE(4804),
    [sym_address] = STATE(4804),
    [sym_map_type] = STATE(4804),
    [sym_matrix_type] = STATE(4804),
    [sym_distinct_type] = STATE(4804),
    [sym_literal] = STATE(4804),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1442),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1988] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5955),
    [sym_unary_expression] = STATE(5955),
    [sym_binary_expression] = STATE(5955),
    [sym_ternary_expression] = STATE(5955),
    [sym_call_expression] = STATE(4111),
    [sym_selector_call_expression] = STATE(5955),
    [sym_member_expression] = STATE(5955),
    [sym_index_expression] = STATE(5955),
    [sym_slice_expression] = STATE(5955),
    [sym_range_expression] = STATE(5955),
    [sym_cast_expression] = STATE(5955),
    [sym_in_expression] = STATE(5955),
    [sym_variadic_expression] = STATE(5955),
    [sym_parenthesized_expression] = STATE(5955),
    [sym_or_return_expression] = STATE(5955),
    [sym_or_continue_expression] = STATE(5955),
    [sym_or_break_expression] = STATE(5955),
    [sym_address] = STATE(5955),
    [sym_map_type] = STATE(5955),
    [sym_matrix_type] = STATE(5955),
    [sym_distinct_type] = STATE(5955),
    [sym_literal] = STATE(5955),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6437),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6439),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [1989] = {
    [sym_expression] = STATE(4707),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1990] = {
    [sym_expression] = STATE(4708),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1991] = {
    [sym_expression] = STATE(4709),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1992] = {
    [sym_expression] = STATE(4710),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1993] = {
    [sym_expression] = STATE(4711),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1994] = {
    [sym_expression] = STATE(4712),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1995] = {
    [sym_expression] = STATE(4713),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1996] = {
    [sym_expression] = STATE(4696),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1997] = {
    [sym_expression] = STATE(4742),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1998] = {
    [sym_expression] = STATE(4717),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [1999] = {
    [sym_expression] = STATE(4718),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2000] = {
    [sym_expression] = STATE(4719),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2001] = {
    [sym_expression] = STATE(4209),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2002] = {
    [sym_expression] = STATE(4213),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2003] = {
    [ts_builtin_sym_end] = ACTIONS(893),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_COMMA] = ACTIONS(893),
    [anon_sym_COLON_COLON] = ACTIONS(893),
    [anon_sym_DASH_GT] = ACTIONS(893),
    [anon_sym_EQ] = ACTIONS(895),
    [anon_sym_COLON] = ACTIONS(895),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_COLON_EQ] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(893),
    [anon_sym_PLUS_EQ] = ACTIONS(893),
    [anon_sym_DASH_EQ] = ACTIONS(893),
    [anon_sym_STAR_EQ] = ACTIONS(893),
    [anon_sym_SLASH_EQ] = ACTIONS(893),
    [anon_sym_PERCENT_EQ] = ACTIONS(893),
    [anon_sym_AMP_EQ] = ACTIONS(893),
    [anon_sym_PIPE_EQ] = ACTIONS(893),
    [anon_sym_CARET_EQ] = ACTIONS(893),
    [anon_sym_LT_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_GT_EQ] = ACTIONS(893),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(893),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(893),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_else] = ACTIONS(893),
    [anon_sym_when] = ACTIONS(893),
    [anon_sym_in] = ACTIONS(893),
    [anon_sym_case] = ACTIONS(893),
    [anon_sym_QMARK] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(895),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(895),
    [anon_sym_or_else] = ACTIONS(893),
    [anon_sym_AMP_AMP] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ] = ACTIONS(893),
    [anon_sym_TILDE_EQ] = ACTIONS(893),
    [anon_sym_AMP_TILDE] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(895),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(895),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(893),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(893),
    [anon_sym_DOT_DOT_LT] = ACTIONS(893),
    [anon_sym_not_in] = ACTIONS(893),
    [anon_sym_or_return] = ACTIONS(893),
    [anon_sym_or_continue] = ACTIONS(893),
    [anon_sym_or_break] = ACTIONS(893),
    [anon_sym_CARET] = ACTIONS(895),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(893),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2004] = {
    [sym_expression] = STATE(4881),
    [sym__expression_no_tag] = STATE(4681),
    [sym_unary_expression] = STATE(4681),
    [sym_binary_expression] = STATE(4681),
    [sym_ternary_expression] = STATE(4681),
    [sym_call_expression] = STATE(4681),
    [sym_selector_call_expression] = STATE(4681),
    [sym_member_expression] = STATE(4681),
    [sym_index_expression] = STATE(4681),
    [sym_slice_expression] = STATE(4681),
    [sym_range_expression] = STATE(4681),
    [sym_cast_expression] = STATE(4681),
    [sym_in_expression] = STATE(4681),
    [sym_variadic_expression] = STATE(4681),
    [sym_parenthesized_expression] = STATE(4681),
    [sym_or_return_expression] = STATE(4681),
    [sym_or_continue_expression] = STATE(4681),
    [sym_or_break_expression] = STATE(4681),
    [sym_address] = STATE(4681),
    [sym_map_type] = STATE(4681),
    [sym_matrix_type] = STATE(4681),
    [sym_distinct_type] = STATE(4681),
    [sym_literal] = STATE(4681),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(6441),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2005] = {
    [sym_expression] = STATE(4726),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2006] = {
    [sym_expression] = STATE(4953),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2007] = {
    [sym_expression] = STATE(4727),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2008] = {
    [sym_expression] = STATE(4728),
    [sym__expression_no_tag] = STATE(4698),
    [sym_unary_expression] = STATE(4698),
    [sym_binary_expression] = STATE(4698),
    [sym_ternary_expression] = STATE(4698),
    [sym_call_expression] = STATE(4698),
    [sym_selector_call_expression] = STATE(4698),
    [sym_member_expression] = STATE(4698),
    [sym_index_expression] = STATE(4698),
    [sym_slice_expression] = STATE(4698),
    [sym_range_expression] = STATE(4698),
    [sym_cast_expression] = STATE(4698),
    [sym_in_expression] = STATE(4698),
    [sym_variadic_expression] = STATE(4698),
    [sym_parenthesized_expression] = STATE(4698),
    [sym_or_return_expression] = STATE(4698),
    [sym_or_continue_expression] = STATE(4698),
    [sym_or_break_expression] = STATE(4698),
    [sym_address] = STATE(4698),
    [sym_map_type] = STATE(4698),
    [sym_matrix_type] = STATE(4698),
    [sym_distinct_type] = STATE(4698),
    [sym_literal] = STATE(4698),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2009] = {
    [sym_expression] = STATE(2587),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2010] = {
    [sym_expression] = STATE(2295),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2011] = {
    [sym_expression] = STATE(4937),
    [sym__expression_no_tag] = STATE(4681),
    [sym_unary_expression] = STATE(4681),
    [sym_binary_expression] = STATE(4681),
    [sym_ternary_expression] = STATE(4681),
    [sym_call_expression] = STATE(4681),
    [sym_selector_call_expression] = STATE(4681),
    [sym_member_expression] = STATE(4681),
    [sym_index_expression] = STATE(4681),
    [sym_slice_expression] = STATE(4681),
    [sym_range_expression] = STATE(4681),
    [sym_cast_expression] = STATE(4681),
    [sym_in_expression] = STATE(4681),
    [sym_variadic_expression] = STATE(4681),
    [sym_parenthesized_expression] = STATE(4681),
    [sym_or_return_expression] = STATE(4681),
    [sym_or_continue_expression] = STATE(4681),
    [sym_or_break_expression] = STATE(4681),
    [sym_address] = STATE(4681),
    [sym_map_type] = STATE(4681),
    [sym_matrix_type] = STATE(4681),
    [sym_distinct_type] = STATE(4681),
    [sym_literal] = STATE(4681),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(6441),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2012] = {
    [sym_expression] = STATE(2589),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2013] = {
    [sym_expression] = STATE(2318),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2014] = {
    [sym_expression] = STATE(2389),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [2015] = {
    [sym_expression] = STATE(4883),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2016] = {
    [sym_expression] = STATE(4058),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2017] = {
    [sym_expression] = STATE(4884),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2018] = {
    [sym_expression] = STATE(4090),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2019] = {
    [sym_expression] = STATE(4823),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2020] = {
    [sym_expression] = STATE(4824),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2021] = {
    [sym_expression] = STATE(4825),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2022] = {
    [sym_expression] = STATE(4826),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2023] = {
    [sym_expression] = STATE(4827),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2024] = {
    [sym_expression] = STATE(4828),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2025] = {
    [sym_expression] = STATE(4829),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2026] = {
    [sym_expression] = STATE(4830),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2027] = {
    [sym_expression] = STATE(4831),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2028] = {
    [sym_expression] = STATE(4832),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2029] = {
    [sym_expression] = STATE(4833),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2030] = {
    [sym_expression] = STATE(4834),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2031] = {
    [sym_expression] = STATE(4245),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2032] = {
    [sym_expression] = STATE(4249),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2033] = {
    [sym_expression] = STATE(4839),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2034] = {
    [sym_expression] = STATE(4840),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2035] = {
    [sym_expression] = STATE(4841),
    [sym__expression_no_tag] = STATE(4844),
    [sym_unary_expression] = STATE(4844),
    [sym_binary_expression] = STATE(4844),
    [sym_ternary_expression] = STATE(4844),
    [sym_call_expression] = STATE(4844),
    [sym_selector_call_expression] = STATE(4844),
    [sym_member_expression] = STATE(4844),
    [sym_index_expression] = STATE(4844),
    [sym_slice_expression] = STATE(4844),
    [sym_range_expression] = STATE(4844),
    [sym_cast_expression] = STATE(4844),
    [sym_in_expression] = STATE(4844),
    [sym_variadic_expression] = STATE(4844),
    [sym_parenthesized_expression] = STATE(4844),
    [sym_or_return_expression] = STATE(4844),
    [sym_or_continue_expression] = STATE(4844),
    [sym_or_break_expression] = STATE(4844),
    [sym_address] = STATE(4844),
    [sym_map_type] = STATE(4844),
    [sym_matrix_type] = STATE(4844),
    [sym_distinct_type] = STATE(4844),
    [sym_literal] = STATE(4844),
    [sym_struct] = STATE(4882),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(1126),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_PLUS] = ACTIONS(1130),
    [anon_sym_DASH] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1130),
    [anon_sym_BANG] = ACTIONS(1130),
    [anon_sym_AMP] = ACTIONS(1130),
    [anon_sym_DOT] = ACTIONS(1132),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(1085),
    [anon_sym_transmute] = ACTIONS(1085),
    [anon_sym_auto_cast] = ACTIONS(1087),
    [anon_sym_DOT_DOT] = ACTIONS(4783),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2036] = {
    [sym_expression] = STATE(2763),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2037] = {
    [sym_expression] = STATE(2708),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2038] = {
    [sym_expression] = STATE(2764),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2039] = {
    [sym_expression] = STATE(2709),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2040] = {
    [ts_builtin_sym_end] = ACTIONS(69),
    [sym_identifier] = ACTIONS(6445),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_LPAREN] = ACTIONS(6447),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(73),
    [anon_sym_when] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_case] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(69),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2041] = {
    [sym_expression] = STATE(2739),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2042] = {
    [sym_expression] = STATE(2740),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2043] = {
    [sym_expression] = STATE(2741),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2044] = {
    [sym_expression] = STATE(2742),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2045] = {
    [sym_expression] = STATE(2743),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2046] = {
    [sym_expression] = STATE(2744),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2047] = {
    [sym_expression] = STATE(2745),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2048] = {
    [sym_expression] = STATE(2746),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2049] = {
    [sym_expression] = STATE(2747),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2050] = {
    [sym_expression] = STATE(2748),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2051] = {
    [sym_expression] = STATE(2749),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2052] = {
    [sym_expression] = STATE(2750),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2053] = {
    [sym_expression] = STATE(2733),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2054] = {
    [sym_expression] = STATE(2734),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2055] = {
    [sym_expression] = STATE(2753),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2056] = {
    [sym_expression] = STATE(2754),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2057] = {
    [sym_expression] = STATE(2755),
    [sym__expression_no_tag] = STATE(2757),
    [sym_unary_expression] = STATE(2757),
    [sym_binary_expression] = STATE(2757),
    [sym_ternary_expression] = STATE(2757),
    [sym_call_expression] = STATE(2757),
    [sym_selector_call_expression] = STATE(2757),
    [sym_member_expression] = STATE(2757),
    [sym_index_expression] = STATE(2757),
    [sym_slice_expression] = STATE(2757),
    [sym_range_expression] = STATE(2757),
    [sym_cast_expression] = STATE(2757),
    [sym_in_expression] = STATE(2757),
    [sym_variadic_expression] = STATE(2757),
    [sym_parenthesized_expression] = STATE(2757),
    [sym_or_return_expression] = STATE(2757),
    [sym_or_continue_expression] = STATE(2757),
    [sym_or_break_expression] = STATE(2757),
    [sym_address] = STATE(2757),
    [sym_map_type] = STATE(2757),
    [sym_matrix_type] = STATE(2757),
    [sym_distinct_type] = STATE(2757),
    [sym_literal] = STATE(2757),
    [sym_struct] = STATE(2762),
    [sym_map] = STATE(2699),
    [sym_bit_set] = STATE(2699),
    [sym_matrix] = STATE(2699),
    [sym_string] = STATE(2699),
    [sym__string_literal] = STATE(2707),
    [sym__raw_string_literal] = STATE(2707),
    [sym_character] = STATE(2699),
    [sym_boolean] = STATE(2699),
    [sym_field_identifier] = STATE(8856),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_LPAREN] = ACTIONS(257),
    [anon_sym_QMARK] = ACTIONS(259),
    [anon_sym_PLUS] = ACTIONS(2870),
    [anon_sym_DASH] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(2870),
    [anon_sym_BANG] = ACTIONS(2870),
    [anon_sym_AMP] = ACTIONS(2870),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_cast] = ACTIONS(267),
    [anon_sym_transmute] = ACTIONS(267),
    [anon_sym_auto_cast] = ACTIONS(269),
    [anon_sym_DOT_DOT] = ACTIONS(2872),
    [anon_sym_map] = ACTIONS(273),
    [anon_sym_bit_set] = ACTIONS(275),
    [anon_sym_matrix] = ACTIONS(277),
    [anon_sym_distinct] = ACTIONS(279),
    [sym_number] = ACTIONS(281),
    [anon_sym_DQUOTE] = ACTIONS(283),
    [anon_sym_BQUOTE] = ACTIONS(285),
    [anon_sym_SQUOTE] = ACTIONS(287),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_nil] = ACTIONS(291),
    [sym_uninitialized] = ACTIONS(281),
    [sym_tag] = ACTIONS(293),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(281),
    [sym_block_comment] = ACTIONS(3),
  },
  [2058] = {
    [sym_expression] = STATE(4679),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2059] = {
    [sym_expression] = STATE(3115),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2060] = {
    [sym_expression] = STATE(4680),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2061] = {
    [sym_expression] = STATE(3123),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2062] = {
    [sym_expression] = STATE(4625),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2063] = {
    [sym_expression] = STATE(4626),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2064] = {
    [sym_expression] = STATE(4627),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2065] = {
    [sym_expression] = STATE(4628),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2066] = {
    [sym_expression] = STATE(4629),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2067] = {
    [sym_expression] = STATE(4630),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2068] = {
    [sym_expression] = STATE(4631),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2069] = {
    [sym_expression] = STATE(4632),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2070] = {
    [sym_expression] = STATE(4633),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2071] = {
    [sym_expression] = STATE(4634),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2072] = {
    [sym_expression] = STATE(4635),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2073] = {
    [sym_expression] = STATE(4636),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2074] = {
    [sym_expression] = STATE(3054),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2075] = {
    [sym_expression] = STATE(3055),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2076] = {
    [sym_expression] = STATE(4639),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2077] = {
    [sym_expression] = STATE(4640),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2078] = {
    [sym_expression] = STATE(4641),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2079] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5963),
    [sym_unary_expression] = STATE(5963),
    [sym_binary_expression] = STATE(5963),
    [sym_ternary_expression] = STATE(5963),
    [sym_call_expression] = STATE(4130),
    [sym_selector_call_expression] = STATE(5963),
    [sym_member_expression] = STATE(5963),
    [sym_index_expression] = STATE(5963),
    [sym_slice_expression] = STATE(5963),
    [sym_range_expression] = STATE(5963),
    [sym_cast_expression] = STATE(5963),
    [sym_in_expression] = STATE(5963),
    [sym_variadic_expression] = STATE(5963),
    [sym_parenthesized_expression] = STATE(5963),
    [sym_or_return_expression] = STATE(5963),
    [sym_or_continue_expression] = STATE(5963),
    [sym_or_break_expression] = STATE(5963),
    [sym_address] = STATE(5963),
    [sym_map_type] = STATE(5963),
    [sym_matrix_type] = STATE(5963),
    [sym_distinct_type] = STATE(5963),
    [sym_literal] = STATE(5963),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6449),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(1091),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2080] = {
    [sym_expression] = STATE(4966),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2081] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5904),
    [sym_unary_expression] = STATE(5904),
    [sym_binary_expression] = STATE(5904),
    [sym_ternary_expression] = STATE(5904),
    [sym_call_expression] = STATE(2522),
    [sym_selector_call_expression] = STATE(5904),
    [sym_member_expression] = STATE(5904),
    [sym_index_expression] = STATE(5904),
    [sym_slice_expression] = STATE(5904),
    [sym_range_expression] = STATE(5904),
    [sym_cast_expression] = STATE(5904),
    [sym_in_expression] = STATE(5904),
    [sym_variadic_expression] = STATE(5904),
    [sym_parenthesized_expression] = STATE(5904),
    [sym_or_return_expression] = STATE(5904),
    [sym_or_continue_expression] = STATE(5904),
    [sym_or_break_expression] = STATE(5904),
    [sym_address] = STATE(5904),
    [sym_map_type] = STATE(5904),
    [sym_matrix_type] = STATE(5904),
    [sym_distinct_type] = STATE(5904),
    [sym_literal] = STATE(5904),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6451),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6453),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2082] = {
    [sym_expression] = STATE(4481),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2083] = {
    [sym_expression] = STATE(4674),
    [sym__expression_no_tag] = STATE(3196),
    [sym_unary_expression] = STATE(3196),
    [sym_binary_expression] = STATE(3196),
    [sym_ternary_expression] = STATE(3196),
    [sym_call_expression] = STATE(3196),
    [sym_selector_call_expression] = STATE(3196),
    [sym_member_expression] = STATE(3196),
    [sym_index_expression] = STATE(3196),
    [sym_slice_expression] = STATE(3196),
    [sym_range_expression] = STATE(3196),
    [sym_cast_expression] = STATE(3196),
    [sym_in_expression] = STATE(3196),
    [sym_variadic_expression] = STATE(3196),
    [sym_parenthesized_expression] = STATE(3196),
    [sym_or_return_expression] = STATE(3196),
    [sym_or_continue_expression] = STATE(3196),
    [sym_or_break_expression] = STATE(3196),
    [sym_address] = STATE(3196),
    [sym_map_type] = STATE(3196),
    [sym_matrix_type] = STATE(3196),
    [sym_distinct_type] = STATE(3196),
    [sym_literal] = STATE(3196),
    [sym_struct] = STATE(4678),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(1295),
    [anon_sym_QMARK] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(1297),
    [anon_sym_DASH] = ACTIONS(1299),
    [anon_sym_TILDE] = ACTIONS(1297),
    [anon_sym_BANG] = ACTIONS(1297),
    [anon_sym_AMP] = ACTIONS(1297),
    [anon_sym_DOT] = ACTIONS(1301),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(1303),
    [anon_sym_transmute] = ACTIONS(1303),
    [anon_sym_auto_cast] = ACTIONS(1305),
    [anon_sym_DOT_DOT] = ACTIONS(6443),
    [anon_sym_map] = ACTIONS(1309),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(1311),
    [anon_sym_distinct] = ACTIONS(1313),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2084] = {
    [sym_expression] = STATE(6616),
    [sym__expression_no_tag] = STATE(5933),
    [sym_unary_expression] = STATE(5933),
    [sym_binary_expression] = STATE(5933),
    [sym_ternary_expression] = STATE(5933),
    [sym_call_expression] = STATE(2727),
    [sym_selector_call_expression] = STATE(5933),
    [sym_member_expression] = STATE(5933),
    [sym_index_expression] = STATE(5933),
    [sym_slice_expression] = STATE(5933),
    [sym_range_expression] = STATE(5933),
    [sym_cast_expression] = STATE(5933),
    [sym_in_expression] = STATE(5933),
    [sym_variadic_expression] = STATE(5933),
    [sym_parenthesized_expression] = STATE(5933),
    [sym_or_return_expression] = STATE(5933),
    [sym_or_continue_expression] = STATE(5933),
    [sym_or_break_expression] = STATE(5933),
    [sym_address] = STATE(5933),
    [sym_map_type] = STATE(5933),
    [sym_matrix_type] = STATE(5933),
    [sym_distinct_type] = STATE(5933),
    [sym_literal] = STATE(5933),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(6455),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(6457),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2085] = {
    [sym_expression] = STATE(6001),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [2086] = {
    [sym_expression] = STATE(2562),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2087] = {
    [sym_expression] = STATE(6612),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2088] = {
    [sym_expression] = STATE(6613),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2089] = {
    [sym_expression] = STATE(5808),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2090] = {
    [sym_expression] = STATE(5015),
    [sym__expression_no_tag] = STATE(4723),
    [sym_unary_expression] = STATE(4723),
    [sym_binary_expression] = STATE(4723),
    [sym_ternary_expression] = STATE(4723),
    [sym_call_expression] = STATE(4723),
    [sym_selector_call_expression] = STATE(4723),
    [sym_member_expression] = STATE(4723),
    [sym_index_expression] = STATE(4723),
    [sym_slice_expression] = STATE(4723),
    [sym_range_expression] = STATE(4723),
    [sym_cast_expression] = STATE(4723),
    [sym_in_expression] = STATE(4723),
    [sym_variadic_expression] = STATE(4723),
    [sym_parenthesized_expression] = STATE(4723),
    [sym_or_return_expression] = STATE(4723),
    [sym_or_continue_expression] = STATE(4723),
    [sym_or_break_expression] = STATE(4723),
    [sym_address] = STATE(4723),
    [sym_map_type] = STATE(4723),
    [sym_matrix_type] = STATE(4723),
    [sym_distinct_type] = STATE(4723),
    [sym_literal] = STATE(4723),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(6459),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2091] = {
    [sym_expression] = STATE(2572),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2092] = {
    [sym_expression] = STATE(6251),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2093] = {
    [sym_expression] = STATE(6257),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2094] = {
    [sym_expression] = STATE(4116),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2095] = {
    [sym_expression] = STATE(6357),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2096] = {
    [sym_expression] = STATE(6385),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2097] = {
    [sym_expression] = STATE(4149),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2098] = {
    [ts_builtin_sym_end] = ACTIONS(4689),
    [anon_sym_LBRACE] = ACTIONS(4689),
    [anon_sym_RBRACE] = ACTIONS(4689),
    [anon_sym_COMMA] = ACTIONS(4689),
    [anon_sym_COLON_COLON] = ACTIONS(4689),
    [anon_sym_DASH_GT] = ACTIONS(4689),
    [anon_sym_EQ] = ACTIONS(4691),
    [anon_sym_COLON] = ACTIONS(4691),
    [anon_sym_PIPE] = ACTIONS(4691),
    [anon_sym_COLON_EQ] = ACTIONS(4689),
    [anon_sym_LPAREN] = ACTIONS(4689),
    [anon_sym_PLUS_EQ] = ACTIONS(4689),
    [anon_sym_DASH_EQ] = ACTIONS(4689),
    [anon_sym_STAR_EQ] = ACTIONS(4689),
    [anon_sym_SLASH_EQ] = ACTIONS(4689),
    [anon_sym_PERCENT_EQ] = ACTIONS(4689),
    [anon_sym_AMP_EQ] = ACTIONS(4689),
    [anon_sym_PIPE_EQ] = ACTIONS(4689),
    [anon_sym_CARET_EQ] = ACTIONS(4689),
    [anon_sym_LT_LT_EQ] = ACTIONS(4689),
    [anon_sym_GT_GT_EQ] = ACTIONS(4689),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4689),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4689),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4689),
    [anon_sym_if] = ACTIONS(4689),
    [anon_sym_SEMI] = ACTIONS(4689),
    [anon_sym_else] = ACTIONS(4689),
    [anon_sym_when] = ACTIONS(4689),
    [anon_sym_in] = ACTIONS(4689),
    [anon_sym_case] = ACTIONS(4689),
    [anon_sym_QMARK] = ACTIONS(4689),
    [anon_sym_PLUS] = ACTIONS(4691),
    [anon_sym_DASH] = ACTIONS(4691),
    [anon_sym_TILDE] = ACTIONS(4691),
    [anon_sym_AMP] = ACTIONS(4691),
    [anon_sym_PIPE_PIPE] = ACTIONS(4691),
    [anon_sym_or_else] = ACTIONS(4689),
    [anon_sym_AMP_AMP] = ACTIONS(4691),
    [anon_sym_GT] = ACTIONS(4691),
    [anon_sym_GT_EQ] = ACTIONS(4689),
    [anon_sym_LT_EQ] = ACTIONS(4689),
    [anon_sym_LT] = ACTIONS(4691),
    [anon_sym_EQ_EQ] = ACTIONS(4689),
    [anon_sym_BANG_EQ] = ACTIONS(4689),
    [anon_sym_TILDE_EQ] = ACTIONS(4689),
    [anon_sym_AMP_TILDE] = ACTIONS(4691),
    [anon_sym_LT_LT] = ACTIONS(4691),
    [anon_sym_GT_GT] = ACTIONS(4691),
    [anon_sym_STAR] = ACTIONS(4691),
    [anon_sym_SLASH] = ACTIONS(4691),
    [anon_sym_PERCENT] = ACTIONS(4691),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4689),
    [anon_sym_DOT] = ACTIONS(4691),
    [anon_sym_LBRACK] = ACTIONS(4689),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4689),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4689),
    [anon_sym_not_in] = ACTIONS(4689),
    [anon_sym_or_return] = ACTIONS(4689),
    [anon_sym_or_continue] = ACTIONS(4689),
    [anon_sym_or_break] = ACTIONS(4689),
    [anon_sym_CARET] = ACTIONS(4691),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4689),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2099] = {
    [sym_expression] = STATE(5902),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [2100] = {
    [sym_expression] = STATE(6581),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2101] = {
    [sym_expression] = STATE(758),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [2102] = {
    [aux_sym_struct_type_repeat2] = STATE(2102),
    [anon_sym_LBRACE] = ACTIONS(6461),
    [anon_sym_COMMA] = ACTIONS(3701),
    [anon_sym_COLON_COLON] = ACTIONS(3701),
    [anon_sym_DASH_GT] = ACTIONS(3701),
    [anon_sym_where] = ACTIONS(3701),
    [anon_sym_EQ] = ACTIONS(3706),
    [anon_sym_COLON] = ACTIONS(3706),
    [anon_sym_PIPE] = ACTIONS(3706),
    [anon_sym_COLON_EQ] = ACTIONS(3701),
    [anon_sym_LPAREN] = ACTIONS(3701),
    [anon_sym_PLUS_EQ] = ACTIONS(3701),
    [anon_sym_DASH_EQ] = ACTIONS(3701),
    [anon_sym_STAR_EQ] = ACTIONS(3701),
    [anon_sym_SLASH_EQ] = ACTIONS(3701),
    [anon_sym_PERCENT_EQ] = ACTIONS(3701),
    [anon_sym_AMP_EQ] = ACTIONS(3701),
    [anon_sym_PIPE_EQ] = ACTIONS(3701),
    [anon_sym_CARET_EQ] = ACTIONS(3701),
    [anon_sym_LT_LT_EQ] = ACTIONS(3701),
    [anon_sym_GT_GT_EQ] = ACTIONS(3701),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3701),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3701),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3701),
    [anon_sym_if] = ACTIONS(3701),
    [anon_sym_SEMI] = ACTIONS(3701),
    [anon_sym_do] = ACTIONS(3701),
    [anon_sym_when] = ACTIONS(3701),
    [anon_sym_in] = ACTIONS(3701),
    [anon_sym_QMARK] = ACTIONS(3701),
    [anon_sym_PLUS] = ACTIONS(3706),
    [anon_sym_DASH] = ACTIONS(3706),
    [anon_sym_TILDE] = ACTIONS(3706),
    [anon_sym_AMP] = ACTIONS(3706),
    [anon_sym_PIPE_PIPE] = ACTIONS(3706),
    [anon_sym_or_else] = ACTIONS(3701),
    [anon_sym_AMP_AMP] = ACTIONS(3706),
    [anon_sym_GT] = ACTIONS(3706),
    [anon_sym_GT_EQ] = ACTIONS(3701),
    [anon_sym_LT_EQ] = ACTIONS(3701),
    [anon_sym_LT] = ACTIONS(3706),
    [anon_sym_EQ_EQ] = ACTIONS(3701),
    [anon_sym_BANG_EQ] = ACTIONS(3701),
    [anon_sym_TILDE_EQ] = ACTIONS(3701),
    [anon_sym_AMP_TILDE] = ACTIONS(3706),
    [anon_sym_LT_LT] = ACTIONS(3706),
    [anon_sym_GT_GT] = ACTIONS(3706),
    [anon_sym_STAR] = ACTIONS(3706),
    [anon_sym_SLASH] = ACTIONS(3706),
    [anon_sym_PERCENT] = ACTIONS(3706),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3701),
    [anon_sym_DOT] = ACTIONS(3706),
    [anon_sym_LBRACK] = ACTIONS(3701),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3701),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3701),
    [anon_sym_not_in] = ACTIONS(3701),
    [anon_sym_or_return] = ACTIONS(3701),
    [anon_sym_or_continue] = ACTIONS(3701),
    [anon_sym_or_break] = ACTIONS(3701),
    [anon_sym_CARET] = ACTIONS(3706),
    [sym_uninitialized] = ACTIONS(3701),
    [sym_tag] = ACTIONS(3701),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2103] = {
    [sym_expression] = STATE(768),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [2104] = {
    [sym_expression] = STATE(769),
    [sym__expression_no_tag] = STATE(735),
    [sym_unary_expression] = STATE(735),
    [sym_binary_expression] = STATE(735),
    [sym_ternary_expression] = STATE(735),
    [sym_call_expression] = STATE(735),
    [sym_selector_call_expression] = STATE(735),
    [sym_member_expression] = STATE(735),
    [sym_index_expression] = STATE(735),
    [sym_slice_expression] = STATE(735),
    [sym_range_expression] = STATE(735),
    [sym_cast_expression] = STATE(735),
    [sym_in_expression] = STATE(735),
    [sym_variadic_expression] = STATE(735),
    [sym_parenthesized_expression] = STATE(735),
    [sym_or_return_expression] = STATE(735),
    [sym_or_continue_expression] = STATE(735),
    [sym_or_break_expression] = STATE(735),
    [sym_address] = STATE(735),
    [sym_map_type] = STATE(735),
    [sym_matrix_type] = STATE(735),
    [sym_distinct_type] = STATE(735),
    [sym_literal] = STATE(735),
    [sym_struct] = STATE(713),
    [sym_map] = STATE(772),
    [sym_bit_set] = STATE(772),
    [sym_matrix] = STATE(772),
    [sym_string] = STATE(772),
    [sym__string_literal] = STATE(715),
    [sym__raw_string_literal] = STATE(715),
    [sym_character] = STATE(772),
    [sym_boolean] = STATE(772),
    [sym_field_identifier] = STATE(8892),
    [sym_identifier] = ACTIONS(133),
    [anon_sym_LBRACE] = ACTIONS(167),
    [anon_sym_LPAREN] = ACTIONS(171),
    [anon_sym_QMARK] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(6348),
    [anon_sym_DASH] = ACTIONS(137),
    [anon_sym_TILDE] = ACTIONS(6348),
    [anon_sym_BANG] = ACTIONS(6348),
    [anon_sym_AMP] = ACTIONS(6348),
    [anon_sym_DOT] = ACTIONS(175),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_cast] = ACTIONS(139),
    [anon_sym_transmute] = ACTIONS(139),
    [anon_sym_auto_cast] = ACTIONS(141),
    [anon_sym_DOT_DOT] = ACTIONS(6350),
    [anon_sym_map] = ACTIONS(145),
    [anon_sym_bit_set] = ACTIONS(147),
    [anon_sym_matrix] = ACTIONS(149),
    [anon_sym_distinct] = ACTIONS(151),
    [sym_number] = ACTIONS(153),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [anon_sym_BQUOTE] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_true] = ACTIONS(161),
    [anon_sym_false] = ACTIONS(161),
    [sym_nil] = ACTIONS(163),
    [sym_uninitialized] = ACTIONS(153),
    [sym_tag] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(153),
    [sym_block_comment] = ACTIONS(3),
  },
  [2105] = {
    [ts_builtin_sym_end] = ACTIONS(4701),
    [anon_sym_LBRACE] = ACTIONS(4701),
    [anon_sym_RBRACE] = ACTIONS(4701),
    [anon_sym_COMMA] = ACTIONS(4701),
    [anon_sym_COLON_COLON] = ACTIONS(4701),
    [anon_sym_DASH_GT] = ACTIONS(4701),
    [anon_sym_EQ] = ACTIONS(4703),
    [anon_sym_COLON] = ACTIONS(4703),
    [anon_sym_PIPE] = ACTIONS(4703),
    [anon_sym_COLON_EQ] = ACTIONS(4701),
    [anon_sym_LPAREN] = ACTIONS(4701),
    [anon_sym_PLUS_EQ] = ACTIONS(4701),
    [anon_sym_DASH_EQ] = ACTIONS(4701),
    [anon_sym_STAR_EQ] = ACTIONS(4701),
    [anon_sym_SLASH_EQ] = ACTIONS(4701),
    [anon_sym_PERCENT_EQ] = ACTIONS(4701),
    [anon_sym_AMP_EQ] = ACTIONS(4701),
    [anon_sym_PIPE_EQ] = ACTIONS(4701),
    [anon_sym_CARET_EQ] = ACTIONS(4701),
    [anon_sym_LT_LT_EQ] = ACTIONS(4701),
    [anon_sym_GT_GT_EQ] = ACTIONS(4701),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4701),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4701),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4701),
    [anon_sym_if] = ACTIONS(4701),
    [anon_sym_SEMI] = ACTIONS(4701),
    [anon_sym_else] = ACTIONS(4701),
    [anon_sym_when] = ACTIONS(4701),
    [anon_sym_in] = ACTIONS(4701),
    [anon_sym_case] = ACTIONS(4701),
    [anon_sym_QMARK] = ACTIONS(4701),
    [anon_sym_PLUS] = ACTIONS(4703),
    [anon_sym_DASH] = ACTIONS(4703),
    [anon_sym_TILDE] = ACTIONS(4703),
    [anon_sym_AMP] = ACTIONS(4703),
    [anon_sym_PIPE_PIPE] = ACTIONS(4703),
    [anon_sym_or_else] = ACTIONS(4701),
    [anon_sym_AMP_AMP] = ACTIONS(4703),
    [anon_sym_GT] = ACTIONS(4703),
    [anon_sym_GT_EQ] = ACTIONS(4701),
    [anon_sym_LT_EQ] = ACTIONS(4701),
    [anon_sym_LT] = ACTIONS(4703),
    [anon_sym_EQ_EQ] = ACTIONS(4701),
    [anon_sym_BANG_EQ] = ACTIONS(4701),
    [anon_sym_TILDE_EQ] = ACTIONS(4701),
    [anon_sym_AMP_TILDE] = ACTIONS(4703),
    [anon_sym_LT_LT] = ACTIONS(4703),
    [anon_sym_GT_GT] = ACTIONS(4703),
    [anon_sym_STAR] = ACTIONS(4703),
    [anon_sym_SLASH] = ACTIONS(4703),
    [anon_sym_PERCENT] = ACTIONS(4703),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4701),
    [anon_sym_DOT] = ACTIONS(4703),
    [anon_sym_LBRACK] = ACTIONS(4701),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4701),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4701),
    [anon_sym_not_in] = ACTIONS(4701),
    [anon_sym_or_return] = ACTIONS(4701),
    [anon_sym_or_continue] = ACTIONS(4701),
    [anon_sym_or_break] = ACTIONS(4701),
    [anon_sym_CARET] = ACTIONS(4703),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4701),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2106] = {
    [sym_expression] = STATE(6150),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [2107] = {
    [sym_expression] = STATE(4112),
    [sym__expression_no_tag] = STATE(4052),
    [sym_unary_expression] = STATE(4052),
    [sym_binary_expression] = STATE(4052),
    [sym_ternary_expression] = STATE(4052),
    [sym_call_expression] = STATE(4052),
    [sym_selector_call_expression] = STATE(4052),
    [sym_member_expression] = STATE(4052),
    [sym_index_expression] = STATE(4052),
    [sym_slice_expression] = STATE(4052),
    [sym_range_expression] = STATE(4052),
    [sym_cast_expression] = STATE(4052),
    [sym_in_expression] = STATE(4052),
    [sym_variadic_expression] = STATE(4052),
    [sym_parenthesized_expression] = STATE(4052),
    [sym_or_return_expression] = STATE(4052),
    [sym_or_continue_expression] = STATE(4052),
    [sym_or_break_expression] = STATE(4052),
    [sym_address] = STATE(4052),
    [sym_map_type] = STATE(4052),
    [sym_matrix_type] = STATE(4052),
    [sym_distinct_type] = STATE(4052),
    [sym_literal] = STATE(4052),
    [sym_struct] = STATE(4200),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(23),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_PLUS] = ACTIONS(29),
    [anon_sym_DASH] = ACTIONS(31),
    [anon_sym_TILDE] = ACTIONS(29),
    [anon_sym_BANG] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(29),
    [anon_sym_DOT] = ACTIONS(33),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(37),
    [anon_sym_transmute] = ACTIONS(37),
    [anon_sym_auto_cast] = ACTIONS(39),
    [anon_sym_DOT_DOT] = ACTIONS(41),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(655),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2108] = {
    [sym_expression] = STATE(6214),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(6464),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [2109] = {
    [ts_builtin_sym_end] = ACTIONS(4709),
    [anon_sym_LBRACE] = ACTIONS(4709),
    [anon_sym_RBRACE] = ACTIONS(4709),
    [anon_sym_COMMA] = ACTIONS(4709),
    [anon_sym_COLON_COLON] = ACTIONS(4709),
    [anon_sym_DASH_GT] = ACTIONS(4709),
    [anon_sym_EQ] = ACTIONS(4711),
    [anon_sym_COLON] = ACTIONS(4711),
    [anon_sym_PIPE] = ACTIONS(4711),
    [anon_sym_COLON_EQ] = ACTIONS(4709),
    [anon_sym_LPAREN] = ACTIONS(4709),
    [anon_sym_PLUS_EQ] = ACTIONS(4709),
    [anon_sym_DASH_EQ] = ACTIONS(4709),
    [anon_sym_STAR_EQ] = ACTIONS(4709),
    [anon_sym_SLASH_EQ] = ACTIONS(4709),
    [anon_sym_PERCENT_EQ] = ACTIONS(4709),
    [anon_sym_AMP_EQ] = ACTIONS(4709),
    [anon_sym_PIPE_EQ] = ACTIONS(4709),
    [anon_sym_CARET_EQ] = ACTIONS(4709),
    [anon_sym_LT_LT_EQ] = ACTIONS(4709),
    [anon_sym_GT_GT_EQ] = ACTIONS(4709),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4709),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4709),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4709),
    [anon_sym_if] = ACTIONS(4709),
    [anon_sym_SEMI] = ACTIONS(4709),
    [anon_sym_else] = ACTIONS(4709),
    [anon_sym_when] = ACTIONS(4709),
    [anon_sym_in] = ACTIONS(4709),
    [anon_sym_case] = ACTIONS(4709),
    [anon_sym_QMARK] = ACTIONS(4709),
    [anon_sym_PLUS] = ACTIONS(4711),
    [anon_sym_DASH] = ACTIONS(4711),
    [anon_sym_TILDE] = ACTIONS(4711),
    [anon_sym_AMP] = ACTIONS(4711),
    [anon_sym_PIPE_PIPE] = ACTIONS(4711),
    [anon_sym_or_else] = ACTIONS(4709),
    [anon_sym_AMP_AMP] = ACTIONS(4711),
    [anon_sym_GT] = ACTIONS(4711),
    [anon_sym_GT_EQ] = ACTIONS(4709),
    [anon_sym_LT_EQ] = ACTIONS(4709),
    [anon_sym_LT] = ACTIONS(4711),
    [anon_sym_EQ_EQ] = ACTIONS(4709),
    [anon_sym_BANG_EQ] = ACTIONS(4709),
    [anon_sym_TILDE_EQ] = ACTIONS(4709),
    [anon_sym_AMP_TILDE] = ACTIONS(4711),
    [anon_sym_LT_LT] = ACTIONS(4711),
    [anon_sym_GT_GT] = ACTIONS(4711),
    [anon_sym_STAR] = ACTIONS(4711),
    [anon_sym_SLASH] = ACTIONS(4711),
    [anon_sym_PERCENT] = ACTIONS(4711),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4709),
    [anon_sym_DOT] = ACTIONS(4711),
    [anon_sym_LBRACK] = ACTIONS(4709),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4709),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4709),
    [anon_sym_not_in] = ACTIONS(4709),
    [anon_sym_or_return] = ACTIONS(4709),
    [anon_sym_or_continue] = ACTIONS(4709),
    [anon_sym_or_break] = ACTIONS(4709),
    [anon_sym_CARET] = ACTIONS(4711),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4709),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2110] = {
    [sym_expression] = STATE(2579),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2111] = {
    [sym_expression] = STATE(6130),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2112] = {
    [sym_expression] = STATE(6188),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2113] = {
    [sym_expression] = STATE(4412),
    [sym__expression_no_tag] = STATE(3913),
    [sym_unary_expression] = STATE(3913),
    [sym_binary_expression] = STATE(3913),
    [sym_ternary_expression] = STATE(3913),
    [sym_call_expression] = STATE(3913),
    [sym_selector_call_expression] = STATE(3913),
    [sym_member_expression] = STATE(3913),
    [sym_index_expression] = STATE(3913),
    [sym_slice_expression] = STATE(3913),
    [sym_range_expression] = STATE(3913),
    [sym_cast_expression] = STATE(3913),
    [sym_in_expression] = STATE(3913),
    [sym_variadic_expression] = STATE(3913),
    [sym_parenthesized_expression] = STATE(3913),
    [sym_or_return_expression] = STATE(3913),
    [sym_or_continue_expression] = STATE(3913),
    [sym_or_break_expression] = STATE(3913),
    [sym_address] = STATE(3913),
    [sym_map_type] = STATE(3913),
    [sym_matrix_type] = STATE(3913),
    [sym_distinct_type] = STATE(3913),
    [sym_literal] = STATE(3913),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(6466),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2114] = {
    [sym_expression] = STATE(6055),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [2115] = {
    [sym_expression] = STATE(5922),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [2116] = {
    [sym_expression] = STATE(6092),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2117] = {
    [sym_expression] = STATE(6162),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2118] = {
    [sym_expression] = STATE(6156),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2119] = {
    [sym_expression] = STATE(4963),
    [sym__expression_no_tag] = STATE(4697),
    [sym_unary_expression] = STATE(4697),
    [sym_binary_expression] = STATE(4697),
    [sym_ternary_expression] = STATE(4697),
    [sym_call_expression] = STATE(4697),
    [sym_selector_call_expression] = STATE(4697),
    [sym_member_expression] = STATE(4697),
    [sym_index_expression] = STATE(4697),
    [sym_slice_expression] = STATE(4697),
    [sym_range_expression] = STATE(4697),
    [sym_cast_expression] = STATE(4697),
    [sym_in_expression] = STATE(4697),
    [sym_variadic_expression] = STATE(4697),
    [sym_parenthesized_expression] = STATE(4697),
    [sym_or_return_expression] = STATE(4697),
    [sym_or_continue_expression] = STATE(4697),
    [sym_or_break_expression] = STATE(4697),
    [sym_address] = STATE(4697),
    [sym_map_type] = STATE(4697),
    [sym_matrix_type] = STATE(4697),
    [sym_distinct_type] = STATE(4697),
    [sym_literal] = STATE(4697),
    [sym_struct] = STATE(4741),
    [sym_map] = STATE(4113),
    [sym_bit_set] = STATE(4113),
    [sym_matrix] = STATE(4113),
    [sym_string] = STATE(4113),
    [sym__string_literal] = STATE(4019),
    [sym__raw_string_literal] = STATE(4019),
    [sym_character] = STATE(4113),
    [sym_boolean] = STATE(4113),
    [sym_field_identifier] = STATE(8630),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LBRACE] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(35),
    [anon_sym_cast] = ACTIONS(611),
    [anon_sym_transmute] = ACTIONS(611),
    [anon_sym_auto_cast] = ACTIONS(613),
    [anon_sym_DOT_DOT] = ACTIONS(2890),
    [anon_sym_map] = ACTIONS(43),
    [anon_sym_bit_set] = ACTIONS(45),
    [anon_sym_matrix] = ACTIONS(47),
    [anon_sym_distinct] = ACTIONS(49),
    [sym_number] = ACTIONS(51),
    [anon_sym_DQUOTE] = ACTIONS(53),
    [anon_sym_BQUOTE] = ACTIONS(55),
    [anon_sym_SQUOTE] = ACTIONS(57),
    [anon_sym_true] = ACTIONS(59),
    [anon_sym_false] = ACTIONS(59),
    [sym_nil] = ACTIONS(61),
    [sym_uninitialized] = ACTIONS(51),
    [sym_tag] = ACTIONS(935),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(51),
    [sym_block_comment] = ACTIONS(3),
  },
  [2120] = {
    [sym_expression] = STATE(6069),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [2121] = {
    [sym_expression] = STATE(6046),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2122] = {
    [sym_expression] = STATE(2569),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2123] = {
    [sym_expression] = STATE(6168),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2124] = {
    [sym_expression] = STATE(2492),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [2125] = {
    [sym_expression] = STATE(2583),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2126] = {
    [sym_expression] = STATE(2588),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2127] = {
    [sym_expression] = STATE(2496),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [2128] = {
    [sym_expression] = STATE(2591),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2129] = {
    [sym_expression] = STATE(6338),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2130] = {
    [sym_expression] = STATE(2567),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2131] = {
    [sym_expression] = STATE(2563),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2132] = {
    [sym_expression] = STATE(2564),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2133] = {
    [sym_expression] = STATE(2573),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2134] = {
    [sym_expression] = STATE(2578),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2135] = {
    [sym_expression] = STATE(2582),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2136] = {
    [sym_expression] = STATE(2475),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2137] = {
    [sym_expression] = STATE(2240),
    [sym__expression_no_tag] = STATE(2585),
    [sym_unary_expression] = STATE(2585),
    [sym_binary_expression] = STATE(2585),
    [sym_ternary_expression] = STATE(2585),
    [sym_call_expression] = STATE(2585),
    [sym_selector_call_expression] = STATE(2585),
    [sym_member_expression] = STATE(2585),
    [sym_index_expression] = STATE(2585),
    [sym_slice_expression] = STATE(2585),
    [sym_range_expression] = STATE(2585),
    [sym_cast_expression] = STATE(2585),
    [sym_in_expression] = STATE(2585),
    [sym_variadic_expression] = STATE(2585),
    [sym_parenthesized_expression] = STATE(2585),
    [sym_or_return_expression] = STATE(2585),
    [sym_or_continue_expression] = STATE(2585),
    [sym_or_break_expression] = STATE(2585),
    [sym_address] = STATE(2585),
    [sym_map_type] = STATE(2585),
    [sym_matrix_type] = STATE(2585),
    [sym_distinct_type] = STATE(2585),
    [sym_literal] = STATE(2585),
    [sym_struct] = STATE(2586),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(389),
    [anon_sym_DASH] = ACTIONS(97),
    [anon_sym_TILDE] = ACTIONS(389),
    [anon_sym_BANG] = ACTIONS(389),
    [anon_sym_AMP] = ACTIONS(389),
    [anon_sym_DOT] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(103),
    [anon_sym_transmute] = ACTIONS(103),
    [anon_sym_auto_cast] = ACTIONS(105),
    [anon_sym_DOT_DOT] = ACTIONS(391),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2138] = {
    [ts_builtin_sym_end] = ACTIONS(4450),
    [sym_identifier] = ACTIONS(6468),
    [anon_sym_RBRACE] = ACTIONS(4450),
    [anon_sym_COMMA] = ACTIONS(4450),
    [anon_sym_COLON_COLON] = ACTIONS(4450),
    [anon_sym_DASH_GT] = ACTIONS(4450),
    [anon_sym_EQ] = ACTIONS(4454),
    [anon_sym_COLON] = ACTIONS(4454),
    [anon_sym_PIPE] = ACTIONS(4454),
    [anon_sym_COLON_EQ] = ACTIONS(4450),
    [anon_sym_LPAREN] = ACTIONS(4450),
    [anon_sym_PLUS_EQ] = ACTIONS(4450),
    [anon_sym_DASH_EQ] = ACTIONS(4450),
    [anon_sym_STAR_EQ] = ACTIONS(4450),
    [anon_sym_SLASH_EQ] = ACTIONS(4450),
    [anon_sym_PERCENT_EQ] = ACTIONS(4450),
    [anon_sym_AMP_EQ] = ACTIONS(4450),
    [anon_sym_PIPE_EQ] = ACTIONS(4450),
    [anon_sym_CARET_EQ] = ACTIONS(4450),
    [anon_sym_LT_LT_EQ] = ACTIONS(4450),
    [anon_sym_GT_GT_EQ] = ACTIONS(4450),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4450),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4450),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4450),
    [anon_sym_if] = ACTIONS(4454),
    [anon_sym_SEMI] = ACTIONS(4450),
    [anon_sym_else] = ACTIONS(4454),
    [anon_sym_when] = ACTIONS(4454),
    [anon_sym_in] = ACTIONS(4454),
    [anon_sym_case] = ACTIONS(4454),
    [anon_sym_QMARK] = ACTIONS(4450),
    [anon_sym_PLUS] = ACTIONS(4454),
    [anon_sym_DASH] = ACTIONS(4454),
    [anon_sym_TILDE] = ACTIONS(4454),
    [anon_sym_AMP] = ACTIONS(4454),
    [anon_sym_PIPE_PIPE] = ACTIONS(4454),
    [anon_sym_or_else] = ACTIONS(4454),
    [anon_sym_AMP_AMP] = ACTIONS(4454),
    [anon_sym_GT] = ACTIONS(4454),
    [anon_sym_GT_EQ] = ACTIONS(4450),
    [anon_sym_LT_EQ] = ACTIONS(4450),
    [anon_sym_LT] = ACTIONS(4454),
    [anon_sym_EQ_EQ] = ACTIONS(4450),
    [anon_sym_BANG_EQ] = ACTIONS(4450),
    [anon_sym_TILDE_EQ] = ACTIONS(4450),
    [anon_sym_AMP_TILDE] = ACTIONS(4454),
    [anon_sym_LT_LT] = ACTIONS(4454),
    [anon_sym_GT_GT] = ACTIONS(4454),
    [anon_sym_STAR] = ACTIONS(4454),
    [anon_sym_SLASH] = ACTIONS(4454),
    [anon_sym_PERCENT] = ACTIONS(4454),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4450),
    [anon_sym_DOT] = ACTIONS(4454),
    [anon_sym_LBRACK] = ACTIONS(4450),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4450),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4450),
    [anon_sym_not_in] = ACTIONS(4454),
    [anon_sym_or_return] = ACTIONS(4454),
    [anon_sym_or_continue] = ACTIONS(4454),
    [anon_sym_or_break] = ACTIONS(4454),
    [anon_sym_CARET] = ACTIONS(4454),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4450),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2139] = {
    [sym_expression] = STATE(2420),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2140] = {
    [sym_expression] = STATE(2295),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2141] = {
    [sym_expression] = STATE(2421),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2142] = {
    [sym_expression] = STATE(2318),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2143] = {
    [sym_expression] = STATE(2437),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2144] = {
    [sym_expression] = STATE(2438),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2145] = {
    [sym_expression] = STATE(2439),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2146] = {
    [sym_expression] = STATE(2440),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2147] = {
    [sym_expression] = STATE(2441),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2148] = {
    [sym_expression] = STATE(2442),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2149] = {
    [sym_expression] = STATE(2443),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2150] = {
    [sym_expression] = STATE(2444),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2151] = {
    [sym_expression] = STATE(2445),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2152] = {
    [sym_expression] = STATE(2446),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2153] = {
    [sym_expression] = STATE(2447),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2154] = {
    [sym_expression] = STATE(2448),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2155] = {
    [sym_expression] = STATE(2475),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2156] = {
    [sym_expression] = STATE(2240),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2157] = {
    [sym_expression] = STATE(2454),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2158] = {
    [sym_expression] = STATE(2455),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2159] = {
    [sym_expression] = STATE(2456),
    [sym__expression_no_tag] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym_binary_expression] = STATE(2344),
    [sym_ternary_expression] = STATE(2344),
    [sym_call_expression] = STATE(2344),
    [sym_selector_call_expression] = STATE(2344),
    [sym_member_expression] = STATE(2344),
    [sym_index_expression] = STATE(2344),
    [sym_slice_expression] = STATE(2344),
    [sym_range_expression] = STATE(2344),
    [sym_cast_expression] = STATE(2344),
    [sym_in_expression] = STATE(2344),
    [sym_variadic_expression] = STATE(2344),
    [sym_parenthesized_expression] = STATE(2344),
    [sym_or_return_expression] = STATE(2344),
    [sym_or_continue_expression] = STATE(2344),
    [sym_or_break_expression] = STATE(2344),
    [sym_address] = STATE(2344),
    [sym_map_type] = STATE(2344),
    [sym_matrix_type] = STATE(2344),
    [sym_distinct_type] = STATE(2344),
    [sym_literal] = STATE(2344),
    [sym_struct] = STATE(2516),
    [sym_map] = STATE(2268),
    [sym_bit_set] = STATE(2268),
    [sym_matrix] = STATE(2268),
    [sym_string] = STATE(2268),
    [sym__string_literal] = STATE(2276),
    [sym__raw_string_literal] = STATE(2276),
    [sym_character] = STATE(2268),
    [sym_boolean] = STATE(2268),
    [sym_field_identifier] = STATE(8702),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LPAREN] = ACTIONS(195),
    [anon_sym_QMARK] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_BANG] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(199),
    [anon_sym_LBRACK] = ACTIONS(101),
    [anon_sym_cast] = ACTIONS(187),
    [anon_sym_transmute] = ACTIONS(187),
    [anon_sym_auto_cast] = ACTIONS(189),
    [anon_sym_DOT_DOT] = ACTIONS(505),
    [anon_sym_map] = ACTIONS(109),
    [anon_sym_bit_set] = ACTIONS(111),
    [anon_sym_matrix] = ACTIONS(113),
    [anon_sym_distinct] = ACTIONS(115),
    [sym_number] = ACTIONS(117),
    [anon_sym_DQUOTE] = ACTIONS(119),
    [anon_sym_BQUOTE] = ACTIONS(121),
    [anon_sym_SQUOTE] = ACTIONS(123),
    [anon_sym_true] = ACTIONS(125),
    [anon_sym_false] = ACTIONS(125),
    [sym_nil] = ACTIONS(127),
    [sym_uninitialized] = ACTIONS(117),
    [sym_tag] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(117),
    [sym_block_comment] = ACTIONS(3),
  },
  [2160] = {
    [sym_expression] = STATE(6463),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2161] = {
    [sym_expression] = STATE(6464),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2162] = {
    [sym_expression] = STATE(2500),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [2163] = {
    [sym_expression] = STATE(4401),
    [sym__expression_no_tag] = STATE(3913),
    [sym_unary_expression] = STATE(3913),
    [sym_binary_expression] = STATE(3913),
    [sym_ternary_expression] = STATE(3913),
    [sym_call_expression] = STATE(3913),
    [sym_selector_call_expression] = STATE(3913),
    [sym_member_expression] = STATE(3913),
    [sym_index_expression] = STATE(3913),
    [sym_slice_expression] = STATE(3913),
    [sym_range_expression] = STATE(3913),
    [sym_cast_expression] = STATE(3913),
    [sym_in_expression] = STATE(3913),
    [sym_variadic_expression] = STATE(3913),
    [sym_parenthesized_expression] = STATE(3913),
    [sym_or_return_expression] = STATE(3913),
    [sym_or_continue_expression] = STATE(3913),
    [sym_or_break_expression] = STATE(3913),
    [sym_address] = STATE(3913),
    [sym_map_type] = STATE(3913),
    [sym_matrix_type] = STATE(3913),
    [sym_distinct_type] = STATE(3913),
    [sym_literal] = STATE(3913),
    [sym_struct] = STATE(3275),
    [sym_map] = STATE(3146),
    [sym_bit_set] = STATE(3146),
    [sym_matrix] = STATE(3146),
    [sym_string] = STATE(3146),
    [sym__string_literal] = STATE(3109),
    [sym__raw_string_literal] = STATE(3109),
    [sym_character] = STATE(3146),
    [sym_boolean] = STATE(3146),
    [sym_field_identifier] = STATE(8694),
    [sym_identifier] = ACTIONS(509),
    [anon_sym_LBRACE] = ACTIONS(511),
    [anon_sym_LPAREN] = ACTIONS(513),
    [anon_sym_QMARK] = ACTIONS(6466),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(519),
    [anon_sym_TILDE] = ACTIONS(517),
    [anon_sym_BANG] = ACTIONS(517),
    [anon_sym_AMP] = ACTIONS(517),
    [anon_sym_DOT] = ACTIONS(521),
    [anon_sym_LBRACK] = ACTIONS(523),
    [anon_sym_cast] = ACTIONS(525),
    [anon_sym_transmute] = ACTIONS(525),
    [anon_sym_auto_cast] = ACTIONS(527),
    [anon_sym_DOT_DOT] = ACTIONS(6322),
    [anon_sym_map] = ACTIONS(531),
    [anon_sym_bit_set] = ACTIONS(533),
    [anon_sym_matrix] = ACTIONS(535),
    [anon_sym_distinct] = ACTIONS(537),
    [sym_number] = ACTIONS(539),
    [anon_sym_DQUOTE] = ACTIONS(541),
    [anon_sym_BQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(545),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [sym_nil] = ACTIONS(549),
    [sym_uninitialized] = ACTIONS(539),
    [sym_tag] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(539),
    [sym_block_comment] = ACTIONS(3),
  },
  [2164] = {
    [sym_expression] = STATE(6158),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2165] = {
    [sym_expression] = STATE(2502),
    [sym__expression_no_tag] = STATE(2434),
    [sym_unary_expression] = STATE(2434),
    [sym_binary_expression] = STATE(2434),
    [sym_ternary_expression] = STATE(2434),
    [sym_call_expression] = STATE(2434),
    [sym_selector_call_expression] = STATE(2434),
    [sym_member_expression] = STATE(2434),
    [sym_index_expression] = STATE(2434),
    [sym_slice_expression] = STATE(2434),
    [sym_range_expression] = STATE(2434),
    [sym_cast_expression] = STATE(2434),
    [sym_in_expression] = STATE(2434),
    [sym_variadic_expression] = STATE(2434),
    [sym_parenthesized_expression] = STATE(2434),
    [sym_or_return_expression] = STATE(2434),
    [sym_or_continue_expression] = STATE(2434),
    [sym_or_break_expression] = STATE(2434),
    [sym_address] = STATE(2434),
    [sym_map_type] = STATE(2434),
    [sym_matrix_type] = STATE(2434),
    [sym_distinct_type] = STATE(2434),
    [sym_literal] = STATE(2434),
    [sym_struct] = STATE(2477),
    [sym_map] = STATE(2397),
    [sym_bit_set] = STATE(2397),
    [sym_matrix] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym__string_literal] = STATE(2481),
    [sym__raw_string_literal] = STATE(2481),
    [sym_character] = STATE(2397),
    [sym_boolean] = STATE(2397),
    [sym_field_identifier] = STATE(8628),
    [sym_identifier] = ACTIONS(211),
    [anon_sym_LBRACE] = ACTIONS(213),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_QMARK] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(6292),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(6292),
    [anon_sym_BANG] = ACTIONS(6292),
    [anon_sym_AMP] = ACTIONS(6292),
    [anon_sym_DOT] = ACTIONS(221),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_cast] = ACTIONS(225),
    [anon_sym_transmute] = ACTIONS(225),
    [anon_sym_auto_cast] = ACTIONS(227),
    [anon_sym_DOT_DOT] = ACTIONS(6294),
    [anon_sym_map] = ACTIONS(231),
    [anon_sym_bit_set] = ACTIONS(233),
    [anon_sym_matrix] = ACTIONS(235),
    [anon_sym_distinct] = ACTIONS(237),
    [sym_number] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(241),
    [anon_sym_BQUOTE] = ACTIONS(243),
    [anon_sym_SQUOTE] = ACTIONS(245),
    [anon_sym_true] = ACTIONS(247),
    [anon_sym_false] = ACTIONS(247),
    [sym_nil] = ACTIONS(249),
    [sym_uninitialized] = ACTIONS(239),
    [sym_tag] = ACTIONS(251),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(239),
    [sym_block_comment] = ACTIONS(3),
  },
  [2166] = {
    [sym_expression] = STATE(6233),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2167] = {
    [sym_expression] = STATE(6161),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2168] = {
    [sym_expression] = STATE(6247),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2169] = {
    [sym_expression] = STATE(6164),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2170] = {
    [sym_identifier] = ACTIONS(6470),
    [anon_sym_LBRACE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_where] = ACTIONS(73),
    [anon_sym_EQ] = ACTIONS(73),
    [anon_sym_COLON] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(73),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_LPAREN] = ACTIONS(6472),
    [anon_sym_PLUS_EQ] = ACTIONS(69),
    [anon_sym_DASH_EQ] = ACTIONS(69),
    [anon_sym_STAR_EQ] = ACTIONS(69),
    [anon_sym_SLASH_EQ] = ACTIONS(69),
    [anon_sym_PERCENT_EQ] = ACTIONS(69),
    [anon_sym_AMP_EQ] = ACTIONS(69),
    [anon_sym_PIPE_EQ] = ACTIONS(69),
    [anon_sym_CARET_EQ] = ACTIONS(69),
    [anon_sym_LT_LT_EQ] = ACTIONS(69),
    [anon_sym_GT_GT_EQ] = ACTIONS(69),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(69),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(73),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_do] = ACTIONS(73),
    [anon_sym_when] = ACTIONS(73),
    [anon_sym_in] = ACTIONS(73),
    [anon_sym_QMARK] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(73),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_TILDE] = ACTIONS(73),
    [anon_sym_AMP] = ACTIONS(73),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_or_else] = ACTIONS(73),
    [anon_sym_AMP_AMP] = ACTIONS(73),
    [anon_sym_GT] = ACTIONS(73),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(73),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_BANG_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_AMP_TILDE] = ACTIONS(73),
    [anon_sym_LT_LT] = ACTIONS(73),
    [anon_sym_GT_GT] = ACTIONS(73),
    [anon_sym_STAR] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(73),
    [anon_sym_PERCENT] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(69),
    [anon_sym_DOT] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(69),
    [anon_sym_DOT_DOT_LT] = ACTIONS(69),
    [anon_sym_not_in] = ACTIONS(73),
    [anon_sym_or_return] = ACTIONS(73),
    [anon_sym_or_continue] = ACTIONS(73),
    [anon_sym_or_break] = ACTIONS(73),
    [anon_sym_CARET] = ACTIONS(73),
    [sym_uninitialized] = ACTIONS(69),
    [sym_tag] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2171] = {
    [sym_expression] = STATE(6262),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2172] = {
    [sym_expression] = STATE(6167),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2173] = {
    [aux_sym_field_identifier_repeat1] = STATE(7617),
    [anon_sym_LBRACE] = ACTIONS(6474),
    [anon_sym_COMMA] = ACTIONS(3912),
    [anon_sym_COLON_COLON] = ACTIONS(3912),
    [anon_sym_DASH_GT] = ACTIONS(3912),
    [anon_sym_where] = ACTIONS(3912),
    [anon_sym_EQ] = ACTIONS(3917),
    [anon_sym_COLON] = ACTIONS(3917),
    [anon_sym_PIPE] = ACTIONS(3917),
    [anon_sym_COLON_EQ] = ACTIONS(3912),
    [anon_sym_LPAREN] = ACTIONS(6477),
    [anon_sym_PLUS_EQ] = ACTIONS(3912),
    [anon_sym_DASH_EQ] = ACTIONS(3912),
    [anon_sym_STAR_EQ] = ACTIONS(3912),
    [anon_sym_SLASH_EQ] = ACTIONS(3912),
    [anon_sym_PERCENT_EQ] = ACTIONS(3912),
    [anon_sym_AMP_EQ] = ACTIONS(3912),
    [anon_sym_PIPE_EQ] = ACTIONS(3912),
    [anon_sym_CARET_EQ] = ACTIONS(3912),
    [anon_sym_LT_LT_EQ] = ACTIONS(3912),
    [anon_sym_GT_GT_EQ] = ACTIONS(3912),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(3912),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(3912),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(3912),
    [anon_sym_if] = ACTIONS(3912),
    [anon_sym_SEMI] = ACTIONS(3912),
    [anon_sym_do] = ACTIONS(3912),
    [anon_sym_when] = ACTIONS(3912),
    [anon_sym_in] = ACTIONS(3912),
    [anon_sym_QMARK] = ACTIONS(3912),
    [anon_sym_PLUS] = ACTIONS(3917),
    [anon_sym_DASH] = ACTIONS(3917),
    [anon_sym_TILDE] = ACTIONS(3917),
    [anon_sym_AMP] = ACTIONS(3917),
    [anon_sym_PIPE_PIPE] = ACTIONS(3917),
    [anon_sym_or_else] = ACTIONS(3912),
    [anon_sym_AMP_AMP] = ACTIONS(3917),
    [anon_sym_GT] = ACTIONS(3917),
    [anon_sym_GT_EQ] = ACTIONS(3912),
    [anon_sym_LT_EQ] = ACTIONS(3912),
    [anon_sym_LT] = ACTIONS(3917),
    [anon_sym_EQ_EQ] = ACTIONS(3912),
    [anon_sym_BANG_EQ] = ACTIONS(3912),
    [anon_sym_TILDE_EQ] = ACTIONS(3912),
    [anon_sym_AMP_TILDE] = ACTIONS(3917),
    [anon_sym_LT_LT] = ACTIONS(3917),
    [anon_sym_GT_GT] = ACTIONS(3917),
    [anon_sym_STAR] = ACTIONS(3917),
    [anon_sym_SLASH] = ACTIONS(3917),
    [anon_sym_PERCENT] = ACTIONS(3917),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(3912),
    [anon_sym_DOT] = ACTIONS(3917),
    [anon_sym_LBRACK] = ACTIONS(3912),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(3912),
    [anon_sym_DOT_DOT_LT] = ACTIONS(3912),
    [anon_sym_not_in] = ACTIONS(3912),
    [anon_sym_or_return] = ACTIONS(3912),
    [anon_sym_or_continue] = ACTIONS(3912),
    [anon_sym_or_break] = ACTIONS(3912),
    [anon_sym_CARET] = ACTIONS(3917),
    [sym_uninitialized] = ACTIONS(3912),
    [sym_tag] = ACTIONS(3912),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2174] = {
    [sym_expression] = STATE(6273),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2175] = {
    [sym_expression] = STATE(6169),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2176] = {
    [sym_expression] = STATE(6284),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2177] = {
    [sym_expression] = STATE(6171),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2178] = {
    [sym_expression] = STATE(6295),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2179] = {
    [sym_expression] = STATE(6172),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2180] = {
    [sym_expression] = STATE(6303),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2181] = {
    [sym_expression] = STATE(6174),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2182] = {
    [ts_builtin_sym_end] = ACTIONS(4717),
    [anon_sym_LBRACE] = ACTIONS(4717),
    [anon_sym_RBRACE] = ACTIONS(4717),
    [anon_sym_COMMA] = ACTIONS(4717),
    [anon_sym_COLON_COLON] = ACTIONS(4717),
    [anon_sym_DASH_GT] = ACTIONS(4717),
    [anon_sym_EQ] = ACTIONS(4719),
    [anon_sym_COLON] = ACTIONS(4719),
    [anon_sym_PIPE] = ACTIONS(4719),
    [anon_sym_COLON_EQ] = ACTIONS(4717),
    [anon_sym_LPAREN] = ACTIONS(4717),
    [anon_sym_PLUS_EQ] = ACTIONS(4717),
    [anon_sym_DASH_EQ] = ACTIONS(4717),
    [anon_sym_STAR_EQ] = ACTIONS(4717),
    [anon_sym_SLASH_EQ] = ACTIONS(4717),
    [anon_sym_PERCENT_EQ] = ACTIONS(4717),
    [anon_sym_AMP_EQ] = ACTIONS(4717),
    [anon_sym_PIPE_EQ] = ACTIONS(4717),
    [anon_sym_CARET_EQ] = ACTIONS(4717),
    [anon_sym_LT_LT_EQ] = ACTIONS(4717),
    [anon_sym_GT_GT_EQ] = ACTIONS(4717),
    [anon_sym_PIPE_PIPE_EQ] = ACTIONS(4717),
    [anon_sym_AMP_AMP_EQ] = ACTIONS(4717),
    [anon_sym_AMP_TILDE_EQ] = ACTIONS(4717),
    [anon_sym_if] = ACTIONS(4717),
    [anon_sym_SEMI] = ACTIONS(4717),
    [anon_sym_else] = ACTIONS(4717),
    [anon_sym_when] = ACTIONS(4717),
    [anon_sym_in] = ACTIONS(4717),
    [anon_sym_case] = ACTIONS(4717),
    [anon_sym_QMARK] = ACTIONS(4717),
    [anon_sym_PLUS] = ACTIONS(4719),
    [anon_sym_DASH] = ACTIONS(4719),
    [anon_sym_TILDE] = ACTIONS(4719),
    [anon_sym_AMP] = ACTIONS(4719),
    [anon_sym_PIPE_PIPE] = ACTIONS(4719),
    [anon_sym_or_else] = ACTIONS(4717),
    [anon_sym_AMP_AMP] = ACTIONS(4719),
    [anon_sym_GT] = ACTIONS(4719),
    [anon_sym_GT_EQ] = ACTIONS(4717),
    [anon_sym_LT_EQ] = ACTIONS(4717),
    [anon_sym_LT] = ACTIONS(4719),
    [anon_sym_EQ_EQ] = ACTIONS(4717),
    [anon_sym_BANG_EQ] = ACTIONS(4717),
    [anon_sym_TILDE_EQ] = ACTIONS(4717),
    [anon_sym_AMP_TILDE] = ACTIONS(4719),
    [anon_sym_LT_LT] = ACTIONS(4719),
    [anon_sym_GT_GT] = ACTIONS(4719),
    [anon_sym_STAR] = ACTIONS(4719),
    [anon_sym_SLASH] = ACTIONS(4719),
    [anon_sym_PERCENT] = ACTIONS(4719),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(4717),
    [anon_sym_DOT] = ACTIONS(4719),
    [anon_sym_LBRACK] = ACTIONS(4717),
    [anon_sym_DOT_DOT_EQ] = ACTIONS(4717),
    [anon_sym_DOT_DOT_LT] = ACTIONS(4717),
    [anon_sym_not_in] = ACTIONS(4717),
    [anon_sym_or_return] = ACTIONS(4717),
    [anon_sym_or_continue] = ACTIONS(4717),
    [anon_sym_or_break] = ACTIONS(4717),
    [anon_sym_CARET] = ACTIONS(4719),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(4717),
    [sym__backslash] = ACTIONS(3),
    [sym_block_comment] = ACTIONS(3),
  },
  [2183] = {
    [sym_expression] = STATE(6311),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2184] = {
    [sym_expression] = STATE(6176),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2185] = {
    [sym_expression] = STATE(6319),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2186] = {
    [sym_expression] = STATE(6177),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2187] = {
    [sym_expression] = STATE(6329),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2188] = {
    [sym_expression] = STATE(6125),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2189] = {
    [sym_expression] = STATE(6178),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2190] = {
    [sym_expression] = STATE(6339),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2191] = {
    [sym_expression] = STATE(6346),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2192] = {
    [sym_expression] = STATE(6351),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2193] = {
    [sym_expression] = STATE(6355),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2194] = {
    [sym_expression] = STATE(6358),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2195] = {
    [sym_expression] = STATE(6389),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2196] = {
    [sym_expression] = STATE(6390),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2197] = {
    [sym_expression] = STATE(5996),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(6480),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [2198] = {
    [sym_expression] = STATE(6614),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2199] = {
    [sym_expression] = STATE(6477),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2200] = {
    [sym_expression] = STATE(6484),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2201] = {
    [sym_expression] = STATE(6492),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2202] = {
    [sym_expression] = STATE(6501),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2203] = {
    [sym_expression] = STATE(6510),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2204] = {
    [sym_expression] = STATE(6110),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(6482),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [2205] = {
    [sym_expression] = STATE(6123),
    [sym__expression_no_tag] = STATE(4818),
    [sym_unary_expression] = STATE(4818),
    [sym_binary_expression] = STATE(4818),
    [sym_ternary_expression] = STATE(4818),
    [sym_call_expression] = STATE(4818),
    [sym_selector_call_expression] = STATE(4818),
    [sym_member_expression] = STATE(4818),
    [sym_index_expression] = STATE(4818),
    [sym_slice_expression] = STATE(4818),
    [sym_range_expression] = STATE(4818),
    [sym_cast_expression] = STATE(4818),
    [sym_in_expression] = STATE(4818),
    [sym_variadic_expression] = STATE(4818),
    [sym_parenthesized_expression] = STATE(4818),
    [sym_or_return_expression] = STATE(4818),
    [sym_or_continue_expression] = STATE(4818),
    [sym_or_break_expression] = STATE(4818),
    [sym_address] = STATE(4818),
    [sym_map_type] = STATE(4818),
    [sym_matrix_type] = STATE(4818),
    [sym_distinct_type] = STATE(4818),
    [sym_literal] = STATE(4818),
    [sym_struct] = STATE(4805),
    [sym_map] = STATE(4851),
    [sym_bit_set] = STATE(4851),
    [sym_matrix] = STATE(4851),
    [sym_string] = STATE(4851),
    [sym__string_literal] = STATE(4807),
    [sym__raw_string_literal] = STATE(4807),
    [sym_character] = STATE(4851),
    [sym_boolean] = STATE(4851),
    [sym_field_identifier] = STATE(8870),
    [sym_identifier] = ACTIONS(347),
    [anon_sym_LBRACE] = ACTIONS(1211),
    [anon_sym_LPAREN] = ACTIONS(1213),
    [anon_sym_QMARK] = ACTIONS(399),
    [anon_sym_PLUS] = ACTIONS(1217),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(1217),
    [anon_sym_BANG] = ACTIONS(1217),
    [anon_sym_AMP] = ACTIONS(1217),
    [anon_sym_DOT] = ACTIONS(1219),
    [anon_sym_LBRACK] = ACTIONS(1221),
    [anon_sym_cast] = ACTIONS(351),
    [anon_sym_transmute] = ACTIONS(351),
    [anon_sym_auto_cast] = ACTIONS(353),
    [anon_sym_DOT_DOT] = ACTIONS(3360),
    [anon_sym_map] = ACTIONS(357),
    [anon_sym_bit_set] = ACTIONS(359),
    [anon_sym_matrix] = ACTIONS(361),
    [anon_sym_distinct] = ACTIONS(363),
    [sym_number] = ACTIONS(365),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_BQUOTE] = ACTIONS(369),
    [anon_sym_SQUOTE] = ACTIONS(371),
    [anon_sym_true] = ACTIONS(373),
    [anon_sym_false] = ACTIONS(373),
    [sym_nil] = ACTIONS(375),
    [sym_uninitialized] = ACTIONS(365),
    [sym_tag] = ACTIONS(377),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(365),
    [sym_block_comment] = ACTIONS(3),
  },
  [2206] = {
    [sym_expression] = STATE(6585),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2207] = {
    [sym_expression] = STATE(6586),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2208] = {
    [sym_expression] = STATE(6587),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2209] = {
    [sym_expression] = STATE(6588),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2210] = {
    [sym_expression] = STATE(6589),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
  [2211] = {
    [sym_expression] = STATE(6077),
    [sym__expression_no_tag] = STATE(4016),
    [sym_unary_expression] = STATE(4016),
    [sym_binary_expression] = STATE(4016),
    [sym_ternary_expression] = STATE(4016),
    [sym_call_expression] = STATE(4016),
    [sym_selector_call_expression] = STATE(4016),
    [sym_member_expression] = STATE(4016),
    [sym_index_expression] = STATE(4016),
    [sym_slice_expression] = STATE(4016),
    [sym_range_expression] = STATE(4016),
    [sym_cast_expression] = STATE(4016),
    [sym_in_expression] = STATE(4016),
    [sym_variadic_expression] = STATE(4016),
    [sym_parenthesized_expression] = STATE(4016),
    [sym_or_return_expression] = STATE(4016),
    [sym_or_continue_expression] = STATE(4016),
    [sym_or_break_expression] = STATE(4016),
    [sym_address] = STATE(4016),
    [sym_map_type] = STATE(4016),
    [sym_matrix_type] = STATE(4016),
    [sym_distinct_type] = STATE(4016),
    [sym_literal] = STATE(4016),
    [sym_struct] = STATE(4034),
    [sym_map] = STATE(4202),
    [sym_bit_set] = STATE(4202),
    [sym_matrix] = STATE(4202),
    [sym_string] = STATE(4202),
    [sym__string_literal] = STATE(4035),
    [sym__raw_string_literal] = STATE(4035),
    [sym_character] = STATE(4202),
    [sym_boolean] = STATE(4202),
    [sym_field_identifier] = STATE(8881),
    [sym_identifier] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(659),
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(2926),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(667),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_BANG] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_cast] = ACTIONS(673),
    [anon_sym_transmute] = ACTIONS(673),
    [anon_sym_auto_cast] = ACTIONS(675),
    [anon_sym_DOT_DOT] = ACTIONS(2930),
    [anon_sym_map] = ACTIONS(679),
    [anon_sym_bit_set] = ACTIONS(681),
    [anon_sym_matrix] = ACTIONS(683),
    [anon_sym_distinct] = ACTIONS(685),
    [sym_number] = ACTIONS(687),
    [anon_sym_DQUOTE] = ACTIONS(689),
    [anon_sym_BQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(693),
    [anon_sym_true] = ACTIONS(695),
    [anon_sym_false] = ACTIONS(695),
    [sym_nil] = ACTIONS(697),
    [sym_uninitialized] = ACTIONS(687),
    [sym_tag] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym__backslash] = ACTIONS(3),
    [sym_float] = ACTIONS(687),
    [sym_block_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4985), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [71] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4937), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [142] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4867), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [213] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4701), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [284] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4639), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [355] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4807), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [426] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4871), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [497] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4811), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [568] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4835), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [639] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4643), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [710] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(207), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [781] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4647), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [852] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4875), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [923] = 25,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6393), 1,
      anon_sym_PIPE,
    ACTIONS(6397), 1,
      anon_sym_TILDE,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6403), 1,
      anon_sym_or_else,
    ACTIONS(6405), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6427), 1,
      anon_sym_or_return,
    ACTIONS(6429), 1,
      anon_sym_or_continue,
    ACTIONS(6431), 1,
      anon_sym_or_break,
    ACTIONS(6433), 1,
      anon_sym_CARET,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6407), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6409), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6411), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4879), 28,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [1038] = 21,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6393), 1,
      anon_sym_PIPE,
    ACTIONS(6397), 1,
      anon_sym_TILDE,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6403), 1,
      anon_sym_or_else,
    ACTIONS(6405), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6407), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6409), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4881), 3,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_CARET,
    ACTIONS(6411), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4879), 31,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [1145] = 7,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6241), 1,
      sym_uninitialized,
    ACTIONS(6247), 1,
      sym_tag,
    STATE(2667), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [1224] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3425), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [1295] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5055), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [1366] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5015), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [1437] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4651), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [1508] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4655), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [1579] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4815), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [1650] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5035), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [1721] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4855), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [1792] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4883), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [1863] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4659), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [1934] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4799), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2005] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4701), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2076] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4763), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2147] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4663), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2218] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4887), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [2289] = 7,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6249), 1,
      sym_uninitialized,
    ACTIONS(6251), 1,
      sym_tag,
    STATE(2639), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3400), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2368] = 7,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6484), 1,
      sym_uninitialized,
    ACTIONS(6486), 1,
      sym_tag,
    STATE(2641), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4577), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2447] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4667), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2518] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4891), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [2589] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4859), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2660] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4683), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2731] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4671), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2802] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [2873] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4675), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [2944] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4863), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [3015] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [3086] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5127), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [3157] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4917), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [3228] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5131), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [3299] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4965), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [3370] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4965), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [3441] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4969), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [3512] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4973), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [3583] = 7,
    ACTIONS(6447), 1,
      anon_sym_LPAREN,
    ACTIONS(6492), 1,
      anon_sym_QMARK,
    ACTIONS(6490), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6488), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [3662] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4883), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [3733] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5027), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [3804] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5135), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [3875] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4717), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [3946] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4887), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [4017] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5039), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [4088] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4693), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [4159] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5139), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [4230] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5237), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [4301] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4981), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [4372] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4709), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [4443] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4985), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [4514] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4679), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [4585] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5241), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [4656] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4705), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [4727] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [4798] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5245), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [4869] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5139), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [4940] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5019), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5011] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5241), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5082] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5245), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5153] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5249), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5224] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4725), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5295] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5249), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [5366] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5253), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5437] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5031), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5508] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5059), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5579] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5043), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5650] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5047), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5721] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5051), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5792] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5051), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5863] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [5934] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5253), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [6005] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4909), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [6076] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(809), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [6147] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4725), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [6218] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4735), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [6289] = 5,
    ACTIONS(6494), 1,
      anon_sym_LPAREN,
    ACTIONS(6496), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4751), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [6364] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5119), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [6435] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4827), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [6506] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5063), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [6577] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5073), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [6648] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5077), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [6719] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3451), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [6790] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(871), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [6861] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4831), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [6932] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5099), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7003] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5145), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7074] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4933), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7145] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5111), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7216] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4905), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7287] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5115), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7358] = 6,
    ACTIONS(5986), 1,
      anon_sym_LPAREN,
    ACTIONS(5988), 1,
      anon_sym_SLASH,
    ACTIONS(6498), 1,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5009), 17,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5005), 41,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7435] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4823), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [7506] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5025), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5023), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7577] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4913), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7648] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4925), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [7719] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5123), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7790] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4937), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7861] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4639), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [7932] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4739), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [8003] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4743), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [8074] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5059), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [8145] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4631), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [8216] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3425), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [8287] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4643), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [8358] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4891), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [8429] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [8500] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(909), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [8571] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4759), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [8642] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [8713] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4647), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [8784] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4917), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [8855] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4965), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [8926] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4965), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [8997] = 10,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6502), 1,
      anon_sym_DASH_GT,
    ACTIONS(6504), 1,
      sym_uninitialized,
    ACTIONS(6506), 1,
      sym_tag,
    STATE(2571), 1,
      sym_where_clause,
    STATE(2831), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3439), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [9082] = 10,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6508), 1,
      anon_sym_DASH_GT,
    ACTIONS(6510), 1,
      sym_uninitialized,
    ACTIONS(6512), 1,
      sym_tag,
    STATE(2575), 1,
      sym_where_clause,
    STATE(2818), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3451), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [9167] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4651), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [9238] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4953), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [9309] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [9380] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [9451] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4655), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [9522] = 4,
    ACTIONS(6447), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [9595] = 11,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(5986), 1,
      anon_sym_LPAREN,
    ACTIONS(5988), 1,
      anon_sym_SLASH,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6514), 1,
      sym_uninitialized,
    ACTIONS(6516), 1,
      sym_tag,
    STATE(2576), 1,
      sym_where_clause,
    STATE(2936), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3425), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [9682] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3481), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [9753] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4659), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [9824] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5081), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [9895] = 9,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6514), 1,
      sym_uninitialized,
    ACTIONS(6516), 1,
      sym_tag,
    STATE(2576), 1,
      sym_where_clause,
    STATE(2936), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3425), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [9978] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4663), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [10049] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4667), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [10120] = 5,
    ACTIONS(6494), 1,
      anon_sym_LPAREN,
    ACTIONS(6496), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4961), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [10195] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4631), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [10266] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5257), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [10337] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4671), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [10408] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3400), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [10479] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4577), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [10550] = 11,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(5986), 1,
      anon_sym_LPAREN,
    ACTIONS(5988), 1,
      anon_sym_SLASH,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6518), 1,
      sym_uninitialized,
    ACTIONS(6520), 1,
      sym_tag,
    STATE(2577), 1,
      sym_where_clause,
    STATE(2881), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [10637] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4585), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [10708] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4675), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [10779] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4949), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [10850] = 9,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6518), 1,
      sym_uninitialized,
    ACTIONS(6520), 1,
      sym_tag,
    STATE(2577), 1,
      sym_where_clause,
    STATE(2881), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [10933] = 9,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6518), 1,
      sym_uninitialized,
    ACTIONS(6522), 1,
      sym_tag,
    STATE(2577), 1,
      sym_where_clause,
    STATE(2881), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [11016] = 11,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(5986), 1,
      anon_sym_LPAREN,
    ACTIONS(5988), 1,
      anon_sym_SLASH,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      sym_uninitialized,
    ACTIONS(6526), 1,
      sym_tag,
    STATE(2600), 1,
      sym_where_clause,
    STATE(2856), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [11103] = 9,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      sym_uninitialized,
    ACTIONS(6526), 1,
      sym_tag,
    STATE(2600), 1,
      sym_where_clause,
    STATE(2856), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [11186] = 9,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      sym_uninitialized,
    ACTIONS(6528), 1,
      sym_tag,
    STATE(2600), 1,
      sym_where_clause,
    STATE(2856), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [11269] = 9,
    ACTIONS(5974), 1,
      anon_sym_where,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6530), 1,
      sym_uninitialized,
    ACTIONS(6532), 1,
      sym_tag,
    STATE(2580), 1,
      sym_where_clause,
    STATE(2879), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3400), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [11352] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4969), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [11423] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4973), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [11494] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3400), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [11565] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4713), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [11636] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3701), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [11707] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(893), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [11778] = 14,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6397), 1,
      anon_sym_TILDE,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 8,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [11871] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4787), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [11942] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4795), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [12013] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4803), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [12084] = 26,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6393), 1,
      anon_sym_PIPE,
    ACTIONS(6397), 1,
      anon_sym_TILDE,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6403), 1,
      anon_sym_or_else,
    ACTIONS(6405), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6427), 1,
      anon_sym_or_return,
    ACTIONS(6429), 1,
      anon_sym_or_continue,
    ACTIONS(6431), 1,
      anon_sym_or_break,
    ACTIONS(6433), 1,
      anon_sym_CARET,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6407), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6409), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6534), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6411), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5067), 26,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_QMARK,
      sym_uninitialized,
      sym_tag,
  [12201] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4841), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4839), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [12272] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4981), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [12343] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4773), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [12414] = 9,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 15,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [12497] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5123), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [12568] = 5,
    ACTIONS(5986), 1,
      anon_sym_LPAREN,
    ACTIONS(5988), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5103), 41,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [12643] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5019), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [12714] = 13,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 9,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [12805] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4807), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [12876] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4725), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [12947] = 12,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [13036] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4735), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [13107] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4811), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [13178] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5127), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [13249] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4739), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [13320] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5131), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [13391] = 19,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6393), 1,
      anon_sym_PIPE,
    ACTIONS(6397), 1,
      anon_sym_TILDE,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6405), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6407), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6409), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6411), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [13494] = 18,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6393), 1,
      anon_sym_PIPE,
    ACTIONS(6397), 1,
      anon_sym_TILDE,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6407), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6409), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6411), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [13595] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4693), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [13666] = 16,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6393), 1,
      anon_sym_PIPE,
    ACTIONS(6397), 1,
      anon_sym_TILDE,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6411), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 34,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [13763] = 15,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6393), 1,
      anon_sym_PIPE,
    ACTIONS(6397), 1,
      anon_sym_TILDE,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [13858] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4743), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [13929] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4585), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14000] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4815), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14071] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4855), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14142] = 11,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14229] = 25,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6393), 1,
      anon_sym_PIPE,
    ACTIONS(6397), 1,
      anon_sym_TILDE,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6403), 1,
      anon_sym_or_else,
    ACTIONS(6405), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6427), 1,
      anon_sym_or_return,
    ACTIONS(6429), 1,
      anon_sym_or_continue,
    ACTIONS(6431), 1,
      anon_sym_or_break,
    ACTIONS(6433), 1,
      anon_sym_CARET,
    ACTIONS(4471), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6407), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6409), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6411), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4466), 28,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [14344] = 10,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 13,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14429] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4949), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14500] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4859), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14571] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4863), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14642] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4945), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14713] = 7,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4635), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14792] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4755), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14863] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4763), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [14934] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4941), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [15005] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4773), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [15076] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(893), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [15147] = 25,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6393), 1,
      anon_sym_PIPE,
    ACTIONS(6397), 1,
      anon_sym_TILDE,
    ACTIONS(6399), 1,
      anon_sym_AMP,
    ACTIONS(6401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6403), 1,
      anon_sym_or_else,
    ACTIONS(6405), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6413), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6419), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6427), 1,
      anon_sym_or_return,
    ACTIONS(6429), 1,
      anon_sym_or_continue,
    ACTIONS(6431), 1,
      anon_sym_or_break,
    ACTIONS(6433), 1,
      anon_sym_CARET,
    ACTIONS(4793), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6395), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6407), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6409), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6415), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6411), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6417), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4791), 28,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [15262] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(809), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [15333] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [15404] = 7,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4731), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [15483] = 7,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4921), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [15562] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5095), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [15633] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4799), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [15704] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4723), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4721), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [15775] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5257), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [15846] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(871), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [15917] = 7,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4819), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [15996] = 7,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6184), 1,
      sym_uninitialized,
    ACTIONS(6186), 1,
      sym_tag,
    STATE(2616), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3451), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [16075] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5095), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [16146] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(909), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [16217] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(767), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [16288] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5055), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [16359] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5081), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [16430] = 4,
    ACTIONS(6472), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 41,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [16503] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4875), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [16574] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5015), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [16645] = 14,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6546), 1,
      anon_sym_TILDE,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 8,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [16738] = 26,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6546), 1,
      anon_sym_TILDE,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6558), 1,
      anon_sym_PIPE,
    ACTIONS(6562), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6564), 1,
      anon_sym_or_else,
    ACTIONS(6566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6574), 1,
      anon_sym_or_return,
    ACTIONS(6576), 1,
      anon_sym_or_continue,
    ACTIONS(6578), 1,
      anon_sym_or_break,
    ACTIONS(6580), 1,
      anon_sym_CARET,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6560), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6568), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6570), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6572), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 26,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_case,
      anon_sym_QMARK,
  [16855] = 9,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 15,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [16938] = 13,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 9,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [17029] = 12,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [17118] = 19,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6546), 1,
      anon_sym_TILDE,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6558), 1,
      anon_sym_PIPE,
    ACTIONS(6566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6568), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6570), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6572), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [17221] = 18,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6546), 1,
      anon_sym_TILDE,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6558), 1,
      anon_sym_PIPE,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6568), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6570), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6572), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [17322] = 16,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6546), 1,
      anon_sym_TILDE,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6558), 1,
      anon_sym_PIPE,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6572), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 34,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [17419] = 15,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6546), 1,
      anon_sym_TILDE,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6558), 1,
      anon_sym_PIPE,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [17514] = 11,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [17601] = 10,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 13,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [17686] = 7,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4635), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [17765] = 25,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6546), 1,
      anon_sym_TILDE,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6558), 1,
      anon_sym_PIPE,
    ACTIONS(6562), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6564), 1,
      anon_sym_or_else,
    ACTIONS(6566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6574), 1,
      anon_sym_or_return,
    ACTIONS(6576), 1,
      anon_sym_or_continue,
    ACTIONS(6578), 1,
      anon_sym_or_break,
    ACTIONS(6580), 1,
      anon_sym_CARET,
    ACTIONS(4793), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6568), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6570), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6572), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 28,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
  [17880] = 7,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4819), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [17959] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4867), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [18030] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4759), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [18101] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4717), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [18172] = 7,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4843), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [18251] = 25,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6546), 1,
      anon_sym_TILDE,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6558), 1,
      anon_sym_PIPE,
    ACTIONS(6562), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6564), 1,
      anon_sym_or_else,
    ACTIONS(6566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6574), 1,
      anon_sym_or_return,
    ACTIONS(6576), 1,
      anon_sym_or_continue,
    ACTIONS(6578), 1,
      anon_sym_or_break,
    ACTIONS(6580), 1,
      anon_sym_CARET,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6568), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6570), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6572), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 28,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
  [18366] = 21,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6546), 1,
      anon_sym_TILDE,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6558), 1,
      anon_sym_PIPE,
    ACTIONS(6562), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6564), 1,
      anon_sym_or_else,
    ACTIONS(6566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6568), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6570), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4881), 3,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_CARET,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6572), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [18473] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5027), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [18544] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4749), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4747), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [18615] = 7,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6200), 1,
      sym_uninitialized,
    ACTIONS(6582), 1,
      sym_tag,
    STATE(2625), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3425), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [18694] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5237), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [18765] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5031), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [18836] = 4,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4683), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(4715), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4713), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [18909] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4847), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [18980] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5043), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [19051] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4953), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [19122] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4679), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [19193] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(207), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [19264] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5039), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [19335] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5047), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [19406] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5051), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [19477] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3481), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [19548] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5051), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [19619] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4709), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [19690] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4823), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [19761] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4755), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [19832] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4683), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [19903] = 5,
    ACTIONS(6586), 1,
      anon_sym_QMARK,
    ACTIONS(6584), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4693), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [19978] = 5,
    ACTIONS(5986), 1,
      anon_sym_LPAREN,
    ACTIONS(5988), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4961), 41,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [20053] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4989), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [20124] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4827), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [20195] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4705), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [20266] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4941), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [20337] = 5,
    ACTIONS(6494), 1,
      anon_sym_LPAREN,
    ACTIONS(6496), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5001), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [20412] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4931), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4929), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [20483] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4713), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [20554] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4989), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [20625] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5063), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [20696] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4831), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [20767] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5073), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [20838] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4945), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [20909] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5077), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [20980] = 7,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4731), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [21059] = 5,
    ACTIONS(5986), 1,
      anon_sym_LPAREN,
    ACTIONS(5988), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5001), 41,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [21134] = 5,
    ACTIONS(6494), 1,
      anon_sym_LPAREN,
    ACTIONS(6496), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5011), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [21209] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4787), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [21280] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4909), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [21351] = 5,
    ACTIONS(5986), 1,
      anon_sym_LPAREN,
    ACTIONS(5988), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4751), 41,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [21426] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4795), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [21497] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4835), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [21568] = 7,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4921), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [21647] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4689), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [21718] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4925), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [21789] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3451), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [21860] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5135), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [21931] = 6,
    ACTIONS(6281), 1,
      anon_sym_LBRACE,
    ACTIONS(6588), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3912), 39,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22008] = 7,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6214), 1,
      sym_uninitialized,
    ACTIONS(6220), 1,
      sym_tag,
    STATE(2634), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22087] = 7,
    ACTIONS(6391), 1,
      anon_sym_DASH_GT,
    ACTIONS(6421), 1,
      anon_sym_DOT,
    ACTIONS(6423), 1,
      anon_sym_LBRACK,
    ACTIONS(6425), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4843), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [22166] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5119), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22237] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4803), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22308] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(767), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22379] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5145), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22450] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5099), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22521] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4933), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22592] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4905), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22663] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4871), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22734] = 5,
    ACTIONS(6492), 1,
      anon_sym_QMARK,
    ACTIONS(6490), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4693), 39,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22809] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5111), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [22880] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4847), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [22951] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4959), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4957), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [23022] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5115), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [23093] = 5,
    ACTIONS(5986), 1,
      anon_sym_LPAREN,
    ACTIONS(5988), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5011), 41,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [23168] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4913), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [23239] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [23310] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5035), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [23381] = 5,
    ACTIONS(6494), 1,
      anon_sym_LPAREN,
    ACTIONS(6496), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5103), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [23456] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [23527] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4689), 42,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [23598] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [23669] = 6,
    ACTIONS(5986), 1,
      anon_sym_LPAREN,
    ACTIONS(5988), 1,
      anon_sym_SLASH,
    ACTIONS(6590), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4751), 40,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [23746] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4577), 42,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_uninitialized,
      sym_tag,
  [23817] = 5,
    ACTIONS(6592), 1,
      anon_sym_DOT2,
    STATE(2531), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3408), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [23891] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7456), 1,
      sym_type,
    STATE(7979), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [24021] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7438), 1,
      sym_type,
    STATE(8228), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [24151] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7403), 1,
      sym_type,
    STATE(7860), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [24281] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7383), 1,
      sym_type,
    STATE(8091), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [24411] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7397), 1,
      sym_type,
    STATE(8555), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [24541] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7366), 1,
      sym_type,
    STATE(7876), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [24671] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7463), 1,
      sym_type,
    STATE(7987), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [24801] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7553), 1,
      sym_type,
    STATE(8709), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [24931] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7375), 1,
      sym_type,
    STATE(8081), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [25061] = 5,
    ACTIONS(6445), 1,
      sym_identifier,
    ACTIONS(6617), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 28,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
    ACTIONS(69), 30,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
  [25135] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7358), 1,
      sym_type,
    STATE(8194), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [25265] = 5,
    ACTIONS(6619), 1,
      anon_sym_DOT2,
    STATE(2556), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3481), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [25339] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7465), 1,
      sym_type,
    STATE(8333), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [25469] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7491), 1,
      sym_type,
    STATE(8486), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [25599] = 4,
    ACTIONS(6621), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4823), 40,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [25671] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7522), 1,
      sym_type,
    STATE(8573), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [25801] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7494), 1,
      sym_type,
    STATE(8130), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [25931] = 6,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6184), 1,
      sym_uninitialized,
    STATE(2616), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3451), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [26007] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7435), 1,
      sym_type,
    STATE(8016), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [26137] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7498), 1,
      sym_type,
    STATE(8199), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [26267] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7446), 1,
      sym_type,
    STATE(8405), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [26397] = 6,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6200), 1,
      sym_uninitialized,
    STATE(2625), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3425), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [26473] = 33,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6595), 1,
      sym_identifier,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6601), 1,
      anon_sym_LBRACK,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6607), 1,
      anon_sym_map,
    ACTIONS(6609), 1,
      anon_sym_bit_set,
    ACTIONS(6611), 1,
      anon_sym_matrix,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7395), 1,
      sym_type,
    STATE(7786), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [26603] = 6,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6214), 1,
      sym_uninitialized,
    STATE(2634), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [26679] = 5,
    ACTIONS(6619), 1,
      anon_sym_DOT2,
    STATE(2531), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3433), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [26753] = 6,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6241), 1,
      sym_uninitialized,
    STATE(2667), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [26829] = 6,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6249), 1,
      sym_uninitialized,
    STATE(2639), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3400), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [26905] = 6,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6484), 1,
      sym_uninitialized,
    STATE(2641), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4577), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [26981] = 6,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(6623), 1,
      sym_uninitialized,
    STATE(2643), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4585), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [27057] = 7,
    ACTIONS(6617), 1,
      anon_sym_LPAREN,
    ACTIONS(6627), 1,
      anon_sym_QMARK,
    ACTIONS(6625), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6488), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [27134] = 14,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 8,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 35,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [27225] = 16,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6649), 1,
      anon_sym_PIPE,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6651), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [27320] = 15,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6649), 1,
      anon_sym_PIPE,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 35,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [27413] = 25,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6574), 1,
      anon_sym_or_return,
    ACTIONS(6576), 1,
      anon_sym_or_continue,
    ACTIONS(6580), 1,
      anon_sym_CARET,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6649), 1,
      anon_sym_PIPE,
    ACTIONS(6653), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6655), 1,
      anon_sym_or_else,
    ACTIONS(6657), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6663), 1,
      anon_sym_or_break,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6659), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6661), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6651), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 26,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
  [27526] = 21,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6649), 1,
      anon_sym_PIPE,
    ACTIONS(6653), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6655), 1,
      anon_sym_or_else,
    ACTIONS(6657), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6659), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6661), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4881), 3,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_CARET,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6651), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 29,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [27631] = 18,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6649), 1,
      anon_sym_PIPE,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6659), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6661), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6651), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
    ACTIONS(4635), 30,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [27730] = 4,
    STATE(2581), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3547), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [27801] = 9,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 15,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 35,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [27882] = 7,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4819), 36,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [27959] = 7,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6510), 1,
      sym_uninitialized,
    ACTIONS(6512), 1,
      sym_tag,
    STATE(2818), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3451), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28036] = 26,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6574), 1,
      anon_sym_or_return,
    ACTIONS(6576), 1,
      anon_sym_or_continue,
    ACTIONS(6580), 1,
      anon_sym_CARET,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6649), 1,
      anon_sym_PIPE,
    ACTIONS(6653), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6655), 1,
      anon_sym_or_else,
    ACTIONS(6657), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6663), 1,
      anon_sym_or_break,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6659), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6661), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6665), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6651), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 24,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_case,
      anon_sym_QMARK,
  [28151] = 11,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_CARET,
    ACTIONS(4635), 35,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28236] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(207), 40,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28305] = 7,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6514), 1,
      sym_uninitialized,
    ACTIONS(6667), 1,
      sym_tag,
    STATE(2936), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3425), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28382] = 7,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6518), 1,
      sym_uninitialized,
    ACTIONS(6522), 1,
      sym_tag,
    STATE(2881), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28459] = 7,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      sym_uninitialized,
    ACTIONS(6528), 1,
      sym_tag,
    STATE(2856), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28536] = 10,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 13,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 35,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28619] = 7,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4843), 36,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28696] = 7,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6669), 1,
      sym_uninitialized,
    ACTIONS(6671), 1,
      sym_tag,
    STATE(2826), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4577), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28773] = 5,
    ACTIONS(6673), 1,
      anon_sym_LBRACE,
    STATE(2581), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3701), 38,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28846] = 7,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4635), 36,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [28923] = 13,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 9,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 35,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29012] = 4,
    STATE(2581), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4462), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29083] = 4,
    ACTIONS(6617), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 39,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29154] = 5,
    ACTIONS(6627), 1,
      anon_sym_QMARK,
    ACTIONS(6625), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4693), 37,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_case,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29227] = 7,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4731), 36,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29304] = 12,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 35,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29391] = 7,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4921), 36,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29468] = 4,
    STATE(2581), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4475), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29539] = 19,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6649), 1,
      anon_sym_PIPE,
    ACTIONS(6657), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6659), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6661), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6651), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
    ACTIONS(4635), 30,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29640] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 40,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29709] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 40,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29778] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 40,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29847] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 20,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
      anon_sym_DOT2,
    ACTIONS(3408), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [29916] = 25,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6574), 1,
      anon_sym_or_return,
    ACTIONS(6576), 1,
      anon_sym_or_continue,
    ACTIONS(6580), 1,
      anon_sym_CARET,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6649), 1,
      anon_sym_PIPE,
    ACTIONS(6653), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6655), 1,
      anon_sym_or_else,
    ACTIONS(6657), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6663), 1,
      anon_sym_or_break,
    ACTIONS(4793), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6659), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6661), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6651), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 26,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
  [30029] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 40,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30098] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 40,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30167] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 40,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30236] = 7,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6530), 1,
      sym_uninitialized,
    ACTIONS(6532), 1,
      sym_tag,
    STATE(2879), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3400), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30313] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4709), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30381] = 6,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6514), 1,
      sym_uninitialized,
    STATE(2936), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3425), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30455] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4795), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30523] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4803), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30591] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4945), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30659] = 6,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6518), 1,
      sym_uninitialized,
    STATE(2881), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30733] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3701), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30801] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3451), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30869] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4739), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [30937] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5055), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31005] = 6,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6524), 1,
      sym_uninitialized,
    STATE(2856), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31079] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4701), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31147] = 5,
    ACTIONS(6676), 1,
      anon_sym_LPAREN,
    ACTIONS(6678), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5103), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31219] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(893), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31287] = 6,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6530), 1,
      sym_uninitialized,
    STATE(2879), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3400), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31361] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3425), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31429] = 6,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6669), 1,
      sym_uninitialized,
    STATE(2826), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4577), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31503] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4743), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31571] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4841), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4839), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31639] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4807), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31707] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(809), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31775] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4811), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31843] = 4,
    ACTIONS(6680), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4454), 28,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
    ACTIONS(4450), 29,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
  [31913] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5127), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [31981] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32049] = 6,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6682), 1,
      sym_uninitialized,
    STATE(2828), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4585), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32123] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4683), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32191] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4815), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32259] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4855), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32327] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(871), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32395] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4989), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32463] = 5,
    ACTIONS(6676), 1,
      anon_sym_LPAREN,
    ACTIONS(6678), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5001), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32535] = 5,
    ACTIONS(6676), 1,
      anon_sym_LPAREN,
    ACTIONS(6678), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5011), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32607] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32675] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5131), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32743] = 5,
    ACTIONS(6676), 1,
      anon_sym_LPAREN,
    ACTIONS(6678), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4751), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32815] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4787), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32883] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5241), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [32951] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4577), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33019] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5245), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33087] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4585), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33155] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5249), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33223] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4949), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33291] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5253), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33359] = 5,
    ACTIONS(6684), 1,
      sym_identifier,
    ACTIONS(6686), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(69), 28,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(73), 28,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [33431] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4859), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33499] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4689), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33567] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4863), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33635] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5095), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33703] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5135), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33771] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5139), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33839] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4717), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33907] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5035), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [33975] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(909), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34043] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5237), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34111] = 6,
    ACTIONS(6688), 1,
      anon_sym_LBRACE,
    ACTIONS(6691), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3912), 36,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34185] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(767), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34253] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5059), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34321] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4759), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34389] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4953), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34457] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3481), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34525] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5081), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34593] = 6,
    ACTIONS(6500), 1,
      anon_sym_LBRACE,
    ACTIONS(6510), 1,
      sym_uninitialized,
    STATE(2818), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3451), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34667] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4725), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34735] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4735), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34803] = 5,
    ACTIONS(6676), 1,
      anon_sym_LPAREN,
    ACTIONS(6678), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4961), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34875] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3400), 39,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [34943] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4835), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35010] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4725), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35077] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4847), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35144] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5031), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35211] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5043), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35278] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5047), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35345] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5051), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35412] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5051), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35479] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35546] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5063), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35613] = 5,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    STATE(2581), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4462), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35684] = 5,
    ACTIONS(6696), 1,
      anon_sym_DOT2,
    STATE(2684), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3433), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35755] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5073), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35822] = 5,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    STATE(2581), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4475), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35893] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5077), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [35960] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36027] = 5,
    ACTIONS(6698), 1,
      anon_sym_DOT2,
    STATE(2684), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3408), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36098] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5099), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36165] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5111), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36232] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5115), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36299] = 5,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    STATE(2581), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3547), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36370] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5123), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36437] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4937), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36504] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4639), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36571] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4643), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36638] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(207), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36705] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4647), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36772] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4651), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36839] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4655), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36906] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4827), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [36973] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4659), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37040] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4693), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37107] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4663), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37174] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4667), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37241] = 5,
    ACTIONS(6696), 1,
      anon_sym_DOT2,
    STATE(2679), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3481), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37312] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4671), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37379] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4675), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37446] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4867), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37513] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4679), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37580] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4705), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37647] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4909), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37714] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4925), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37781] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4631), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [37848] = 27,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6715), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6717), 1,
      anon_sym_or_else,
    ACTIONS(6719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6745), 1,
      anon_sym_or_break,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6701), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(6707), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5067), 20,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_QMARK,
  [37963] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5257), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38030] = 6,
    ACTIONS(6676), 1,
      anon_sym_LPAREN,
    ACTIONS(6678), 1,
      anon_sym_SLASH,
    ACTIONS(6749), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4751), 36,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38103] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4871), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38170] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4941), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38237] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4875), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38304] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5015), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38371] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5027), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38438] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5039), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38505] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4883), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38572] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4887), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38639] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4823), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38706] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5119), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38773] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5145), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38840] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4933), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38907] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4905), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [38974] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4913), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39041] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4891), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39108] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39175] = 6,
    ACTIONS(6751), 1,
      anon_sym_LBRACE,
    ACTIONS(6753), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3912), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39248] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39315] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4713), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39382] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4755), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39449] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4763), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39516] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4773), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39583] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4799), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39650] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4917), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39717] = 5,
    ACTIONS(6684), 1,
      sym_identifier,
    ACTIONS(6756), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(69), 27,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(73), 28,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [39788] = 14,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 8,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [39877] = 26,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6715), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6717), 1,
      anon_sym_or_else,
    ACTIONS(6719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6745), 1,
      anon_sym_or_break,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6707), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5067), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_QMARK,
  [39990] = 9,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 15,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [40069] = 13,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 9,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [40156] = 12,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [40241] = 19,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
    ACTIONS(4635), 28,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [40340] = 18,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
    ACTIONS(4635), 28,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [40437] = 16,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 30,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [40530] = 15,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [40621] = 11,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_CARET,
    ACTIONS(4635), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [40704] = 10,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 13,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [40785] = 7,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4635), 34,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [40860] = 25,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6715), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6717), 1,
      anon_sym_or_else,
    ACTIONS(6719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6745), 1,
      anon_sym_or_break,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(4793), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4791), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
  [40971] = 7,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4819), 34,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41046] = 7,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4843), 34,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41121] = 25,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6715), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6717), 1,
      anon_sym_or_else,
    ACTIONS(6719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6745), 1,
      anon_sym_or_break,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4879), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
  [41232] = 21,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6715), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6717), 1,
      anon_sym_or_else,
    ACTIONS(6719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4881), 3,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_CARET,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4879), 27,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41335] = 6,
    ACTIONS(6686), 1,
      anon_sym_LPAREN,
    ACTIONS(6760), 1,
      anon_sym_QMARK,
    ACTIONS(6758), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 34,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41408] = 4,
    ACTIONS(6686), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41477] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4965), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41544] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4965), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41611] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4969), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41678] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4973), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41745] = 5,
    ACTIONS(6760), 1,
      anon_sym_QMARK,
    ACTIONS(6758), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4693), 35,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41816] = 7,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4731), 34,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41891] = 7,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4921), 34,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [41966] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4981), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42033] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4985), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42100] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5019), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42167] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4831), 38,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42234] = 13,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 9,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42320] = 4,
    ACTIONS(6780), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4454), 27,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
    ACTIONS(4450), 28,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
  [42388] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42454] = 7,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4819), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42528] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(207), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42594] = 7,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4843), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42668] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4823), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42734] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42800] = 6,
    ACTIONS(6676), 1,
      anon_sym_LPAREN,
    ACTIONS(6678), 1,
      anon_sym_SLASH,
    ACTIONS(6782), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4751), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42872] = 5,
    ACTIONS(6786), 1,
      anon_sym_QMARK,
    ACTIONS(6784), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4693), 34,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_do,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [42942] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [43008] = 7,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4731), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [43082] = 14,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 8,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [43170] = 26,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6790), 1,
      anon_sym_PIPE,
    ACTIONS(6794), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6796), 1,
      anon_sym_or_else,
    ACTIONS(6798), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6806), 1,
      anon_sym_or_break,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6792), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6800), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6802), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6804), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_QMARK,
  [43282] = 9,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 15,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [43360] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 20,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
      anon_sym_DOT2,
    ACTIONS(3408), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [43426] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [43492] = 5,
    ACTIONS(6808), 1,
      sym_identifier,
    ACTIONS(6810), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(69), 27,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_QMARK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(73), 27,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [43562] = 25,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6790), 1,
      anon_sym_PIPE,
    ACTIONS(6794), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6796), 1,
      anon_sym_or_else,
    ACTIONS(6798), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6806), 1,
      anon_sym_or_break,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6800), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6802), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6804), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 23,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
  [43672] = 6,
    ACTIONS(6756), 1,
      anon_sym_LPAREN,
    ACTIONS(6786), 1,
      anon_sym_QMARK,
    ACTIONS(6784), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_do,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [43744] = 19,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6790), 1,
      anon_sym_PIPE,
    ACTIONS(6798), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6800), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6802), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6804), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
    ACTIONS(4635), 27,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [43842] = 18,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6790), 1,
      anon_sym_PIPE,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6800), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6802), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6804), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
    ACTIONS(4635), 27,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [43938] = 16,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6790), 1,
      anon_sym_PIPE,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6804), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 29,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44030] = 21,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6790), 1,
      anon_sym_PIPE,
    ACTIONS(6794), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6796), 1,
      anon_sym_or_else,
    ACTIONS(6798), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6800), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6802), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4881), 3,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_CARET,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6804), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 26,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44132] = 15,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6790), 1,
      anon_sym_PIPE,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44222] = 11,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44304] = 4,
    ACTIONS(6812), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4725), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44372] = 10,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 13,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44452] = 4,
    ACTIONS(6756), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 36,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44520] = 7,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4635), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44594] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44660] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 37,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44726] = 7,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4921), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44800] = 25,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6790), 1,
      anon_sym_PIPE,
    ACTIONS(6794), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6796), 1,
      anon_sym_or_else,
    ACTIONS(6798), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6806), 1,
      anon_sym_or_break,
    ACTIONS(4793), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6800), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6802), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6804), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 23,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
  [44910] = 12,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [44994] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4909), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45059] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4717), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45124] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4739), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45189] = 6,
    ACTIONS(6810), 1,
      anon_sym_LPAREN,
    ACTIONS(6816), 1,
      anon_sym_QMARK,
    ACTIONS(6814), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45260] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4743), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45325] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4759), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45390] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4667), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45455] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4787), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45520] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4795), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45585] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4803), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45650] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4807), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45715] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4811), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45780] = 5,
    ACTIONS(6818), 1,
      anon_sym_DOT2,
    STATE(2872), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3481), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [45849] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4815), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45914] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3425), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [45979] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4671), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46044] = 35,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6707), 1,
      anon_sym_not_in,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6715), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6717), 1,
      anon_sym_or_else,
    ACTIONS(6719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6745), 1,
      anon_sym_or_break,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6822), 1,
      anon_sym_COMMA,
    ACTIONS(6824), 1,
      anon_sym_EQ,
    ACTIONS(6826), 1,
      anon_sym_COLON,
    ACTIONS(6828), 1,
      anon_sym_COLON_EQ,
    ACTIONS(6832), 1,
      anon_sym_SEMI,
    ACTIONS(6834), 1,
      anon_sym_do,
    ACTIONS(6836), 1,
      anon_sym_in,
    STATE(6630), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    STATE(7126), 1,
      sym_block,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6830), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [46173] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4855), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46238] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4683), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46303] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4651), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46368] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4859), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46433] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4863), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46498] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4585), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46563] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5095), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46628] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4949), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46693] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4675), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46758] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4655), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46823] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3451), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46888] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4989), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [46953] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4709), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47018] = 5,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5001), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47087] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5055), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47152] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4693), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47217] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5127), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47282] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4701), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47347] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5131), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47412] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5135), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47477] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4679), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47542] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5139), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47607] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(809), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47672] = 5,
    ACTIONS(6816), 1,
      anon_sym_QMARK,
    ACTIONS(6814), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4693), 33,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47741] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4705), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47806] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4713), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47871] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5237), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [47936] = 7,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4731), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48009] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4689), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48074] = 7,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4921), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48147] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4925), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48212] = 5,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4961), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48281] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4631), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48346] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5257), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48411] = 7,
    ACTIONS(6445), 1,
      sym_identifier,
    ACTIONS(6447), 1,
      anon_sym_LPAREN,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    STATE(7138), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 25,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
    ACTIONS(69), 26,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
  [48484] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3400), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48549] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(909), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48614] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5241), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48679] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4659), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48744] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4945), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48809] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5245), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48874] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5249), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [48939] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5253), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49004] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(767), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49069] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4941), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49134] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5015), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49199] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5027), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49264] = 5,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4751), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49333] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5039), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49398] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(871), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49463] = 5,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5011), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49532] = 5,
    ACTIONS(6818), 1,
      anon_sym_DOT2,
    STATE(2904), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3433), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [49601] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5119), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49666] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5145), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49731] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4933), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49796] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4905), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49861] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5059), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49926] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5035), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [49991] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4577), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50056] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(893), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50121] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3384), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50186] = 5,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5103), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50255] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4663), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50320] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4913), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50385] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3481), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50450] = 26,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6860), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6862), 1,
      anon_sym_or_else,
    ACTIONS(6864), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6880), 1,
      anon_sym_or_return,
    ACTIONS(6882), 1,
      anon_sym_or_continue,
    ACTIONS(6884), 1,
      anon_sym_or_break,
    ACTIONS(6886), 1,
      anon_sym_CARET,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6852), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6866), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6868), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6870), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5067), 20,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_QMARK,
  [50561] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4735), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50626] = 9,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 15,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 31,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50703] = 13,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 9,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 31,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50788] = 12,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 31,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50871] = 19,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6864), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6866), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6868), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6870), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
    ACTIONS(4635), 26,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [50968] = 18,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6866), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6868), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6870), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
    ACTIONS(4635), 26,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51063] = 16,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6870), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 28,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51154] = 15,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 31,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51243] = 11,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_CARET,
    ACTIONS(4635), 31,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51324] = 10,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 13,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
    ACTIONS(4635), 31,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51403] = 7,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4635), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51476] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4755), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51541] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4763), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51606] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4773), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51671] = 25,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6860), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6862), 1,
      anon_sym_or_else,
    ACTIONS(6864), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6880), 1,
      anon_sym_or_return,
    ACTIONS(6882), 1,
      anon_sym_or_continue,
    ACTIONS(6884), 1,
      anon_sym_or_break,
    ACTIONS(6886), 1,
      anon_sym_CARET,
    ACTIONS(4793), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6866), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6868), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6870), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4791), 22,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
  [51780] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4799), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51845] = 7,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4819), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [51918] = 5,
    ACTIONS(6888), 1,
      anon_sym_DOT2,
    STATE(2904), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3408), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [51987] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(207), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52052] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4823), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52117] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4827), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52182] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4831), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52247] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4835), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52312] = 7,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 18,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
    ACTIONS(4843), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52385] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4847), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52450] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52515] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4851), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52580] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4867), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52645] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4871), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52710] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4875), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52775] = 25,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6860), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6862), 1,
      anon_sym_or_else,
    ACTIONS(6864), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6880), 1,
      anon_sym_or_return,
    ACTIONS(6882), 1,
      anon_sym_or_continue,
    ACTIONS(6884), 1,
      anon_sym_or_break,
    ACTIONS(6886), 1,
      anon_sym_CARET,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6866), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6868), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6870), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4879), 22,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
  [52884] = 21,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6860), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6862), 1,
      anon_sym_or_else,
    ACTIONS(6864), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6866), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6868), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4881), 3,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_CARET,
    ACTIONS(6870), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4879), 25,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [52985] = 35,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6707), 1,
      anon_sym_not_in,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6715), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6717), 1,
      anon_sym_or_else,
    ACTIONS(6719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6745), 1,
      anon_sym_or_break,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6822), 1,
      anon_sym_COMMA,
    ACTIONS(6824), 1,
      anon_sym_EQ,
    ACTIONS(6826), 1,
      anon_sym_COLON,
    ACTIONS(6828), 1,
      anon_sym_COLON_EQ,
    ACTIONS(6836), 1,
      anon_sym_in,
    ACTIONS(6891), 1,
      anon_sym_SEMI,
    ACTIONS(6893), 1,
      anon_sym_do,
    STATE(6630), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    STATE(7126), 1,
      sym_block,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6830), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [53114] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4883), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53179] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4887), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53244] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4891), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53309] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53374] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4901), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53439] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4917), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53504] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4965), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53569] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4965), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53634] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4969), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53699] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4973), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53764] = 7,
    ACTIONS(6445), 1,
      sym_identifier,
    ACTIONS(6617), 1,
      anon_sym_LPAREN,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    STATE(7138), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 25,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
    ACTIONS(69), 26,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
  [53837] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4981), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53902] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4985), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [53967] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5019), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54032] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4725), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54097] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5081), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54162] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(3368), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54227] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5031), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54292] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5043), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54357] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5047), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54422] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5051), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54487] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5051), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54552] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5063), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54617] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5073), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54682] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5077), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54747] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5099), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54812] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5111), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54877] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5115), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [54942] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(5123), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [55007] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4937), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [55072] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4639), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [55137] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4643), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [55202] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4647), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [55267] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(4953), 36,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [55332] = 4,
    ACTIONS(6810), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_CARET,
    ACTIONS(69), 35,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [55399] = 14,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4637), 8,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_CARET,
    ACTIONS(4635), 31,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_or_else,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
  [55486] = 33,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6715), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6717), 1,
      anon_sym_or_else,
    ACTIONS(6719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6745), 1,
      anon_sym_or_break,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    ACTIONS(6897), 1,
      anon_sym_EQ,
    ACTIONS(6899), 1,
      anon_sym_COLON_EQ,
    ACTIONS(6903), 1,
      anon_sym_SEMI,
    ACTIONS(6905), 1,
      anon_sym_do,
    STATE(6660), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    STATE(7165), 1,
      sym_block,
    ACTIONS(6707), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6901), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [55610] = 9,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6911), 1,
      sym_uninitialized,
    ACTIONS(6913), 1,
      sym_tag,
    STATE(3281), 1,
      sym_where_clause,
    STATE(3730), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [55686] = 7,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6919), 1,
      sym_tag,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3368), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [55758] = 6,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3425), 28,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_tag,
  [55828] = 11,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(6927), 1,
      sym_uninitialized,
    ACTIONS(6929), 1,
      sym_tag,
    STATE(3285), 1,
      sym_where_clause,
    STATE(3732), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [55908] = 9,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6927), 1,
      sym_uninitialized,
    ACTIONS(6929), 1,
      sym_tag,
    STATE(3285), 1,
      sym_where_clause,
    STATE(3732), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [55984] = 5,
    ACTIONS(6931), 1,
      anon_sym_DOT2,
    STATE(2962), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3408), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [56052] = 7,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(6934), 1,
      sym_tag,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3425), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [56124] = 11,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(6936), 1,
      sym_uninitialized,
    ACTIONS(6938), 1,
      sym_tag,
    STATE(3273), 1,
      sym_where_clause,
    STATE(3790), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [56204] = 33,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6790), 1,
      anon_sym_PIPE,
    ACTIONS(6794), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6796), 1,
      anon_sym_or_else,
    ACTIONS(6798), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6806), 1,
      anon_sym_or_break,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6824), 1,
      anon_sym_EQ,
    ACTIONS(6826), 1,
      anon_sym_COLON,
    ACTIONS(6828), 1,
      anon_sym_COLON_EQ,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    ACTIONS(6940), 1,
      anon_sym_do,
    STATE(6651), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    STATE(7009), 1,
      sym_block,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6792), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6800), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6802), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6804), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6830), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [56328] = 9,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(6946), 1,
      sym_uninitialized,
    ACTIONS(6948), 1,
      sym_tag,
    STATE(3174), 1,
      sym_where_clause,
    STATE(3408), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [56404] = 33,
    ACTIONS(6703), 1,
      anon_sym_DASH_GT,
    ACTIONS(6705), 1,
      anon_sym_PIPE,
    ACTIONS(6711), 1,
      anon_sym_TILDE,
    ACTIONS(6713), 1,
      anon_sym_AMP,
    ACTIONS(6715), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6717), 1,
      anon_sym_or_else,
    ACTIONS(6719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6727), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6733), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6735), 1,
      anon_sym_DOT,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6745), 1,
      anon_sym_or_break,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    ACTIONS(6897), 1,
      anon_sym_EQ,
    ACTIONS(6899), 1,
      anon_sym_COLON_EQ,
    ACTIONS(6950), 1,
      anon_sym_SEMI,
    ACTIONS(6952), 1,
      anon_sym_do,
    STATE(6660), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    STATE(7165), 1,
      sym_block,
    ACTIONS(6707), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6721), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6723), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6729), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6739), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6725), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6731), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6901), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [56528] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6954), 1,
      sym_uninitialized,
    ACTIONS(6956), 1,
      sym_tag,
    STATE(2985), 1,
      sym_where_clause,
    STATE(3200), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [56604] = 6,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6954), 1,
      sym_uninitialized,
    STATE(3200), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3400), 28,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_tag,
  [56674] = 9,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(6958), 1,
      sym_uninitialized,
    ACTIONS(6960), 1,
      sym_tag,
    STATE(3168), 1,
      sym_where_clause,
    STATE(3388), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [56750] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(6962), 1,
      sym_tag,
    STATE(2958), 1,
      sym_where_clause,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [56826] = 10,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6964), 1,
      anon_sym_DASH_GT,
    ACTIONS(6966), 1,
      sym_uninitialized,
    ACTIONS(6968), 1,
      sym_tag,
    STATE(3240), 1,
      sym_where_clause,
    STATE(3749), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3439), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [56904] = 9,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6927), 1,
      sym_uninitialized,
    ACTIONS(6970), 1,
      sym_tag,
    STATE(3285), 1,
      sym_where_clause,
    STATE(3732), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [56980] = 7,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(6974), 1,
      sym_tag,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3384), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [57052] = 6,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3384), 28,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_tag,
  [57122] = 6,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6976), 1,
      sym_uninitialized,
    STATE(3203), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4577), 28,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_tag,
  [57192] = 9,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6936), 1,
      sym_uninitialized,
    ACTIONS(6938), 1,
      sym_tag,
    STATE(3273), 1,
      sym_where_clause,
    STATE(3790), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [57268] = 11,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6911), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      sym_tag,
    STATE(3281), 1,
      sym_where_clause,
    STATE(3730), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [57348] = 6,
    ACTIONS(6980), 1,
      anon_sym_LBRACE,
    ACTIONS(6983), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3912), 28,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [57418] = 10,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6986), 1,
      anon_sym_DASH_GT,
    ACTIONS(6988), 1,
      sym_uninitialized,
    ACTIONS(6990), 1,
      sym_tag,
    STATE(3004), 1,
      sym_where_clause,
    STATE(3155), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3439), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [57496] = 10,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6992), 1,
      anon_sym_DASH_GT,
    ACTIONS(6994), 1,
      sym_uninitialized,
    ACTIONS(6996), 1,
      sym_tag,
    STATE(2963), 1,
      sym_where_clause,
    STATE(3163), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [57574] = 11,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(6998), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [57654] = 9,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(6958), 1,
      sym_uninitialized,
    ACTIONS(7000), 1,
      sym_tag,
    STATE(3168), 1,
      sym_where_clause,
    STATE(3388), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [57730] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(6974), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [57806] = 7,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6976), 1,
      sym_uninitialized,
    ACTIONS(7002), 1,
      sym_tag,
    STATE(3203), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4577), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [57878] = 4,
    STATE(2998), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4462), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [57944] = 10,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(7004), 1,
      anon_sym_DASH_GT,
    ACTIONS(7006), 1,
      sym_uninitialized,
    ACTIONS(7008), 1,
      sym_tag,
    STATE(3260), 1,
      sym_where_clause,
    STATE(3769), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [58022] = 6,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(7010), 1,
      sym_uninitialized,
    STATE(3133), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4585), 28,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_tag,
  [58092] = 10,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7012), 1,
      anon_sym_DASH_GT,
    ACTIONS(7014), 1,
      sym_uninitialized,
    ACTIONS(7016), 1,
      sym_tag,
    STATE(3157), 1,
      sym_where_clause,
    STATE(3306), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3439), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [58170] = 10,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7018), 1,
      anon_sym_DASH_GT,
    ACTIONS(7020), 1,
      sym_uninitialized,
    ACTIONS(7022), 1,
      sym_tag,
    STATE(3161), 1,
      sym_where_clause,
    STATE(3334), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [58248] = 6,
    ACTIONS(6818), 1,
      anon_sym_DOT2,
    ACTIONS(7024), 1,
      anon_sym_COLON,
    STATE(2872), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 41,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [58318] = 9,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(6946), 1,
      sym_uninitialized,
    ACTIONS(7026), 1,
      sym_tag,
    STATE(3174), 1,
      sym_where_clause,
    STATE(3408), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [58394] = 11,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(6946), 1,
      sym_uninitialized,
    ACTIONS(6948), 1,
      sym_tag,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    STATE(3174), 1,
      sym_where_clause,
    STATE(3408), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [58474] = 5,
    ACTIONS(7032), 1,
      anon_sym_DOT2,
    STATE(2962), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3433), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [58542] = 6,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6994), 1,
      sym_uninitialized,
    STATE(3163), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3451), 28,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_tag,
  [58612] = 11,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(7034), 1,
      sym_uninitialized,
    ACTIONS(7036), 1,
      sym_tag,
    STATE(3164), 1,
      sym_where_clause,
    STATE(3356), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [58692] = 9,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7034), 1,
      sym_uninitialized,
    ACTIONS(7036), 1,
      sym_tag,
    STATE(3164), 1,
      sym_where_clause,
    STATE(3356), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [58768] = 5,
    ACTIONS(7038), 1,
      anon_sym_LBRACE,
    STATE(2998), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3701), 29,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [58836] = 9,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(7041), 1,
      sym_uninitialized,
    ACTIONS(7043), 1,
      sym_tag,
    STATE(3290), 1,
      sym_where_clause,
    STATE(3715), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [58912] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6919), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [58988] = 4,
    STATE(2998), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4475), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [59054] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 24,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_DOT2,
      sym_identifier,
    ACTIONS(3408), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [59118] = 11,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(6962), 1,
      sym_tag,
    STATE(2958), 1,
      sym_where_clause,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [59198] = 7,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6994), 1,
      sym_uninitialized,
    ACTIONS(6996), 1,
      sym_tag,
    STATE(3163), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3451), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [59270] = 33,
    ACTIONS(6737), 1,
      anon_sym_LBRACK,
    ACTIONS(6741), 1,
      anon_sym_or_return,
    ACTIONS(6743), 1,
      anon_sym_or_continue,
    ACTIONS(6747), 1,
      anon_sym_CARET,
    ACTIONS(6762), 1,
      anon_sym_DASH_GT,
    ACTIONS(6766), 1,
      anon_sym_AMP,
    ACTIONS(6768), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6774), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6776), 1,
      anon_sym_DOT,
    ACTIONS(6788), 1,
      anon_sym_TILDE,
    ACTIONS(6790), 1,
      anon_sym_PIPE,
    ACTIONS(6794), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6796), 1,
      anon_sym_or_else,
    ACTIONS(6798), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6806), 1,
      anon_sym_or_break,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6824), 1,
      anon_sym_EQ,
    ACTIONS(6826), 1,
      anon_sym_COLON,
    ACTIONS(6828), 1,
      anon_sym_COLON_EQ,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    ACTIONS(7045), 1,
      anon_sym_do,
    STATE(6651), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    STATE(6968), 1,
      sym_block,
    ACTIONS(6764), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6770), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6778), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6792), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6800), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6802), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6772), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6804), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6830), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [59394] = 9,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7047), 1,
      sym_uninitialized,
    ACTIONS(7049), 1,
      sym_tag,
    STATE(3177), 1,
      sym_where_clause,
    STATE(3425), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [59470] = 6,
    ACTIONS(7032), 1,
      anon_sym_DOT2,
    ACTIONS(7051), 1,
      anon_sym_COLON,
    STATE(2994), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [59540] = 9,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6911), 1,
      sym_uninitialized,
    ACTIONS(6978), 1,
      sym_tag,
    STATE(3281), 1,
      sym_where_clause,
    STATE(3730), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [59616] = 7,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6954), 1,
      sym_uninitialized,
    ACTIONS(6956), 1,
      sym_tag,
    STATE(3200), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3400), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [59688] = 5,
    ACTIONS(7032), 1,
      anon_sym_DOT2,
    STATE(2994), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [59756] = 11,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(6958), 1,
      sym_uninitialized,
    ACTIONS(7000), 1,
      sym_tag,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    STATE(3168), 1,
      sym_where_clause,
    STATE(3388), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [59836] = 11,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(7053), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [59916] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(7053), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [59992] = 6,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3368), 28,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_tag,
  [60062] = 4,
    STATE(2998), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3547), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60128] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6998), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [60204] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(893), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60267] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4655), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60330] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4659), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60393] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4663), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60456] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4667), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60519] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4671), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60582] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4675), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60645] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5119), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60708] = 5,
    ACTIONS(7055), 1,
      sym_identifier,
    ACTIONS(7057), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 22,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 29,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60775] = 6,
    ACTIONS(7059), 1,
      anon_sym_LBRACE,
    ACTIONS(7062), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 39,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60844] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5145), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60907] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4651), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [60970] = 11,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(7065), 1,
      sym_uninitialized,
    ACTIONS(7067), 1,
      sym_tag,
    STATE(3311), 1,
      sym_where_clause,
    STATE(3914), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [61049] = 9,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7065), 1,
      sym_uninitialized,
    ACTIONS(7067), 1,
      sym_tag,
    STATE(3311), 1,
      sym_where_clause,
    STATE(3914), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [61124] = 27,
    ACTIONS(7069), 1,
      anon_sym_COMMA,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7107), 1,
      anon_sym_or_return,
    ACTIONS(7109), 1,
      anon_sym_or_continue,
    ACTIONS(7111), 1,
      anon_sym_or_break,
    ACTIONS(7113), 1,
      anon_sym_CARET,
    STATE(3040), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(4483), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7083), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7087), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7089), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 18,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [61235] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4905), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [61298] = 4,
    ACTIONS(7115), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4454), 22,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(4450), 30,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [61363] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5095), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [61426] = 4,
    STATE(3158), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4462), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [61491] = 11,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(7117), 1,
      sym_uninitialized,
    ACTIONS(7119), 1,
      sym_tag,
    STATE(3367), 1,
      sym_where_clause,
    STATE(3805), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [61570] = 9,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7117), 1,
      sym_uninitialized,
    ACTIONS(7119), 1,
      sym_tag,
    STATE(3367), 1,
      sym_where_clause,
    STATE(3805), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [61645] = 9,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7117), 1,
      sym_uninitialized,
    ACTIONS(7121), 1,
      sym_tag,
    STATE(3367), 1,
      sym_where_clause,
    STATE(3805), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [61720] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4913), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [61783] = 5,
    ACTIONS(7069), 1,
      anon_sym_COMMA,
    STATE(3049), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4460), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4456), 40,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [61850] = 4,
    STATE(3158), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4475), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [61915] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 12,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_DOT2,
    ACTIONS(3408), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [61978] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(909), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [62041] = 4,
    STATE(3158), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3547), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [62106] = 11,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(7123), 1,
      sym_uninitialized,
    ACTIONS(7125), 1,
      sym_tag,
    STATE(3420), 1,
      sym_where_clause,
    STATE(3962), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [62185] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(767), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [62248] = 9,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7123), 1,
      sym_uninitialized,
    ACTIONS(7125), 1,
      sym_tag,
    STATE(3420), 1,
      sym_where_clause,
    STATE(3962), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [62323] = 9,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7123), 1,
      sym_uninitialized,
    ACTIONS(7127), 1,
      sym_tag,
    STATE(3420), 1,
      sym_where_clause,
    STATE(3962), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [62398] = 5,
    ACTIONS(7129), 1,
      anon_sym_COMMA,
    STATE(3049), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4471), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4466), 40,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [62465] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5025), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5023), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [62528] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5081), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [62591] = 9,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7132), 1,
      sym_uninitialized,
    ACTIONS(7134), 1,
      sym_tag,
    STATE(3214), 1,
      sym_where_clause,
    STATE(3906), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [62666] = 32,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6574), 1,
      anon_sym_or_return,
    ACTIONS(6576), 1,
      anon_sym_or_continue,
    ACTIONS(6580), 1,
      anon_sym_CARET,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6649), 1,
      anon_sym_PIPE,
    ACTIONS(6653), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6655), 1,
      anon_sym_or_else,
    ACTIONS(6657), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6663), 1,
      anon_sym_or_break,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    ACTIONS(7136), 1,
      anon_sym_RBRACE,
    ACTIONS(7138), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7140), 1,
      anon_sym_EQ,
    ACTIONS(7142), 1,
      anon_sym_COLON,
    ACTIONS(7144), 1,
      anon_sym_COLON_EQ,
    STATE(6631), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6659), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6661), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6665), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6651), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(7146), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [62787] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4755), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [62850] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4763), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [62913] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4773), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [62976] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4799), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63039] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4749), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4747), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63102] = 10,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7150), 1,
      anon_sym_DASH_GT,
    ACTIONS(7152), 1,
      sym_uninitialized,
    ACTIONS(7154), 1,
      sym_tag,
    STATE(3358), 1,
      sym_where_clause,
    STATE(3984), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3439), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [63179] = 10,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7156), 1,
      anon_sym_DASH_GT,
    ACTIONS(7158), 1,
      sym_uninitialized,
    ACTIONS(7160), 1,
      sym_tag,
    STATE(3277), 1,
      sym_where_clause,
    STATE(3992), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [63256] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4679), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63319] = 5,
    ACTIONS(7162), 1,
      anon_sym_COMMA,
    STATE(3063), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4460), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4456), 40,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63386] = 5,
    ACTIONS(7164), 1,
      anon_sym_COMMA,
    STATE(3063), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4471), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4466), 40,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63453] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(207), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63516] = 11,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7167), 1,
      sym_uninitialized,
    ACTIONS(7169), 1,
      sym_tag,
    STATE(3313), 1,
      sym_where_clause,
    STATE(3985), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [63595] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7167), 1,
      sym_uninitialized,
    ACTIONS(7169), 1,
      sym_tag,
    STATE(3313), 1,
      sym_where_clause,
    STATE(3985), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [63670] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4823), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63733] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4827), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63796] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4831), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63859] = 5,
    ACTIONS(7171), 1,
      sym_identifier,
    ACTIONS(7173), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 22,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 29,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63926] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4835), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [63989] = 11,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(7177), 1,
      sym_tag,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [64068] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(7177), 1,
      sym_tag,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [64143] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(7179), 1,
      sym_tag,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [64218] = 11,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(7183), 1,
      sym_tag,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [64297] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(7183), 1,
      sym_tag,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [64372] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(7185), 1,
      sym_tag,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [64447] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(809), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [64510] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4847), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [64573] = 9,
    ACTIONS(6909), 1,
      anon_sym_where,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7187), 1,
      sym_uninitialized,
    ACTIONS(7189), 1,
      sym_tag,
    STATE(3385), 1,
      sym_where_clause,
    STATE(3857), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [64648] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4851), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [64711] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4851), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [64774] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4867), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [64837] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4871), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [64900] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4875), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [64963] = 10,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7193), 1,
      anon_sym_DASH_GT,
    ACTIONS(7195), 1,
      sym_uninitialized,
    ACTIONS(7197), 1,
      sym_tag,
    STATE(3452), 1,
      sym_where_clause,
    STATE(3933), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3439), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65040] = 10,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7199), 1,
      anon_sym_DASH_GT,
    ACTIONS(7201), 1,
      sym_uninitialized,
    ACTIONS(7203), 1,
      sym_tag,
    STATE(3453), 1,
      sym_where_clause,
    STATE(3848), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65117] = 11,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7205), 1,
      sym_uninitialized,
    ACTIONS(7207), 1,
      sym_tag,
    STATE(3465), 1,
      sym_where_clause,
    STATE(3819), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65196] = 9,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7205), 1,
      sym_uninitialized,
    ACTIONS(7207), 1,
      sym_tag,
    STATE(3465), 1,
      sym_where_clause,
    STATE(3819), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65271] = 11,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7209), 1,
      sym_uninitialized,
    ACTIONS(7211), 1,
      sym_tag,
    STATE(3479), 1,
      sym_where_clause,
    STATE(3854), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65350] = 9,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7209), 1,
      sym_uninitialized,
    ACTIONS(7211), 1,
      sym_tag,
    STATE(3479), 1,
      sym_where_clause,
    STATE(3854), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65425] = 9,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7209), 1,
      sym_uninitialized,
    ACTIONS(7213), 1,
      sym_tag,
    STATE(3479), 1,
      sym_where_clause,
    STATE(3854), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65500] = 11,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7215), 1,
      sym_uninitialized,
    ACTIONS(7217), 1,
      sym_tag,
    STATE(3491), 1,
      sym_where_clause,
    STATE(3897), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65579] = 9,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7215), 1,
      sym_uninitialized,
    ACTIONS(7217), 1,
      sym_tag,
    STATE(3491), 1,
      sym_where_clause,
    STATE(3897), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65654] = 9,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7215), 1,
      sym_uninitialized,
    ACTIONS(7219), 1,
      sym_tag,
    STATE(3491), 1,
      sym_where_clause,
    STATE(3897), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65729] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4683), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [65792] = 9,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7221), 1,
      sym_uninitialized,
    ACTIONS(7223), 1,
      sym_tag,
    STATE(3498), 1,
      sym_where_clause,
    STATE(3978), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [65867] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4689), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [65930] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4931), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4929), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [65993] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3701), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66056] = 27,
    ACTIONS(7162), 1,
      anon_sym_COMMA,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7261), 1,
      anon_sym_or_return,
    ACTIONS(7263), 1,
      anon_sym_or_continue,
    ACTIONS(7265), 1,
      anon_sym_or_break,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    STATE(3062), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(4483), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7237), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 18,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [66167] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4701), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66230] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4883), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66293] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4841), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4839), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66356] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4887), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66419] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4709), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66482] = 10,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7269), 1,
      anon_sym_DASH_GT,
    ACTIONS(7271), 1,
      sym_uninitialized,
    ACTIONS(7273), 1,
      sym_tag,
    STATE(3424), 1,
      sym_where_clause,
    STATE(3987), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3439), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [66559] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(871), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66622] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4705), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66685] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4713), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66748] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4891), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66811] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4901), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66874] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4901), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [66937] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4917), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67000] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4909), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67063] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4965), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67126] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4717), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67189] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4965), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67252] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4969), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67315] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4973), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67378] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4953), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67441] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3481), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67504] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4925), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67567] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4631), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67630] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5257), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67693] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4855), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67756] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4981), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67819] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4985), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67882] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5019), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [67945] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4725), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68008] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4725), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68071] = 6,
    ACTIONS(7275), 1,
      anon_sym_COLON,
    ACTIONS(7277), 1,
      anon_sym_DOT2,
    STATE(3322), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68140] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4949), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68203] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4989), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68266] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5031), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68329] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5043), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68392] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4859), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68455] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5047), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68518] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5051), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68581] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5051), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68644] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4863), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68707] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4941), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68770] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5063), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68833] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5073), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68896] = 4,
    ACTIONS(7279), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4454), 22,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(4450), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [68961] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4693), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69024] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5015), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69087] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5077), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69150] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5027), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69213] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5039), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69276] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5099), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69339] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5111), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69402] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5115), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69465] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4815), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69528] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3451), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69591] = 6,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7020), 1,
      sym_uninitialized,
    STATE(3334), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 39,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [69660] = 7,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7020), 1,
      sym_uninitialized,
    ACTIONS(7022), 1,
      sym_tag,
    STATE(3334), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [69731] = 5,
    ACTIONS(7281), 1,
      anon_sym_LBRACE,
    STATE(3158), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3701), 40,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69798] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5035), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [69861] = 6,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7034), 1,
      sym_uninitialized,
    STATE(3356), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 39,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [69930] = 7,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7034), 1,
      sym_uninitialized,
    ACTIONS(7284), 1,
      sym_tag,
    STATE(3356), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [70001] = 6,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6958), 1,
      sym_uninitialized,
    STATE(3388), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 39,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [70070] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3425), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [70133] = 7,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6958), 1,
      sym_uninitialized,
    ACTIONS(6960), 1,
      sym_tag,
    STATE(3388), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [70204] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5055), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [70267] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5127), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [70330] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5131), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [70393] = 7,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      sym_uninitialized,
    ACTIONS(7026), 1,
      sym_tag,
    STATE(3408), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [70464] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5135), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [70527] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5139), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [70590] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5237), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [70653] = 6,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      sym_uninitialized,
    STATE(3408), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 39,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [70722] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4945), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [70785] = 7,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7047), 1,
      sym_uninitialized,
    ACTIONS(7049), 1,
      sym_tag,
    STATE(3425), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [70856] = 6,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7047), 1,
      sym_uninitialized,
    STATE(3425), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 39,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [70925] = 6,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7286), 1,
      sym_uninitialized,
    STATE(3433), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 39,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [70994] = 7,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7286), 1,
      sym_uninitialized,
    ACTIONS(7288), 1,
      sym_tag,
    STATE(3433), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [71065] = 6,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7290), 1,
      sym_uninitialized,
    STATE(3209), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 39,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [71134] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3368), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71197] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5241), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71260] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5245), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71323] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5249), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71386] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5253), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71449] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5059), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71512] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3384), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71575] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4959), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4957), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71638] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4723), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4721), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71701] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4735), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71764] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4739), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71827] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4743), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71890] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4759), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [71953] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5123), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72016] = 10,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6944), 1,
      anon_sym_where,
    ACTIONS(7292), 1,
      anon_sym_DASH_GT,
    ACTIONS(7294), 1,
      sym_uninitialized,
    ACTIONS(7296), 1,
      sym_tag,
    STATE(3357), 1,
      sym_where_clause,
    STATE(3883), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [72093] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4937), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72156] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3400), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72219] = 4,
    ACTIONS(7173), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(69), 29,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72284] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4787), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72347] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4795), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72410] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4803), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72473] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4577), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72536] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4807), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72599] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4811), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72662] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4585), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72725] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4639), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72788] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4643), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72851] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4647), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72914] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 23,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4933), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [72977] = 14,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 31,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73061] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4949), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73123] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4663), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73185] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4667), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73247] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4859), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73309] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4671), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73371] = 7,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7298), 1,
      sym_uninitialized,
    ACTIONS(7300), 1,
      sym_tag,
    STATE(3958), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [73441] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4675), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73503] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4863), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73565] = 19,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(4637), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 26,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73659] = 24,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1818), 1,
      anon_sym_LPAREN,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(7320), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3310), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(909), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [73763] = 17,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 28,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73853] = 16,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 31,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [73941] = 5,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4961), 40,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [74007] = 12,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [74087] = 11,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 34,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [74165] = 7,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4635), 37,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [74235] = 24,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1997), 1,
      anon_sym_LPAREN,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(7341), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3689), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(809), 9,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [74339] = 24,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1790), 1,
      anon_sym_LPAREN,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(7345), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3266), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(871), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [74443] = 24,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(2041), 1,
      anon_sym_LPAREN,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(7349), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3700), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(893), 9,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [74547] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4945), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [74609] = 5,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5011), 40,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [74675] = 25,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7261), 1,
      anon_sym_or_return,
    ACTIONS(7263), 1,
      anon_sym_or_continue,
    ACTIONS(7265), 1,
      anon_sym_or_break,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(4793), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7237), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 19,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [74781] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(893), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [74843] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4941), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [74905] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4689), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [74967] = 25,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7261), 1,
      anon_sym_or_return,
    ACTIONS(7263), 1,
      anon_sym_or_continue,
    ACTIONS(7265), 1,
      anon_sym_or_break,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(4471), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7237), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4466), 19,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [75073] = 6,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(7352), 1,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5009), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5005), 40,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75141] = 7,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4819), 37,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75211] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4717), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75273] = 24,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(2053), 1,
      anon_sym_LPAREN,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(7354), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3703), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(909), 9,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [75377] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5015), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75439] = 7,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(7006), 1,
      sym_uninitialized,
    ACTIONS(7008), 1,
      sym_tag,
    STATE(3769), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [75509] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5027), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75571] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5103), 40,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75637] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 40,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75703] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4961), 40,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75769] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5011), 40,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75835] = 7,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4731), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75905] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5039), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [75967] = 10,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7359), 1,
      anon_sym_DASH_GT,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7363), 1,
      sym_uninitialized,
    ACTIONS(7365), 1,
      sym_tag,
    STATE(3500), 1,
      sym_where_clause,
    STATE(3576), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3439), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76043] = 10,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7367), 1,
      anon_sym_DASH_GT,
    ACTIONS(7369), 1,
      sym_uninitialized,
    ACTIONS(7371), 1,
      sym_tag,
    STATE(3503), 1,
      sym_where_clause,
    STATE(3582), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76119] = 11,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7377), 1,
      sym_uninitialized,
    ACTIONS(7379), 1,
      sym_tag,
    STATE(3509), 1,
      sym_where_clause,
    STATE(3588), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76197] = 9,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7377), 1,
      sym_uninitialized,
    ACTIONS(7379), 1,
      sym_tag,
    STATE(3509), 1,
      sym_where_clause,
    STATE(3588), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76271] = 11,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7381), 1,
      sym_uninitialized,
    ACTIONS(7383), 1,
      sym_tag,
    STATE(3511), 1,
      sym_where_clause,
    STATE(3594), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76349] = 9,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7381), 1,
      sym_uninitialized,
    ACTIONS(7383), 1,
      sym_tag,
    STATE(3511), 1,
      sym_where_clause,
    STATE(3594), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76423] = 9,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7381), 1,
      sym_uninitialized,
    ACTIONS(7385), 1,
      sym_tag,
    STATE(3511), 1,
      sym_where_clause,
    STATE(3594), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76497] = 11,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7387), 1,
      sym_uninitialized,
    ACTIONS(7389), 1,
      sym_tag,
    STATE(3516), 1,
      sym_where_clause,
    STATE(3597), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76575] = 9,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7387), 1,
      sym_uninitialized,
    ACTIONS(7389), 1,
      sym_tag,
    STATE(3516), 1,
      sym_where_clause,
    STATE(3597), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76649] = 9,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7387), 1,
      sym_uninitialized,
    ACTIONS(7391), 1,
      sym_tag,
    STATE(3516), 1,
      sym_where_clause,
    STATE(3597), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76723] = 9,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7393), 1,
      sym_uninitialized,
    ACTIONS(7395), 1,
      sym_tag,
    STATE(3519), 1,
      sym_where_clause,
    STATE(3598), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76797] = 24,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1858), 1,
      anon_sym_LPAREN,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(7397), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3391), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(767), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [76901] = 7,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6936), 1,
      sym_uninitialized,
    ACTIONS(7400), 1,
      sym_tag,
    STATE(3790), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [76971] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77033] = 24,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(2025), 1,
      anon_sym_LPAREN,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(7402), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3705), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(871), 9,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [77137] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4909), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77199] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4989), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77261] = 5,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5001), 40,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77327] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5081), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77389] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5119), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77451] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5145), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77513] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4933), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77575] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4905), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77637] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4913), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77699] = 15,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77785] = 7,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6911), 1,
      sym_uninitialized,
    ACTIONS(6913), 1,
      sym_tag,
    STATE(3730), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [77855] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4701), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77917] = 5,
    ACTIONS(7408), 1,
      anon_sym_QMARK,
    ACTIONS(7406), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [77983] = 7,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4843), 37,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [78053] = 7,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7167), 1,
      sym_uninitialized,
    ACTIONS(7410), 1,
      sym_tag,
    STATE(3985), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3425), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [78123] = 26,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7107), 1,
      anon_sym_or_return,
    ACTIONS(7109), 1,
      anon_sym_or_continue,
    ACTIONS(7111), 1,
      anon_sym_or_break,
    ACTIONS(7113), 1,
      anon_sym_CARET,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7083), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7087), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7089), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(7412), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 17,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_case,
      anon_sym_QMARK,
      sym_uninitialized,
      sym_tag,
  [78231] = 9,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 8,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 35,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [78305] = 14,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [78389] = 7,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6927), 1,
      sym_uninitialized,
    ACTIONS(6970), 1,
      sym_tag,
    STATE(3732), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [78459] = 13,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [78541] = 20,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(4637), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7087), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7089), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 25,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [78637] = 19,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(4637), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7087), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7089), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 26,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [78731] = 7,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(7041), 1,
      sym_uninitialized,
    ACTIONS(7043), 1,
      sym_tag,
    STATE(3715), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [78801] = 17,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 28,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [78891] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5025), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5023), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [78953] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5095), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79015] = 16,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79103] = 7,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(7414), 1,
      sym_uninitialized,
    ACTIONS(7416), 1,
      sym_tag,
    STATE(3763), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [79173] = 12,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 32,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79253] = 11,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 34,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79331] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4931), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4929), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79393] = 25,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7261), 1,
      anon_sym_or_return,
    ACTIONS(7263), 1,
      anon_sym_or_continue,
    ACTIONS(7265), 1,
      anon_sym_or_break,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7237), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 19,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [79499] = 21,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7237), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 23,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79597] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4709), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79659] = 7,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4921), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79729] = 7,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4635), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79799] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4755), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79861] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4763), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79923] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4925), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [79985] = 31,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6574), 1,
      anon_sym_or_return,
    ACTIONS(6576), 1,
      anon_sym_or_continue,
    ACTIONS(6580), 1,
      anon_sym_CARET,
    ACTIONS(6629), 1,
      anon_sym_DASH_GT,
    ACTIONS(6633), 1,
      anon_sym_TILDE,
    ACTIONS(6635), 1,
      anon_sym_AMP,
    ACTIONS(6637), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6643), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6645), 1,
      anon_sym_DOT,
    ACTIONS(6649), 1,
      anon_sym_PIPE,
    ACTIONS(6653), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6655), 1,
      anon_sym_or_else,
    ACTIONS(6657), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6663), 1,
      anon_sym_or_break,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    ACTIONS(7138), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7142), 1,
      anon_sym_COLON,
    ACTIONS(7144), 1,
      anon_sym_COLON_EQ,
    ACTIONS(7418), 1,
      anon_sym_EQ,
    STATE(6631), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(6631), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6639), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6647), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6659), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6661), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6665), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6641), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6651), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(7146), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [80103] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4773), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [80165] = 25,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7107), 1,
      anon_sym_or_return,
    ACTIONS(7109), 1,
      anon_sym_or_continue,
    ACTIONS(7111), 1,
      anon_sym_or_break,
    ACTIONS(7113), 1,
      anon_sym_CARET,
    ACTIONS(4793), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7083), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7087), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7089), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 19,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [80271] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4799), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [80333] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [80395] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4953), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [80457] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(909), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [80519] = 7,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4819), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [80589] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(767), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [80651] = 7,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7117), 1,
      sym_uninitialized,
    ACTIONS(7121), 1,
      sym_tag,
    STATE(3805), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [80721] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [80783] = 7,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(7179), 1,
      sym_tag,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3368), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [80853] = 15,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 31,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [80939] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81001] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4659), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81063] = 26,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7261), 1,
      anon_sym_or_return,
    ACTIONS(7263), 1,
      anon_sym_or_continue,
    ACTIONS(7265), 1,
      anon_sym_or_break,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7237), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(7420), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 17,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [81171] = 6,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(7422), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 39,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81239] = 24,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(2116), 1,
      anon_sym_LPAREN,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(7424), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3638), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(767), 9,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [81343] = 9,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 8,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 35,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81417] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5035), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81479] = 5,
    ACTIONS(7277), 1,
      anon_sym_DOT2,
    STATE(3335), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3433), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81545] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4855), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81607] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5257), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81669] = 7,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4731), 37,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81739] = 5,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5103), 40,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81805] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81867] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81929] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4827), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [81991] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4831), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82053] = 13,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 31,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82135] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4835), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82197] = 7,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4921), 37,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82267] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82329] = 5,
    ACTIONS(7427), 1,
      anon_sym_DOT2,
    STATE(3335), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3408), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82395] = 20,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(4637), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 25,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82491] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4749), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4747), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82553] = 7,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4843), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82623] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5127), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82685] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5131), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82747] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5135), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82809] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5139), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82871] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(809), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82933] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5237), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [82995] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4847), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83057] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83119] = 6,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(7430), 1,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5009), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5005), 40,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83187] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83249] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4867), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83311] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4871), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83373] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4959), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4957), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83435] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4875), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83497] = 25,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7107), 1,
      anon_sym_or_return,
    ACTIONS(7109), 1,
      anon_sym_or_continue,
    ACTIONS(7111), 1,
      anon_sym_or_break,
    ACTIONS(7113), 1,
      anon_sym_CARET,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7083), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7087), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7089), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 19,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [83603] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4679), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83665] = 21,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7083), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7087), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7089), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 23,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83763] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [83825] = 7,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7065), 1,
      sym_uninitialized,
    ACTIONS(7432), 1,
      sym_tag,
    STATE(3914), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [83895] = 7,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7158), 1,
      sym_uninitialized,
    ACTIONS(7160), 1,
      sym_tag,
    STATE(3992), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3451), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [83965] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4883), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84027] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4887), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84089] = 5,
    ACTIONS(7436), 1,
      anon_sym_QMARK,
    ACTIONS(7434), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84155] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6925), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5001), 40,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84221] = 24,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(2013), 1,
      anon_sym_LPAREN,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(7438), 1,
      sym_tag,
    STATE(3524), 1,
      sym_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(857), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(855), 9,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [84325] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5241), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84387] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5245), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84449] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5249), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84511] = 7,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7123), 1,
      sym_uninitialized,
    ACTIONS(7127), 1,
      sym_tag,
    STATE(3962), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [84581] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4683), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84643] = 25,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7107), 1,
      anon_sym_or_return,
    ACTIONS(7109), 1,
      anon_sym_or_continue,
    ACTIONS(7111), 1,
      anon_sym_or_break,
    ACTIONS(7113), 1,
      anon_sym_CARET,
    ACTIONS(4471), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(7083), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7087), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7089), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4466), 19,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [84749] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5253), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84811] = 5,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 40,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84877] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(871), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [84939] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5059), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85001] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4705), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85063] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3701), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85125] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4891), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85187] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85249] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85311] = 5,
    ACTIONS(7277), 1,
      anon_sym_DOT2,
    STATE(3322), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85377] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4917), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85439] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85501] = 24,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1674), 1,
      anon_sym_LPAREN,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(7441), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3343), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(836), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(833), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [85605] = 24,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1704), 1,
      anon_sym_LPAREN,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(7445), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3372), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(809), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [85709] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85771] = 7,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      sym_uninitialized,
    ACTIONS(7451), 1,
      sym_tag,
    STATE(3941), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4577), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [85841] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4969), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85903] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4973), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [85965] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86027] = 6,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7030), 1,
      anon_sym_SLASH,
    ACTIONS(7453), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 39,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86095] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4841), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4839), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86157] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5055), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86219] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4981), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86281] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4985), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86343] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5019), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86405] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86467] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4735), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86529] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4739), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86591] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86653] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4743), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86715] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4759), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86777] = 24,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1806), 1,
      anon_sym_LPAREN,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(7455), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3308), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(893), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [86881] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5031), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [86943] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5043), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87005] = 31,
    ACTIONS(6536), 1,
      anon_sym_DASH_GT,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6546), 1,
      anon_sym_TILDE,
    ACTIONS(6548), 1,
      anon_sym_AMP,
    ACTIONS(6550), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6556), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6558), 1,
      anon_sym_PIPE,
    ACTIONS(6562), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6564), 1,
      anon_sym_or_else,
    ACTIONS(6566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6574), 1,
      anon_sym_or_return,
    ACTIONS(6576), 1,
      anon_sym_or_continue,
    ACTIONS(6578), 1,
      anon_sym_or_break,
    ACTIONS(6580), 1,
      anon_sym_CARET,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    ACTIONS(7138), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7144), 1,
      anon_sym_COLON_EQ,
    ACTIONS(7418), 1,
      anon_sym_EQ,
    ACTIONS(7458), 1,
      anon_sym_COLON,
    STATE(6631), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(6542), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6544), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6560), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6568), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6570), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6554), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6572), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(7146), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [87123] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5047), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87185] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87247] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87309] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87371] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5063), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87433] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5073), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87495] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5077), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87557] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4787), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87619] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4795), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87681] = 4,
    ACTIONS(7057), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 40,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87745] = 7,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(7185), 1,
      sym_tag,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3384), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [87815] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4803), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87877] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5099), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [87939] = 24,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1967), 1,
      anon_sym_LPAREN,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(7460), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3688), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(836), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(833), 9,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [88043] = 24,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1720), 1,
      anon_sym_LPAREN,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(7464), 1,
      sym_tag,
    STATE(3231), 1,
      sym_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(857), 4,
      anon_sym_where,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(855), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      sym_uninitialized,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [88147] = 7,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7132), 1,
      sym_uninitialized,
    ACTIONS(7134), 1,
      sym_tag,
    STATE(3906), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [88217] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5111), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [88279] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4723), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4721), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [88341] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5115), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [88403] = 7,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7294), 1,
      sym_uninitialized,
    ACTIONS(7296), 1,
      sym_tag,
    STATE(3883), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [88473] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [88535] = 7,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7187), 1,
      sym_uninitialized,
    ACTIONS(7189), 1,
      sym_tag,
    STATE(3857), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3400), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [88605] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5123), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [88667] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4937), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [88729] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4639), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [88791] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4807), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [88853] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4811), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [88915] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4643), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [88977] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [89039] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4647), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [89101] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4651), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [89163] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4655), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [89225] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4815), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [89287] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4631), 41,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [89349] = 11,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7469), 1,
      sym_uninitialized,
    ACTIONS(7471), 1,
      sym_tag,
    STATE(3759), 1,
      sym_where_clause,
    STATE(4292), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [89426] = 6,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7298), 1,
      sym_uninitialized,
    STATE(3958), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [89493] = 5,
    ACTIONS(7473), 1,
      anon_sym_LBRACE,
    STATE(3441), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3701), 39,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [89558] = 6,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(7476), 1,
      sym_uninitialized,
    STATE(3774), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [89625] = 4,
    STATE(3441), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4462), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [89688] = 5,
    ACTIONS(7478), 1,
      sym_identifier,
    ACTIONS(7480), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 21,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 28,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [89753] = 6,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7482), 1,
      sym_uninitialized,
    STATE(3929), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4585), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [89820] = 6,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(7006), 1,
      sym_uninitialized,
    STATE(3769), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [89887] = 6,
    ACTIONS(7484), 1,
      anon_sym_LBRACE,
    ACTIONS(7487), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 38,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [89954] = 6,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6911), 1,
      sym_uninitialized,
    STATE(3730), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [90021] = 5,
    ACTIONS(7490), 1,
      anon_sym_DOT2,
    STATE(3507), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3433), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [90086] = 10,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7494), 1,
      anon_sym_DASH_GT,
    ACTIONS(7496), 1,
      sym_uninitialized,
    ACTIONS(7498), 1,
      sym_tag,
    STATE(3750), 1,
      sym_where_clause,
    STATE(4669), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3439), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [90161] = 10,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7500), 1,
      anon_sym_DASH_GT,
    ACTIONS(7502), 1,
      sym_uninitialized,
    ACTIONS(7504), 1,
      sym_tag,
    STATE(3770), 1,
      sym_where_clause,
    STATE(4650), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [90236] = 7,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7201), 1,
      sym_uninitialized,
    ACTIONS(7203), 1,
      sym_tag,
    STATE(3848), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [90305] = 7,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7205), 1,
      sym_uninitialized,
    ACTIONS(7506), 1,
      sym_tag,
    STATE(3819), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [90374] = 6,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7167), 1,
      sym_uninitialized,
    STATE(3985), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3425), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [90441] = 11,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7508), 1,
      sym_uninitialized,
    ACTIONS(7510), 1,
      sym_tag,
    STATE(3793), 1,
      sym_where_clause,
    STATE(4511), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [90518] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7508), 1,
      sym_uninitialized,
    ACTIONS(7510), 1,
      sym_tag,
    STATE(3793), 1,
      sym_where_clause,
    STATE(4511), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [90591] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1830), 1,
      anon_sym_LPAREN,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(7530), 1,
      sym_tag,
    STATE(3043), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(895), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [90694] = 6,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7117), 1,
      sym_uninitialized,
    STATE(3805), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [90761] = 27,
    ACTIONS(4483), 1,
      anon_sym_EQ,
    ACTIONS(7533), 1,
      anon_sym_COMMA,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7549), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7571), 1,
      anon_sym_or_return,
    ACTIONS(7573), 1,
      anon_sym_or_continue,
    ACTIONS(7575), 1,
      anon_sym_or_break,
    ACTIONS(7577), 1,
      anon_sym_CARET,
    STATE(3469), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(7547), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7551), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7553), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 17,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [90870] = 4,
    STATE(3441), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4475), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [90933] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 11,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_DOT2,
    ACTIONS(3408), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [90994] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1744), 1,
      anon_sym_LPAREN,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(7579), 1,
      sym_tag,
    STATE(3078), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(836), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(833), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [91097] = 11,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7583), 1,
      sym_uninitialized,
    ACTIONS(7585), 1,
      sym_tag,
    STATE(3745), 1,
      sym_where_clause,
    STATE(4520), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [91174] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7583), 1,
      sym_uninitialized,
    ACTIONS(7585), 1,
      sym_tag,
    STATE(3745), 1,
      sym_where_clause,
    STATE(4520), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [91247] = 7,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7209), 1,
      sym_uninitialized,
    ACTIONS(7213), 1,
      sym_tag,
    STATE(3854), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [91316] = 6,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7065), 1,
      sym_uninitialized,
    STATE(3914), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [91383] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1894), 1,
      anon_sym_LPAREN,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(7587), 1,
      sym_tag,
    STATE(3046), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(911), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [91486] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7583), 1,
      sym_uninitialized,
    ACTIONS(7590), 1,
      sym_tag,
    STATE(3745), 1,
      sym_where_clause,
    STATE(4520), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [91559] = 5,
    ACTIONS(7533), 1,
      anon_sym_COMMA,
    STATE(3493), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4460), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4456), 39,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [91624] = 4,
    STATE(3441), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3547), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [91687] = 10,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7592), 1,
      anon_sym_DASH_GT,
    ACTIONS(7594), 1,
      sym_uninitialized,
    ACTIONS(7596), 1,
      sym_tag,
    STATE(3746), 1,
      sym_where_clause,
    STATE(4285), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3439), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [91762] = 10,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7598), 1,
      anon_sym_DASH_GT,
    ACTIONS(7600), 1,
      sym_uninitialized,
    ACTIONS(7602), 1,
      sym_tag,
    STATE(3747), 1,
      sym_where_clause,
    STATE(4287), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [91837] = 11,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      sym_uninitialized,
    ACTIONS(7606), 1,
      sym_tag,
    STATE(3741), 1,
      sym_where_clause,
    STATE(4528), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [91914] = 26,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6860), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6862), 1,
      anon_sym_or_else,
    ACTIONS(6864), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6880), 1,
      anon_sym_or_return,
    ACTIONS(6882), 1,
      anon_sym_or_continue,
    ACTIONS(6884), 1,
      anon_sym_or_break,
    ACTIONS(6886), 1,
      anon_sym_CARET,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6852), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6866), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6868), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7610), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6870), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7608), 16,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [92021] = 11,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7612), 1,
      sym_uninitialized,
    ACTIONS(7614), 1,
      sym_tag,
    STATE(3796), 1,
      sym_where_clause,
    STATE(4290), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92098] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7612), 1,
      sym_uninitialized,
    ACTIONS(7614), 1,
      sym_tag,
    STATE(3796), 1,
      sym_where_clause,
    STATE(4290), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92171] = 6,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6927), 1,
      sym_uninitialized,
    STATE(3732), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92238] = 6,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6936), 1,
      sym_uninitialized,
    STATE(3790), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92305] = 7,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7215), 1,
      sym_uninitialized,
    ACTIONS(7219), 1,
      sym_tag,
    STATE(3897), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92374] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1774), 1,
      anon_sym_LPAREN,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(7616), 1,
      sym_tag,
    STATE(3108), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(812), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [92477] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      sym_uninitialized,
    ACTIONS(7606), 1,
      sym_tag,
    STATE(3741), 1,
      sym_where_clause,
    STATE(4528), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92550] = 6,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(7414), 1,
      sym_uninitialized,
    STATE(3763), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92617] = 6,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7620), 1,
      sym_uninitialized,
    STATE(3812), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92684] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7469), 1,
      sym_uninitialized,
    ACTIONS(7622), 1,
      sym_tag,
    STATE(3759), 1,
      sym_where_clause,
    STATE(4292), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92757] = 11,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7624), 1,
      sym_uninitialized,
    ACTIONS(7626), 1,
      sym_tag,
    STATE(3762), 1,
      sym_where_clause,
    STATE(4293), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92834] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7624), 1,
      sym_uninitialized,
    ACTIONS(7626), 1,
      sym_tag,
    STATE(3762), 1,
      sym_where_clause,
    STATE(4293), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92907] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7624), 1,
      sym_uninitialized,
    ACTIONS(7628), 1,
      sym_tag,
    STATE(3762), 1,
      sym_where_clause,
    STATE(4293), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [92980] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1842), 1,
      anon_sym_LPAREN,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(7630), 1,
      sym_tag,
    STATE(3051), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(874), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [93083] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7634), 1,
      sym_uninitialized,
    ACTIONS(7636), 1,
      sym_tag,
    STATE(3766), 1,
      sym_where_clause,
    STATE(4294), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [93156] = 6,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      sym_uninitialized,
    STATE(3941), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4577), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [93223] = 7,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7221), 1,
      sym_uninitialized,
    ACTIONS(7223), 1,
      sym_tag,
    STATE(3978), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [93292] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      sym_uninitialized,
    ACTIONS(7638), 1,
      sym_tag,
    STATE(3741), 1,
      sym_where_clause,
    STATE(4528), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [93365] = 5,
    ACTIONS(7640), 1,
      anon_sym_COMMA,
    STATE(3493), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4471), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4466), 39,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [93430] = 6,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3384), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [93497] = 6,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(7041), 1,
      sym_uninitialized,
    STATE(3715), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [93564] = 6,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3368), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [93631] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7643), 1,
      sym_uninitialized,
    ACTIONS(7645), 1,
      sym_tag,
    STATE(3725), 1,
      sym_where_clause,
    STATE(4531), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [93704] = 7,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7647), 1,
      sym_uninitialized,
    ACTIONS(7649), 1,
      sym_tag,
    STATE(4013), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [93773] = 6,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7369), 1,
      sym_uninitialized,
    STATE(3582), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 38,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [93840] = 7,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7369), 1,
      sym_uninitialized,
    ACTIONS(7371), 1,
      sym_tag,
    STATE(3582), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [93909] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1870), 1,
      anon_sym_LPAREN,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(7651), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3165), 1,
      sym_type,
    ACTIONS(773), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [94012] = 6,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7377), 1,
      sym_uninitialized,
    STATE(3588), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 38,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [94079] = 7,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7377), 1,
      sym_uninitialized,
    ACTIONS(7654), 1,
      sym_tag,
    STATE(3588), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [94148] = 6,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7294), 1,
      sym_uninitialized,
    STATE(3883), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [94215] = 6,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7381), 1,
      sym_uninitialized,
    STATE(3594), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 38,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [94282] = 6,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7158), 1,
      sym_uninitialized,
    STATE(3992), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3451), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [94349] = 5,
    ACTIONS(7656), 1,
      anon_sym_DOT2,
    STATE(3507), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3408), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [94414] = 6,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7132), 1,
      sym_uninitialized,
    STATE(3906), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [94481] = 7,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7381), 1,
      sym_uninitialized,
    ACTIONS(7385), 1,
      sym_tag,
    STATE(3594), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [94550] = 6,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7187), 1,
      sym_uninitialized,
    STATE(3857), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3400), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [94617] = 7,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7387), 1,
      sym_uninitialized,
    ACTIONS(7391), 1,
      sym_tag,
    STATE(3597), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [94686] = 5,
    ACTIONS(7659), 1,
      anon_sym_LBRACE,
    STATE(3512), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 22,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3701), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [94751] = 6,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7387), 1,
      sym_uninitialized,
    STATE(3597), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 38,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [94818] = 4,
    ACTIONS(7662), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4454), 21,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(4450), 29,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [94881] = 5,
    ACTIONS(7490), 1,
      anon_sym_DOT2,
    STATE(3449), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [94946] = 7,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7393), 1,
      sym_uninitialized,
    ACTIONS(7395), 1,
      sym_tag,
    STATE(3598), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [95015] = 6,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7393), 1,
      sym_uninitialized,
    STATE(3598), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 38,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [95082] = 6,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7664), 1,
      sym_uninitialized,
    STATE(3599), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 38,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [95149] = 7,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7664), 1,
      sym_uninitialized,
    ACTIONS(7666), 1,
      sym_tag,
    STATE(3599), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [95218] = 6,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7123), 1,
      sym_uninitialized,
    STATE(3962), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [95285] = 6,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7668), 1,
      sym_uninitialized,
    STATE(3600), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 38,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_tag,
  [95352] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1882), 1,
      anon_sym_LPAREN,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(7670), 1,
      sym_tag,
    STATE(3017), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(857), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [95455] = 9,
    ACTIONS(7361), 1,
      anon_sym_where,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7469), 1,
      sym_uninitialized,
    ACTIONS(7471), 1,
      sym_tag,
    STATE(3759), 1,
      sym_where_clause,
    STATE(4292), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [95528] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(893), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [95588] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4887), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [95648] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4891), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [95708] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [95768] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [95828] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4917), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [95888] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [95948] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96008] = 25,
    ACTIONS(4471), 1,
      anon_sym_EQ,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7549), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7571), 1,
      anon_sym_or_return,
    ACTIONS(7573), 1,
      anon_sym_or_continue,
    ACTIONS(7575), 1,
      anon_sym_or_break,
    ACTIONS(7577), 1,
      anon_sym_CARET,
    ACTIONS(7547), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7551), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7553), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4466), 18,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [96112] = 5,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5103), 39,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96176] = 5,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 39,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96240] = 5,
    ACTIONS(7673), 1,
      anon_sym_DOT2,
    STATE(3535), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3408), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [96304] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4969), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96364] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4973), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96424] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4981), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96484] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4985), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96544] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5019), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96604] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96664] = 5,
    ACTIONS(7676), 1,
      anon_sym_DOT2,
    STATE(3535), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3433), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [96728] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5031), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96788] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5043), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96848] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5047), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96908] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4959), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4957), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [96968] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97028] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97088] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5063), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97148] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5073), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97208] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5077), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97268] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5099), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97328] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5111), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97388] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5115), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97448] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5123), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97508] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4937), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97568] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4639), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97628] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4643), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97688] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4647), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97748] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4651), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97808] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4655), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97868] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4841), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4839), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97928] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4659), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [97988] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4663), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [98048] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4667), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [98108] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4671), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [98168] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4675), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [98228] = 6,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 38,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [98294] = 5,
    ACTIONS(7680), 1,
      anon_sym_LBRACE,
    STATE(3569), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3701), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [98358] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4717), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [98418] = 5,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    STATE(3569), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3547), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [98482] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5025), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5023), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [98542] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4841), 22,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4839), 28,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [98602] = 5,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    STATE(3512), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3547), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [98666] = 29,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6860), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6862), 1,
      anon_sym_or_else,
    ACTIONS(6864), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6880), 1,
      anon_sym_or_return,
    ACTIONS(6882), 1,
      anon_sym_or_continue,
    ACTIONS(6884), 1,
      anon_sym_or_break,
    ACTIONS(6886), 1,
      anon_sym_CARET,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    ACTIONS(6897), 1,
      anon_sym_EQ,
    ACTIONS(6899), 1,
      anon_sym_COLON_EQ,
    STATE(6660), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6852), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6866), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6868), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6870), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6901), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [98778] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [98838] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [98898] = 6,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7201), 1,
      sym_uninitialized,
    STATE(3848), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [98964] = 6,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7205), 1,
      sym_uninitialized,
    STATE(3819), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [99030] = 6,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7209), 1,
      sym_uninitialized,
    STATE(3854), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [99096] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4679), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99156] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99216] = 5,
    ACTIONS(7689), 1,
      anon_sym_QMARK,
    ACTIONS(7687), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99280] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4705), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99340] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99400] = 6,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7215), 1,
      sym_uninitialized,
    STATE(3897), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [99466] = 7,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4731), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99534] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99594] = 6,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7221), 1,
      sym_uninitialized,
    STATE(3978), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [99660] = 6,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7647), 1,
      sym_uninitialized,
    STATE(4013), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [99726] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4909), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99786] = 7,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4921), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99854] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4925), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99914] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [99974] = 6,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7691), 1,
      sym_uninitialized,
    STATE(4005), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [100040] = 5,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    STATE(3569), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4462), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [100104] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100164] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100224] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100284] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4949), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100344] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4631), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100404] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5257), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100464] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4953), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100524] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100584] = 5,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    STATE(3512), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4462), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [100648] = 5,
    ACTIONS(7693), 1,
      anon_sym_DOT2,
    STATE(3710), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3433), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [100712] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4989), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100772] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4941), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100832] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3701), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100892] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5015), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [100952] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5027), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101012] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4683), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101072] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5039), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101132] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5035), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101192] = 5,
    ACTIONS(7695), 1,
      anon_sym_DOT2,
    STATE(3636), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3433), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [101256] = 5,
    ACTIONS(7676), 1,
      anon_sym_DOT2,
    STATE(3542), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [101320] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5127), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101380] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5131), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101440] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5135), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101500] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5139), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101560] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5237), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101620] = 4,
    ACTIONS(7480), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 39,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101682] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5119), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101742] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4883), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101802] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4933), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101862] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5241), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101922] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5245), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [101982] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5249), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102042] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5253), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102102] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4905), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102162] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5059), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102222] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4913), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102282] = 15,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 30,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102366] = 26,
    ACTIONS(5069), 1,
      anon_sym_EQ,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7549), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7571), 1,
      anon_sym_or_return,
    ACTIONS(7573), 1,
      anon_sym_or_continue,
    ACTIONS(7575), 1,
      anon_sym_or_break,
    ACTIONS(7577), 1,
      anon_sym_CARET,
    ACTIONS(7547), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7551), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7553), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(7697), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 16,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_case,
      anon_sym_QMARK,
      sym_uninitialized,
      sym_tag,
  [102472] = 6,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(7699), 1,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5009), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5005), 39,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102538] = 5,
    ACTIONS(7701), 1,
      anon_sym_DOT2,
    STATE(3636), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3408), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [102602] = 9,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 34,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102674] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5055), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102734] = 14,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 30,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102816] = 13,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 30,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102896] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [102956] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4735), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103016] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4739), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103076] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4743), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103136] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4759), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103196] = 20,
    ACTIONS(4637), 1,
      anon_sym_EQ,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7549), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7551), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7553), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 24,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103290] = 5,
    ACTIONS(7695), 1,
      anon_sym_DOT2,
    STATE(3615), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [103354] = 19,
    ACTIONS(4637), 1,
      anon_sym_EQ,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7551), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7553), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 25,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103446] = 17,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 27,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103534] = 16,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 30,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103620] = 12,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 31,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103698] = 11,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 33,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103774] = 7,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4635), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103842] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4755), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103902] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4763), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [103962] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4773), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104022] = 25,
    ACTIONS(4793), 1,
      anon_sym_EQ,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7549), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7571), 1,
      anon_sym_or_return,
    ACTIONS(7573), 1,
      anon_sym_or_continue,
    ACTIONS(7575), 1,
      anon_sym_or_break,
    ACTIONS(7577), 1,
      anon_sym_CARET,
    ACTIONS(7547), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7551), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7553), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 18,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [104126] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4787), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104186] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4795), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104246] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4803), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104306] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4799), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104366] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4689), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104426] = 7,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4819), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104494] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4807), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104554] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4811), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104614] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4815), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104674] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4855), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104734] = 6,
    ACTIONS(7057), 1,
      anon_sym_LPAREN,
    ACTIONS(7436), 1,
      anon_sym_QMARK,
    ACTIONS(7434), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104800] = 5,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4961), 39,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104864] = 5,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5001), 39,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104928] = 5,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7375), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5011), 39,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [104992] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4859), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105052] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4863), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105112] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105172] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105232] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4827), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105292] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4831), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105352] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4835), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105412] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4701), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105472] = 7,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4843), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105540] = 4,
    STATE(3512), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4462), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [105602] = 6,
    ACTIONS(7480), 1,
      anon_sym_LPAREN,
    ACTIONS(7689), 1,
      anon_sym_QMARK,
    ACTIONS(7687), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105668] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4945), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [105728] = 5,
    ACTIONS(7693), 1,
      anon_sym_DOT2,
    STATE(3606), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3481), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [105792] = 26,
    ACTIONS(6842), 1,
      anon_sym_DASH_GT,
    ACTIONS(6844), 1,
      anon_sym_DOT,
    ACTIONS(6846), 1,
      anon_sym_LBRACK,
    ACTIONS(6850), 1,
      anon_sym_PIPE,
    ACTIONS(6852), 1,
      anon_sym_not_in,
    ACTIONS(6856), 1,
      anon_sym_TILDE,
    ACTIONS(6858), 1,
      anon_sym_AMP,
    ACTIONS(6860), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6862), 1,
      anon_sym_or_else,
    ACTIONS(6864), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6872), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(6878), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(6880), 1,
      anon_sym_or_return,
    ACTIONS(6882), 1,
      anon_sym_or_continue,
    ACTIONS(6884), 1,
      anon_sym_or_break,
    ACTIONS(6886), 1,
      anon_sym_CARET,
    ACTIONS(6848), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(6854), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6866), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6868), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7610), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6870), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(6876), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7608), 16,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_in,
  [105898] = 5,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    STATE(3569), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4475), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [105962] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4723), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4721), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106022] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(809), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106082] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(871), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106142] = 4,
    STATE(3512), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4475), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [106204] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4847), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106264] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106324] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 12,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_DOT2,
    ACTIONS(3408), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [106384] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106444] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4867), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106504] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4871), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106564] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4749), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4747), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106624] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5095), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106684] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4875), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106744] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(909), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [106804] = 25,
    ACTIONS(4881), 1,
      anon_sym_EQ,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7549), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7571), 1,
      anon_sym_or_return,
    ACTIONS(7573), 1,
      anon_sym_or_continue,
    ACTIONS(7575), 1,
      anon_sym_or_break,
    ACTIONS(7577), 1,
      anon_sym_CARET,
    ACTIONS(7547), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7551), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7553), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 18,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      sym_uninitialized,
      sym_tag,
  [106908] = 21,
    ACTIONS(4881), 1,
      anon_sym_EQ,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7549), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7547), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7551), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7553), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 22,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [107004] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(767), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [107064] = 4,
    STATE(3512), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3547), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [107126] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5081), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [107186] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 22,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3701), 28,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [107246] = 5,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    STATE(3512), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4475), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [107310] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4709), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [107370] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4931), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4929), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [107430] = 5,
    ACTIONS(7704), 1,
      anon_sym_DOT2,
    STATE(3710), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3408), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [107494] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5145), 40,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [107554] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5127), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [107613] = 6,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [107678] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4803), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [107737] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [107796] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [107855] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2242), 1,
      anon_sym_LPAREN,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    STATE(3893), 1,
      sym_type,
    STATE(3909), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(836), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(833), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [107956] = 4,
    STATE(3569), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3547), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108017] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 11,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_DOT2,
    ACTIONS(3408), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108076] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5253), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108135] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2331), 1,
      anon_sym_LPAREN,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(3952), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(893), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [108236] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4841), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4839), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108295] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2270), 1,
      anon_sym_LPAREN,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    STATE(3798), 1,
      sym_type,
    STATE(3909), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(809), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [108396] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3701), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108455] = 7,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7730), 1,
      sym_uninitialized,
    ACTIONS(7732), 1,
      sym_tag,
    STATE(4534), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108522] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(909), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108581] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 12,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_DOT2,
    ACTIONS(3408), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108640] = 4,
    STATE(3569), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4462), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108701] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4807), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108760] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108819] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4683), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108878] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [108937] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2418), 1,
      anon_sym_LPAREN,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(3980), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(871), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [109038] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4735), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109097] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4989), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109156] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4739), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109215] = 5,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(7736), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5001), 37,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109278] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2349), 1,
      anon_sym_LPAREN,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(3951), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(857), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(855), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [109379] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4945), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109438] = 5,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(7736), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5011), 37,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109501] = 7,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7643), 1,
      sym_uninitialized,
    ACTIONS(7645), 1,
      sym_tag,
    STATE(4531), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109568] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4689), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109627] = 4,
    STATE(3569), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4475), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109688] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4743), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109747] = 7,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      sym_uninitialized,
    ACTIONS(7638), 1,
      sym_tag,
    STATE(4528), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109814] = 7,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7600), 1,
      sym_uninitialized,
    ACTIONS(7602), 1,
      sym_tag,
    STATE(4287), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109881] = 7,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7612), 1,
      sym_uninitialized,
    ACTIONS(7738), 1,
      sym_tag,
    STATE(4290), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [109948] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2409), 1,
      anon_sym_LPAREN,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(3943), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(767), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [110049] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110108] = 7,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7502), 1,
      sym_uninitialized,
    ACTIONS(7504), 1,
      sym_tag,
    STATE(4650), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110175] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(871), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110234] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4759), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110293] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5081), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110352] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5035), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110411] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(893), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110470] = 5,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(7736), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4961), 37,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110533] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4717), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110592] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(767), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110651] = 7,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7624), 1,
      sym_uninitialized,
    ACTIONS(7628), 1,
      sym_tag,
    STATE(4293), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110718] = 5,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(7736), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5103), 37,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110781] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4811), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110840] = 7,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7634), 1,
      sym_uninitialized,
    ACTIONS(7636), 1,
      sym_tag,
    STATE(4294), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110907] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [110966] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4701), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111025] = 6,
    ACTIONS(7740), 1,
      anon_sym_LBRACE,
    ACTIONS(7742), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111090] = 7,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7745), 1,
      sym_uninitialized,
    ACTIONS(7747), 1,
      sym_tag,
    STATE(4295), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111157] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4953), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111216] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4815), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111275] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111334] = 7,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7508), 1,
      sym_uninitialized,
    ACTIONS(7749), 1,
      sym_tag,
    STATE(4511), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111401] = 6,
    ACTIONS(7751), 1,
      anon_sym_COLON,
    ACTIONS(7753), 1,
      anon_sym_DOT2,
    STATE(3934), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [111466] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4855), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111525] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5095), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111584] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4949), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111643] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4859), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111702] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4863), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111761] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5059), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111820] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5249), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111879] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5131), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111938] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5135), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [111997] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4787), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112056] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5139), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112115] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(809), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112174] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5237), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112233] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2358), 1,
      anon_sym_LPAREN,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    STATE(3859), 1,
      sym_type,
    STATE(3909), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(909), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [112334] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4795), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112393] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5055), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112452] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4709), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112511] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112570] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112629] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 22,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_DOT2,
      sym_identifier,
    ACTIONS(3408), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [112688] = 5,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(7736), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 37,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112751] = 7,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7583), 1,
      sym_uninitialized,
    ACTIONS(7590), 1,
      sym_tag,
    STATE(4520), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112818] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5241), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112877] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5245), 38,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [112936] = 7,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7469), 1,
      sym_uninitialized,
    ACTIONS(7622), 1,
      sym_tag,
    STATE(4292), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [113003] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4743), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [113061] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(871), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [113119] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5059), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [113177] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4989), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [113235] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4709), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [113293] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5253), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [113351] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4945), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [113409] = 6,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7730), 1,
      sym_uninitialized,
    STATE(4534), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [113473] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [113531] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4855), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [113589] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4759), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [113647] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5081), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [113705] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2218), 1,
      anon_sym_LPAREN,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    STATE(3266), 1,
      sym_type,
    STATE(3839), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(871), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [113805] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4859), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [113863] = 24,
    ACTIONS(911), 1,
      anon_sym_SLASH,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2340), 1,
      anon_sym_LPAREN,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(4007), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [113963] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4949), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [114021] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4855), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [114079] = 4,
    ACTIONS(7781), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [114139] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4863), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [114197] = 4,
    ACTIONS(7783), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4454), 20,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(4450), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [114257] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4725), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [114315] = 28,
    ACTIONS(4483), 1,
      anon_sym_EQ,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7549), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7571), 1,
      anon_sym_or_return,
    ACTIONS(7573), 1,
      anon_sym_or_continue,
    ACTIONS(7575), 1,
      anon_sym_or_break,
    ACTIONS(7577), 1,
      anon_sym_CARET,
    ACTIONS(7785), 1,
      anon_sym_COMMA,
    STATE(6712), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(7547), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7551), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7553), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(7697), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 12,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [114423] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [114481] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4859), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [114539] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4863), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [114597] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4683), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [114655] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5095), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [114713] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5241), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [114771] = 6,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      sym_uninitialized,
    STATE(4528), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [114835] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4989), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [114893] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5245), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [114951] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4945), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [115009] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5249), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [115067] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2185), 1,
      anon_sym_LPAREN,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    STATE(3343), 1,
      sym_type,
    STATE(3839), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(836), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(833), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [115167] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5253), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [115225] = 5,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(7789), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [115287] = 24,
    ACTIONS(874), 1,
      anon_sym_SLASH,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2294), 1,
      anon_sym_LPAREN,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3808), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [115387] = 24,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2582), 1,
      anon_sym_LPAREN,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(7809), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4373), 1,
      sym_type,
    ACTIONS(857), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [115487] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4863), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [115545] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5059), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [115603] = 24,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2606), 1,
      anon_sym_LPAREN,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(7812), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4376), 1,
      sym_type,
    ACTIONS(836), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(833), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [115703] = 24,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2622), 1,
      anon_sym_LPAREN,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(7816), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4378), 1,
      sym_type,
    ACTIONS(812), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [115803] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4717), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [115861] = 24,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2570), 1,
      anon_sym_LPAREN,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(7820), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4382), 1,
      sym_type,
    ACTIONS(895), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [115961] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(809), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [116019] = 24,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2594), 1,
      anon_sym_LPAREN,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(7823), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4383), 1,
      sym_type,
    ACTIONS(911), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [116119] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5095), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [116177] = 6,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(7736), 1,
      anon_sym_SLASH,
    ACTIONS(7826), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [116241] = 4,
    ACTIONS(7828), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4454), 20,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(4450), 27,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [116301] = 5,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(7789), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4961), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [116363] = 5,
    ACTIONS(7830), 1,
      sym_identifier,
    ACTIONS(7832), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 20,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 26,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [116425] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [116483] = 24,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2544), 1,
      anon_sym_LPAREN,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(7834), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4317), 1,
      sym_type,
    ACTIONS(773), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [116583] = 24,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2638), 1,
      anon_sym_LPAREN,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(7837), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4384), 1,
      sym_type,
    ACTIONS(874), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [116683] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5237), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [116741] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4953), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [116799] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2206), 1,
      anon_sym_LPAREN,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    STATE(3372), 1,
      sym_type,
    STATE(3839), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(809), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [116899] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [116957] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [117015] = 6,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7841), 1,
      sym_uninitialized,
    STATE(4537), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [117079] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4577), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [117137] = 5,
    ACTIONS(7843), 1,
      anon_sym_DOT2,
    STATE(3858), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3408), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [117199] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(767), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [117257] = 24,
    ACTIONS(773), 1,
      anon_sym_SLASH,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2400), 1,
      anon_sym_LPAREN,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(3938), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [117357] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4815), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [117415] = 10,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7848), 1,
      anon_sym_DASH_GT,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7852), 1,
      sym_uninitialized,
    ACTIONS(7854), 1,
      sym_tag,
    STATE(4264), 1,
      sym_where_clause,
    STATE(4302), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3439), 31,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [117487] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5127), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [117545] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5131), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [117603] = 6,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(7789), 1,
      anon_sym_SLASH,
    ACTIONS(7856), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [117667] = 10,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7858), 1,
      anon_sym_DASH_GT,
    ACTIONS(7860), 1,
      sym_uninitialized,
    ACTIONS(7862), 1,
      sym_tag,
    STATE(4158), 1,
      sym_where_clause,
    STATE(4304), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 31,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [117739] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5135), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [117797] = 11,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_SLASH,
    ACTIONS(7868), 1,
      sym_uninitialized,
    ACTIONS(7870), 1,
      sym_tag,
    STATE(4163), 1,
      sym_where_clause,
    STATE(4310), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 31,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [117871] = 9,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7868), 1,
      sym_uninitialized,
    ACTIONS(7870), 1,
      sym_tag,
    STATE(4163), 1,
      sym_where_clause,
    STATE(4310), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [117941] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5127), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [117999] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5131), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [118057] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4735), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [118115] = 11,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_SLASH,
    ACTIONS(7872), 1,
      sym_uninitialized,
    ACTIONS(7874), 1,
      sym_tag,
    STATE(4164), 1,
      sym_where_clause,
    STATE(4316), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 31,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [118189] = 9,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7872), 1,
      sym_uninitialized,
    ACTIONS(7874), 1,
      sym_tag,
    STATE(4164), 1,
      sym_where_clause,
    STATE(4316), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [118259] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4859), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [118317] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4787), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [118375] = 9,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7872), 1,
      sym_uninitialized,
    ACTIONS(7876), 1,
      sym_tag,
    STATE(4164), 1,
      sym_where_clause,
    STATE(4316), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [118445] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5139), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [118503] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4795), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [118561] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5237), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [118619] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4739), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [118677] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(767), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [118735] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [118793] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4683), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [118851] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4803), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [118909] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5035), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [118967] = 11,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_SLASH,
    ACTIONS(7878), 1,
      sym_uninitialized,
    ACTIONS(7880), 1,
      sym_tag,
    STATE(4171), 1,
      sym_where_clause,
    STATE(4323), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 31,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [119041] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4759), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [119099] = 24,
    ACTIONS(895), 1,
      anon_sym_SLASH,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2322), 1,
      anon_sym_LPAREN,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(3976), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [119199] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5135), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [119257] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5139), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [119315] = 9,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7878), 1,
      sym_uninitialized,
    ACTIONS(7880), 1,
      sym_tag,
    STATE(4171), 1,
      sym_where_clause,
    STATE(4323), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [119385] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(809), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [119443] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5081), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [119501] = 28,
    ACTIONS(4483), 1,
      anon_sym_EQ,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7107), 1,
      anon_sym_or_return,
    ACTIONS(7109), 1,
      anon_sym_or_continue,
    ACTIONS(7111), 1,
      anon_sym_or_break,
    ACTIONS(7113), 1,
      anon_sym_CARET,
    ACTIONS(7882), 1,
      anon_sym_COMMA,
    STATE(6702), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(7083), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7087), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7089), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(7412), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 12,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [119609] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5237), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [119667] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [119725] = 9,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7878), 1,
      sym_uninitialized,
    ACTIONS(7884), 1,
      sym_tag,
    STATE(4171), 1,
      sym_where_clause,
    STATE(4323), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [119795] = 9,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      anon_sym_where,
    ACTIONS(7886), 1,
      sym_uninitialized,
    ACTIONS(7888), 1,
      sym_tag,
    STATE(4179), 1,
      sym_where_clause,
    STATE(4327), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [119865] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5127), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [119923] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4787), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [119981] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4701), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120039] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4795), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120097] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4803), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120155] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4683), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120213] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120271] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4701), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [120329] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4689), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120387] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4717), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120445] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4807), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120503] = 5,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(7789), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5103), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120565] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5131), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [120623] = 6,
    ACTIONS(7173), 1,
      anon_sym_LPAREN,
    ACTIONS(7408), 1,
      anon_sym_QMARK,
    ACTIONS(7406), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 34,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_COLON,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [120687] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120745] = 24,
    ACTIONS(836), 1,
      anon_sym_SLASH,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2367), 1,
      anon_sym_LPAREN,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3841), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(833), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [120845] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5241), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [120903] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4803), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [120961] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4989), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [121019] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5095), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [121077] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4701), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [121135] = 5,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(7789), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5001), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [121197] = 6,
    ACTIONS(6818), 1,
      anon_sym_DOT2,
    ACTIONS(7890), 1,
      anon_sym_COLON,
    STATE(2872), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 20,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3481), 25,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [121261] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(909), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [121319] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4953), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [121377] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5135), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [121435] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4953), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [121493] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5139), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [121551] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3481), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [121609] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4949), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [121667] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4717), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [121725] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [121783] = 24,
    ACTIONS(812), 1,
      anon_sym_SLASH,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2379), 1,
      anon_sym_LPAREN,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(3945), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [121883] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [121941] = 5,
    ACTIONS(7753), 1,
      anon_sym_DOT2,
    STATE(3858), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3433), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [122003] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4945), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [122061] = 24,
    ACTIONS(857), 1,
      anon_sym_SLASH,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(3998), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [122161] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4807), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [122219] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5055), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [122277] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5035), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [122335] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4811), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [122393] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4585), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [122451] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4709), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [122509] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5055), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [122567] = 6,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7600), 1,
      sym_uninitialized,
    STATE(4287), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [122631] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(871), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [122689] = 6,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7612), 1,
      sym_uninitialized,
    STATE(4290), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [122753] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5245), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [122811] = 6,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7502), 1,
      sym_uninitialized,
    STATE(4650), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [122875] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4689), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [122933] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5059), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [122991] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(893), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123049] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(909), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123107] = 6,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7469), 1,
      sym_uninitialized,
    STATE(4292), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123171] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(809), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123229] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4735), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [123287] = 6,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7624), 1,
      sym_uninitialized,
    STATE(4293), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123351] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5055), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123409] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123467] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4709), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123525] = 6,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7634), 1,
      sym_uninitialized,
    STATE(4294), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123589] = 6,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7745), 1,
      sym_uninitialized,
    STATE(4295), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123653] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123711] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3384), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [123769] = 5,
    ACTIONS(7892), 1,
      anon_sym_DOT2,
    STATE(3997), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [123831] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4739), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [123889] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2197), 1,
      anon_sym_LPAREN,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    STATE(3839), 1,
      sym_procedure,
    STATE(3957), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(767), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [123989] = 6,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7508), 1,
      sym_uninitialized,
    STATE(4511), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124053] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2167), 1,
      anon_sym_LPAREN,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    STATE(3839), 1,
      sym_procedure,
    STATE(3993), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(857), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(855), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [124153] = 6,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7643), 1,
      sym_uninitialized,
    STATE(4531), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124217] = 4,
    ACTIONS(7894), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124277] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124335] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4735), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124393] = 6,
    ACTIONS(7467), 1,
      anon_sym_LBRACE,
    ACTIONS(7896), 1,
      sym_uninitialized,
    STATE(4296), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124457] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4739), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124515] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4743), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124573] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(909), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [124631] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4689), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [124689] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124747] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4759), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124805] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5081), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124863] = 5,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(7789), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5011), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124925] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(871), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [124983] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4743), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [125041] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3451), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [125099] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3368), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [125157] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4811), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [125215] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [125273] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4815), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [125331] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3400), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [125389] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [125447] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5249), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [125505] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3425), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [125563] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(893), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [125621] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5241), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [125679] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5245), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [125737] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5035), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [125795] = 5,
    ACTIONS(7892), 1,
      anon_sym_DOT2,
    STATE(4001), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3433), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [125857] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(893), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [125915] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2140), 1,
      anon_sym_LPAREN,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    STATE(3839), 1,
      sym_procedure,
    STATE(3923), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(893), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [126015] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4787), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [126073] = 5,
    ACTIONS(7898), 1,
      anon_sym_DOT2,
    STATE(4001), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3408), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [126135] = 6,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7583), 1,
      sym_uninitialized,
    STATE(4520), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [126199] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2176), 1,
      anon_sym_LPAREN,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    STATE(3839), 1,
      sym_procedure,
    STATE(3882), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 3,
      anon_sym_else,
      anon_sym_case,
      anon_sym_SLASH,
    ACTIONS(909), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [126299] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4815), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [126357] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4949), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [126415] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4795), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [126473] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 21,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(767), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [126531] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5249), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [126589] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5253), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [126647] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4807), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [126705] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4811), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [126763] = 5,
    ACTIONS(7901), 1,
      sym_identifier,
    ACTIONS(7903), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 20,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 26,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [126825] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 38,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [126883] = 5,
    ACTIONS(7753), 1,
      anon_sym_DOT2,
    STATE(3934), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [126945] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4855), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127003] = 6,
    ACTIONS(7903), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127066] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127123] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4799), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127180] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4705), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127237] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5115), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127294] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4867), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127351] = 5,
    ACTIONS(7909), 1,
      anon_sym_DOT2,
    STATE(4195), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127412] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4887), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127469] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5015), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127526] = 5,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(7913), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5011), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127587] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5043), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127644] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4679), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127701] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5047), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127758] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4835), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127815] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127872] = 5,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    STATE(4086), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3547), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [127933] = 5,
    ACTIONS(7917), 1,
      anon_sym_LBRACE,
    STATE(4032), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3701), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [127994] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5015), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [128051] = 5,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 33,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [128112] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4705), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [128169] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4671), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [128226] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4871), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [128283] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4847), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [128340] = 4,
    STATE(4032), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3547), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [128399] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4867), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [128456] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [128513] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1882), 1,
      anon_sym_LPAREN,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(7936), 1,
      sym_tag,
    STATE(3017), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(857), 3,
      anon_sym_where,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(855), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [128612] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1744), 1,
      anon_sym_LPAREN,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(7939), 1,
      sym_tag,
    STATE(3078), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(836), 3,
      anon_sym_where,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(833), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [128711] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1774), 1,
      anon_sym_LPAREN,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(7943), 1,
      sym_tag,
    STATE(3108), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 3,
      anon_sym_where,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(809), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [128810] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4871), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [128867] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4875), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [128924] = 25,
    ACTIONS(4881), 1,
      anon_sym_COLON,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7949), 1,
      anon_sym_PIPE,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7961), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7987), 1,
      anon_sym_or_break,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(7959), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7965), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7967), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 15,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
  [129025] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1830), 1,
      anon_sym_LPAREN,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(7991), 1,
      sym_tag,
    STATE(3043), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 3,
      anon_sym_where,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(893), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [129124] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1894), 1,
      anon_sym_LPAREN,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(7994), 1,
      sym_tag,
    STATE(3046), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 3,
      anon_sym_where,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(909), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [129223] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1842), 1,
      anon_sym_LPAREN,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(7997), 1,
      sym_tag,
    STATE(3051), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 3,
      anon_sym_where,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(871), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [129322] = 24,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1870), 1,
      anon_sym_LPAREN,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8001), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3165), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 3,
      anon_sym_where,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(767), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [129421] = 4,
    ACTIONS(7832), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [129480] = 21,
    ACTIONS(4881), 1,
      anon_sym_COLON,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7949), 1,
      anon_sym_PIPE,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7961), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7959), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7965), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7967), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 19,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [129573] = 5,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    STATE(4086), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4475), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [129634] = 7,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4731), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [129699] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [129756] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4883), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [129813] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4909), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [129870] = 10,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6988), 1,
      sym_uninitialized,
    ACTIONS(6990), 1,
      sym_tag,
    ACTIONS(8012), 1,
      anon_sym_DASH_GT,
    ACTIONS(8014), 1,
      anon_sym_where,
    STATE(3004), 1,
      sym_where_clause,
    STATE(3155), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3445), 19,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3439), 21,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [129941] = 10,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6994), 1,
      sym_uninitialized,
    ACTIONS(6996), 1,
      sym_tag,
    ACTIONS(8014), 1,
      anon_sym_where,
    ACTIONS(8016), 1,
      anon_sym_DASH_GT,
    STATE(2963), 1,
      sym_where_clause,
    STATE(3163), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 19,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3451), 21,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [130012] = 11,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_where,
    ACTIONS(8018), 1,
      anon_sym_SLASH,
    ACTIONS(8020), 1,
      sym_tag,
    STATE(2958), 1,
      sym_where_clause,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 18,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3425), 21,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [130085] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(8014), 1,
      anon_sym_where,
    ACTIONS(8020), 1,
      sym_tag,
    STATE(2958), 1,
      sym_where_clause,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 19,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3425), 22,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [130154] = 11,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(8014), 1,
      anon_sym_where,
    ACTIONS(8018), 1,
      anon_sym_SLASH,
    ACTIONS(8022), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 18,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3368), 21,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [130227] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(8014), 1,
      anon_sym_where,
    ACTIONS(8022), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3368), 22,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [130296] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6919), 1,
      sym_tag,
    ACTIONS(8014), 1,
      anon_sym_where,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 19,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3368), 22,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [130365] = 11,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(8014), 1,
      anon_sym_where,
    ACTIONS(8018), 1,
      anon_sym_SLASH,
    ACTIONS(8024), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 18,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3384), 21,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [130438] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(8014), 1,
      anon_sym_where,
    ACTIONS(8024), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3384), 22,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [130507] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(6974), 1,
      sym_tag,
    ACTIONS(8014), 1,
      anon_sym_where,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 19,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3384), 22,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [130576] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6954), 1,
      sym_uninitialized,
    ACTIONS(6956), 1,
      sym_tag,
    ACTIONS(8014), 1,
      anon_sym_where,
    STATE(2985), 1,
      sym_where_clause,
    STATE(3200), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 19,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(3400), 22,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [130645] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5027), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [130702] = 5,
    ACTIONS(8026), 1,
      anon_sym_COMMA,
    STATE(4071), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4471), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4466), 35,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [130763] = 5,
    ACTIONS(8029), 1,
      sym_identifier,
    ACTIONS(8031), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 26,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [130824] = 6,
    ACTIONS(8033), 1,
      anon_sym_LBRACE,
    ACTIONS(8036), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 34,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [130887] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5073), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [130944] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4933), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131001] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4643), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131058] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4667), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131115] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4799), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131172] = 7,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4921), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131237] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131294] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5039), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131351] = 5,
    ACTIONS(8039), 1,
      anon_sym_DOT2,
    STATE(4082), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3408), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131412] = 26,
    ACTIONS(4471), 1,
      anon_sym_EQ,
    ACTIONS(7071), 1,
      anon_sym_DASH_GT,
    ACTIONS(7073), 1,
      anon_sym_PIPE,
    ACTIONS(7075), 1,
      anon_sym_PLUS,
    ACTIONS(7077), 1,
      anon_sym_DASH,
    ACTIONS(7079), 1,
      anon_sym_TILDE,
    ACTIONS(7081), 1,
      anon_sym_AMP,
    ACTIONS(7085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7093), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7101), 1,
      anon_sym_DOT,
    ACTIONS(7103), 1,
      anon_sym_LBRACK,
    ACTIONS(7107), 1,
      anon_sym_or_return,
    ACTIONS(7109), 1,
      anon_sym_or_continue,
    ACTIONS(7111), 1,
      anon_sym_or_break,
    ACTIONS(7113), 1,
      anon_sym_CARET,
    ACTIONS(7083), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7087), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7089), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7095), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7097), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7099), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7105), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(7412), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7091), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4466), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [131515] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4875), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131572] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131629] = 5,
    ACTIONS(8042), 1,
      anon_sym_LBRACE,
    STATE(4086), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3701), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131690] = 5,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(7913), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4961), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131751] = 5,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(7913), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5001), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131812] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4679), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131869] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4925), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131926] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [131983] = 5,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5001), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132044] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 14,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_not_in,
  [132145] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5123), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132202] = 4,
    ACTIONS(8085), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4454), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(4450), 27,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [132261] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4905), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132318] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4937), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132375] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4937), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132432] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4639), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132489] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4659), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132546] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4659), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132603] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132660] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132717] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4831), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132774] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4917), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132831] = 21,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 18,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132924] = 5,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5011), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [132985] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133042] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5123), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133099] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4663), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133156] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4913), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133213] = 7,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4843), 33,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133278] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133335] = 5,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4961), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133396] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 11,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_DOT2,
    ACTIONS(3408), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [133453] = 7,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4731), 33,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133518] = 15,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 4,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 27,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133599] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5145), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133656] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5119), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133713] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4933), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133770] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4905), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133827] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4969), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133884] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [133941] = 26,
    ACTIONS(4471), 1,
      anon_sym_EQ,
    ACTIONS(7535), 1,
      anon_sym_DASH_GT,
    ACTIONS(7537), 1,
      anon_sym_PIPE,
    ACTIONS(7539), 1,
      anon_sym_PLUS,
    ACTIONS(7541), 1,
      anon_sym_DASH,
    ACTIONS(7543), 1,
      anon_sym_TILDE,
    ACTIONS(7545), 1,
      anon_sym_AMP,
    ACTIONS(7549), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7557), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7565), 1,
      anon_sym_DOT,
    ACTIONS(7567), 1,
      anon_sym_LBRACK,
    ACTIONS(7571), 1,
      anon_sym_or_return,
    ACTIONS(7573), 1,
      anon_sym_or_continue,
    ACTIONS(7575), 1,
      anon_sym_or_break,
    ACTIONS(7577), 1,
      anon_sym_CARET,
    ACTIONS(7547), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7551), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7553), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7559), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7561), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7563), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7569), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(7697), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7555), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4466), 13,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [134044] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4973), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [134101] = 27,
    ACTIONS(83), 1,
      anon_sym_switch,
    ACTIONS(495), 1,
      anon_sym_if,
    ACTIONS(497), 1,
      anon_sym_for,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(8089), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(6936), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7163), 4,
      sym_block,
      sym_if_statement,
      sym_for_statement,
      sym_switch_statement,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [134206] = 26,
    ACTIONS(5069), 1,
      anon_sym_COLON,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7949), 1,
      anon_sym_PIPE,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7961), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7987), 1,
      anon_sym_or_break,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(7959), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7965), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8091), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7967), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_case,
      anon_sym_QMARK,
  [134309] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4643), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [134366] = 4,
    ACTIONS(7903), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [134425] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4913), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [134482] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4941), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [134539] = 9,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [134608] = 27,
    ACTIONS(4483), 1,
      anon_sym_EQ,
    ACTIONS(8093), 1,
      anon_sym_COMMA,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8109), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8131), 1,
      anon_sym_or_return,
    ACTIONS(8133), 1,
      anon_sym_or_continue,
    ACTIONS(8135), 1,
      anon_sym_or_break,
    ACTIONS(8137), 1,
      anon_sym_CARET,
    STATE(4196), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(8107), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8111), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8113), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [134713] = 15,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [134794] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 12,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [134897] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5019), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [134954] = 9,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 8,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 30,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135023] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4773), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135080] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135137] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4631), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135194] = 14,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 27,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135273] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5119), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135330] = 6,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7860), 1,
      sym_uninitialized,
    STATE(4304), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 34,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_tag,
  [135393] = 7,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4843), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135458] = 14,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135537] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4663), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135594] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5145), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135651] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4831), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135708] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4909), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135765] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4981), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135822] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5039), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135879] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [135936] = 6,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7868), 1,
      sym_uninitialized,
    STATE(4310), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 34,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_tag,
  [135999] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4671), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136056] = 7,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4921), 33,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136121] = 5,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136182] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5077), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136239] = 7,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7868), 1,
      sym_uninitialized,
    ACTIONS(8141), 1,
      sym_tag,
    STATE(4310), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 33,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [136304] = 5,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    STATE(4086), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4462), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136365] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4675), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136422] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4891), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136479] = 6,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7872), 1,
      sym_uninitialized,
    STATE(4316), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 34,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_tag,
  [136542] = 7,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7872), 1,
      sym_uninitialized,
    ACTIONS(7876), 1,
      sym_tag,
    STATE(4316), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 33,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [136607] = 7,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7878), 1,
      sym_uninitialized,
    ACTIONS(7884), 1,
      sym_tag,
    STATE(4323), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 33,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [136672] = 6,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7878), 1,
      sym_uninitialized,
    STATE(4323), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 34,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_tag,
  [136735] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4827), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136792] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4835), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136849] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4981), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136906] = 13,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [136983] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4985), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [137040] = 7,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7886), 1,
      sym_uninitialized,
    ACTIONS(7888), 1,
      sym_tag,
    STATE(4327), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 33,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [137105] = 4,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8143), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(4715), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 31,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [137164] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4925), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [137221] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5019), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [137278] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4639), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [137335] = 20,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(4637), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 20,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [137426] = 6,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7886), 1,
      sym_uninitialized,
    STATE(4327), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 34,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_tag,
  [137489] = 6,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(8145), 1,
      sym_uninitialized,
    STATE(4330), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 34,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_tag,
  [137552] = 7,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(8145), 1,
      sym_uninitialized,
    ACTIONS(8147), 1,
      sym_tag,
    STATE(4330), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 33,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [137617] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5111), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [137674] = 7,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4819), 33,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [137739] = 6,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(8149), 1,
      sym_uninitialized,
    STATE(4333), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 34,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_tag,
  [137802] = 25,
    ACTIONS(4793), 1,
      anon_sym_COLON,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7949), 1,
      anon_sym_PIPE,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7961), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7987), 1,
      anon_sym_or_break,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(7959), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7965), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7967), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 15,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
  [137903] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4891), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [137960] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138017] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5031), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138074] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138131] = 13,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 27,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138208] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5043), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138265] = 20,
    ACTIONS(4637), 1,
      anon_sym_COLON,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7949), 1,
      anon_sym_PIPE,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7961), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7965), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7967), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 21,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138356] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5047), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138413] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4647), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138470] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138527] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138584] = 5,
    ACTIONS(7909), 1,
      anon_sym_DOT2,
    STATE(4082), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3435), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3433), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138645] = 5,
    ACTIONS(8093), 1,
      anon_sym_COMMA,
    STATE(4071), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4460), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4456), 35,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [138706] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4647), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138763] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138820] = 19,
    ACTIONS(4637), 1,
      anon_sym_COLON,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7949), 1,
      anon_sym_PIPE,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7965), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7967), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 22,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138909] = 5,
    ACTIONS(8153), 1,
      anon_sym_QMARK,
    ACTIONS(8151), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 34,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [138970] = 17,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7949), 1,
      anon_sym_PIPE,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 3,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7967), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 24,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139055] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139112] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4675), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139169] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4667), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139226] = 16,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7949), 1,
      anon_sym_PIPE,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 3,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 27,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139309] = 12,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 28,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139384] = 11,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 30,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139457] = 7,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4635), 33,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139522] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4755), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139579] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4985), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139636] = 19,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(4637), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 21,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139725] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4631), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139782] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4763), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139839] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4651), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139896] = 7,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4819), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [139961] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4883), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140018] = 27,
    ACTIONS(77), 1,
      anon_sym_if,
    ACTIONS(81), 1,
      anon_sym_for,
    ACTIONS(83), 1,
      anon_sym_switch,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(8089), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(6936), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7163), 4,
      sym_block,
      sym_if_statement,
      sym_for_statement,
      sym_switch_statement,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [140123] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4651), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140180] = 17,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 23,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140265] = 16,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140348] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5257), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140405] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5063), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140462] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5099), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140519] = 5,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(7913), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5103), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140580] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4887), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140637] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5073), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140694] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4655), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140751] = 6,
    ACTIONS(8155), 1,
      anon_sym_LBRACE,
    ACTIONS(8157), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140814] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140871] = 4,
    STATE(4086), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4462), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140930] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5077), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [140987] = 6,
    ACTIONS(8155), 1,
      anon_sym_LBRACE,
    ACTIONS(8160), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141050] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5111), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141107] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4969), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141164] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5063), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141221] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4973), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141278] = 4,
    STATE(4086), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4475), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141337] = 12,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 27,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141412] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 10,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_DOT2,
    ACTIONS(3408), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141469] = 11,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 29,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141542] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5257), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141599] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4655), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141656] = 7,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4635), 32,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RBRACK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141721] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4827), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141778] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4755), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141835] = 4,
    STATE(4086), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3549), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3547), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141894] = 5,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5103), 35,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [141955] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142012] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4763), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142069] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4773), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142126] = 4,
    STATE(4032), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4477), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4475), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [142185] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142242] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5115), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142299] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4847), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142356] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4917), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142413] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4941), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142470] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5027), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142527] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142584] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5031), 36,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142641] = 5,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(7913), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 9,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 36,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142702] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(4793), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 14,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_not_in,
  [142803] = 4,
    STATE(4032), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4464), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4462), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [142862] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5099), 37,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [142919] = 7,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7860), 1,
      sym_uninitialized,
    ACTIONS(7862), 1,
      sym_tag,
    STATE(4304), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 33,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [142984] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4811), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143040] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5073), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143096] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5099), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143152] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5111), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143208] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5115), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143264] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5123), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143320] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4937), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143376] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4639), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143432] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4643), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143488] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4647), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143544] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4651), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143600] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4655), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143656] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4659), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143712] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4663), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143768] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4667), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143824] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4671), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143880] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4675), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [143936] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4717), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [143992] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4683), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [144048] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4689), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [144104] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144160] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4701), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [144216] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144272] = 4,
    ACTIONS(8162), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144330] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5077), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [144386] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144442] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5025), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5023), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [144498] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144554] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144610] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144666] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144722] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4949), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144778] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4717), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [144834] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4953), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144890] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [144946] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4989), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145002] = 5,
    ACTIONS(8164), 1,
      anon_sym_LPAREN,
    ACTIONS(8166), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5001), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145062] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [145118] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5035), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145174] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [145230] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5127), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145286] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5131), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145342] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5135), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145398] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5139), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145454] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5237), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145510] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [145566] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5241), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145622] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5245), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145678] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5249), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145734] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5253), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145790] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5059), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [145846] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [145902] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5055), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [145958] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146014] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4735), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146070] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4739), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146126] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4743), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146182] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4759), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146238] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [146294] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4787), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146350] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4795), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146406] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4803), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146462] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [146518] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4807), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146574] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4811), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146630] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [146686] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4815), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146742] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4855), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146798] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4949), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [146854] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4859), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146910] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4863), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [146966] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4953), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147022] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147078] = 5,
    ACTIONS(8164), 1,
      anon_sym_LPAREN,
    ACTIONS(8166), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4961), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [147138] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4989), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147194] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4945), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [147250] = 5,
    ACTIONS(8164), 1,
      anon_sym_LPAREN,
    ACTIONS(8166), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5011), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [147310] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5035), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147366] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(893), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [147422] = 5,
    ACTIONS(8164), 1,
      anon_sym_LPAREN,
    ACTIONS(8166), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5103), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [147482] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5127), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147538] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5131), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147594] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5135), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147650] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5139), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147706] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(809), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [147762] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5237), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147818] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5241), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147874] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5245), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147930] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5249), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [147986] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5253), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148042] = 5,
    ACTIONS(8164), 1,
      anon_sym_LPAREN,
    ACTIONS(8166), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [148102] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(871), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [148158] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5059), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148214] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148270] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4735), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148326] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4739), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148382] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4743), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148438] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4759), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148494] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4787), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148550] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4795), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148606] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4803), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148662] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4807), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148718] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4815), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148774] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4855), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148830] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4859), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148886] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4863), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [148942] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5095), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [148998] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4945), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [149054] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(893), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [149110] = 4,
    ACTIONS(8168), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [149168] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(909), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [149224] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(809), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [149280] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(767), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [149336] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(871), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [149392] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6981), 1,
      sym_type,
    ACTIONS(874), 2,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [149490] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5081), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [149546] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5095), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [149602] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(909), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [149658] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(767), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [149714] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5081), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [149770] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6951), 1,
      sym_type,
    ACTIONS(911), 2,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [149868] = 6,
    ACTIONS(8031), 1,
      anon_sym_LPAREN,
    ACTIONS(8172), 1,
      anon_sym_QMARK,
    ACTIONS(8170), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 32,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [149930] = 4,
    ACTIONS(8031), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 35,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [149988] = 24,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1882), 1,
      anon_sym_LPAREN,
    ACTIONS(2848), 1,
      sym_identifier,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8190), 1,
      sym_tag,
    STATE(3017), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(857), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [150086] = 24,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1744), 1,
      anon_sym_LPAREN,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2820), 1,
      sym_identifier,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8193), 1,
      sym_tag,
    STATE(3078), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(836), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(833), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [150184] = 24,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1774), 1,
      anon_sym_LPAREN,
    ACTIONS(2754), 1,
      sym_identifier,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8197), 1,
      sym_tag,
    STATE(3108), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(812), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [150282] = 24,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1830), 1,
      anon_sym_LPAREN,
    ACTIONS(2836), 1,
      sym_identifier,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8201), 1,
      sym_tag,
    STATE(3043), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(895), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [150380] = 24,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1894), 1,
      anon_sym_LPAREN,
    ACTIONS(2780), 1,
      sym_identifier,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8204), 1,
      sym_tag,
    STATE(3046), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(911), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [150478] = 24,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1870), 1,
      anon_sym_LPAREN,
    ACTIONS(2792), 1,
      sym_identifier,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8207), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3165), 1,
      sym_type,
    ACTIONS(773), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [150576] = 24,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1842), 1,
      anon_sym_LPAREN,
    ACTIONS(2804), 1,
      sym_identifier,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8210), 1,
      sym_tag,
    STATE(3051), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(874), 2,
      anon_sym_where,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [150674] = 6,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_SLASH,
    ACTIONS(8214), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 34,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [150736] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    STATE(3839), 1,
      sym_procedure,
    STATE(6903), 1,
      sym_type,
    ACTIONS(857), 2,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [150834] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    STATE(3839), 1,
      sym_procedure,
    STATE(6912), 1,
      sym_type,
    ACTIONS(812), 2,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [150932] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4723), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4721), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [150988] = 25,
    ACTIONS(4471), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8109), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8131), 1,
      anon_sym_or_return,
    ACTIONS(8133), 1,
      anon_sym_or_continue,
    ACTIONS(8135), 1,
      anon_sym_or_break,
    ACTIONS(8137), 1,
      anon_sym_CARET,
    ACTIONS(8107), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8111), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8113), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4466), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [151088] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3701), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [151144] = 28,
    ACTIONS(4483), 1,
      anon_sym_EQ,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7261), 1,
      anon_sym_or_return,
    ACTIONS(7263), 1,
      anon_sym_or_continue,
    ACTIONS(7265), 1,
      anon_sym_or_break,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(8218), 1,
      anon_sym_COMMA,
    STATE(6737), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(7237), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(7420), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [151250] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4749), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4747), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [151306] = 6,
    ACTIONS(8164), 1,
      anon_sym_LPAREN,
    ACTIONS(8166), 1,
      anon_sym_SLASH,
    ACTIONS(8220), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [151368] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4841), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4839), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [151424] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3706), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3701), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [151480] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4841), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4839), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [151536] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4931), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4929), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [151592] = 6,
    ACTIONS(7740), 1,
      anon_sym_LBRACE,
    ACTIONS(8222), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 34,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [151654] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6938), 1,
      sym_type,
    ACTIONS(773), 2,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [151752] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4959), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4957), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [151808] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    STATE(3839), 1,
      sym_procedure,
    STATE(6898), 1,
      sym_type,
    ACTIONS(895), 2,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [151906] = 26,
    ACTIONS(4471), 1,
      anon_sym_EQ,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7261), 1,
      anon_sym_or_return,
    ACTIONS(7263), 1,
      anon_sym_or_continue,
    ACTIONS(7265), 1,
      anon_sym_or_break,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(7237), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(7420), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4466), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [152008] = 5,
    ACTIONS(8224), 1,
      sym_identifier,
    ACTIONS(8226), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 25,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [152068] = 4,
    ACTIONS(8228), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4454), 19,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(4450), 26,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [152126] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152182] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4679), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152238] = 5,
    ACTIONS(8172), 1,
      anon_sym_QMARK,
    ACTIONS(8170), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 33,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152298] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4705), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152354] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152410] = 24,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6971), 1,
      sym_type,
    ACTIONS(895), 2,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [152508] = 7,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4731), 32,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152572] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4909), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152628] = 7,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4921), 32,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152692] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4925), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152748] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4631), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152804] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5257), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152860] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3410), 10,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_DOT2,
    ACTIONS(3408), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [152916] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4941), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [152972] = 6,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_SLASH,
    ACTIONS(8230), 1,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5009), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5005), 35,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153034] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5015), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153090] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5027), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153146] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4683), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [153202] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5039), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153258] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5119), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153314] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5145), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153370] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4933), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153426] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4905), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153482] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4913), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153538] = 15,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153618] = 26,
    ACTIONS(5069), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8109), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8131), 1,
      anon_sym_or_return,
    ACTIONS(8133), 1,
      anon_sym_or_continue,
    ACTIONS(8135), 1,
      anon_sym_or_break,
    ACTIONS(8137), 1,
      anon_sym_CARET,
    ACTIONS(8107), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8111), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8113), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8232), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_QMARK,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153720] = 5,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5001), 35,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153780] = 5,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4961), 35,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153840] = 5,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5011), 35,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153900] = 5,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5103), 35,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [153960] = 5,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7866), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 35,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154020] = 9,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 30,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154088] = 14,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154166] = 13,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154242] = 20,
    ACTIONS(4637), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8109), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8111), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8113), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 20,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154332] = 19,
    ACTIONS(4637), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8111), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8113), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 21,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154420] = 17,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 23,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154504] = 16,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154586] = 5,
    ACTIONS(8234), 1,
      anon_sym_COMMA,
    STATE(4454), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4460), 20,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4456), 24,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [154646] = 5,
    ACTIONS(8236), 1,
      anon_sym_COMMA,
    STATE(4454), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4471), 20,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4466), 24,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [154706] = 12,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 27,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154780] = 11,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 29,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154852] = 7,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4635), 32,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154916] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4755), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [154972] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4763), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155028] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4773), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155084] = 25,
    ACTIONS(4793), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8109), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8131), 1,
      anon_sym_or_return,
    ACTIONS(8133), 1,
      anon_sym_or_continue,
    ACTIONS(8135), 1,
      anon_sym_or_break,
    ACTIONS(8137), 1,
      anon_sym_CARET,
    ACTIONS(8107), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8111), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8113), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155184] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4799), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155240] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4689), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [155296] = 7,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4819), 32,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155360] = 24,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    STATE(3839), 1,
      sym_procedure,
    STATE(6901), 1,
      sym_type,
    ACTIONS(836), 2,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(833), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [155458] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155514] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155570] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4827), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155626] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4831), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155682] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4835), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155738] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4701), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [155794] = 7,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4843), 32,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155858] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4847), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155914] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [155970] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156026] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4867), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156082] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4871), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156138] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4875), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156194] = 25,
    ACTIONS(4881), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8109), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8131), 1,
      anon_sym_or_return,
    ACTIONS(8133), 1,
      anon_sym_or_continue,
    ACTIONS(8135), 1,
      anon_sym_or_break,
    ACTIONS(8137), 1,
      anon_sym_CARET,
    ACTIONS(8107), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8111), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8113), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156294] = 21,
    ACTIONS(4881), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8109), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8107), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8111), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8113), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 18,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156386] = 28,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(8234), 1,
      anon_sym_COMMA,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8249), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8251), 1,
      anon_sym_or_else,
    ACTIONS(8253), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8273), 1,
      anon_sym_or_return,
    ACTIONS(8275), 1,
      anon_sym_or_continue,
    ACTIONS(8277), 1,
      anon_sym_or_break,
    STATE(4453), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(8255), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8257), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 6,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4483), 7,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_not_in,
      sym_identifier,
  [156492] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4709), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [156548] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4883), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156604] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4887), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156660] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4891), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156716] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156772] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156828] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4917), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156884] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156940] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [156996] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4969), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157052] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4973), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157108] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5055), 37,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [157164] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4981), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157220] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4985), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157276] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5019), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157332] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157388] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5031), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157444] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5043), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157500] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5047), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157556] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157612] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157668] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5063), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157724] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4709), 36,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [157780] = 12,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 27,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [157853] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [157908] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4651), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [157963] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4655), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158018] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4711), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4709), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158073] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4917), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158128] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3374), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3368), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158183] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4817), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4815), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158238] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4857), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4855), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158293] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158348] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4659), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158403] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(895), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(893), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158458] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158513] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158568] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158623] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3388), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3384), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158678] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4663), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158733] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4667), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158788] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4861), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4859), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158843] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(812), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(809), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158898] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [158953] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159008] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159063] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3402), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3400), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159118] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159173] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(874), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(871), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159228] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4579), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4577), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159283] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4671), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159338] = 4,
    ACTIONS(8226), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159395] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4587), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4585), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159450] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4675), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159505] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4865), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4863), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159560] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4951), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4949), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159615] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4969), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159670] = 5,
    ACTIONS(7830), 1,
      sym_identifier,
    ACTIONS(8297), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 24,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [159729] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4973), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159784] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159839] = 4,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4683), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(4715), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 30,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159896] = 6,
    ACTIONS(8226), 1,
      anon_sym_LPAREN,
    ACTIONS(8301), 1,
      anon_sym_QMARK,
    ACTIONS(8299), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 32,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [159957] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(8018), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5103), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [160016] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(8018), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4751), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [160075] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(8018), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4961), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [160134] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(8018), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5011), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [160193] = 24,
    ACTIONS(857), 1,
      anon_sym_SLASH,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(2089), 1,
      anon_sym_LPAREN,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    STATE(3755), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [160290] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4887), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [160345] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5097), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5095), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [160400] = 24,
    ACTIONS(836), 1,
      anon_sym_SLASH,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(2065), 1,
      anon_sym_LPAREN,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    STATE(3757), 1,
      sym_procedure,
    STATE(3783), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(833), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [160497] = 24,
    ACTIONS(773), 1,
      anon_sym_SLASH,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1946), 1,
      anon_sym_LPAREN,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    STATE(3757), 1,
      sym_procedure,
    STATE(3787), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [160594] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(911), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(909), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [160649] = 24,
    ACTIONS(812), 1,
      anon_sym_SLASH,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1918), 1,
      anon_sym_LPAREN,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    STATE(3751), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [160746] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(773), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(767), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [160801] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5057), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5055), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [160856] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5084), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5081), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [160911] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [160966] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4679), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161021] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4981), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161076] = 5,
    ACTIONS(8301), 1,
      anon_sym_QMARK,
    ACTIONS(8299), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 33,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161135] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4705), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161190] = 7,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4731), 32,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161253] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4909), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161308] = 7,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4921), 32,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161371] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4925), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161426] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4955), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4953), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161481] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3481), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161536] = 5,
    ACTIONS(8323), 1,
      anon_sym_LPAREN,
    ACTIONS(8325), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4963), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4961), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161595] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4631), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161650] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5257), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161705] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4719), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4717), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161760] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4941), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161815] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4985), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161870] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5015), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161925] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5027), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [161980] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5039), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162035] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4991), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4989), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162090] = 5,
    ACTIONS(8323), 1,
      anon_sym_LPAREN,
    ACTIONS(8325), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5001), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162149] = 5,
    ACTIONS(8323), 1,
      anon_sym_LPAREN,
    ACTIONS(8325), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5013), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5011), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162208] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5119), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162263] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5145), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162318] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4933), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162373] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4905), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162428] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4913), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162483] = 15,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 3,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162562] = 25,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(8339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8347), 1,
      anon_sym_or_return,
    ACTIONS(8349), 1,
      anon_sym_or_continue,
    ACTIONS(8351), 1,
      anon_sym_or_break,
    ACTIONS(8353), 1,
      anon_sym_CARET,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8335), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8337), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8341), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8343), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8345), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 12,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_case,
      anon_sym_QMARK,
  [162661] = 9,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 30,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162728] = 14,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 4,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162805] = 13,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162880] = 19,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(8339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8341), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8343), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8345), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 20,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [162967] = 18,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8341), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8343), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8345), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 21,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163052] = 17,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(4637), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8345), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 23,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163135] = 16,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(4637), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4635), 26,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163216] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4947), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4945), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163271] = 7,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4635), 32,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163334] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4755), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163389] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5019), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163444] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4763), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163499] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4773), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163554] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5243), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5241), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163609] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163664] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4737), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4735), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163719] = 24,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(8339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8347), 1,
      anon_sym_or_return,
    ACTIONS(8349), 1,
      anon_sym_or_continue,
    ACTIONS(8351), 1,
      anon_sym_or_break,
    ACTIONS(8353), 1,
      anon_sym_CARET,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8337), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8341), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8343), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8345), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 14,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
  [163816] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4741), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4739), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163871] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4745), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4743), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163926] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4799), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [163981] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5247), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5245), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164036] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4761), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4759), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164091] = 24,
    ACTIONS(895), 1,
      anon_sym_SLASH,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(2098), 1,
      anon_sym_LPAREN,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    STATE(3726), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [164188] = 7,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4819), 32,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164251] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5037), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5035), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164306] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5031), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164361] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5043), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164416] = 5,
    ACTIONS(8323), 1,
      anon_sym_LPAREN,
    ACTIONS(8325), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5105), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5103), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164475] = 6,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7422), 1,
      anon_sym_LBRACE,
    ACTIONS(8018), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4751), 23,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [164536] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5047), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164591] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164646] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164701] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164756] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164811] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4827), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164866] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4831), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164921] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4835), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [164976] = 15,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 14,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4635), 15,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [165055] = 27,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8249), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8251), 1,
      anon_sym_or_else,
    ACTIONS(8253), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8273), 1,
      anon_sym_or_return,
    ACTIONS(8275), 1,
      anon_sym_or_continue,
    ACTIONS(8277), 1,
      anon_sym_or_break,
    ACTIONS(8255), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8257), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8355), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5069), 5,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_when,
      sym_identifier,
    ACTIONS(5067), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      sym_uninitialized,
      sym_tag,
  [165158] = 9,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 17,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4635), 19,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [165225] = 14,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4635), 15,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4637), 15,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_TILDE,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
  [165302] = 13,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4635), 15,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4637), 16,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
  [165377] = 20,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8253), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8255), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8257), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4637), 11,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
  [165466] = 19,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8255), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8257), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 10,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4637), 11,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
  [165553] = 17,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 12,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4637), 13,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
  [165636] = 16,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 13,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4635), 15,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [165717] = 12,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4635), 16,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4637), 16,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
  [165790] = 11,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 16,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4635), 18,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [165861] = 7,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4635), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [165924] = 26,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8249), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8251), 1,
      anon_sym_or_else,
    ACTIONS(8253), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8273), 1,
      anon_sym_or_return,
    ACTIONS(8275), 1,
      anon_sym_or_continue,
    ACTIONS(8277), 1,
      anon_sym_or_break,
    ACTIONS(8255), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8257), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4793), 7,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_not_in,
      sym_identifier,
  [166025] = 7,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4819), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [166088] = 7,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4843), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [166151] = 26,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8249), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8251), 1,
      anon_sym_or_else,
    ACTIONS(8253), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8273), 1,
      anon_sym_or_return,
    ACTIONS(8275), 1,
      anon_sym_or_continue,
    ACTIONS(8277), 1,
      anon_sym_or_break,
    ACTIONS(8255), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8257), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4881), 7,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_not_in,
      sym_identifier,
  [166252] = 22,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8249), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8251), 1,
      anon_sym_or_else,
    ACTIONS(8253), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8255), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8257), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4881), 10,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
  [166345] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5251), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5249), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166400] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4691), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4689), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166455] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5063), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166510] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5073), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166565] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5077), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166620] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4789), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4787), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166675] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4703), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4701), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166730] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4797), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4795), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166785] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3427), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3425), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166840] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4805), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4803), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166895] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5255), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5253), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [166950] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5099), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167005] = 6,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7430), 1,
      anon_sym_EQ,
    ACTIONS(8018), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5009), 18,
      anon_sym_where,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5005), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [167066] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(8018), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5003), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(5001), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [167125] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4685), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4683), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167180] = 4,
    ACTIONS(8357), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 35,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167237] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5111), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167292] = 24,
    ACTIONS(911), 1,
      anon_sym_SLASH,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(2107), 1,
      anon_sym_LPAREN,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    STATE(3757), 1,
      sym_procedure,
    STATE(3758), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [167389] = 7,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4843), 32,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167452] = 5,
    ACTIONS(8323), 1,
      anon_sym_LPAREN,
    ACTIONS(8325), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 35,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167511] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5129), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5127), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167566] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5115), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167621] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5133), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5131), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167676] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5137), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5135), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167731] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5141), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5139), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167786] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5239), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5237), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167841] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4883), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167896] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3455), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3451), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [167951] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5123), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [168006] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5061), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5059), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [168061] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4891), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [168116] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [168171] = 26,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8249), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8251), 1,
      anon_sym_or_else,
    ACTIONS(8253), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8273), 1,
      anon_sym_or_return,
    ACTIONS(8275), 1,
      anon_sym_or_continue,
    ACTIONS(8277), 1,
      anon_sym_or_break,
    ACTIONS(8255), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8257), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4466), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      sym_uninitialized,
      sym_tag,
    ACTIONS(4471), 7,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_not_in,
      sym_identifier,
  [168272] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4847), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [168327] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [168382] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4937), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [168437] = 5,
    ACTIONS(8361), 1,
      anon_sym_QMARK,
    ACTIONS(8359), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 18,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4693), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [168496] = 7,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4731), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [168559] = 7,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 19,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(4921), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [168622] = 6,
    ACTIONS(7173), 1,
      anon_sym_LPAREN,
    ACTIONS(8361), 1,
      anon_sym_QMARK,
    ACTIONS(8359), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 18,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      sym_identifier,
    ACTIONS(69), 23,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [168683] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4639), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [168738] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [168793] = 24,
    ACTIONS(874), 1,
      anon_sym_SLASH,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(2077), 1,
      anon_sym_LPAREN,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    STATE(3753), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [168890] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4867), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [168945] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4871), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169000] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4875), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169055] = 24,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(8339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8347), 1,
      anon_sym_or_return,
    ACTIONS(8349), 1,
      anon_sym_or_continue,
    ACTIONS(8351), 1,
      anon_sym_or_break,
    ACTIONS(8353), 1,
      anon_sym_CARET,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8337), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8341), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8343), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8345), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 14,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
  [169152] = 20,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(8339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8337), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8341), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8343), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8345), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 18,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169241] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4809), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4807), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169296] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4813), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4811), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169351] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4643), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169406] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169461] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4647), 36,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169516] = 11,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 29,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169587] = 17,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(4637), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 22,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169669] = 6,
    ACTIONS(8297), 1,
      anon_sym_LPAREN,
    ACTIONS(8391), 1,
      anon_sym_QMARK,
    ACTIONS(8389), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169729] = 4,
    ACTIONS(8297), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 34,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169785] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 35,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169839] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 35,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [169893] = 24,
    ACTIONS(812), 1,
      anon_sym_SLASH,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8405), 1,
      anon_sym_LPAREN,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    STATE(7115), 1,
      sym_procedure,
    STATE(7206), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [169989] = 7,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4731), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170051] = 7,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4921), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170113] = 4,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8431), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(4715), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 29,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170169] = 4,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8433), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(4715), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 29,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170225] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 35,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170279] = 15,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 3,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 25,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170357] = 25,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 11,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_case,
      anon_sym_QMARK,
  [170455] = 9,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 29,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170521] = 14,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 4,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 25,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170597] = 13,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 25,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170671] = 19,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 19,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170757] = 18,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 20,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [170841] = 28,
    ACTIONS(4483), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8109), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8131), 1,
      anon_sym_or_return,
    ACTIONS(8133), 1,
      anon_sym_or_continue,
    ACTIONS(8135), 1,
      anon_sym_or_break,
    ACTIONS(8137), 1,
      anon_sym_CARET,
    ACTIONS(8447), 1,
      anon_sym_COMMA,
    STATE(6869), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(8107), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8111), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8113), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8232), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [170945] = 6,
    ACTIONS(8449), 1,
      anon_sym_LBRACE,
    ACTIONS(8452), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 31,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [171005] = 5,
    ACTIONS(8455), 1,
      sym_identifier,
    ACTIONS(8457), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 23,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [171063] = 12,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [171135] = 11,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 28,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [171205] = 7,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4635), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [171267] = 24,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
  [171363] = 24,
    ACTIONS(773), 1,
      anon_sym_SLASH,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(8459), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7296), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [171459] = 7,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4819), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [171521] = 6,
    ACTIONS(7832), 1,
      anon_sym_LPAREN,
    ACTIONS(8153), 1,
      anon_sym_QMARK,
    ACTIONS(8151), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [171581] = 4,
    ACTIONS(8462), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [171637] = 24,
    ACTIONS(874), 1,
      anon_sym_SLASH,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(8464), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7192), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [171733] = 7,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 8,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4843), 31,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [171795] = 24,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
  [171891] = 20,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 17,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [171979] = 5,
    ACTIONS(7901), 1,
      sym_identifier,
    ACTIONS(8468), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 19,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 23,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [172037] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 35,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [172091] = 24,
    ACTIONS(857), 1,
      anon_sym_SLASH,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(8470), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7235), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [172187] = 4,
    ACTIONS(8473), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4454), 19,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(4450), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [172243] = 7,
    ACTIONS(7832), 1,
      anon_sym_LPAREN,
    ACTIONS(8153), 1,
      anon_sym_QMARK,
    ACTIONS(8151), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8475), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(73), 10,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 27,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [172305] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 35,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [172359] = 24,
    ACTIONS(836), 1,
      anon_sym_SLASH,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(8477), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7329), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(833), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [172455] = 24,
    ACTIONS(895), 1,
      anon_sym_SLASH,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(8481), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7129), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [172551] = 6,
    ACTIONS(7173), 1,
      anon_sym_LPAREN,
    ACTIONS(7406), 1,
      anon_sym_if,
    ACTIONS(7408), 1,
      anon_sym_QMARK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 31,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_where,
      anon_sym_RPAREN,
      anon_sym_when,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
      sym_uninitialized,
      sym_tag,
  [172611] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 35,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [172665] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 35,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [172719] = 24,
    ACTIONS(911), 1,
      anon_sym_SLASH,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(8484), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7162), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [172815] = 5,
    ACTIONS(8391), 1,
      anon_sym_QMARK,
    ACTIONS(8389), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 32,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [172873] = 16,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(4637), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4635), 25,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_when,
      anon_sym_in,
      anon_sym_case,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [172953] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5045), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5043), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [173006] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4833), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4831), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [173059] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7078), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [173152] = 7,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4843), 29,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [173213] = 6,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(8497), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 30,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [173272] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7357), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [173365] = 24,
    ACTIONS(812), 1,
      anon_sym_SLASH,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2379), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8499), 1,
      sym_identifier,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(3945), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [173460] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7311), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [173553] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4849), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4847), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [173606] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [173659] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [173712] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4869), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4867), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [173765] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4873), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4871), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [173818] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4877), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4875), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [173871] = 25,
    ACTIONS(4881), 1,
      anon_sym_EQ,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 11,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
  [173968] = 21,
    ACTIONS(4881), 1,
      anon_sym_EQ,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 15,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174057] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4885), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4883), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174110] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4889), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4887), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174163] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7060), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [174256] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174309] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4893), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4891), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174362] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174415] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174468] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4681), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4679), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174521] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4919), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4917), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174574] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174627] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4967), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4965), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174680] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4971), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4969), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174733] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4975), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4973), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174786] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4983), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4981), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174839] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4987), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4985), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174892] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5021), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5019), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174945] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [174998] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175051] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175104] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4727), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4725), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175157] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5033), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5031), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175210] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5049), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5047), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175263] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175316] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5053), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5051), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175369] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175422] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175475] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 32,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175528] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5065), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5063), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175581] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5075), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5073), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175634] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5079), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5077), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175687] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5101), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5099), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175740] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5113), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5111), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175793] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5117), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5115), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175846] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5125), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5123), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175899] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4939), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4937), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [175952] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4641), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4639), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176005] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4645), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4643), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176058] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4649), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4647), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176111] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4653), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4651), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176164] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4657), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4655), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176217] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4661), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4659), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176270] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4665), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4663), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176323] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4669), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4667), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176376] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4673), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4671), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176429] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4677), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4675), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176482] = 6,
    ACTIONS(8468), 1,
      anon_sym_LPAREN,
    ACTIONS(8559), 1,
      anon_sym_QMARK,
    ACTIONS(8557), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 28,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176541] = 5,
    ACTIONS(8563), 1,
      anon_sym_QMARK,
    ACTIONS(8561), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 30,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176598] = 24,
    ACTIONS(773), 1,
      anon_sym_SLASH,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2400), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    ACTIONS(8565), 1,
      sym_identifier,
    STATE(3930), 1,
      sym_procedure,
    STATE(3938), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [176693] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4707), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4705), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176746] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4715), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4713), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176799] = 7,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4731), 29,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176860] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4911), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4909), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176913] = 7,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4921), 29,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [176974] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4927), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4925), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [177027] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4633), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4631), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [177080] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5259), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5257), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [177133] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7184), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [177226] = 9,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LPAREN,
    ACTIONS(8568), 1,
      anon_sym_COMMA,
    ACTIONS(8571), 1,
      anon_sym_RPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    STATE(8273), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 27,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [177291] = 24,
    ACTIONS(836), 1,
      anon_sym_SLASH,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2367), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    ACTIONS(8574), 1,
      sym_identifier,
    STATE(3841), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(833), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [177386] = 6,
    ACTIONS(8457), 1,
      anon_sym_LPAREN,
    ACTIONS(8563), 1,
      anon_sym_QMARK,
    ACTIONS(8561), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 29,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [177445] = 26,
    ACTIONS(4471), 1,
      anon_sym_EQ,
    ACTIONS(8095), 1,
      anon_sym_DASH_GT,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8099), 1,
      anon_sym_PLUS,
    ACTIONS(8101), 1,
      anon_sym_DASH,
    ACTIONS(8103), 1,
      anon_sym_TILDE,
    ACTIONS(8105), 1,
      anon_sym_AMP,
    ACTIONS(8109), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8117), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8125), 1,
      anon_sym_DOT,
    ACTIONS(8127), 1,
      anon_sym_LBRACK,
    ACTIONS(8131), 1,
      anon_sym_or_return,
    ACTIONS(8133), 1,
      anon_sym_or_continue,
    ACTIONS(8135), 1,
      anon_sym_or_break,
    ACTIONS(8137), 1,
      anon_sym_CARET,
    ACTIONS(8107), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8111), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8113), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8119), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8121), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8123), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8129), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8232), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8115), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4466), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [177544] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4943), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4941), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [177597] = 24,
    ACTIONS(895), 1,
      anon_sym_SLASH,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2322), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    ACTIONS(8578), 1,
      sym_identifier,
    STATE(3930), 1,
      sym_procedure,
    STATE(3976), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [177692] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5017), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5015), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [177745] = 15,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 22,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [177822] = 26,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(5069), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 8,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_QMARK,
  [177921] = 9,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 8,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [177986] = 14,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 22,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178061] = 13,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 22,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178134] = 20,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4637), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 16,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178221] = 19,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(4637), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 17,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178306] = 17,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 19,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178387] = 16,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 22,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178466] = 12,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 23,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178537] = 11,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 25,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178606] = 7,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4635), 28,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178667] = 25,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(4793), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 10,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
  [178764] = 7,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4819), 28,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178825] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5029), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5027), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [178878] = 24,
    ACTIONS(911), 1,
      anon_sym_SLASH,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2340), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    ACTIONS(8619), 1,
      sym_identifier,
    STATE(3930), 1,
      sym_procedure,
    STATE(4007), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [178973] = 7,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4845), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4843), 28,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [179034] = 25,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 10,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
  [179131] = 21,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4881), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4879), 14,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [179220] = 24,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2400), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(3938), 1,
      sym_type,
    ACTIONS(767), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(773), 2,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [179315] = 24,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(3998), 1,
      sym_type,
    ACTIONS(855), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(857), 2,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [179410] = 4,
    ACTIONS(8468), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 31,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [179465] = 24,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2322), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(3976), 1,
      sym_type,
    ACTIONS(893), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(895), 2,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [179560] = 24,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2340), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(4007), 1,
      sym_type,
    ACTIONS(909), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(911), 2,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [179655] = 28,
    ACTIONS(4483), 1,
      anon_sym_EQ,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7227), 1,
      anon_sym_PIPE,
    ACTIONS(7229), 1,
      anon_sym_PLUS,
    ACTIONS(7231), 1,
      anon_sym_DASH,
    ACTIONS(7233), 1,
      anon_sym_TILDE,
    ACTIONS(7235), 1,
      anon_sym_AMP,
    ACTIONS(7239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7247), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7255), 1,
      anon_sym_DOT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7261), 1,
      anon_sym_or_return,
    ACTIONS(7263), 1,
      anon_sym_or_continue,
    ACTIONS(7265), 1,
      anon_sym_or_break,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(8640), 1,
      anon_sym_COMMA,
    STATE(6887), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(7237), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7241), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7243), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7249), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7253), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7259), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(7420), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7245), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 7,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
      sym_uninitialized,
      sym_tag,
  [179758] = 9,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LPAREN,
    ACTIONS(8568), 1,
      anon_sym_COMMA,
    ACTIONS(8642), 1,
      anon_sym_RPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    STATE(8034), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 27,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [179823] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5041), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5039), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [179876] = 6,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(7736), 1,
      anon_sym_SLASH,
    ACTIONS(8645), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4753), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4751), 31,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [179935] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [179988] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5121), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5119), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180041] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5147), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(5145), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180094] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4935), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4933), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180147] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4907), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4905), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180200] = 4,
    ACTIONS(8457), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 32,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180255] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4915), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4913), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180308] = 15,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 23,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180385] = 26,
    ACTIONS(5069), 1,
      anon_sym_EQ,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(5067), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_QMARK,
  [180484] = 24,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2367), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3841), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(833), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(836), 2,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [180579] = 24,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2379), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(3945), 1,
      sym_type,
    ACTIONS(809), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(812), 2,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [180674] = 9,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 27,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180739] = 14,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 23,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180814] = 13,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 23,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180887] = 20,
    ACTIONS(4637), 1,
      anon_sym_EQ,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 17,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [180974] = 19,
    ACTIONS(4637), 1,
      anon_sym_EQ,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 18,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181059] = 17,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4635), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181140] = 16,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 23,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181219] = 12,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 24,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181290] = 11,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4635), 26,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181359] = 7,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4637), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4635), 29,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181420] = 24,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2294), 1,
      anon_sym_LPAREN,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3808), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(871), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(874), 2,
      anon_sym_when,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [181515] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4757), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4755), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181568] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4765), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4763), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181621] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4775), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4773), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181674] = 25,
    ACTIONS(4793), 1,
      anon_sym_EQ,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4791), 11,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_not_in,
  [181771] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4801), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4799), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181824] = 9,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LPAREN,
    ACTIONS(8568), 1,
      anon_sym_COMMA,
    ACTIONS(8649), 1,
      anon_sym_RPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    STATE(8318), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 27,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181889] = 9,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LPAREN,
    ACTIONS(8568), 1,
      anon_sym_COMMA,
    ACTIONS(8652), 1,
      anon_sym_RPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    STATE(8073), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 27,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [181954] = 24,
    ACTIONS(874), 1,
      anon_sym_SLASH,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2294), 1,
      anon_sym_LPAREN,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    ACTIONS(8655), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [182049] = 29,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8249), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8251), 1,
      anon_sym_or_else,
    ACTIONS(8253), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8273), 1,
      anon_sym_or_return,
    ACTIONS(8275), 1,
      anon_sym_or_continue,
    ACTIONS(8277), 1,
      anon_sym_or_break,
    ACTIONS(8659), 1,
      anon_sym_COMMA,
    STATE(6885), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(8255), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8257), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8355), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4483), 3,
      anon_sym_where,
      anon_sym_EQ,
      sym_identifier,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4479), 5,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [182154] = 5,
    ACTIONS(8559), 1,
      anon_sym_QMARK,
    ACTIONS(8557), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4695), 11,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4693), 29,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [182211] = 7,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4733), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4731), 28,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [182272] = 7,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4923), 10,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4921), 28,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [182333] = 7,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4821), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4819), 29,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [182394] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [182447] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [182500] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4829), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4827), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [182553] = 24,
    ACTIONS(857), 1,
      anon_sym_SLASH,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    ACTIONS(8661), 1,
      sym_identifier,
    STATE(3930), 1,
      sym_procedure,
    STATE(3998), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [182648] = 9,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(7709), 1,
      anon_sym_LPAREN,
    ACTIONS(8568), 1,
      anon_sym_COMMA,
    ACTIONS(8664), 1,
      anon_sym_RPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    STATE(8289), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 27,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [182713] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4837), 10,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4835), 33,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [182766] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8669), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7196), 1,
      sym_type,
    STATE(8061), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [182860] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8671), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7191), 1,
      sym_type,
    STATE(8051), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [182954] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7373), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [183046] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8673), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7239), 1,
      sym_type,
    STATE(8173), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [183140] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8675), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7125), 1,
      sym_type,
    STATE(7964), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [183234] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8677), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [183328] = 6,
    ACTIONS(7830), 1,
      sym_identifier,
    ACTIONS(8297), 1,
      anon_sym_LPAREN,
    ACTIONS(8679), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 17,
      anon_sym_PIPE,
      anon_sym_else,
      anon_sym_in,
      anon_sym_case,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 22,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [183386] = 28,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(8339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8347), 1,
      anon_sym_or_return,
    ACTIONS(8349), 1,
      anon_sym_or_continue,
    ACTIONS(8351), 1,
      anon_sym_or_break,
    ACTIONS(8353), 1,
      anon_sym_CARET,
    ACTIONS(8681), 1,
      anon_sym_COMMA,
    ACTIONS(8683), 1,
      sym__nl_comma,
    STATE(6939), 1,
      aux_sym_return_statement_repeat1,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8335), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8337), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8341), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8343), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8345), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(717), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [183488] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7408), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [183580] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8685), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [183674] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8687), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [183768] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8689), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [183862] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8691), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [183956] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8693), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [184050] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8695), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7183), 1,
      sym_type,
    STATE(8119), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [184144] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8697), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [184238] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8699), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [184332] = 23,
    ACTIONS(857), 1,
      anon_sym_SLASH,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    STATE(3757), 1,
      sym_procedure,
    STATE(7368), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(855), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [184424] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8701), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [184518] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8703), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7244), 1,
      sym_type,
    STATE(7968), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [184612] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8705), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [184706] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8707), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7279), 1,
      sym_type,
    STATE(8299), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [184800] = 28,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(8339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8347), 1,
      anon_sym_or_return,
    ACTIONS(8349), 1,
      anon_sym_or_continue,
    ACTIONS(8351), 1,
      anon_sym_or_break,
    ACTIONS(8353), 1,
      anon_sym_CARET,
    ACTIONS(8683), 1,
      sym__nl_comma,
    ACTIONS(8709), 1,
      anon_sym_COMMA,
    STATE(6960), 1,
      aux_sym_return_statement_repeat1,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8335), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8337), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8341), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8343), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8345), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(2914), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [184902] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7504), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(833), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [184994] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8711), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [185088] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8713), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [185182] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8715), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7349), 1,
      sym_type,
    STATE(8311), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [185276] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8717), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [185370] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8719), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [185464] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8721), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7189), 1,
      sym_type,
    STATE(8045), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [185558] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8723), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [185652] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8725), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [185746] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8727), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [185840] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8729), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7092), 1,
      sym_type,
    STATE(8585), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [185934] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8731), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186028] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8733), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186122] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8735), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7318), 1,
      sym_type,
    STATE(8456), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186216] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8737), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186310] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8739), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186404] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8741), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186498] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8743), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186592] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8745), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186686] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8747), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186780] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8749), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7348), 1,
      sym_type,
    STATE(8454), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186874] = 23,
    ACTIONS(895), 1,
      anon_sym_SLASH,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    STATE(3757), 1,
      sym_procedure,
    STATE(7407), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [186966] = 27,
    ACTIONS(7225), 1,
      anon_sym_DASH_GT,
    ACTIONS(7257), 1,
      anon_sym_LBRACK,
    ACTIONS(7267), 1,
      anon_sym_CARET,
    ACTIONS(8239), 1,
      anon_sym_PIPE,
    ACTIONS(8241), 1,
      anon_sym_PLUS,
    ACTIONS(8243), 1,
      anon_sym_DASH,
    ACTIONS(8245), 1,
      anon_sym_TILDE,
    ACTIONS(8247), 1,
      anon_sym_AMP,
    ACTIONS(8249), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8251), 1,
      anon_sym_or_else,
    ACTIONS(8253), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8261), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8269), 1,
      anon_sym_DOT,
    ACTIONS(8273), 1,
      anon_sym_or_return,
    ACTIONS(8275), 1,
      anon_sym_or_continue,
    ACTIONS(8277), 1,
      anon_sym_or_break,
    ACTIONS(8255), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8257), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8263), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8267), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8271), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8355), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4471), 3,
      anon_sym_where,
      anon_sym_EQ,
      sym_identifier,
    ACTIONS(8259), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(4466), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [187066] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8751), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [187160] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7385), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [187252] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8753), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [187346] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8755), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [187440] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8757), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [187534] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8759), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7312), 1,
      sym_type,
    STATE(8123), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [187628] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8761), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [187722] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8763), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [187816] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8765), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7345), 1,
      sym_type,
    STATE(8559), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [187910] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8767), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7155), 1,
      sym_type,
    STATE(7970), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [188004] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8769), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [188098] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8771), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7119), 1,
      sym_type,
    STATE(7847), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [188192] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8773), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [188286] = 24,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8775), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [188380] = 24,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(8667), 1,
      sym_identifier,
    ACTIONS(8777), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7240), 1,
      sym_type,
    STATE(8176), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [188474] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7026), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8779), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [188573] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7043), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8783), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [188672] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7030), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8785), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [188771] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7010), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8789), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [188870] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7017), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8791), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [188969] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7052), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8795), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [189068] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7008), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8797), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [189167] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7013), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8799), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [189266] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(6998), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8801), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [189365] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(6999), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8803), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [189464] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7033), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8805), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [189563] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8667), 1,
      sym_identifier,
    STATE(3930), 1,
      sym_procedure,
    STATE(7669), 1,
      sym_type,
    STATE(8849), 2,
      sym_named_type,
      sym_default_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [189654] = 25,
    ACTIONS(8279), 1,
      anon_sym_DASH_GT,
    ACTIONS(8281), 1,
      anon_sym_PLUS,
    ACTIONS(8283), 1,
      anon_sym_DASH,
    ACTIONS(8291), 1,
      anon_sym_DOT,
    ACTIONS(8293), 1,
      anon_sym_LBRACK,
    ACTIONS(8327), 1,
      anon_sym_TILDE,
    ACTIONS(8329), 1,
      anon_sym_AMP,
    ACTIONS(8331), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8333), 1,
      anon_sym_PIPE,
    ACTIONS(8339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8347), 1,
      anon_sym_or_return,
    ACTIONS(8349), 1,
      anon_sym_or_continue,
    ACTIONS(8351), 1,
      anon_sym_or_break,
    ACTIONS(8353), 1,
      anon_sym_CARET,
    ACTIONS(8285), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8287), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8289), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8295), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8335), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8337), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8341), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8343), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8345), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8807), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [189749] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7021), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8809), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [189848] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7012), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8811), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [189947] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(6990), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8813), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [190046] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7023), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8815), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [190145] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(8817), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8396), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [190235] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8819), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [190325] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8825), 1,
      anon_sym_LBRACK,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    STATE(3473), 1,
      sym_type,
    STATE(3481), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [190415] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8831), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7488), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [190505] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8833), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [190595] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8835), 1,
      sym_identifier,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8839), 1,
      anon_sym_LBRACK,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6835), 1,
      sym_type,
    STATE(6837), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [190685] = 23,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      sym_identifier,
    ACTIONS(8845), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6711), 1,
      sym_type,
    STATE(6754), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [190775] = 23,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      sym_identifier,
    ACTIONS(8847), 1,
      anon_sym_LBRACK,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6711), 1,
      sym_type,
    STATE(6754), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [190865] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8857), 1,
      anon_sym_LBRACK,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    STATE(531), 1,
      sym_type,
    STATE(556), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [190955] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8869), 1,
      anon_sym_LBRACK,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    STATE(2364), 1,
      sym_type,
    STATE(2365), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [191045] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8875), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [191135] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8835), 1,
      sym_identifier,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8877), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6844), 1,
      sym_type,
    STATE(6845), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [191225] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    ACTIONS(8881), 1,
      sym_tag,
    STATE(537), 1,
      sym_type,
    STATE(565), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [191315] = 25,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8883), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [191409] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8835), 1,
      sym_identifier,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8839), 1,
      anon_sym_LBRACK,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6821), 1,
      sym_type,
    STATE(6839), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [191499] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8835), 1,
      sym_identifier,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8839), 1,
      anon_sym_LBRACK,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6844), 1,
      sym_type,
    STATE(6845), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [191589] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8885), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [191679] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(8889), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6716), 1,
      sym_type,
    STATE(6717), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [191769] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8891), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [191859] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8895), 1,
      anon_sym_LBRACK,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    STATE(3075), 1,
      sym_type,
    STATE(3076), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [191949] = 23,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8901), 1,
      sym_identifier,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8905), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6860), 1,
      sym_type,
    STATE(6861), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [192039] = 31,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(6824), 1,
      anon_sym_EQ,
    ACTIONS(6828), 1,
      anon_sym_COLON_EQ,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(8909), 1,
      anon_sym_do,
    STATE(7356), 1,
      sym_block,
    STATE(7745), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [192145] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8911), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [192235] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8917), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6663), 1,
      sym_type,
    STATE(6664), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [192325] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8919), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6665), 1,
      sym_type,
    STATE(6666), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [192415] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6665), 1,
      sym_type,
    STATE(6666), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [192505] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    ACTIONS(8927), 1,
      sym_tag,
    STATE(2345), 1,
      sym_type,
    STATE(2349), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [192595] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    ACTIONS(8931), 1,
      sym_tag,
    STATE(3065), 1,
      sym_type,
    STATE(3066), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [192685] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    ACTIONS(8933), 1,
      sym_tag,
    STATE(520), 1,
      sym_type,
    STATE(521), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [192775] = 23,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8935), 1,
      sym_identifier,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(8941), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4061), 1,
      sym_type,
    STATE(4062), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [192865] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8943), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [192955] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8951), 1,
      sym_tag,
    STATE(2983), 1,
      sym_named_type,
    STATE(3011), 1,
      sym_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193045] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8835), 1,
      sym_identifier,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8839), 1,
      anon_sym_LBRACK,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6825), 1,
      sym_type,
    STATE(6826), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193135] = 23,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8901), 1,
      sym_identifier,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8953), 1,
      anon_sym_LBRACK,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6817), 1,
      sym_type,
    STATE(6818), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193225] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8957), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(2983), 1,
      sym_named_type,
    STATE(3011), 1,
      sym_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193315] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8869), 1,
      anon_sym_LBRACK,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    STATE(1426), 1,
      sym_type,
    STATE(1428), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193405] = 23,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8961), 1,
      sym_identifier,
    ACTIONS(8963), 1,
      anon_sym_LBRACK,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    STATE(3887), 1,
      sym_type,
    STATE(3892), 1,
      sym_named_type,
    STATE(4297), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193495] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    ACTIONS(8971), 1,
      sym_tag,
    STATE(3455), 1,
      sym_type,
    STATE(3456), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193585] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    ACTIONS(8973), 1,
      sym_tag,
    STATE(3463), 1,
      sym_type,
    STATE(3464), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193675] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8825), 1,
      anon_sym_LBRACK,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    STATE(3463), 1,
      sym_type,
    STATE(3464), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193765] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8895), 1,
      anon_sym_LBRACK,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    STATE(2982), 1,
      sym_type,
    STATE(3016), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193855] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    ACTIONS(8975), 1,
      sym_tag,
    STATE(3250), 1,
      sym_type,
    STATE(3251), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [193945] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    ACTIONS(8977), 1,
      sym_tag,
    STATE(3252), 1,
      sym_type,
    STATE(3253), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [194035] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8825), 1,
      anon_sym_LBRACK,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    STATE(3252), 1,
      sym_type,
    STATE(3253), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [194125] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8979), 1,
      sym_identifier,
    ACTIONS(8981), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6846), 1,
      sym_named_type,
    STATE(6872), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [194215] = 26,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7949), 1,
      anon_sym_PIPE,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7961), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7987), 1,
      anon_sym_or_break,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8985), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7959), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7965), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8091), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7967), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8983), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [194311] = 23,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8961), 1,
      sym_identifier,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    ACTIONS(8989), 1,
      sym_tag,
    STATE(3868), 1,
      sym_type,
    STATE(3869), 1,
      sym_named_type,
    STATE(4297), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [194401] = 23,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8961), 1,
      sym_identifier,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    ACTIONS(8991), 1,
      sym_tag,
    STATE(3873), 1,
      sym_type,
    STATE(3874), 1,
      sym_named_type,
    STATE(4297), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [194491] = 23,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8961), 1,
      sym_identifier,
    ACTIONS(8963), 1,
      anon_sym_LBRACK,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    STATE(3873), 1,
      sym_type,
    STATE(3874), 1,
      sym_named_type,
    STATE(4297), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [194581] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(8993), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8062), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [194671] = 23,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8901), 1,
      sym_identifier,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8995), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6830), 1,
      sym_type,
    STATE(6832), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [194761] = 23,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8901), 1,
      sym_identifier,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8953), 1,
      anon_sym_LBRACK,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6830), 1,
      sym_type,
    STATE(6832), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [194851] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8997), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [194941] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8999), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195031] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8857), 1,
      anon_sym_LBRACK,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    STATE(522), 1,
      sym_type,
    STATE(524), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195121] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    ACTIONS(9001), 1,
      sym_tag,
    STATE(557), 1,
      sym_named_type,
    STATE(558), 1,
      sym_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195211] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9003), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7425), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195301] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8857), 1,
      anon_sym_LBRACK,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    STATE(520), 1,
      sym_type,
    STATE(521), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195391] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8835), 1,
      sym_identifier,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9005), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6870), 1,
      sym_type,
    STATE(6871), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195481] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9007), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195571] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(9009), 1,
      sym_tag,
    STATE(3029), 1,
      sym_type,
    STATE(3030), 1,
      sym_named_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195661] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9011), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195751] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9013), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195841] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(9015), 1,
      sym_tag,
    STATE(2996), 1,
      sym_type,
    STATE(2997), 1,
      sym_named_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [195931] = 23,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8935), 1,
      sym_identifier,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9017), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4063), 1,
      sym_type,
    STATE(4064), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196021] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9019), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196111] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    ACTIONS(9021), 1,
      sym_tag,
    STATE(2964), 1,
      sym_type,
    STATE(2977), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196201] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    ACTIONS(9023), 1,
      sym_tag,
    STATE(523), 1,
      sym_type,
    STATE(543), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196291] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8857), 1,
      anon_sym_LBRACK,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    STATE(523), 1,
      sym_type,
    STATE(543), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196381] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    ACTIONS(9025), 1,
      sym_tag,
    STATE(540), 1,
      sym_type,
    STATE(541), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196471] = 6,
    ACTIONS(8449), 1,
      anon_sym_LBRACE,
    ACTIONS(9027), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [196527] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9029), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196617] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9031), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6704), 1,
      sym_type,
    STATE(6705), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196707] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8979), 1,
      sym_identifier,
    ACTIONS(9035), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6848), 1,
      sym_type,
    STATE(6849), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196797] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(9037), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6734), 1,
      sym_named_type,
    STATE(6745), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196887] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    ACTIONS(9039), 1,
      sym_tag,
    STATE(2978), 1,
      sym_type,
    STATE(3008), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [196977] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9041), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197067] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8895), 1,
      anon_sym_LBRACK,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    STATE(2978), 1,
      sym_type,
    STATE(3008), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197157] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9043), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197247] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(9045), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6721), 1,
      sym_named_type,
    STATE(6742), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197337] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(9047), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6673), 1,
      sym_type,
    STATE(6674), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197427] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9049), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8271), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197517] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    ACTIONS(9051), 1,
      sym_tag,
    STATE(3475), 1,
      sym_type,
    STATE(3476), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197607] = 23,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8901), 1,
      sym_identifier,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(9053), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6812), 1,
      sym_type,
    STATE(6813), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197697] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9055), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8287), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197787] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8979), 1,
      sym_identifier,
    ACTIONS(9057), 1,
      anon_sym_LBRACK,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6848), 1,
      sym_type,
    STATE(6849), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197877] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8895), 1,
      anon_sym_LBRACK,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    STATE(2960), 1,
      sym_type,
    STATE(2961), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [197967] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9061), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6708), 1,
      sym_type,
    STATE(6709), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198057] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9063), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8301), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198147] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9065), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8315), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198237] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9067), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198327] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9069), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8327), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198417] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9071), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8339), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198507] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(9073), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6675), 1,
      sym_named_type,
    STATE(6691), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198597] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9075), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8350), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198687] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9077), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8361), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198777] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6675), 1,
      sym_named_type,
    STATE(6691), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198867] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9079), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8372), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [198957] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9081), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8385), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199047] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9083), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199137] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6721), 1,
      sym_named_type,
    STATE(6742), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199227] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9085), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8406), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199317] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8957), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3093), 1,
      sym_type,
    STATE(3094), 1,
      sym_named_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199407] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9087), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8413), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199497] = 23,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      sym_identifier,
    ACTIONS(8847), 1,
      anon_sym_LBRACK,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6688), 1,
      sym_type,
    STATE(6689), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199587] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9089), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8418), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199677] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    ACTIONS(9091), 1,
      sym_tag,
    STATE(2982), 1,
      sym_type,
    STATE(3016), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199767] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9093), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8423), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199857] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9095), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8436), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [199947] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8869), 1,
      anon_sym_LBRACK,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    STATE(1312), 1,
      sym_type,
    STATE(1313), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200037] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8857), 1,
      anon_sym_LBRACK,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    STATE(540), 1,
      sym_type,
    STATE(541), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200127] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9097), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200217] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(9099), 1,
      sym_tag,
    STATE(3090), 1,
      sym_type,
    STATE(3091), 1,
      sym_named_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200307] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6668), 1,
      sym_type,
    STATE(6669), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200397] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9101), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6831), 1,
      sym_type,
    STATE(6833), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200487] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(9103), 1,
      sym_tag,
    STATE(3036), 1,
      sym_type,
    STATE(3037), 1,
      sym_named_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200577] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9105), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200667] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    ACTIONS(9107), 1,
      sym_tag,
    STATE(3439), 1,
      sym_type,
    STATE(3523), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200757] = 23,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8901), 1,
      sym_identifier,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(9109), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6814), 1,
      sym_type,
    STATE(6815), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200847] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8979), 1,
      sym_identifier,
    ACTIONS(9057), 1,
      anon_sym_LBRACK,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6852), 1,
      sym_type,
    STATE(6854), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [200937] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8957), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3036), 1,
      sym_type,
    STATE(3037), 1,
      sym_named_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201027] = 23,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8901), 1,
      sym_identifier,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8953), 1,
      anon_sym_LBRACK,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6814), 1,
      sym_type,
    STATE(6815), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201117] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8869), 1,
      anon_sym_LBRACK,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    STATE(1309), 1,
      sym_type,
    STATE(1310), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201207] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9111), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6823), 1,
      sym_type,
    STATE(6824), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201297] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9031), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6823), 1,
      sym_type,
    STATE(6824), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201387] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9031), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6855), 1,
      sym_type,
    STATE(6857), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201477] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9113), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201567] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9115), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201657] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9113), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7512), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201747] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9117), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201837] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9119), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [201927] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8957), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3045), 1,
      sym_type,
    STATE(3047), 1,
      sym_named_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [202017] = 23,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8935), 1,
      sym_identifier,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9121), 1,
      anon_sym_LBRACK,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4063), 1,
      sym_type,
    STATE(4064), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [202107] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9125), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [202197] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    ACTIONS(9127), 1,
      sym_tag,
    STATE(1406), 1,
      sym_type,
    STATE(1411), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [202287] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9129), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [202377] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9131), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [202467] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8835), 1,
      sym_identifier,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9133), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6835), 1,
      sym_type,
    STATE(6837), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [202557] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8957), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(2966), 1,
      sym_named_type,
    STATE(2993), 1,
      sym_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [202647] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8825), 1,
      anon_sym_LBRACK,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    STATE(3255), 1,
      sym_type,
    STATE(3256), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [202737] = 25,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(7608), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [202831] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    ACTIONS(9135), 1,
      sym_tag,
    STATE(1413), 1,
      sym_type,
    STATE(1414), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [202921] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8869), 1,
      anon_sym_LBRACK,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    STATE(1413), 1,
      sym_type,
    STATE(1414), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203011] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9137), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203101] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    ACTIONS(9139), 1,
      sym_tag,
    STATE(532), 1,
      sym_type,
    STATE(542), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203191] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9141), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203281] = 6,
    ACTIONS(8449), 1,
      anon_sym_LBRACE,
    ACTIONS(9143), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [203337] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9145), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203427] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9147), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203517] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9149), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(7958), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203607] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9151), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203697] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8825), 1,
      anon_sym_LBRACK,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    STATE(3439), 1,
      sym_type,
    STATE(3523), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203787] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    ACTIONS(9153), 1,
      sym_tag,
    STATE(2358), 1,
      sym_type,
    STATE(2362), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203877] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8979), 1,
      sym_identifier,
    ACTIONS(9155), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6873), 1,
      sym_type,
    STATE(6881), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [203967] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9157), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204057] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(8833), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7400), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204147] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8979), 1,
      sym_identifier,
    ACTIONS(9159), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6882), 1,
      sym_type,
    STATE(6883), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204237] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8979), 1,
      sym_identifier,
    ACTIONS(9057), 1,
      anon_sym_LBRACK,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6882), 1,
      sym_type,
    STATE(6883), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204327] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8979), 1,
      sym_identifier,
    ACTIONS(9057), 1,
      anon_sym_LBRACK,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6889), 1,
      sym_type,
    STATE(6890), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204417] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    ACTIONS(9161), 1,
      sym_tag,
    STATE(1307), 1,
      sym_type,
    STATE(1308), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204507] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9163), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204597] = 23,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      sym_identifier,
    ACTIONS(8847), 1,
      anon_sym_LBRACK,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6713), 1,
      sym_type,
    STATE(6759), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204687] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6723), 1,
      sym_type,
    STATE(6728), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204777] = 23,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8821), 1,
      sym_identifier,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8825), 1,
      anon_sym_LBRACK,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    STATE(3485), 1,
      sym_type,
    STATE(3486), 1,
      sym_named_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204867] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9165), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6693), 1,
      sym_type,
    STATE(6694), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [204957] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9167), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205047] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9169), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(8022), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205137] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9031), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6716), 1,
      sym_type,
    STATE(6717), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205227] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9171), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6695), 1,
      sym_type,
    STATE(6696), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205317] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8835), 1,
      sym_identifier,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9173), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6834), 1,
      sym_type,
    STATE(6836), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205407] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9031), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6695), 1,
      sym_type,
    STATE(6696), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205497] = 23,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8935), 1,
      sym_identifier,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9121), 1,
      anon_sym_LBRACK,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4066), 1,
      sym_type,
    STATE(4067), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205587] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8869), 1,
      anon_sym_LBRACK,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    STATE(2358), 1,
      sym_type,
    STATE(2362), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205677] = 23,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8887), 1,
      sym_identifier,
    ACTIONS(9031), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6698), 1,
      sym_type,
    STATE(6699), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205767] = 23,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8863), 1,
      sym_identifier,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    ACTIONS(9175), 1,
      sym_tag,
    STATE(1309), 1,
      sym_type,
    STATE(1310), 1,
      sym_named_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205857] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9177), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [205947] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    ACTIONS(9179), 1,
      sym_tag,
    STATE(3072), 1,
      sym_type,
    STATE(3073), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [206037] = 23,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      sym_identifier,
    ACTIONS(9181), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6683), 1,
      sym_type,
    STATE(6684), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [206127] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8895), 1,
      anon_sym_LBRACK,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    STATE(3072), 1,
      sym_type,
    STATE(3073), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [206217] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9183), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [206307] = 25,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(9185), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [206401] = 23,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8901), 1,
      sym_identifier,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8953), 1,
      anon_sym_LBRACK,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6847), 1,
      sym_type,
    STATE(6851), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [206491] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9187), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [206581] = 23,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8913), 1,
      sym_identifier,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6658), 1,
      sym_type,
    STATE(6677), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [206671] = 23,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      sym_identifier,
    ACTIONS(9189), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6685), 1,
      sym_type,
    STATE(6686), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [206761] = 23,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      sym_identifier,
    ACTIONS(8847), 1,
      anon_sym_LBRACK,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6685), 1,
      sym_type,
    STATE(6686), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [206851] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    ACTIONS(9191), 1,
      sym_tag,
    STATE(2971), 1,
      sym_named_type,
    STATE(3003), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [206941] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8957), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3090), 1,
      sym_type,
    STATE(3091), 1,
      sym_named_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207031] = 23,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8945), 1,
      sym_identifier,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(9193), 1,
      sym_tag,
    STATE(3088), 1,
      sym_type,
    STATE(3089), 1,
      sym_named_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207121] = 23,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9195), 1,
      anon_sym_RBRACE,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207211] = 23,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9197), 1,
      anon_sym_LBRACE,
    STATE(3757), 1,
      sym_procedure,
    STATE(7829), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207301] = 23,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8893), 1,
      sym_identifier,
    ACTIONS(8895), 1,
      anon_sym_LBRACK,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    STATE(3012), 1,
      sym_type,
    STATE(3013), 1,
      sym_named_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207391] = 23,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      sym_identifier,
    ACTIONS(9199), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6710), 1,
      sym_type,
    STATE(6751), 1,
      sym_named_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207481] = 23,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8851), 1,
      sym_identifier,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8857), 1,
      anon_sym_LBRACK,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    STATE(548), 1,
      sym_type,
    STATE(549), 1,
      sym_named_type,
    STATE(719), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207571] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8188), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207658] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9203), 1,
      anon_sym_LBRACK,
    STATE(6962), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207745] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3034), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207832] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7508), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [207919] = 22,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4381), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208006] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3034), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208093] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    STATE(4297), 1,
      sym_procedure,
    STATE(4381), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208180] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8455), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208267] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9205), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(6895), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208354] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8165), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208441] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6879), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208528] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    STATE(2453), 1,
      sym_procedure,
    STATE(2529), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208615] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8063), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208702] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8069), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208789] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7432), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208876] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8223), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [208963] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7344), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209050] = 22,
    ACTIONS(323), 1,
      anon_sym_distinct,
    ACTIONS(1467), 1,
      sym_identifier,
    ACTIONS(1469), 1,
      anon_sym_proc,
    ACTIONS(1471), 1,
      anon_sym_struct,
    ACTIONS(1473), 1,
      anon_sym_enum,
    ACTIONS(1475), 1,
      anon_sym_union,
    ACTIONS(1477), 1,
      anon_sym_bit_field,
    ACTIONS(1483), 1,
      anon_sym_DOLLAR,
    ACTIONS(1491), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1497), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1499), 1,
      anon_sym_map,
    ACTIONS(1501), 1,
      anon_sym_bit_set,
    ACTIONS(1503), 1,
      anon_sym_matrix,
    ACTIONS(1505), 1,
      sym_tag,
    ACTIONS(9207), 1,
      anon_sym_LPAREN,
    ACTIONS(9209), 1,
      anon_sym_BANG,
    ACTIONS(9211), 1,
      anon_sym_LBRACK,
    ACTIONS(9213), 1,
      anon_sym_CARET,
    STATE(2805), 1,
      sym_procedure,
    STATE(2882), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2885), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209137] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4853), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4851), 30,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [209186] = 22,
    ACTIONS(2430), 1,
      sym_identifier,
    ACTIONS(2432), 1,
      anon_sym_proc,
    ACTIONS(2434), 1,
      anon_sym_struct,
    ACTIONS(2436), 1,
      anon_sym_enum,
    ACTIONS(2438), 1,
      anon_sym_union,
    ACTIONS(2440), 1,
      anon_sym_bit_field,
    ACTIONS(2446), 1,
      anon_sym_DOLLAR,
    ACTIONS(2454), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2462), 1,
      anon_sym_map,
    ACTIONS(2464), 1,
      anon_sym_bit_set,
    ACTIONS(2466), 1,
      anon_sym_matrix,
    ACTIONS(2468), 1,
      anon_sym_distinct,
    ACTIONS(2470), 1,
      sym_tag,
    ACTIONS(9215), 1,
      anon_sym_LPAREN,
    ACTIONS(9217), 1,
      anon_sym_BANG,
    ACTIONS(9219), 1,
      anon_sym_LBRACK,
    ACTIONS(9221), 1,
      anon_sym_CARET,
    STATE(4282), 1,
      sym_procedure,
    STATE(4340), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4299), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209273] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8380), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209360] = 22,
    ACTIONS(685), 1,
      anon_sym_distinct,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2284), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2298), 1,
      anon_sym_DOLLAR,
    ACTIONS(2306), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2314), 1,
      anon_sym_map,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2318), 1,
      anon_sym_matrix,
    ACTIONS(2320), 1,
      sym_tag,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(9223), 1,
      anon_sym_LBRACK,
    ACTIONS(9225), 1,
      anon_sym_CARET,
    STATE(3828), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209447] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8427), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209534] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8434), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209621] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3828), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209708] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9227), 1,
      anon_sym_LBRACK,
    STATE(3930), 1,
      sym_procedure,
    STATE(6902), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209795] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(6904), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209882] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(6922), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [209969] = 22,
    ACTIONS(323), 1,
      anon_sym_distinct,
    ACTIONS(1467), 1,
      sym_identifier,
    ACTIONS(1469), 1,
      anon_sym_proc,
    ACTIONS(1471), 1,
      anon_sym_struct,
    ACTIONS(1473), 1,
      anon_sym_enum,
    ACTIONS(1475), 1,
      anon_sym_union,
    ACTIONS(1477), 1,
      anon_sym_bit_field,
    ACTIONS(1483), 1,
      anon_sym_DOLLAR,
    ACTIONS(1491), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1497), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1499), 1,
      anon_sym_map,
    ACTIONS(1501), 1,
      anon_sym_bit_set,
    ACTIONS(1503), 1,
      anon_sym_matrix,
    ACTIONS(1505), 1,
      sym_tag,
    ACTIONS(9207), 1,
      anon_sym_LPAREN,
    ACTIONS(9209), 1,
      anon_sym_BANG,
    ACTIONS(9211), 1,
      anon_sym_LBRACK,
    ACTIONS(9213), 1,
      anon_sym_CARET,
    STATE(2805), 1,
      sym_procedure,
    STATE(2860), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2885), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210056] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3817), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210143] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3739), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210230] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9229), 1,
      anon_sym_LBRACK,
    STATE(3757), 1,
      sym_procedure,
    STATE(7079), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210317] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7070), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210404] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7946), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210491] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    STATE(3568), 1,
      sym_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210578] = 22,
    ACTIONS(685), 1,
      anon_sym_distinct,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2284), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2298), 1,
      anon_sym_DOLLAR,
    ACTIONS(2306), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2314), 1,
      anon_sym_map,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2318), 1,
      anon_sym_matrix,
    ACTIONS(2320), 1,
      sym_tag,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(9225), 1,
      anon_sym_CARET,
    ACTIONS(9231), 1,
      anon_sym_LBRACK,
    STATE(3930), 1,
      sym_procedure,
    STATE(4107), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210665] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7080), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210752] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6928), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210839] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    STATE(3541), 1,
      sym_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [210926] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3716), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211013] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    STATE(3757), 1,
      sym_procedure,
    STATE(3760), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211100] = 22,
    ACTIONS(2430), 1,
      sym_identifier,
    ACTIONS(2432), 1,
      anon_sym_proc,
    ACTIONS(2434), 1,
      anon_sym_struct,
    ACTIONS(2436), 1,
      anon_sym_enum,
    ACTIONS(2438), 1,
      anon_sym_union,
    ACTIONS(2440), 1,
      anon_sym_bit_field,
    ACTIONS(2446), 1,
      anon_sym_DOLLAR,
    ACTIONS(2454), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2462), 1,
      anon_sym_map,
    ACTIONS(2464), 1,
      anon_sym_bit_set,
    ACTIONS(2466), 1,
      anon_sym_matrix,
    ACTIONS(2468), 1,
      anon_sym_distinct,
    ACTIONS(2470), 1,
      sym_tag,
    ACTIONS(9215), 1,
      anon_sym_LPAREN,
    ACTIONS(9217), 1,
      anon_sym_BANG,
    ACTIONS(9219), 1,
      anon_sym_LBRACK,
    ACTIONS(9221), 1,
      anon_sym_CARET,
    STATE(4282), 1,
      sym_procedure,
    STATE(4344), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4299), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211187] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    STATE(3117), 1,
      sym_procedure,
    STATE(3173), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211274] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    STATE(3117), 1,
      sym_procedure,
    STATE(3242), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211361] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    STATE(3117), 1,
      sym_procedure,
    STATE(3243), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211448] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    STATE(3839), 1,
      sym_procedure,
    STATE(3935), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211535] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8895), 1,
      anon_sym_LBRACK,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3245), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211622] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    STATE(3839), 1,
      sym_procedure,
    STATE(6933), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211709] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    STATE(3839), 1,
      sym_procedure,
    STATE(6934), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211796] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    STATE(3117), 1,
      sym_procedure,
    STATE(3131), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211883] = 22,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3228), 1,
      sym_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [211970] = 22,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6738), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212057] = 22,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6739), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212144] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    STATE(3839), 1,
      sym_procedure,
    STATE(3990), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212231] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    STATE(3570), 1,
      sym_procedure,
    STATE(3683), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212318] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    STATE(3533), 1,
      sym_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212405] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    STATE(3534), 1,
      sym_type,
    STATE(3570), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212492] = 22,
    ACTIONS(685), 1,
      anon_sym_distinct,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2284), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2298), 1,
      anon_sym_DOLLAR,
    ACTIONS(2306), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2314), 1,
      anon_sym_map,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2318), 1,
      anon_sym_matrix,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(9223), 1,
      anon_sym_LBRACK,
    ACTIONS(9225), 1,
      anon_sym_CARET,
    ACTIONS(9237), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(4114), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212579] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9239), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(6900), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212666] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(6897), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212753] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3173), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212840] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    STATE(3757), 1,
      sym_procedure,
    STATE(4850), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [212927] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    STATE(3117), 1,
      sym_procedure,
    STATE(3347), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213014] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7246), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213101] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(3814), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213188] = 22,
    ACTIONS(49), 1,
      anon_sym_distinct,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2232), 1,
      anon_sym_proc,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2246), 1,
      anon_sym_DOLLAR,
    ACTIONS(2254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2262), 1,
      anon_sym_map,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2266), 1,
      anon_sym_matrix,
    ACTIONS(2268), 1,
      sym_tag,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9241), 1,
      anon_sym_LBRACK,
    ACTIONS(9243), 1,
      anon_sym_CARET,
    STATE(3823), 1,
      sym_type,
    STATE(3909), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213275] = 22,
    ACTIONS(685), 1,
      anon_sym_distinct,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2284), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2298), 1,
      anon_sym_DOLLAR,
    ACTIONS(2306), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2314), 1,
      anon_sym_map,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2318), 1,
      anon_sym_matrix,
    ACTIONS(2320), 1,
      sym_tag,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(9223), 1,
      anon_sym_LBRACK,
    ACTIONS(9225), 1,
      anon_sym_CARET,
    STATE(3930), 1,
      sym_procedure,
    STATE(4092), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213362] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3803), 1,
      sym_type,
    STATE(3909), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213449] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9245), 1,
      anon_sym_LBRACK,
    STATE(3909), 1,
      sym_procedure,
    STATE(6880), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213536] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    STATE(2605), 1,
      sym_type,
    STATE(2652), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213623] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    ACTIONS(9255), 1,
      anon_sym_LBRACK,
    STATE(2633), 1,
      sym_type,
    STATE(2652), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213710] = 22,
    ACTIONS(323), 1,
      anon_sym_distinct,
    ACTIONS(1467), 1,
      sym_identifier,
    ACTIONS(1469), 1,
      anon_sym_proc,
    ACTIONS(1471), 1,
      anon_sym_struct,
    ACTIONS(1473), 1,
      anon_sym_enum,
    ACTIONS(1475), 1,
      anon_sym_union,
    ACTIONS(1477), 1,
      anon_sym_bit_field,
    ACTIONS(1483), 1,
      anon_sym_DOLLAR,
    ACTIONS(1491), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1497), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1499), 1,
      anon_sym_map,
    ACTIONS(1501), 1,
      anon_sym_bit_set,
    ACTIONS(1503), 1,
      anon_sym_matrix,
    ACTIONS(1505), 1,
      sym_tag,
    ACTIONS(9207), 1,
      anon_sym_LPAREN,
    ACTIONS(9209), 1,
      anon_sym_BANG,
    ACTIONS(9213), 1,
      anon_sym_CARET,
    ACTIONS(9257), 1,
      anon_sym_LBRACK,
    STATE(2805), 1,
      sym_procedure,
    STATE(2871), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2885), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213797] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7852), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213884] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9245), 1,
      anon_sym_LBRACK,
    STATE(3909), 1,
      sym_procedure,
    STATE(6925), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [213971] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6892), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214058] = 22,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8953), 1,
      anon_sym_LBRACK,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6875), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214145] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9259), 1,
      anon_sym_LBRACK,
    STATE(3839), 1,
      sym_procedure,
    STATE(6931), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214232] = 22,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3261), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214319] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    STATE(4297), 1,
      sym_procedure,
    STATE(4372), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214406] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    STATE(4297), 1,
      sym_procedure,
    STATE(4444), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214493] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    STATE(4297), 1,
      sym_procedure,
    STATE(4445), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214580] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9261), 1,
      sym_tag,
    STATE(3757), 1,
      sym_procedure,
    STATE(7076), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214667] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7061), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214754] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9263), 1,
      sym_tag,
    STATE(3839), 1,
      sym_procedure,
    STATE(6906), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214841] = 22,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6720), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [214928] = 22,
    ACTIONS(49), 1,
      anon_sym_distinct,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2232), 1,
      anon_sym_proc,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2246), 1,
      anon_sym_DOLLAR,
    ACTIONS(2254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2262), 1,
      anon_sym_map,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2266), 1,
      anon_sym_matrix,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9241), 1,
      anon_sym_LBRACK,
    ACTIONS(9243), 1,
      anon_sym_CARET,
    ACTIONS(9265), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(4087), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215015] = 22,
    ACTIONS(751), 1,
      anon_sym_distinct,
    ACTIONS(2654), 1,
      sym_identifier,
    ACTIONS(2656), 1,
      anon_sym_proc,
    ACTIONS(2658), 1,
      anon_sym_struct,
    ACTIONS(2660), 1,
      anon_sym_enum,
    ACTIONS(2662), 1,
      anon_sym_union,
    ACTIONS(2664), 1,
      anon_sym_bit_field,
    ACTIONS(2670), 1,
      anon_sym_DOLLAR,
    ACTIONS(2678), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2684), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2686), 1,
      anon_sym_map,
    ACTIONS(2688), 1,
      anon_sym_bit_set,
    ACTIONS(2690), 1,
      anon_sym_matrix,
    ACTIONS(2692), 1,
      sym_tag,
    ACTIONS(9267), 1,
      anon_sym_LPAREN,
    ACTIONS(9269), 1,
      anon_sym_BANG,
    ACTIONS(9271), 1,
      anon_sym_LBRACK,
    ACTIONS(9273), 1,
      anon_sym_CARET,
    STATE(4550), 1,
      sym_type,
    STATE(4572), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4568), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215102] = 22,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6741), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215189] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    STATE(2652), 1,
      sym_procedure,
    STATE(2777), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215276] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    STATE(3570), 1,
      sym_procedure,
    STATE(3635), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215363] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    STATE(3570), 1,
      sym_procedure,
    STATE(3641), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215450] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8825), 1,
      anon_sym_LBRACK,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3671), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215537] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4616), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215624] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    STATE(3117), 1,
      sym_procedure,
    STATE(3362), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215711] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    STATE(4297), 1,
      sym_procedure,
    STATE(4429), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215798] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    ACTIONS(9275), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3244), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215885] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3130), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [215972] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    STATE(4297), 1,
      sym_procedure,
    STATE(4358), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216059] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8963), 1,
      anon_sym_LBRACK,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4443), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216146] = 22,
    ACTIONS(323), 1,
      anon_sym_distinct,
    ACTIONS(1467), 1,
      sym_identifier,
    ACTIONS(1469), 1,
      anon_sym_proc,
    ACTIONS(1471), 1,
      anon_sym_struct,
    ACTIONS(1473), 1,
      anon_sym_enum,
    ACTIONS(1475), 1,
      anon_sym_union,
    ACTIONS(1477), 1,
      anon_sym_bit_field,
    ACTIONS(1483), 1,
      anon_sym_DOLLAR,
    ACTIONS(1491), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1497), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1499), 1,
      anon_sym_map,
    ACTIONS(1501), 1,
      anon_sym_bit_set,
    ACTIONS(1503), 1,
      anon_sym_matrix,
    ACTIONS(1505), 1,
      sym_tag,
    ACTIONS(9207), 1,
      anon_sym_LPAREN,
    ACTIONS(9209), 1,
      anon_sym_BANG,
    ACTIONS(9211), 1,
      anon_sym_LBRACK,
    ACTIONS(9213), 1,
      anon_sym_CARET,
    STATE(2805), 1,
      sym_procedure,
    STATE(2834), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2885), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216233] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    ACTIONS(9277), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3669), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216320] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    STATE(3570), 1,
      sym_procedure,
    STATE(3670), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216407] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    ACTIONS(9279), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4442), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216494] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    STATE(4297), 1,
      sym_procedure,
    STATE(4441), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216581] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8054), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216668] = 22,
    ACTIONS(2430), 1,
      sym_identifier,
    ACTIONS(2432), 1,
      anon_sym_proc,
    ACTIONS(2434), 1,
      anon_sym_struct,
    ACTIONS(2436), 1,
      anon_sym_enum,
    ACTIONS(2438), 1,
      anon_sym_union,
    ACTIONS(2440), 1,
      anon_sym_bit_field,
    ACTIONS(2446), 1,
      anon_sym_DOLLAR,
    ACTIONS(2454), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2462), 1,
      anon_sym_map,
    ACTIONS(2464), 1,
      anon_sym_bit_set,
    ACTIONS(2466), 1,
      anon_sym_matrix,
    ACTIONS(2468), 1,
      anon_sym_distinct,
    ACTIONS(2470), 1,
      sym_tag,
    ACTIONS(9215), 1,
      anon_sym_LPAREN,
    ACTIONS(9217), 1,
      anon_sym_BANG,
    ACTIONS(9219), 1,
      anon_sym_LBRACK,
    ACTIONS(9221), 1,
      anon_sym_CARET,
    STATE(4282), 1,
      sym_procedure,
    STATE(4355), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4299), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216755] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7390), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216842] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8320), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [216929] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(8089), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(7062), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217016] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    STATE(3757), 1,
      sym_procedure,
    STATE(3844), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217103] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6752), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217190] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9203), 1,
      anon_sym_LBRACK,
    STATE(6975), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217277] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8280), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217364] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3389), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217451] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8463), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217538] = 5,
    ACTIONS(7830), 1,
      sym_identifier,
    ACTIONS(7832), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 16,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 21,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_DASH_GT,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [217591] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    STATE(3828), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217678] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    ACTIONS(9281), 1,
      anon_sym_LBRACK,
    STATE(3930), 1,
      sym_procedure,
    STATE(7282), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217765] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7090), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217852] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7091), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [217939] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    STATE(3817), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218026] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    STATE(4297), 1,
      sym_procedure,
    STATE(4395), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218113] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3173), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218200] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6915), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218287] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6918), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218374] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8839), 1,
      anon_sym_LBRACK,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6930), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218461] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3131), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218548] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(9283), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7280), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218635] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7281), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218722] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7401), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218809] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6920), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218896] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8841), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6921), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [218983] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8174), 1,
      anon_sym_proc,
    ACTIONS(8176), 1,
      anon_sym_DOLLAR,
    ACTIONS(8178), 1,
      anon_sym_LBRACK,
    ACTIONS(8180), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8182), 1,
      anon_sym_CARET,
    ACTIONS(8184), 1,
      anon_sym_map,
    ACTIONS(8186), 1,
      anon_sym_matrix,
    ACTIONS(8188), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9285), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6927), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219070] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8036), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219157] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7378), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219244] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7762), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219331] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7104), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219418] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7732), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219505] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9245), 1,
      anon_sym_LBRACK,
    STATE(3909), 1,
      sym_procedure,
    STATE(6899), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219592] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8210), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219679] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8249), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219766] = 22,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6878), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219853] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3173), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [219940] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4544), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220027] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4545), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220114] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9121), 1,
      anon_sym_LBRACK,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4547), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220201] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3131), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220288] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4654), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220375] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9123), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4655), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220462] = 22,
    ACTIONS(1313), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(2758), 1,
      anon_sym_proc,
    ACTIONS(2760), 1,
      anon_sym_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2772), 1,
      anon_sym_map,
    ACTIONS(2774), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8937), 1,
      anon_sym_LBRACK,
    ACTIONS(8939), 1,
      anon_sym_CARET,
    ACTIONS(9287), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(4546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220549] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8441), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220636] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6894), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220723] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7478), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220810] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8451), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220897] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7780), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [220984] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7795), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221071] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2130), 1,
      anon_sym_proc,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2143), 1,
      anon_sym_DOLLAR,
    ACTIONS(2150), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2157), 1,
      anon_sym_map,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2161), 1,
      anon_sym_matrix,
    ACTIONS(2163), 1,
      anon_sym_distinct,
    ACTIONS(2165), 1,
      sym_tag,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9289), 1,
      anon_sym_LBRACK,
    ACTIONS(9291), 1,
      anon_sym_CARET,
    STATE(3839), 1,
      sym_procedure,
    STATE(3935), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221158] = 22,
    ACTIONS(49), 1,
      anon_sym_distinct,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2232), 1,
      anon_sym_proc,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2246), 1,
      anon_sym_DOLLAR,
    ACTIONS(2254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2262), 1,
      anon_sym_map,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2266), 1,
      anon_sym_matrix,
    ACTIONS(2268), 1,
      sym_tag,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9241), 1,
      anon_sym_LBRACK,
    ACTIONS(9243), 1,
      anon_sym_CARET,
    STATE(3909), 1,
      sym_procedure,
    STATE(4224), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221245] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9031), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6757), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221332] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7846), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221419] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    STATE(2613), 1,
      sym_type,
    STATE(2652), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221506] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    STATE(3757), 1,
      sym_procedure,
    STATE(3814), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221593] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7360), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221680] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8086), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221767] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(3971), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221854] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    STATE(719), 1,
      sym_procedure,
    STATE(823), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [221941] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6905), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222028] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    STATE(3117), 1,
      sym_procedure,
    STATE(3130), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222115] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7920), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222202] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7930), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222289] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7288), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222376] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    STATE(2410), 1,
      sym_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222463] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7967), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222550] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9293), 1,
      sym_tag,
    STATE(6953), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222637] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7458), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222724] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8543), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222811] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8184), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222898] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8020), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [222985] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8029), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223072] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(9295), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7254), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223159] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8058), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223246] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7864), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223333] = 22,
    ACTIONS(115), 1,
      anon_sym_distinct,
    ACTIONS(1043), 1,
      sym_identifier,
    ACTIONS(1045), 1,
      anon_sym_proc,
    ACTIONS(1047), 1,
      anon_sym_struct,
    ACTIONS(1049), 1,
      anon_sym_enum,
    ACTIONS(1051), 1,
      anon_sym_union,
    ACTIONS(1053), 1,
      anon_sym_bit_field,
    ACTIONS(1059), 1,
      anon_sym_DOLLAR,
    ACTIONS(1067), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1073), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1075), 1,
      anon_sym_map,
    ACTIONS(1077), 1,
      anon_sym_bit_set,
    ACTIONS(1079), 1,
      anon_sym_matrix,
    ACTIONS(1081), 1,
      sym_tag,
    ACTIONS(9297), 1,
      anon_sym_LPAREN,
    ACTIONS(9299), 1,
      anon_sym_BANG,
    ACTIONS(9301), 1,
      anon_sym_LBRACK,
    ACTIONS(9303), 1,
      anon_sym_CARET,
    STATE(2265), 1,
      sym_procedure,
    STATE(2299), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2346), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223420] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7370), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223507] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7871), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223594] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9305), 1,
      sym_tag,
    STATE(7115), 1,
      sym_procedure,
    STATE(7201), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223681] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8458), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223768] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7363), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223855] = 22,
    ACTIONS(49), 1,
      anon_sym_distinct,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2232), 1,
      anon_sym_proc,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2246), 1,
      anon_sym_DOLLAR,
    ACTIONS(2254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2262), 1,
      anon_sym_map,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2266), 1,
      anon_sym_matrix,
    ACTIONS(2268), 1,
      sym_tag,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9241), 1,
      anon_sym_LBRACK,
    ACTIONS(9243), 1,
      anon_sym_CARET,
    STATE(3803), 1,
      sym_type,
    STATE(3909), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [223942] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2130), 1,
      anon_sym_proc,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2143), 1,
      anon_sym_DOLLAR,
    ACTIONS(2150), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2157), 1,
      anon_sym_map,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2161), 1,
      anon_sym_matrix,
    ACTIONS(2163), 1,
      anon_sym_distinct,
    ACTIONS(2165), 1,
      sym_tag,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9289), 1,
      anon_sym_LBRACK,
    ACTIONS(9291), 1,
      anon_sym_CARET,
    STATE(3839), 1,
      sym_procedure,
    STATE(3911), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224029] = 22,
    ACTIONS(685), 1,
      anon_sym_distinct,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2284), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2298), 1,
      anon_sym_DOLLAR,
    ACTIONS(2306), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2314), 1,
      anon_sym_map,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2318), 1,
      anon_sym_matrix,
    ACTIONS(2320), 1,
      sym_tag,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(9223), 1,
      anon_sym_LBRACK,
    ACTIONS(9225), 1,
      anon_sym_CARET,
    STATE(3930), 1,
      sym_procedure,
    STATE(4247), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224116] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3034), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224203] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7221), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224290] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8126), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224377] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8138), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224464] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    STATE(3757), 1,
      sym_procedure,
    STATE(3792), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224551] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8169), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224638] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9227), 1,
      anon_sym_LBRACK,
    STATE(3930), 1,
      sym_procedure,
    STATE(7453), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224725] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7422), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224812] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7984), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224899] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7956), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [224986] = 22,
    ACTIONS(2430), 1,
      sym_identifier,
    ACTIONS(2432), 1,
      anon_sym_proc,
    ACTIONS(2434), 1,
      anon_sym_struct,
    ACTIONS(2436), 1,
      anon_sym_enum,
    ACTIONS(2438), 1,
      anon_sym_union,
    ACTIONS(2440), 1,
      anon_sym_bit_field,
    ACTIONS(2446), 1,
      anon_sym_DOLLAR,
    ACTIONS(2454), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2462), 1,
      anon_sym_map,
    ACTIONS(2464), 1,
      anon_sym_bit_set,
    ACTIONS(2466), 1,
      anon_sym_matrix,
    ACTIONS(2468), 1,
      anon_sym_distinct,
    ACTIONS(2470), 1,
      sym_tag,
    ACTIONS(9215), 1,
      anon_sym_LPAREN,
    ACTIONS(9217), 1,
      anon_sym_BANG,
    ACTIONS(9219), 1,
      anon_sym_LBRACK,
    ACTIONS(9221), 1,
      anon_sym_CARET,
    STATE(4282), 1,
      sym_procedure,
    STATE(4288), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4299), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225073] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9203), 1,
      anon_sym_LBRACK,
    STATE(6980), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225160] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8231), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225247] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9307), 1,
      sym_tag,
    STATE(6980), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225334] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8244), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225421] = 6,
    ACTIONS(7901), 1,
      sym_identifier,
    ACTIONS(7903), 1,
      anon_sym_LPAREN,
    ACTIONS(9309), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 16,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 20,
      anon_sym_COMMA,
      anon_sym_DASH_GT,
      anon_sym_COLON,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [225476] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8292), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225563] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    STATE(2384), 1,
      sym_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225650] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7464), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225737] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8078), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225824] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2130), 1,
      anon_sym_proc,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2143), 1,
      anon_sym_DOLLAR,
    ACTIONS(2150), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2157), 1,
      anon_sym_map,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2161), 1,
      anon_sym_matrix,
    ACTIONS(2163), 1,
      anon_sym_distinct,
    ACTIONS(2165), 1,
      sym_tag,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9289), 1,
      anon_sym_LBRACK,
    ACTIONS(9291), 1,
      anon_sym_CARET,
    STATE(3839), 1,
      sym_procedure,
    STATE(3865), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225911] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8284), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [225998] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    STATE(2636), 1,
      sym_type,
    STATE(2652), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226085] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8869), 1,
      anon_sym_LBRACK,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    STATE(2453), 1,
      sym_procedure,
    STATE(2521), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226172] = 22,
    ACTIONS(2430), 1,
      sym_identifier,
    ACTIONS(2432), 1,
      anon_sym_proc,
    ACTIONS(2434), 1,
      anon_sym_struct,
    ACTIONS(2436), 1,
      anon_sym_enum,
    ACTIONS(2438), 1,
      anon_sym_union,
    ACTIONS(2440), 1,
      anon_sym_bit_field,
    ACTIONS(2446), 1,
      anon_sym_DOLLAR,
    ACTIONS(2454), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2462), 1,
      anon_sym_map,
    ACTIONS(2464), 1,
      anon_sym_bit_set,
    ACTIONS(2466), 1,
      anon_sym_matrix,
    ACTIONS(2468), 1,
      anon_sym_distinct,
    ACTIONS(2470), 1,
      sym_tag,
    ACTIONS(9215), 1,
      anon_sym_LPAREN,
    ACTIONS(9217), 1,
      anon_sym_BANG,
    ACTIONS(9219), 1,
      anon_sym_LBRACK,
    ACTIONS(9221), 1,
      anon_sym_CARET,
    STATE(4282), 1,
      sym_procedure,
    STATE(4318), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4299), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226259] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8392), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226346] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    STATE(3716), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226433] = 22,
    ACTIONS(49), 1,
      anon_sym_distinct,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2232), 1,
      anon_sym_proc,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2246), 1,
      anon_sym_DOLLAR,
    ACTIONS(2254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2262), 1,
      anon_sym_map,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2266), 1,
      anon_sym_matrix,
    ACTIONS(2268), 1,
      sym_tag,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9243), 1,
      anon_sym_CARET,
    ACTIONS(9311), 1,
      anon_sym_LBRACK,
    STATE(3909), 1,
      sym_procedure,
    STATE(4025), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226520] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8407), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226607] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8452), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226694] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9313), 1,
      sym_tag,
    STATE(6954), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226781] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2130), 1,
      anon_sym_proc,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2143), 1,
      anon_sym_DOLLAR,
    ACTIONS(2150), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2157), 1,
      anon_sym_map,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2161), 1,
      anon_sym_matrix,
    ACTIONS(2163), 1,
      anon_sym_distinct,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9289), 1,
      anon_sym_LBRACK,
    ACTIONS(9291), 1,
      anon_sym_CARET,
    ACTIONS(9315), 1,
      sym_tag,
    STATE(3839), 1,
      sym_procedure,
    STATE(3846), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226868] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7489), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [226955] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8190), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227042] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9317), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7453), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227129] = 22,
    ACTIONS(115), 1,
      anon_sym_distinct,
    ACTIONS(1043), 1,
      sym_identifier,
    ACTIONS(1045), 1,
      anon_sym_proc,
    ACTIONS(1047), 1,
      anon_sym_struct,
    ACTIONS(1049), 1,
      anon_sym_enum,
    ACTIONS(1051), 1,
      anon_sym_union,
    ACTIONS(1053), 1,
      anon_sym_bit_field,
    ACTIONS(1059), 1,
      anon_sym_DOLLAR,
    ACTIONS(1067), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1073), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1075), 1,
      anon_sym_map,
    ACTIONS(1077), 1,
      anon_sym_bit_set,
    ACTIONS(1079), 1,
      anon_sym_matrix,
    ACTIONS(1081), 1,
      sym_tag,
    ACTIONS(9297), 1,
      anon_sym_LPAREN,
    ACTIONS(9299), 1,
      anon_sym_BANG,
    ACTIONS(9301), 1,
      anon_sym_LBRACK,
    ACTIONS(9303), 1,
      anon_sym_CARET,
    STATE(2265), 1,
      sym_procedure,
    STATE(2422), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2346), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227216] = 22,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3683), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227303] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    STATE(719), 1,
      sym_procedure,
    STATE(792), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227390] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2130), 1,
      anon_sym_proc,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2143), 1,
      anon_sym_DOLLAR,
    ACTIONS(2150), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2157), 1,
      anon_sym_map,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2161), 1,
      anon_sym_matrix,
    ACTIONS(2163), 1,
      anon_sym_distinct,
    ACTIONS(2165), 1,
      sym_tag,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9289), 1,
      anon_sym_LBRACK,
    ACTIONS(9291), 1,
      anon_sym_CARET,
    STATE(3832), 1,
      sym_type,
    STATE(3839), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227477] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8516), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227564] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3265), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227651] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8527), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227738] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9319), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(6925), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227825] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    STATE(2652), 1,
      sym_procedure,
    STATE(2664), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227912] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8556), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [227999] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    STATE(2284), 1,
      sym_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228086] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7421), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228173] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7521), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228260] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8481), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228347] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7496), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228434] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6749), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228521] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3131), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228608] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8239), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228695] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7945), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228782] = 22,
    ACTIONS(323), 1,
      anon_sym_distinct,
    ACTIONS(1467), 1,
      sym_identifier,
    ACTIONS(1469), 1,
      anon_sym_proc,
    ACTIONS(1471), 1,
      anon_sym_struct,
    ACTIONS(1473), 1,
      anon_sym_enum,
    ACTIONS(1475), 1,
      anon_sym_union,
    ACTIONS(1477), 1,
      anon_sym_bit_field,
    ACTIONS(1483), 1,
      anon_sym_DOLLAR,
    ACTIONS(1491), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1497), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1499), 1,
      anon_sym_map,
    ACTIONS(1501), 1,
      anon_sym_bit_set,
    ACTIONS(1503), 1,
      anon_sym_matrix,
    ACTIONS(1505), 1,
      sym_tag,
    ACTIONS(9207), 1,
      anon_sym_LPAREN,
    ACTIONS(9209), 1,
      anon_sym_BANG,
    ACTIONS(9211), 1,
      anon_sym_LBRACK,
    ACTIONS(9213), 1,
      anon_sym_CARET,
    STATE(2805), 1,
      sym_procedure,
    STATE(2868), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2885), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228869] = 22,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6736), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [228956] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7477), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229043] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8479), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229130] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8582), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229217] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7799), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229304] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2130), 1,
      anon_sym_proc,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2143), 1,
      anon_sym_DOLLAR,
    ACTIONS(2150), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2157), 1,
      anon_sym_map,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2161), 1,
      anon_sym_matrix,
    ACTIONS(2163), 1,
      anon_sym_distinct,
    ACTIONS(2165), 1,
      sym_tag,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9291), 1,
      anon_sym_CARET,
    ACTIONS(9321), 1,
      anon_sym_LBRACK,
    STATE(3839), 1,
      sym_procedure,
    STATE(3981), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229391] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3261), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229478] = 22,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4372), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229565] = 22,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6876), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229652] = 22,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6877), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229739] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7430), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229826] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8325), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [229913] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    ACTIONS(9323), 1,
      sym_tag,
    STATE(3756), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230000] = 22,
    ACTIONS(685), 1,
      anon_sym_distinct,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2284), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2298), 1,
      anon_sym_DOLLAR,
    ACTIONS(2306), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2314), 1,
      anon_sym_map,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2318), 1,
      anon_sym_matrix,
    ACTIONS(2320), 1,
      sym_tag,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(9223), 1,
      anon_sym_LBRACK,
    ACTIONS(9225), 1,
      anon_sym_CARET,
    STATE(3919), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230087] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8074), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230174] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    STATE(3737), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230261] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8080), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230348] = 22,
    ACTIONS(49), 1,
      anon_sym_distinct,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2232), 1,
      anon_sym_proc,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2246), 1,
      anon_sym_DOLLAR,
    ACTIONS(2254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2262), 1,
      anon_sym_map,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2266), 1,
      anon_sym_matrix,
    ACTIONS(2268), 1,
      sym_tag,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9241), 1,
      anon_sym_LBRACK,
    ACTIONS(9243), 1,
      anon_sym_CARET,
    STATE(3909), 1,
      sym_procedure,
    STATE(4260), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230435] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7492), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230522] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7753), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230609] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7779), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230696] = 22,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(9325), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6740), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230783] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8240), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230870] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8257), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [230957] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2130), 1,
      anon_sym_proc,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2143), 1,
      anon_sym_DOLLAR,
    ACTIONS(2150), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2157), 1,
      anon_sym_map,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2161), 1,
      anon_sym_matrix,
    ACTIONS(2163), 1,
      anon_sym_distinct,
    ACTIONS(2165), 1,
      sym_tag,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9289), 1,
      anon_sym_LBRACK,
    ACTIONS(9291), 1,
      anon_sym_CARET,
    STATE(3839), 1,
      sym_procedure,
    STATE(3843), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231044] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7359), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231131] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8483), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231218] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8494), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231305] = 22,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(6732), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231392] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8528), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231479] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7670), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231566] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7384), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231653] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8487), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231740] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    STATE(2652), 1,
      sym_procedure,
    STATE(2795), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231827] = 22,
    ACTIONS(941), 1,
      sym_identifier,
    ACTIONS(943), 1,
      anon_sym_proc,
    ACTIONS(945), 1,
      anon_sym_struct,
    ACTIONS(947), 1,
      anon_sym_enum,
    ACTIONS(949), 1,
      anon_sym_union,
    ACTIONS(951), 1,
      anon_sym_bit_field,
    ACTIONS(956), 1,
      anon_sym_DOLLAR,
    ACTIONS(963), 1,
      anon_sym_DOT_DOT,
    ACTIONS(968), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(970), 1,
      anon_sym_map,
    ACTIONS(972), 1,
      anon_sym_bit_set,
    ACTIONS(974), 1,
      anon_sym_matrix,
    ACTIONS(976), 1,
      anon_sym_distinct,
    ACTIONS(978), 1,
      sym_tag,
    ACTIONS(9327), 1,
      anon_sym_LPAREN,
    ACTIONS(9329), 1,
      anon_sym_BANG,
    ACTIONS(9331), 1,
      anon_sym_LBRACK,
    ACTIONS(9333), 1,
      anon_sym_CARET,
    STATE(1716), 1,
      sym_type,
    STATE(2182), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(1624), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [231914] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3235), 1,
      sym_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232001] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7827), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232088] = 22,
    ACTIONS(115), 1,
      anon_sym_distinct,
    ACTIONS(1043), 1,
      sym_identifier,
    ACTIONS(1045), 1,
      anon_sym_proc,
    ACTIONS(1047), 1,
      anon_sym_struct,
    ACTIONS(1049), 1,
      anon_sym_enum,
    ACTIONS(1051), 1,
      anon_sym_union,
    ACTIONS(1053), 1,
      anon_sym_bit_field,
    ACTIONS(1059), 1,
      anon_sym_DOLLAR,
    ACTIONS(1067), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1073), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1075), 1,
      anon_sym_map,
    ACTIONS(1077), 1,
      anon_sym_bit_set,
    ACTIONS(1079), 1,
      anon_sym_matrix,
    ACTIONS(1081), 1,
      sym_tag,
    ACTIONS(9297), 1,
      anon_sym_LPAREN,
    ACTIONS(9299), 1,
      anon_sym_BANG,
    ACTIONS(9301), 1,
      anon_sym_LBRACK,
    ACTIONS(9303), 1,
      anon_sym_CARET,
    STATE(2265), 1,
      sym_procedure,
    STATE(2388), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2346), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232175] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7836), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232262] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8571), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232349] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8103), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232436] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7853), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232523] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7996), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232610] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7980), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232697] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9203), 1,
      anon_sym_LBRACK,
    STATE(6973), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232784] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8185), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232871] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9335), 1,
      sym_tag,
    STATE(6973), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [232958] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8501), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233045] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9337), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7515), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233132] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8366), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233219] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7758), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233306] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7497), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233393] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9227), 1,
      anon_sym_LBRACK,
    STATE(3930), 1,
      sym_procedure,
    STATE(7440), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233480] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9339), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7440), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233567] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7769), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233654] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7796), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233741] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8521), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233828] = 22,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6731), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [233915] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    STATE(3757), 1,
      sym_procedure,
    STATE(4778), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234002] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7546), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234089] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8134), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234176] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8137), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234263] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9203), 1,
      anon_sym_LBRACK,
    STATE(6985), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234350] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    STATE(719), 1,
      sym_procedure,
    STATE(857), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234437] = 22,
    ACTIONS(751), 1,
      anon_sym_distinct,
    ACTIONS(2654), 1,
      sym_identifier,
    ACTIONS(2656), 1,
      anon_sym_proc,
    ACTIONS(2658), 1,
      anon_sym_struct,
    ACTIONS(2660), 1,
      anon_sym_enum,
    ACTIONS(2662), 1,
      anon_sym_union,
    ACTIONS(2664), 1,
      anon_sym_bit_field,
    ACTIONS(2670), 1,
      anon_sym_DOLLAR,
    ACTIONS(2678), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2684), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2686), 1,
      anon_sym_map,
    ACTIONS(2688), 1,
      anon_sym_bit_set,
    ACTIONS(2690), 1,
      anon_sym_matrix,
    ACTIONS(2692), 1,
      sym_tag,
    ACTIONS(9267), 1,
      anon_sym_LPAREN,
    ACTIONS(9269), 1,
      anon_sym_BANG,
    ACTIONS(9271), 1,
      anon_sym_LBRACK,
    ACTIONS(9273), 1,
      anon_sym_CARET,
    STATE(4572), 1,
      sym_procedure,
    STATE(4595), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4568), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234524] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8161), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234611] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8168), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234698] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    ACTIONS(9281), 1,
      anon_sym_LBRACK,
    STATE(3930), 1,
      sym_procedure,
    STATE(7178), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234785] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7978), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234872] = 22,
    ACTIONS(1343), 1,
      anon_sym_distinct,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2534), 1,
      anon_sym_proc,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2547), 1,
      anon_sym_DOLLAR,
    ACTIONS(2554), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2561), 1,
      anon_sym_map,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(2565), 1,
      anon_sym_matrix,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8965), 1,
      anon_sym_CARET,
    ACTIONS(8967), 1,
      sym_tag,
    ACTIONS(8987), 1,
      anon_sym_LBRACK,
    STATE(4297), 1,
      sym_procedure,
    STATE(4497), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [234959] = 22,
    ACTIONS(751), 1,
      anon_sym_distinct,
    ACTIONS(2654), 1,
      sym_identifier,
    ACTIONS(2656), 1,
      anon_sym_proc,
    ACTIONS(2658), 1,
      anon_sym_struct,
    ACTIONS(2660), 1,
      anon_sym_enum,
    ACTIONS(2662), 1,
      anon_sym_union,
    ACTIONS(2664), 1,
      anon_sym_bit_field,
    ACTIONS(2670), 1,
      anon_sym_DOLLAR,
    ACTIONS(2678), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2684), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2686), 1,
      anon_sym_map,
    ACTIONS(2688), 1,
      anon_sym_bit_set,
    ACTIONS(2690), 1,
      anon_sym_matrix,
    ACTIONS(2692), 1,
      sym_tag,
    ACTIONS(9267), 1,
      anon_sym_LPAREN,
    ACTIONS(9269), 1,
      anon_sym_BANG,
    ACTIONS(9273), 1,
      anon_sym_CARET,
    ACTIONS(9341), 1,
      anon_sym_LBRACK,
    STATE(4572), 1,
      sym_procedure,
    STATE(4580), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4568), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235046] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3228), 1,
      sym_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235133] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    STATE(719), 1,
      sym_procedure,
    STATE(734), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235220] = 22,
    ACTIONS(685), 1,
      anon_sym_distinct,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2284), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2298), 1,
      anon_sym_DOLLAR,
    ACTIONS(2306), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2314), 1,
      anon_sym_map,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2318), 1,
      anon_sym_matrix,
    ACTIONS(2320), 1,
      sym_tag,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(9223), 1,
      anon_sym_LBRACK,
    ACTIONS(9225), 1,
      anon_sym_CARET,
    STATE(3817), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235307] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7447), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235394] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7563), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235481] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    STATE(2453), 1,
      sym_procedure,
    STATE(2497), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235568] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9343), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(6899), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235655] = 22,
    ACTIONS(115), 1,
      anon_sym_distinct,
    ACTIONS(1043), 1,
      sym_identifier,
    ACTIONS(1045), 1,
      anon_sym_proc,
    ACTIONS(1047), 1,
      anon_sym_struct,
    ACTIONS(1049), 1,
      anon_sym_enum,
    ACTIONS(1051), 1,
      anon_sym_union,
    ACTIONS(1053), 1,
      anon_sym_bit_field,
    ACTIONS(1059), 1,
      anon_sym_DOLLAR,
    ACTIONS(1067), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1073), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1075), 1,
      anon_sym_map,
    ACTIONS(1077), 1,
      anon_sym_bit_set,
    ACTIONS(1079), 1,
      anon_sym_matrix,
    ACTIONS(1081), 1,
      sym_tag,
    ACTIONS(9297), 1,
      anon_sym_LPAREN,
    ACTIONS(9299), 1,
      anon_sym_BANG,
    ACTIONS(9301), 1,
      anon_sym_LBRACK,
    ACTIONS(9303), 1,
      anon_sym_CARET,
    STATE(2265), 1,
      sym_procedure,
    STATE(2490), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2346), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235742] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9345), 1,
      sym_tag,
    STATE(6983), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235829] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8191), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [235916] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8192), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236003] = 22,
    ACTIONS(115), 1,
      anon_sym_distinct,
    ACTIONS(1043), 1,
      sym_identifier,
    ACTIONS(1045), 1,
      anon_sym_proc,
    ACTIONS(1047), 1,
      anon_sym_struct,
    ACTIONS(1049), 1,
      anon_sym_enum,
    ACTIONS(1051), 1,
      anon_sym_union,
    ACTIONS(1053), 1,
      anon_sym_bit_field,
    ACTIONS(1059), 1,
      anon_sym_DOLLAR,
    ACTIONS(1067), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1073), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1075), 1,
      anon_sym_map,
    ACTIONS(1077), 1,
      anon_sym_bit_set,
    ACTIONS(1079), 1,
      anon_sym_matrix,
    ACTIONS(1081), 1,
      sym_tag,
    ACTIONS(9297), 1,
      anon_sym_LPAREN,
    ACTIONS(9299), 1,
      anon_sym_BANG,
    ACTIONS(9303), 1,
      anon_sym_CARET,
    ACTIONS(9347), 1,
      anon_sym_LBRACK,
    STATE(2265), 1,
      sym_procedure,
    STATE(2494), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2346), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236090] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9203), 1,
      anon_sym_LBRACK,
    STATE(6983), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236177] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8576), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236264] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6932), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236351] = 22,
    ACTIONS(685), 1,
      anon_sym_distinct,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2284), 1,
      anon_sym_proc,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2298), 1,
      anon_sym_DOLLAR,
    ACTIONS(2306), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2314), 1,
      anon_sym_map,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(2318), 1,
      anon_sym_matrix,
    ACTIONS(2320), 1,
      sym_tag,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(9223), 1,
      anon_sym_LBRACK,
    ACTIONS(9225), 1,
      anon_sym_CARET,
    STATE(3930), 1,
      sym_procedure,
    STATE(4156), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236438] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3326), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236525] = 22,
    ACTIONS(751), 1,
      anon_sym_distinct,
    ACTIONS(2654), 1,
      sym_identifier,
    ACTIONS(2656), 1,
      anon_sym_proc,
    ACTIONS(2658), 1,
      anon_sym_struct,
    ACTIONS(2660), 1,
      anon_sym_enum,
    ACTIONS(2662), 1,
      anon_sym_union,
    ACTIONS(2664), 1,
      anon_sym_bit_field,
    ACTIONS(2670), 1,
      anon_sym_DOLLAR,
    ACTIONS(2678), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2684), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2686), 1,
      anon_sym_map,
    ACTIONS(2688), 1,
      anon_sym_bit_set,
    ACTIONS(2690), 1,
      anon_sym_matrix,
    ACTIONS(2692), 1,
      sym_tag,
    ACTIONS(9267), 1,
      anon_sym_LPAREN,
    ACTIONS(9269), 1,
      anon_sym_BANG,
    ACTIONS(9271), 1,
      anon_sym_LBRACK,
    ACTIONS(9273), 1,
      anon_sym_CARET,
    STATE(4572), 1,
      sym_procedure,
    STATE(4615), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4568), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236612] = 22,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(9349), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6735), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236699] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3288), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236786] = 22,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6743), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236873] = 22,
    ACTIONS(941), 1,
      sym_identifier,
    ACTIONS(943), 1,
      anon_sym_proc,
    ACTIONS(945), 1,
      anon_sym_struct,
    ACTIONS(947), 1,
      anon_sym_enum,
    ACTIONS(949), 1,
      anon_sym_union,
    ACTIONS(951), 1,
      anon_sym_bit_field,
    ACTIONS(956), 1,
      anon_sym_DOLLAR,
    ACTIONS(963), 1,
      anon_sym_DOT_DOT,
    ACTIONS(968), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(970), 1,
      anon_sym_map,
    ACTIONS(972), 1,
      anon_sym_bit_set,
    ACTIONS(974), 1,
      anon_sym_matrix,
    ACTIONS(976), 1,
      anon_sym_distinct,
    ACTIONS(978), 1,
      sym_tag,
    ACTIONS(9327), 1,
      anon_sym_LPAREN,
    ACTIONS(9329), 1,
      anon_sym_BANG,
    ACTIONS(9333), 1,
      anon_sym_CARET,
    ACTIONS(9351), 1,
      anon_sym_LBRACK,
    STATE(1667), 1,
      sym_type,
    STATE(2182), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(1624), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [236960] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    STATE(719), 1,
      sym_procedure,
    STATE(723), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [237047] = 22,
    ACTIONS(323), 1,
      anon_sym_distinct,
    ACTIONS(1467), 1,
      sym_identifier,
    ACTIONS(1469), 1,
      anon_sym_proc,
    ACTIONS(1471), 1,
      anon_sym_struct,
    ACTIONS(1473), 1,
      anon_sym_enum,
    ACTIONS(1475), 1,
      anon_sym_union,
    ACTIONS(1477), 1,
      anon_sym_bit_field,
    ACTIONS(1483), 1,
      anon_sym_DOLLAR,
    ACTIONS(1491), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1497), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1499), 1,
      anon_sym_map,
    ACTIONS(1501), 1,
      anon_sym_bit_set,
    ACTIONS(1503), 1,
      anon_sym_matrix,
    ACTIONS(9207), 1,
      anon_sym_LPAREN,
    ACTIONS(9209), 1,
      anon_sym_BANG,
    ACTIONS(9211), 1,
      anon_sym_LBRACK,
    ACTIONS(9213), 1,
      anon_sym_CARET,
    ACTIONS(9353), 1,
      sym_tag,
    STATE(2805), 1,
      sym_procedure,
    STATE(2852), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2885), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [237134] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9203), 1,
      anon_sym_LBRACK,
    STATE(6959), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [237221] = 22,
    ACTIONS(941), 1,
      sym_identifier,
    ACTIONS(943), 1,
      anon_sym_proc,
    ACTIONS(945), 1,
      anon_sym_struct,
    ACTIONS(947), 1,
      anon_sym_enum,
    ACTIONS(949), 1,
      anon_sym_union,
    ACTIONS(951), 1,
      anon_sym_bit_field,
    ACTIONS(956), 1,
      anon_sym_DOLLAR,
    ACTIONS(963), 1,
      anon_sym_DOT_DOT,
    ACTIONS(968), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(970), 1,
      anon_sym_map,
    ACTIONS(972), 1,
      anon_sym_bit_set,
    ACTIONS(974), 1,
      anon_sym_matrix,
    ACTIONS(976), 1,
      anon_sym_distinct,
    ACTIONS(9327), 1,
      anon_sym_LPAREN,
    ACTIONS(9329), 1,
      anon_sym_BANG,
    ACTIONS(9331), 1,
      anon_sym_LBRACK,
    ACTIONS(9333), 1,
      anon_sym_CARET,
    ACTIONS(9355), 1,
      sym_tag,
    STATE(1625), 1,
      sym_type,
    STATE(2182), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(1624), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [237308] = 30,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(9357), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9359), 1,
      anon_sym_EQ,
    ACTIONS(9361), 1,
      anon_sym_COLON,
    ACTIONS(9363), 1,
      anon_sym_COLON_EQ,
    STATE(7158), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [237411] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    STATE(3839), 1,
      sym_procedure,
    STATE(3843), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [237498] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3395), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [237585] = 22,
    ACTIONS(941), 1,
      sym_identifier,
    ACTIONS(943), 1,
      anon_sym_proc,
    ACTIONS(945), 1,
      anon_sym_struct,
    ACTIONS(947), 1,
      anon_sym_enum,
    ACTIONS(949), 1,
      anon_sym_union,
    ACTIONS(951), 1,
      anon_sym_bit_field,
    ACTIONS(956), 1,
      anon_sym_DOLLAR,
    ACTIONS(963), 1,
      anon_sym_DOT_DOT,
    ACTIONS(968), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(970), 1,
      anon_sym_map,
    ACTIONS(972), 1,
      anon_sym_bit_set,
    ACTIONS(974), 1,
      anon_sym_matrix,
    ACTIONS(976), 1,
      anon_sym_distinct,
    ACTIONS(978), 1,
      sym_tag,
    ACTIONS(9327), 1,
      anon_sym_LPAREN,
    ACTIONS(9329), 1,
      anon_sym_BANG,
    ACTIONS(9331), 1,
      anon_sym_LBRACK,
    ACTIONS(9333), 1,
      anon_sym_CARET,
    STATE(1661), 1,
      sym_type,
    STATE(2182), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(1624), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [237672] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9343), 1,
      sym_tag,
    STATE(3909), 1,
      sym_procedure,
    STATE(7053), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [237759] = 22,
    ACTIONS(941), 1,
      sym_identifier,
    ACTIONS(943), 1,
      anon_sym_proc,
    ACTIONS(945), 1,
      anon_sym_struct,
    ACTIONS(947), 1,
      anon_sym_enum,
    ACTIONS(949), 1,
      anon_sym_union,
    ACTIONS(951), 1,
      anon_sym_bit_field,
    ACTIONS(956), 1,
      anon_sym_DOLLAR,
    ACTIONS(963), 1,
      anon_sym_DOT_DOT,
    ACTIONS(968), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(970), 1,
      anon_sym_map,
    ACTIONS(972), 1,
      anon_sym_bit_set,
    ACTIONS(974), 1,
      anon_sym_matrix,
    ACTIONS(976), 1,
      anon_sym_distinct,
    ACTIONS(978), 1,
      sym_tag,
    ACTIONS(9327), 1,
      anon_sym_LPAREN,
    ACTIONS(9329), 1,
      anon_sym_BANG,
    ACTIONS(9331), 1,
      anon_sym_LBRACK,
    ACTIONS(9333), 1,
      anon_sym_CARET,
    STATE(1917), 1,
      sym_type,
    STATE(2182), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(1624), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [237846] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6964), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [237933] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7982), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238020] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6916), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238107] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9245), 1,
      anon_sym_LBRACK,
    STATE(3909), 1,
      sym_procedure,
    STATE(6935), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238194] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    ACTIONS(9227), 1,
      anon_sym_LBRACK,
    STATE(3930), 1,
      sym_procedure,
    STATE(7472), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238281] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9365), 1,
      sym_tag,
    STATE(6959), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238368] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    ACTIONS(9367), 1,
      sym_tag,
    STATE(719), 1,
      sym_procedure,
    STATE(803), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238455] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    STATE(3034), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238542] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    STATE(719), 1,
      sym_procedure,
    STATE(816), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238629] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3173), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238716] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7919), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238803] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6907), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238890] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6908), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [238977] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6758), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239064] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9057), 1,
      anon_sym_LBRACK,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6911), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239151] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8957), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3229), 1,
      sym_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239238] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    STATE(7115), 1,
      sym_procedure,
    STATE(7298), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239325] = 22,
    ACTIONS(115), 1,
      anon_sym_distinct,
    ACTIONS(1043), 1,
      sym_identifier,
    ACTIONS(1045), 1,
      anon_sym_proc,
    ACTIONS(1047), 1,
      anon_sym_struct,
    ACTIONS(1049), 1,
      anon_sym_enum,
    ACTIONS(1051), 1,
      anon_sym_union,
    ACTIONS(1053), 1,
      anon_sym_bit_field,
    ACTIONS(1059), 1,
      anon_sym_DOLLAR,
    ACTIONS(1067), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1073), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1075), 1,
      anon_sym_map,
    ACTIONS(1077), 1,
      anon_sym_bit_set,
    ACTIONS(1079), 1,
      anon_sym_matrix,
    ACTIONS(9297), 1,
      anon_sym_LPAREN,
    ACTIONS(9299), 1,
      anon_sym_BANG,
    ACTIONS(9301), 1,
      anon_sym_LBRACK,
    ACTIONS(9303), 1,
      anon_sym_CARET,
    ACTIONS(9369), 1,
      sym_tag,
    STATE(2265), 1,
      sym_procedure,
    STATE(2352), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2346), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239412] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3919), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239499] = 22,
    ACTIONS(115), 1,
      anon_sym_distinct,
    ACTIONS(1043), 1,
      sym_identifier,
    ACTIONS(1045), 1,
      anon_sym_proc,
    ACTIONS(1047), 1,
      anon_sym_struct,
    ACTIONS(1049), 1,
      anon_sym_enum,
    ACTIONS(1051), 1,
      anon_sym_union,
    ACTIONS(1053), 1,
      anon_sym_bit_field,
    ACTIONS(1059), 1,
      anon_sym_DOLLAR,
    ACTIONS(1067), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1073), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1075), 1,
      anon_sym_map,
    ACTIONS(1077), 1,
      anon_sym_bit_set,
    ACTIONS(1079), 1,
      anon_sym_matrix,
    ACTIONS(1081), 1,
      sym_tag,
    ACTIONS(9297), 1,
      anon_sym_LPAREN,
    ACTIONS(9299), 1,
      anon_sym_BANG,
    ACTIONS(9301), 1,
      anon_sym_LBRACK,
    ACTIONS(9303), 1,
      anon_sym_CARET,
    STATE(2265), 1,
      sym_procedure,
    STATE(2483), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2346), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239586] = 22,
    ACTIONS(941), 1,
      sym_identifier,
    ACTIONS(943), 1,
      anon_sym_proc,
    ACTIONS(945), 1,
      anon_sym_struct,
    ACTIONS(947), 1,
      anon_sym_enum,
    ACTIONS(949), 1,
      anon_sym_union,
    ACTIONS(951), 1,
      anon_sym_bit_field,
    ACTIONS(956), 1,
      anon_sym_DOLLAR,
    ACTIONS(963), 1,
      anon_sym_DOT_DOT,
    ACTIONS(968), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(970), 1,
      anon_sym_map,
    ACTIONS(972), 1,
      anon_sym_bit_set,
    ACTIONS(974), 1,
      anon_sym_matrix,
    ACTIONS(976), 1,
      anon_sym_distinct,
    ACTIONS(978), 1,
      sym_tag,
    ACTIONS(9327), 1,
      anon_sym_LPAREN,
    ACTIONS(9329), 1,
      anon_sym_BANG,
    ACTIONS(9331), 1,
      anon_sym_LBRACK,
    ACTIONS(9333), 1,
      anon_sym_CARET,
    STATE(1678), 1,
      sym_type,
    STATE(2182), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(1624), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239673] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8857), 1,
      anon_sym_LBRACK,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    STATE(719), 1,
      sym_procedure,
    STATE(818), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239760] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    ACTIONS(9371), 1,
      sym_tag,
    STATE(2453), 1,
      sym_procedure,
    STATE(2478), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239847] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    STATE(2297), 1,
      sym_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [239934] = 22,
    ACTIONS(323), 1,
      anon_sym_distinct,
    ACTIONS(1467), 1,
      sym_identifier,
    ACTIONS(1469), 1,
      anon_sym_proc,
    ACTIONS(1471), 1,
      anon_sym_struct,
    ACTIONS(1473), 1,
      anon_sym_enum,
    ACTIONS(1475), 1,
      anon_sym_union,
    ACTIONS(1477), 1,
      anon_sym_bit_field,
    ACTIONS(1483), 1,
      anon_sym_DOLLAR,
    ACTIONS(1491), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1497), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1499), 1,
      anon_sym_map,
    ACTIONS(1501), 1,
      anon_sym_bit_set,
    ACTIONS(1503), 1,
      anon_sym_matrix,
    ACTIONS(1505), 1,
      sym_tag,
    ACTIONS(9207), 1,
      anon_sym_LPAREN,
    ACTIONS(9209), 1,
      anon_sym_BANG,
    ACTIONS(9211), 1,
      anon_sym_LBRACK,
    ACTIONS(9213), 1,
      anon_sym_CARET,
    STATE(2805), 1,
      sym_procedure,
    STATE(2827), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2885), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240021] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4903), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4901), 30,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [240070] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    STATE(2453), 1,
      sym_procedure,
    STATE(2493), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240157] = 22,
    ACTIONS(49), 1,
      anon_sym_distinct,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2232), 1,
      anon_sym_proc,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2246), 1,
      anon_sym_DOLLAR,
    ACTIONS(2254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2262), 1,
      anon_sym_map,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2266), 1,
      anon_sym_matrix,
    ACTIONS(2268), 1,
      sym_tag,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9241), 1,
      anon_sym_LBRACK,
    ACTIONS(9243), 1,
      anon_sym_CARET,
    STATE(3909), 1,
      sym_procedure,
    STATE(4088), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240244] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(3131), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240331] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9373), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6748), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240418] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7823), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240505] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3823), 1,
      sym_type,
    STATE(3909), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240592] = 22,
    ACTIONS(2430), 1,
      sym_identifier,
    ACTIONS(2432), 1,
      anon_sym_proc,
    ACTIONS(2434), 1,
      anon_sym_struct,
    ACTIONS(2436), 1,
      anon_sym_enum,
    ACTIONS(2438), 1,
      anon_sym_union,
    ACTIONS(2440), 1,
      anon_sym_bit_field,
    ACTIONS(2446), 1,
      anon_sym_DOLLAR,
    ACTIONS(2454), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2462), 1,
      anon_sym_map,
    ACTIONS(2464), 1,
      anon_sym_bit_set,
    ACTIONS(2466), 1,
      anon_sym_matrix,
    ACTIONS(2468), 1,
      anon_sym_distinct,
    ACTIONS(2470), 1,
      sym_tag,
    ACTIONS(9215), 1,
      anon_sym_LPAREN,
    ACTIONS(9217), 1,
      anon_sym_BANG,
    ACTIONS(9221), 1,
      anon_sym_CARET,
    ACTIONS(9375), 1,
      anon_sym_LBRACK,
    STATE(4282), 1,
      sym_procedure,
    STATE(4341), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4299), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240679] = 22,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(4358), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240766] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6924), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240853] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3919), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [240940] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    STATE(2652), 1,
      sym_procedure,
    STATE(2713), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241027] = 22,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6733), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241114] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(9377), 1,
      sym_tag,
    STATE(3221), 1,
      sym_type,
    STATE(3237), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241201] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6926), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241288] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9379), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6909), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241375] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7920), 1,
      anon_sym_proc,
    ACTIONS(7922), 1,
      anon_sym_DOLLAR,
    ACTIONS(7924), 1,
      anon_sym_LBRACK,
    ACTIONS(7926), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7928), 1,
      anon_sym_CARET,
    ACTIONS(7930), 1,
      anon_sym_map,
    ACTIONS(7932), 1,
      anon_sym_matrix,
    ACTIONS(7934), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9059), 1,
      sym_tag,
    STATE(3034), 1,
      sym_type,
    STATE(3117), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241462] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8203), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241549] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    STATE(2649), 1,
      sym_type,
    STATE(2652), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241636] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3828), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241723] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    ACTIONS(9381), 1,
      anon_sym_LBRACK,
    STATE(3930), 1,
      sym_procedure,
    STATE(7451), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241810] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7443), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241897] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7444), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [241984] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3817), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242071] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(9383), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7449), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242158] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8622), 1,
      anon_sym_proc,
    ACTIONS(8624), 1,
      anon_sym_DOLLAR,
    ACTIONS(8626), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8630), 1,
      anon_sym_CARET,
    ACTIONS(8632), 1,
      anon_sym_map,
    ACTIONS(8634), 1,
      anon_sym_matrix,
    ACTIONS(8636), 1,
      anon_sym_distinct,
    ACTIONS(8638), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(7530), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242245] = 22,
    ACTIONS(2430), 1,
      sym_identifier,
    ACTIONS(2432), 1,
      anon_sym_proc,
    ACTIONS(2434), 1,
      anon_sym_struct,
    ACTIONS(2436), 1,
      anon_sym_enum,
    ACTIONS(2438), 1,
      anon_sym_union,
    ACTIONS(2440), 1,
      anon_sym_bit_field,
    ACTIONS(2446), 1,
      anon_sym_DOLLAR,
    ACTIONS(2454), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2462), 1,
      anon_sym_map,
    ACTIONS(2464), 1,
      anon_sym_bit_set,
    ACTIONS(2466), 1,
      anon_sym_matrix,
    ACTIONS(2468), 1,
      anon_sym_distinct,
    ACTIONS(9215), 1,
      anon_sym_LPAREN,
    ACTIONS(9217), 1,
      anon_sym_BANG,
    ACTIONS(9219), 1,
      anon_sym_LBRACK,
    ACTIONS(9221), 1,
      anon_sym_CARET,
    ACTIONS(9385), 1,
      sym_tag,
    STATE(4282), 1,
      sym_procedure,
    STATE(4338), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4299), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242332] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8253), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242419] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8214), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242506] = 22,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(8503), 1,
      anon_sym_proc,
    ACTIONS(8505), 1,
      anon_sym_DOLLAR,
    ACTIONS(8507), 1,
      anon_sym_LBRACK,
    ACTIONS(8509), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8511), 1,
      anon_sym_CARET,
    ACTIONS(8513), 1,
      anon_sym_map,
    ACTIONS(8515), 1,
      anon_sym_matrix,
    ACTIONS(8517), 1,
      anon_sym_distinct,
    ACTIONS(8519), 1,
      sym_tag,
    STATE(3919), 1,
      sym_type,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242593] = 22,
    ACTIONS(2430), 1,
      sym_identifier,
    ACTIONS(2432), 1,
      anon_sym_proc,
    ACTIONS(2434), 1,
      anon_sym_struct,
    ACTIONS(2436), 1,
      anon_sym_enum,
    ACTIONS(2438), 1,
      anon_sym_union,
    ACTIONS(2440), 1,
      anon_sym_bit_field,
    ACTIONS(2446), 1,
      anon_sym_DOLLAR,
    ACTIONS(2454), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2462), 1,
      anon_sym_map,
    ACTIONS(2464), 1,
      anon_sym_bit_set,
    ACTIONS(2466), 1,
      anon_sym_matrix,
    ACTIONS(2468), 1,
      anon_sym_distinct,
    ACTIONS(2470), 1,
      sym_tag,
    ACTIONS(9215), 1,
      anon_sym_LPAREN,
    ACTIONS(9217), 1,
      anon_sym_BANG,
    ACTIONS(9219), 1,
      anon_sym_LBRACK,
    ACTIONS(9221), 1,
      anon_sym_CARET,
    STATE(4282), 1,
      sym_procedure,
    STATE(4301), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4299), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242680] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8229), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242767] = 22,
    ACTIONS(751), 1,
      anon_sym_distinct,
    ACTIONS(2654), 1,
      sym_identifier,
    ACTIONS(2656), 1,
      anon_sym_proc,
    ACTIONS(2658), 1,
      anon_sym_struct,
    ACTIONS(2660), 1,
      anon_sym_enum,
    ACTIONS(2662), 1,
      anon_sym_union,
    ACTIONS(2664), 1,
      anon_sym_bit_field,
    ACTIONS(2670), 1,
      anon_sym_DOLLAR,
    ACTIONS(2678), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2684), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2686), 1,
      anon_sym_map,
    ACTIONS(2688), 1,
      anon_sym_bit_set,
    ACTIONS(2690), 1,
      anon_sym_matrix,
    ACTIONS(2692), 1,
      sym_tag,
    ACTIONS(9267), 1,
      anon_sym_LPAREN,
    ACTIONS(9269), 1,
      anon_sym_BANG,
    ACTIONS(9271), 1,
      anon_sym_LBRACK,
    ACTIONS(9273), 1,
      anon_sym_CARET,
    STATE(4572), 1,
      sym_procedure,
    STATE(4602), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4568), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242854] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8227), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [242941] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8551), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243028] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8552), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243115] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(7755), 1,
      anon_sym_proc,
    ACTIONS(7757), 1,
      anon_sym_DOLLAR,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(7761), 1,
      anon_sym_LBRACK,
    ACTIONS(7763), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7765), 1,
      anon_sym_CARET,
    ACTIONS(7767), 1,
      anon_sym_map,
    ACTIONS(7769), 1,
      anon_sym_matrix,
    ACTIONS(7771), 1,
      anon_sym_distinct,
    ACTIONS(7773), 1,
      sym_tag,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    STATE(3839), 1,
      sym_procedure,
    STATE(6910), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243202] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8561), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243289] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8580), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243376] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8581), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243463] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7770), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243550] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7771), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243637] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7775), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243724] = 22,
    ACTIONS(941), 1,
      sym_identifier,
    ACTIONS(943), 1,
      anon_sym_proc,
    ACTIONS(945), 1,
      anon_sym_struct,
    ACTIONS(947), 1,
      anon_sym_enum,
    ACTIONS(949), 1,
      anon_sym_union,
    ACTIONS(951), 1,
      anon_sym_bit_field,
    ACTIONS(956), 1,
      anon_sym_DOLLAR,
    ACTIONS(963), 1,
      anon_sym_DOT_DOT,
    ACTIONS(968), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(970), 1,
      anon_sym_map,
    ACTIONS(972), 1,
      anon_sym_bit_set,
    ACTIONS(974), 1,
      anon_sym_matrix,
    ACTIONS(976), 1,
      anon_sym_distinct,
    ACTIONS(978), 1,
      sym_tag,
    ACTIONS(9327), 1,
      anon_sym_LPAREN,
    ACTIONS(9329), 1,
      anon_sym_BANG,
    ACTIONS(9331), 1,
      anon_sym_LBRACK,
    ACTIONS(9333), 1,
      anon_sym_CARET,
    STATE(1519), 1,
      sym_type,
    STATE(2182), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(1624), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243811] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7787), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243898] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7788), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [243985] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7804), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244072] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7805), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244159] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7809), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244246] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7820), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244333] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7821), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244420] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7831), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244507] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7832), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244594] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7837), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244681] = 22,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(9387), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6874), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244768] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7844), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244855] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7845), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [244942] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7850), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245029] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7851), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245116] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    STATE(7102), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245203] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7855), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245290] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7867), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245377] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7868), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245464] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7872), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245551] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7873), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245638] = 22,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(2536), 1,
      anon_sym_struct,
    ACTIONS(2538), 1,
      anon_sym_enum,
    ACTIONS(2540), 1,
      anon_sym_union,
    ACTIONS(2542), 1,
      anon_sym_bit_field,
    ACTIONS(2559), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2563), 1,
      anon_sym_bit_set,
    ACTIONS(7791), 1,
      anon_sym_proc,
    ACTIONS(7793), 1,
      anon_sym_DOLLAR,
    ACTIONS(7795), 1,
      anon_sym_BANG,
    ACTIONS(7797), 1,
      anon_sym_LBRACK,
    ACTIONS(7799), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_CARET,
    ACTIONS(7803), 1,
      anon_sym_map,
    ACTIONS(7805), 1,
      anon_sym_matrix,
    ACTIONS(7807), 1,
      anon_sym_distinct,
    ACTIONS(8903), 1,
      anon_sym_LPAREN,
    ACTIONS(8955), 1,
      sym_tag,
    STATE(4297), 1,
      sym_procedure,
    STATE(6896), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4337), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245725] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7877), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245812] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7921), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245899] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7892), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [245986] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7893), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246073] = 22,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(7512), 1,
      anon_sym_proc,
    ACTIONS(7514), 1,
      anon_sym_DOLLAR,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(7518), 1,
      anon_sym_LBRACK,
    ACTIONS(7520), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7522), 1,
      anon_sym_CARET,
    ACTIONS(7524), 1,
      anon_sym_map,
    ACTIONS(7526), 1,
      anon_sym_matrix,
    ACTIONS(7528), 1,
      anon_sym_distinct,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(9033), 1,
      sym_tag,
    STATE(3117), 1,
      sym_procedure,
    STATE(6763), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246160] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7897), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246247] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7915), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246334] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7916), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246421] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7918), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246508] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7934), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246595] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7935), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246682] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7938), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246769] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7954), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246856] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7955), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [246943] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7957), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247030] = 22,
    ACTIONS(581), 1,
      anon_sym_distinct,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1664), 1,
      anon_sym_proc,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1678), 1,
      anon_sym_DOLLAR,
    ACTIONS(1686), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1694), 1,
      anon_sym_map,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(1698), 1,
      anon_sym_matrix,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8947), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_CARET,
    ACTIONS(8959), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3371), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247117] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7971), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247204] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7972), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247291] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(7975), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247378] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7981), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247465] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(7991), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247552] = 22,
    ACTIONS(1662), 1,
      sym_identifier,
    ACTIONS(1666), 1,
      anon_sym_struct,
    ACTIONS(1668), 1,
      anon_sym_enum,
    ACTIONS(1670), 1,
      anon_sym_union,
    ACTIONS(1672), 1,
      anon_sym_bit_field,
    ACTIONS(1692), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1696), 1,
      anon_sym_bit_set,
    ACTIONS(7302), 1,
      anon_sym_proc,
    ACTIONS(7304), 1,
      anon_sym_DOLLAR,
    ACTIONS(7306), 1,
      anon_sym_BANG,
    ACTIONS(7308), 1,
      anon_sym_LBRACK,
    ACTIONS(7310), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7312), 1,
      anon_sym_CARET,
    ACTIONS(7314), 1,
      anon_sym_map,
    ACTIONS(7316), 1,
      anon_sym_matrix,
    ACTIONS(7318), 1,
      anon_sym_distinct,
    ACTIONS(8915), 1,
      anon_sym_LPAREN,
    ACTIONS(8923), 1,
      sym_tag,
    STATE(3237), 1,
      sym_procedure,
    STATE(3288), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3312), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247639] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2130), 1,
      anon_sym_proc,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2143), 1,
      anon_sym_DOLLAR,
    ACTIONS(2150), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2157), 1,
      anon_sym_map,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2161), 1,
      anon_sym_matrix,
    ACTIONS(2163), 1,
      anon_sym_distinct,
    ACTIONS(2165), 1,
      sym_tag,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9289), 1,
      anon_sym_LBRACK,
    ACTIONS(9291), 1,
      anon_sym_CARET,
    STATE(3839), 1,
      sym_procedure,
    STATE(3921), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247726] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(8429), 1,
      sym_tag,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9203), 1,
      anon_sym_LBRACK,
    STATE(7115), 1,
      sym_procedure,
    STATE(7223), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247813] = 22,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3641), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [247900] = 26,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(7610), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(7608), 4,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
      anon_sym_SEMI,
  [247995] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    ACTIONS(9389), 1,
      sym_tag,
    STATE(2652), 1,
      sym_procedure,
    STATE(2666), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248082] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    STATE(3757), 1,
      sym_procedure,
    STATE(3773), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248169] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8079), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248256] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    STATE(2632), 1,
      sym_type,
    STATE(2652), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248343] = 22,
    ACTIONS(599), 1,
      anon_sym_proc,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(7712), 1,
      anon_sym_DOLLAR,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(7716), 1,
      anon_sym_LBRACK,
    ACTIONS(7718), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7720), 1,
      anon_sym_CARET,
    ACTIONS(7722), 1,
      anon_sym_map,
    ACTIONS(7724), 1,
      anon_sym_matrix,
    ACTIONS(7726), 1,
      anon_sym_distinct,
    ACTIONS(7728), 1,
      sym_tag,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    STATE(3909), 1,
      sym_procedure,
    STATE(6988), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248430] = 22,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7329), 1,
      anon_sym_LBRACK,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(3698), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248517] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8092), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248604] = 22,
    ACTIONS(751), 1,
      anon_sym_distinct,
    ACTIONS(2654), 1,
      sym_identifier,
    ACTIONS(2656), 1,
      anon_sym_proc,
    ACTIONS(2658), 1,
      anon_sym_struct,
    ACTIONS(2660), 1,
      anon_sym_enum,
    ACTIONS(2662), 1,
      anon_sym_union,
    ACTIONS(2664), 1,
      anon_sym_bit_field,
    ACTIONS(2670), 1,
      anon_sym_DOLLAR,
    ACTIONS(2678), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2684), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2686), 1,
      anon_sym_map,
    ACTIONS(2688), 1,
      anon_sym_bit_set,
    ACTIONS(2690), 1,
      anon_sym_matrix,
    ACTIONS(2692), 1,
      sym_tag,
    ACTIONS(9267), 1,
      anon_sym_LPAREN,
    ACTIONS(9269), 1,
      anon_sym_BANG,
    ACTIONS(9271), 1,
      anon_sym_LBRACK,
    ACTIONS(9273), 1,
      anon_sym_CARET,
    STATE(4572), 1,
      sym_procedure,
    STATE(4661), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4568), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248691] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    STATE(719), 1,
      sym_procedure,
    STATE(846), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248778] = 22,
    ACTIONS(941), 1,
      sym_identifier,
    ACTIONS(943), 1,
      anon_sym_proc,
    ACTIONS(945), 1,
      anon_sym_struct,
    ACTIONS(947), 1,
      anon_sym_enum,
    ACTIONS(949), 1,
      anon_sym_union,
    ACTIONS(951), 1,
      anon_sym_bit_field,
    ACTIONS(956), 1,
      anon_sym_DOLLAR,
    ACTIONS(963), 1,
      anon_sym_DOT_DOT,
    ACTIONS(968), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(970), 1,
      anon_sym_map,
    ACTIONS(972), 1,
      anon_sym_bit_set,
    ACTIONS(974), 1,
      anon_sym_matrix,
    ACTIONS(976), 1,
      anon_sym_distinct,
    ACTIONS(978), 1,
      sym_tag,
    ACTIONS(9327), 1,
      anon_sym_LPAREN,
    ACTIONS(9329), 1,
      anon_sym_BANG,
    ACTIONS(9331), 1,
      anon_sym_LBRACK,
    ACTIONS(9333), 1,
      anon_sym_CARET,
    STATE(1705), 1,
      sym_type,
    STATE(2182), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(1624), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248865] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2130), 1,
      anon_sym_proc,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2143), 1,
      anon_sym_DOLLAR,
    ACTIONS(2150), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2157), 1,
      anon_sym_map,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2161), 1,
      anon_sym_matrix,
    ACTIONS(2163), 1,
      anon_sym_distinct,
    ACTIONS(2165), 1,
      sym_tag,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9289), 1,
      anon_sym_LBRACK,
    ACTIONS(9291), 1,
      anon_sym_CARET,
    STATE(3839), 1,
      sym_procedure,
    STATE(3990), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [248952] = 22,
    ACTIONS(941), 1,
      sym_identifier,
    ACTIONS(943), 1,
      anon_sym_proc,
    ACTIONS(945), 1,
      anon_sym_struct,
    ACTIONS(947), 1,
      anon_sym_enum,
    ACTIONS(949), 1,
      anon_sym_union,
    ACTIONS(951), 1,
      anon_sym_bit_field,
    ACTIONS(956), 1,
      anon_sym_DOLLAR,
    ACTIONS(963), 1,
      anon_sym_DOT_DOT,
    ACTIONS(968), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(970), 1,
      anon_sym_map,
    ACTIONS(972), 1,
      anon_sym_bit_set,
    ACTIONS(974), 1,
      anon_sym_matrix,
    ACTIONS(976), 1,
      anon_sym_distinct,
    ACTIONS(978), 1,
      sym_tag,
    ACTIONS(9327), 1,
      anon_sym_LPAREN,
    ACTIONS(9329), 1,
      anon_sym_BANG,
    ACTIONS(9331), 1,
      anon_sym_LBRACK,
    ACTIONS(9333), 1,
      anon_sym_CARET,
    STATE(1456), 1,
      sym_type,
    STATE(2182), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(1624), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249039] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9233), 1,
      anon_sym_LBRACK,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    STATE(3739), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249126] = 22,
    ACTIONS(2430), 1,
      sym_identifier,
    ACTIONS(2432), 1,
      anon_sym_proc,
    ACTIONS(2434), 1,
      anon_sym_struct,
    ACTIONS(2436), 1,
      anon_sym_enum,
    ACTIONS(2438), 1,
      anon_sym_union,
    ACTIONS(2440), 1,
      anon_sym_bit_field,
    ACTIONS(2446), 1,
      anon_sym_DOLLAR,
    ACTIONS(2454), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2462), 1,
      anon_sym_map,
    ACTIONS(2464), 1,
      anon_sym_bit_set,
    ACTIONS(2466), 1,
      anon_sym_matrix,
    ACTIONS(2468), 1,
      anon_sym_distinct,
    ACTIONS(2470), 1,
      sym_tag,
    ACTIONS(9215), 1,
      anon_sym_LPAREN,
    ACTIONS(9217), 1,
      anon_sym_BANG,
    ACTIONS(9219), 1,
      anon_sym_LBRACK,
    ACTIONS(9221), 1,
      anon_sym_CARET,
    STATE(4282), 1,
      sym_procedure,
    STATE(4403), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4299), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249213] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    STATE(719), 1,
      sym_procedure,
    STATE(817), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249300] = 22,
    ACTIONS(151), 1,
      anon_sym_distinct,
    ACTIONS(769), 1,
      sym_identifier,
    ACTIONS(771), 1,
      anon_sym_proc,
    ACTIONS(775), 1,
      anon_sym_struct,
    ACTIONS(777), 1,
      anon_sym_enum,
    ACTIONS(779), 1,
      anon_sym_union,
    ACTIONS(781), 1,
      anon_sym_bit_field,
    ACTIONS(786), 1,
      anon_sym_DOLLAR,
    ACTIONS(793), 1,
      anon_sym_DOT_DOT,
    ACTIONS(798), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(800), 1,
      anon_sym_map,
    ACTIONS(802), 1,
      anon_sym_bit_set,
    ACTIONS(804), 1,
      anon_sym_matrix,
    ACTIONS(8853), 1,
      anon_sym_LPAREN,
    ACTIONS(8855), 1,
      anon_sym_BANG,
    ACTIONS(8859), 1,
      anon_sym_CARET,
    ACTIONS(8861), 1,
      sym_tag,
    ACTIONS(8879), 1,
      anon_sym_LBRACK,
    STATE(719), 1,
      sym_procedure,
    STATE(843), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(802), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249387] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8503), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249474] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8275), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249561] = 22,
    ACTIONS(279), 1,
      anon_sym_distinct,
    ACTIONS(1359), 1,
      sym_identifier,
    ACTIONS(1361), 1,
      anon_sym_proc,
    ACTIONS(1363), 1,
      anon_sym_struct,
    ACTIONS(1365), 1,
      anon_sym_enum,
    ACTIONS(1367), 1,
      anon_sym_union,
    ACTIONS(1369), 1,
      anon_sym_bit_field,
    ACTIONS(1374), 1,
      anon_sym_DOLLAR,
    ACTIONS(1381), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1386), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1388), 1,
      anon_sym_map,
    ACTIONS(1390), 1,
      anon_sym_bit_set,
    ACTIONS(1392), 1,
      anon_sym_matrix,
    ACTIONS(1394), 1,
      sym_tag,
    ACTIONS(9247), 1,
      anon_sym_LPAREN,
    ACTIONS(9249), 1,
      anon_sym_BANG,
    ACTIONS(9251), 1,
      anon_sym_LBRACK,
    ACTIONS(9253), 1,
      anon_sym_CARET,
    STATE(2652), 1,
      sym_procedure,
    STATE(2669), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2661), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249648] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8277), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249735] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8291), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249822] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8294), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249909] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    STATE(2429), 1,
      sym_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [249996] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8305), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [250083] = 22,
    ACTIONS(363), 1,
      anon_sym_distinct,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_proc,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1922), 1,
      anon_sym_DOLLAR,
    ACTIONS(1930), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1938), 1,
      anon_sym_map,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(1942), 1,
      anon_sym_matrix,
    ACTIONS(1944), 1,
      sym_tag,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    ACTIONS(9235), 1,
      anon_sym_CARET,
    ACTIONS(9391), 1,
      anon_sym_LBRACK,
    STATE(3740), 1,
      sym_type,
    STATE(3757), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [250170] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8308), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [250257] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(209), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(207), 30,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [250306] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8319), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [250393] = 22,
    ACTIONS(2128), 1,
      sym_identifier,
    ACTIONS(2130), 1,
      anon_sym_proc,
    ACTIONS(2132), 1,
      anon_sym_struct,
    ACTIONS(2134), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      anon_sym_union,
    ACTIONS(2138), 1,
      anon_sym_bit_field,
    ACTIONS(2143), 1,
      anon_sym_DOLLAR,
    ACTIONS(2150), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2155), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2157), 1,
      anon_sym_map,
    ACTIONS(2159), 1,
      anon_sym_bit_set,
    ACTIONS(2161), 1,
      anon_sym_matrix,
    ACTIONS(2163), 1,
      anon_sym_distinct,
    ACTIONS(2165), 1,
      sym_tag,
    ACTIONS(7759), 1,
      anon_sym_BANG,
    ACTIONS(8216), 1,
      anon_sym_LPAREN,
    ACTIONS(9289), 1,
      anon_sym_LBRACK,
    ACTIONS(9291), 1,
      anon_sym_CARET,
    STATE(3839), 1,
      sym_procedure,
    STATE(3970), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3855), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [250480] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8321), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [250567] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8331), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [250654] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8332), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [250741] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8343), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [250828] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8344), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [250915] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8353), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251002] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8355), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251089] = 22,
    ACTIONS(639), 1,
      anon_sym_distinct,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1957), 1,
      anon_sym_proc,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1971), 1,
      anon_sym_DOLLAR,
    ACTIONS(1979), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1987), 1,
      anon_sym_map,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(1991), 1,
      anon_sym_matrix,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8827), 1,
      anon_sym_CARET,
    ACTIONS(8829), 1,
      sym_tag,
    ACTIONS(8969), 1,
      anon_sym_LBRACK,
    STATE(3570), 1,
      sym_procedure,
    STATE(3698), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251176] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8364), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251263] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8367), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251350] = 22,
    ACTIONS(49), 1,
      anon_sym_distinct,
    ACTIONS(2230), 1,
      sym_identifier,
    ACTIONS(2232), 1,
      anon_sym_proc,
    ACTIONS(2234), 1,
      anon_sym_struct,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2238), 1,
      anon_sym_union,
    ACTIONS(2240), 1,
      anon_sym_bit_field,
    ACTIONS(2246), 1,
      anon_sym_DOLLAR,
    ACTIONS(2254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2260), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2262), 1,
      anon_sym_map,
    ACTIONS(2264), 1,
      anon_sym_bit_set,
    ACTIONS(2266), 1,
      anon_sym_matrix,
    ACTIONS(2268), 1,
      sym_tag,
    ACTIONS(7714), 1,
      anon_sym_BANG,
    ACTIONS(8087), 1,
      anon_sym_LPAREN,
    ACTIONS(9241), 1,
      anon_sym_LBRACK,
    ACTIONS(9243), 1,
      anon_sym_CARET,
    STATE(3909), 1,
      sym_procedure,
    STATE(3971), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3931), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251437] = 22,
    ACTIONS(1955), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_struct,
    ACTIONS(1961), 1,
      anon_sym_enum,
    ACTIONS(1963), 1,
      anon_sym_union,
    ACTIONS(1965), 1,
      anon_sym_bit_field,
    ACTIONS(1985), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1989), 1,
      anon_sym_bit_set,
    ACTIONS(7323), 1,
      anon_sym_proc,
    ACTIONS(7325), 1,
      anon_sym_DOLLAR,
    ACTIONS(7327), 1,
      anon_sym_BANG,
    ACTIONS(7331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7333), 1,
      anon_sym_CARET,
    ACTIONS(7335), 1,
      anon_sym_map,
    ACTIONS(7337), 1,
      anon_sym_matrix,
    ACTIONS(7339), 1,
      anon_sym_distinct,
    ACTIONS(8823), 1,
      anon_sym_LPAREN,
    ACTIONS(8847), 1,
      anon_sym_LBRACK,
    ACTIONS(8849), 1,
      sym_tag,
    STATE(3570), 1,
      sym_procedure,
    STATE(6744), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3604), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251524] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8376), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251611] = 22,
    ACTIONS(941), 1,
      sym_identifier,
    ACTIONS(943), 1,
      anon_sym_proc,
    ACTIONS(945), 1,
      anon_sym_struct,
    ACTIONS(947), 1,
      anon_sym_enum,
    ACTIONS(949), 1,
      anon_sym_union,
    ACTIONS(951), 1,
      anon_sym_bit_field,
    ACTIONS(956), 1,
      anon_sym_DOLLAR,
    ACTIONS(963), 1,
      anon_sym_DOT_DOT,
    ACTIONS(968), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(970), 1,
      anon_sym_map,
    ACTIONS(972), 1,
      anon_sym_bit_set,
    ACTIONS(974), 1,
      anon_sym_matrix,
    ACTIONS(976), 1,
      anon_sym_distinct,
    ACTIONS(978), 1,
      sym_tag,
    ACTIONS(9327), 1,
      anon_sym_LPAREN,
    ACTIONS(9329), 1,
      anon_sym_BANG,
    ACTIONS(9331), 1,
      anon_sym_LBRACK,
    ACTIONS(9333), 1,
      anon_sym_CARET,
    STATE(1710), 1,
      sym_type,
    STATE(2182), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(1624), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251698] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8379), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251785] = 22,
    ACTIONS(751), 1,
      anon_sym_distinct,
    ACTIONS(2654), 1,
      sym_identifier,
    ACTIONS(2656), 1,
      anon_sym_proc,
    ACTIONS(2658), 1,
      anon_sym_struct,
    ACTIONS(2660), 1,
      anon_sym_enum,
    ACTIONS(2662), 1,
      anon_sym_union,
    ACTIONS(2664), 1,
      anon_sym_bit_field,
    ACTIONS(2670), 1,
      anon_sym_DOLLAR,
    ACTIONS(2678), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2684), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2686), 1,
      anon_sym_map,
    ACTIONS(2688), 1,
      anon_sym_bit_set,
    ACTIONS(2690), 1,
      anon_sym_matrix,
    ACTIONS(9267), 1,
      anon_sym_LPAREN,
    ACTIONS(9269), 1,
      anon_sym_BANG,
    ACTIONS(9271), 1,
      anon_sym_LBRACK,
    ACTIONS(9273), 1,
      anon_sym_CARET,
    ACTIONS(9393), 1,
      sym_tag,
    STATE(4569), 1,
      sym_type,
    STATE(4572), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4568), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [251872] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4825), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(4823), 30,
      anon_sym_LBRACE,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_do,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [251921] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8388), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252008] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(3773), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252095] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8391), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252182] = 22,
    ACTIONS(751), 1,
      anon_sym_distinct,
    ACTIONS(2654), 1,
      sym_identifier,
    ACTIONS(2656), 1,
      anon_sym_proc,
    ACTIONS(2658), 1,
      anon_sym_struct,
    ACTIONS(2660), 1,
      anon_sym_enum,
    ACTIONS(2662), 1,
      anon_sym_union,
    ACTIONS(2664), 1,
      anon_sym_bit_field,
    ACTIONS(2670), 1,
      anon_sym_DOLLAR,
    ACTIONS(2678), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2684), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2686), 1,
      anon_sym_map,
    ACTIONS(2688), 1,
      anon_sym_bit_set,
    ACTIONS(2690), 1,
      anon_sym_matrix,
    ACTIONS(2692), 1,
      sym_tag,
    ACTIONS(9267), 1,
      anon_sym_LPAREN,
    ACTIONS(9269), 1,
      anon_sym_BANG,
    ACTIONS(9271), 1,
      anon_sym_LBRACK,
    ACTIONS(9273), 1,
      anon_sym_CARET,
    STATE(4572), 1,
      sym_procedure,
    STATE(4579), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4568), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252269] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8400), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252356] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8402), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252443] = 22,
    ACTIONS(115), 1,
      anon_sym_distinct,
    ACTIONS(1043), 1,
      sym_identifier,
    ACTIONS(1045), 1,
      anon_sym_proc,
    ACTIONS(1047), 1,
      anon_sym_struct,
    ACTIONS(1049), 1,
      anon_sym_enum,
    ACTIONS(1051), 1,
      anon_sym_union,
    ACTIONS(1053), 1,
      anon_sym_bit_field,
    ACTIONS(1059), 1,
      anon_sym_DOLLAR,
    ACTIONS(1067), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1073), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1075), 1,
      anon_sym_map,
    ACTIONS(1077), 1,
      anon_sym_bit_set,
    ACTIONS(1079), 1,
      anon_sym_matrix,
    ACTIONS(1081), 1,
      sym_tag,
    ACTIONS(9297), 1,
      anon_sym_LPAREN,
    ACTIONS(9299), 1,
      anon_sym_BANG,
    ACTIONS(9301), 1,
      anon_sym_LBRACK,
    ACTIONS(9303), 1,
      anon_sym_CARET,
    STATE(2265), 1,
      sym_procedure,
    STATE(2525), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2346), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252530] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8408), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252617] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8416), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252704] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8420), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252791] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8425), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252878] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8444), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [252965] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8471), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253052] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8514), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253139] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8519), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253226] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8526), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253313] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8532), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253400] = 22,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2286), 1,
      anon_sym_struct,
    ACTIONS(2288), 1,
      anon_sym_enum,
    ACTIONS(2290), 1,
      anon_sym_union,
    ACTIONS(2292), 1,
      anon_sym_bit_field,
    ACTIONS(2312), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2316), 1,
      anon_sym_bit_set,
    ACTIONS(5272), 1,
      anon_sym_DOLLAR,
    ACTIONS(6597), 1,
      anon_sym_LPAREN,
    ACTIONS(6599), 1,
      anon_sym_BANG,
    ACTIONS(6603), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6605), 1,
      anon_sym_CARET,
    ACTIONS(6613), 1,
      anon_sym_distinct,
    ACTIONS(6615), 1,
      sym_tag,
    ACTIONS(7775), 1,
      anon_sym_LBRACK,
    ACTIONS(7777), 1,
      anon_sym_map,
    ACTIONS(7779), 1,
      anon_sym_matrix,
    STATE(3930), 1,
      sym_procedure,
    STATE(8537), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3928), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253487] = 22,
    ACTIONS(2430), 1,
      sym_identifier,
    ACTIONS(2432), 1,
      anon_sym_proc,
    ACTIONS(2434), 1,
      anon_sym_struct,
    ACTIONS(2436), 1,
      anon_sym_enum,
    ACTIONS(2438), 1,
      anon_sym_union,
    ACTIONS(2440), 1,
      anon_sym_bit_field,
    ACTIONS(2446), 1,
      anon_sym_DOLLAR,
    ACTIONS(2454), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(2462), 1,
      anon_sym_map,
    ACTIONS(2464), 1,
      anon_sym_bit_set,
    ACTIONS(2466), 1,
      anon_sym_matrix,
    ACTIONS(2468), 1,
      anon_sym_distinct,
    ACTIONS(2470), 1,
      sym_tag,
    ACTIONS(9215), 1,
      anon_sym_LPAREN,
    ACTIONS(9217), 1,
      anon_sym_BANG,
    ACTIONS(9219), 1,
      anon_sym_LBRACK,
    ACTIONS(9221), 1,
      anon_sym_CARET,
    STATE(4282), 1,
      sym_procedure,
    STATE(4371), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(4299), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253574] = 22,
    ACTIONS(323), 1,
      anon_sym_distinct,
    ACTIONS(1467), 1,
      sym_identifier,
    ACTIONS(1469), 1,
      anon_sym_proc,
    ACTIONS(1471), 1,
      anon_sym_struct,
    ACTIONS(1473), 1,
      anon_sym_enum,
    ACTIONS(1475), 1,
      anon_sym_union,
    ACTIONS(1477), 1,
      anon_sym_bit_field,
    ACTIONS(1483), 1,
      anon_sym_DOLLAR,
    ACTIONS(1491), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1497), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1499), 1,
      anon_sym_map,
    ACTIONS(1501), 1,
      anon_sym_bit_set,
    ACTIONS(1503), 1,
      anon_sym_matrix,
    ACTIONS(1505), 1,
      sym_tag,
    ACTIONS(9207), 1,
      anon_sym_LPAREN,
    ACTIONS(9209), 1,
      anon_sym_BANG,
    ACTIONS(9211), 1,
      anon_sym_LBRACK,
    ACTIONS(9213), 1,
      anon_sym_CARET,
    STATE(2805), 1,
      sym_procedure,
    STATE(2934), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2885), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253661] = 22,
    ACTIONS(537), 1,
      anon_sym_distinct,
    ACTIONS(1732), 1,
      sym_identifier,
    ACTIONS(1734), 1,
      anon_sym_proc,
    ACTIONS(1736), 1,
      anon_sym_struct,
    ACTIONS(1738), 1,
      anon_sym_enum,
    ACTIONS(1740), 1,
      anon_sym_union,
    ACTIONS(1742), 1,
      anon_sym_bit_field,
    ACTIONS(1748), 1,
      anon_sym_DOLLAR,
    ACTIONS(1756), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1762), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1764), 1,
      anon_sym_map,
    ACTIONS(1766), 1,
      anon_sym_bit_set,
    ACTIONS(1768), 1,
      anon_sym_matrix,
    ACTIONS(7516), 1,
      anon_sym_BANG,
    ACTIONS(8837), 1,
      anon_sym_LPAREN,
    ACTIONS(8897), 1,
      anon_sym_CARET,
    ACTIONS(8899), 1,
      sym_tag,
    ACTIONS(8929), 1,
      anon_sym_LBRACK,
    STATE(3117), 1,
      sym_procedure,
    STATE(3318), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3122), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253748] = 22,
    ACTIONS(237), 1,
      anon_sym_distinct,
    ACTIONS(1161), 1,
      sym_identifier,
    ACTIONS(1163), 1,
      anon_sym_proc,
    ACTIONS(1165), 1,
      anon_sym_struct,
    ACTIONS(1167), 1,
      anon_sym_enum,
    ACTIONS(1169), 1,
      anon_sym_union,
    ACTIONS(1171), 1,
      anon_sym_bit_field,
    ACTIONS(1176), 1,
      anon_sym_DOLLAR,
    ACTIONS(1183), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1188), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1190), 1,
      anon_sym_map,
    ACTIONS(1192), 1,
      anon_sym_bit_set,
    ACTIONS(1194), 1,
      anon_sym_matrix,
    ACTIONS(8865), 1,
      anon_sym_LPAREN,
    ACTIONS(8867), 1,
      anon_sym_BANG,
    ACTIONS(8871), 1,
      anon_sym_CARET,
    ACTIONS(8873), 1,
      sym_tag,
    ACTIONS(8925), 1,
      anon_sym_LBRACK,
    STATE(2314), 1,
      sym_type,
    STATE(2453), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(2471), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253835] = 22,
    ACTIONS(8393), 1,
      sym_identifier,
    ACTIONS(8395), 1,
      anon_sym_proc,
    ACTIONS(8397), 1,
      anon_sym_struct,
    ACTIONS(8399), 1,
      anon_sym_enum,
    ACTIONS(8401), 1,
      anon_sym_union,
    ACTIONS(8403), 1,
      anon_sym_bit_field,
    ACTIONS(8409), 1,
      anon_sym_DOLLAR,
    ACTIONS(8411), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_LBRACK,
    ACTIONS(8415), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8417), 1,
      anon_sym_CARET,
    ACTIONS(8419), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_map,
    ACTIONS(8423), 1,
      anon_sym_bit_set,
    ACTIONS(8425), 1,
      anon_sym_matrix,
    ACTIONS(8427), 1,
      anon_sym_distinct,
    ACTIONS(9201), 1,
      anon_sym_LPAREN,
    ACTIONS(9395), 1,
      sym_tag,
    STATE(6962), 1,
      sym_type,
    STATE(7115), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7199), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [253922] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8586), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254009] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8587), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254096] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8589), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254183] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8591), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254270] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8592), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254357] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8594), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254444] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8595), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254531] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8596), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254618] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8597), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254705] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8598), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254792] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8599), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254879] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8600), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [254966] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8601), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [255053] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8602), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [255140] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8603), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [255227] = 22,
    ACTIONS(1906), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_struct,
    ACTIONS(1912), 1,
      anon_sym_enum,
    ACTIONS(1914), 1,
      anon_sym_union,
    ACTIONS(1916), 1,
      anon_sym_bit_field,
    ACTIONS(1936), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1940), 1,
      anon_sym_bit_set,
    ACTIONS(8303), 1,
      anon_sym_proc,
    ACTIONS(8305), 1,
      anon_sym_DOLLAR,
    ACTIONS(8307), 1,
      anon_sym_BANG,
    ACTIONS(8309), 1,
      anon_sym_LBRACK,
    ACTIONS(8311), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8313), 1,
      anon_sym_CARET,
    ACTIONS(8315), 1,
      anon_sym_map,
    ACTIONS(8317), 1,
      anon_sym_matrix,
    ACTIONS(8319), 1,
      anon_sym_distinct,
    ACTIONS(8321), 1,
      sym_tag,
    ACTIONS(8487), 1,
      anon_sym_LPAREN,
    STATE(3757), 1,
      sym_procedure,
    STATE(8604), 1,
      sym_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(3789), 19,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_map_type,
      sym_union_type,
      sym_bit_set_type,
      sym_matrix_type,
      sym_field_type,
      sym_tuple_type,
      sym_struct_type,
      sym_enum_type,
      sym_bit_field_type,
      sym_constant_type,
      sym_specialized_type,
      sym__procedure_type,
      sym_distinct_type,
      sym_empty_type,
      sym_polymorphic_type,
      sym_conditional_type,
  [255314] = 4,
    ACTIONS(9397), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255364] = 4,
    ACTIONS(9399), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255414] = 4,
    ACTIONS(9401), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255464] = 4,
    ACTIONS(9404), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255514] = 4,
    ACTIONS(9406), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255564] = 4,
    ACTIONS(9408), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255614] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(9412), 1,
      anon_sym_COMMA,
    STATE(7402), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(9410), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [255710] = 4,
    ACTIONS(9414), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255760] = 4,
    ACTIONS(9416), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255810] = 4,
    ACTIONS(9418), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255860] = 4,
    ACTIONS(9420), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255910] = 4,
    ACTIONS(3762), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [255960] = 4,
    ACTIONS(9422), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256010] = 4,
    ACTIONS(9424), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256060] = 4,
    ACTIONS(3792), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256110] = 4,
    ACTIONS(9426), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256160] = 4,
    ACTIONS(9428), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256210] = 4,
    ACTIONS(9430), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256260] = 4,
    ACTIONS(9432), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256310] = 4,
    ACTIONS(9434), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256360] = 4,
    ACTIONS(9436), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256410] = 4,
    ACTIONS(9438), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256460] = 4,
    ACTIONS(9440), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256510] = 4,
    ACTIONS(3996), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256560] = 4,
    ACTIONS(9442), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256610] = 4,
    ACTIONS(9444), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256660] = 4,
    ACTIONS(9446), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256710] = 4,
    ACTIONS(3565), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256760] = 4,
    ACTIONS(9448), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256810] = 4,
    ACTIONS(9450), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [256860] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(9452), 1,
      anon_sym_COMMA,
    STATE(7365), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3509), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [256956] = 4,
    ACTIONS(9454), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257006] = 4,
    ACTIONS(9456), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257056] = 4,
    ACTIONS(4046), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257106] = 4,
    ACTIONS(9458), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257156] = 4,
    ACTIONS(9460), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257206] = 4,
    ACTIONS(9462), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257256] = 4,
    ACTIONS(9464), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257306] = 29,
    ACTIONS(7144), 1,
      anon_sym_COLON_EQ,
    ACTIONS(7418), 1,
      anon_sym_EQ,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(9466), 1,
      anon_sym_LBRACE,
    STATE(7535), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [257406] = 4,
    ACTIONS(9468), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257456] = 4,
    ACTIONS(9470), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257506] = 4,
    ACTIONS(9472), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257556] = 4,
    ACTIONS(4346), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257606] = 4,
    ACTIONS(9474), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257656] = 26,
    ACTIONS(7610), 1,
      anon_sym_COLON,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(7608), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
  [257750] = 4,
    ACTIONS(9476), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257800] = 4,
    ACTIONS(3595), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257850] = 4,
    ACTIONS(4076), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257900] = 4,
    ACTIONS(9478), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [257950] = 4,
    ACTIONS(9480), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258000] = 4,
    ACTIONS(9482), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258050] = 4,
    ACTIONS(9484), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258100] = 4,
    ACTIONS(9486), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258150] = 4,
    ACTIONS(9488), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258200] = 4,
    ACTIONS(4531), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258250] = 29,
    ACTIONS(7138), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7947), 1,
      anon_sym_DASH_GT,
    ACTIONS(7949), 1,
      anon_sym_PIPE,
    ACTIONS(7951), 1,
      anon_sym_PLUS,
    ACTIONS(7953), 1,
      anon_sym_DASH,
    ACTIONS(7955), 1,
      anon_sym_TILDE,
    ACTIONS(7957), 1,
      anon_sym_AMP,
    ACTIONS(7961), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7969), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(7977), 1,
      anon_sym_DOT,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7987), 1,
      anon_sym_or_break,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(9492), 1,
      anon_sym_COLON,
    ACTIONS(9494), 1,
      anon_sym_COLON_EQ,
    STATE(7476), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(7959), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(7963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(7965), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7971), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7973), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(7975), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7981), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8091), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7967), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [258350] = 29,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9357), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(9496), 1,
      anon_sym_COLON,
    ACTIONS(9498), 1,
      anon_sym_COLON_EQ,
    STATE(7364), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [258450] = 4,
    ACTIONS(9500), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258500] = 4,
    ACTIONS(9502), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258550] = 4,
    ACTIONS(9504), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258600] = 4,
    ACTIONS(9506), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258650] = 4,
    ACTIONS(9508), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258700] = 4,
    ACTIONS(9510), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258750] = 4,
    ACTIONS(9512), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258800] = 4,
    ACTIONS(9514), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258850] = 4,
    ACTIONS(3541), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258900] = 4,
    ACTIONS(9516), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [258950] = 4,
    ACTIONS(9518), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259000] = 4,
    ACTIONS(9520), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259050] = 4,
    ACTIONS(9522), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259100] = 4,
    ACTIONS(9524), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259150] = 4,
    ACTIONS(9526), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259200] = 29,
    ACTIONS(7144), 1,
      anon_sym_COLON_EQ,
    ACTIONS(7418), 1,
      anon_sym_EQ,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(9528), 1,
      anon_sym_LBRACE,
    STATE(7535), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [259300] = 4,
    ACTIONS(9530), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259350] = 4,
    ACTIONS(9532), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259400] = 4,
    ACTIONS(9534), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259450] = 4,
    ACTIONS(9536), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259500] = 4,
    ACTIONS(9538), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259550] = 4,
    ACTIONS(4106), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259600] = 4,
    ACTIONS(4605), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259650] = 4,
    ACTIONS(3862), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259700] = 4,
    ACTIONS(9540), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259750] = 4,
    ACTIONS(9542), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259800] = 4,
    ACTIONS(9544), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259850] = 4,
    ACTIONS(9546), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259900] = 4,
    ACTIONS(9548), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [259950] = 4,
    ACTIONS(9550), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260000] = 4,
    ACTIONS(9552), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260050] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7012), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(8811), 3,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [260146] = 4,
    ACTIONS(9554), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260196] = 4,
    ACTIONS(4376), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260246] = 4,
    ACTIONS(9556), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260296] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(9558), 1,
      anon_sym_COMMA,
    STATE(7523), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3366), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [260392] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7026), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(9560), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [260488] = 4,
    ACTIONS(4136), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260538] = 4,
    ACTIONS(9562), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260588] = 4,
    ACTIONS(9564), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260638] = 4,
    ACTIONS(9566), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260688] = 4,
    ACTIONS(9568), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260738] = 4,
    ACTIONS(9570), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260788] = 4,
    ACTIONS(9572), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260838] = 4,
    ACTIONS(9574), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260888] = 4,
    ACTIONS(3832), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260938] = 4,
    ACTIONS(9576), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [260988] = 4,
    ACTIONS(9578), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261038] = 4,
    ACTIONS(9580), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261088] = 4,
    ACTIONS(9582), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261138] = 4,
    ACTIONS(4166), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261188] = 4,
    ACTIONS(9584), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261238] = 4,
    ACTIONS(9586), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261288] = 4,
    ACTIONS(9588), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261338] = 4,
    ACTIONS(9591), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261388] = 4,
    ACTIONS(9593), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261438] = 4,
    ACTIONS(9595), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261488] = 4,
    ACTIONS(9597), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261538] = 4,
    ACTIONS(4016), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261588] = 4,
    ACTIONS(9599), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261638] = 4,
    ACTIONS(9601), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261688] = 4,
    ACTIONS(9603), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261738] = 4,
    ACTIONS(4434), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261788] = 4,
    ACTIONS(9605), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261838] = 4,
    ACTIONS(9607), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261888] = 4,
    ACTIONS(9609), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261938] = 4,
    ACTIONS(9611), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [261988] = 4,
    ACTIONS(9613), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262038] = 4,
    ACTIONS(9615), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262088] = 4,
    ACTIONS(9617), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262138] = 4,
    ACTIONS(3936), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262188] = 4,
    ACTIONS(4226), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262238] = 4,
    ACTIONS(9619), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262288] = 4,
    ACTIONS(3896), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262338] = 4,
    ACTIONS(9621), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262388] = 4,
    ACTIONS(9623), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262438] = 4,
    ACTIONS(9625), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262488] = 4,
    ACTIONS(9627), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262538] = 4,
    ACTIONS(9629), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262588] = 4,
    ACTIONS(9631), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262638] = 4,
    ACTIONS(3722), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262688] = 4,
    ACTIONS(4256), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262738] = 4,
    ACTIONS(9633), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262788] = 4,
    ACTIONS(9635), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262838] = 4,
    ACTIONS(9637), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262888] = 4,
    ACTIONS(9639), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262938] = 4,
    ACTIONS(9642), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [262988] = 4,
    ACTIONS(9644), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263038] = 4,
    ACTIONS(9647), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263088] = 4,
    ACTIONS(3966), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263138] = 4,
    ACTIONS(9649), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263188] = 4,
    ACTIONS(9652), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263238] = 4,
    ACTIONS(4286), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263288] = 4,
    ACTIONS(9654), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263338] = 4,
    ACTIONS(9657), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263388] = 4,
    ACTIONS(9659), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263438] = 4,
    ACTIONS(9661), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263488] = 4,
    ACTIONS(9664), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263538] = 4,
    ACTIONS(9666), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263588] = 4,
    ACTIONS(9669), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263638] = 4,
    ACTIONS(9671), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263688] = 4,
    ACTIONS(9673), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263738] = 4,
    ACTIONS(9675), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263788] = 4,
    ACTIONS(9678), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263838] = 4,
    ACTIONS(9680), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263888] = 4,
    ACTIONS(9683), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263938] = 4,
    ACTIONS(9686), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [263988] = 4,
    ACTIONS(9688), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264038] = 4,
    ACTIONS(9690), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264088] = 4,
    ACTIONS(3695), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264138] = 4,
    ACTIONS(9692), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264188] = 4,
    ACTIONS(9695), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264238] = 4,
    ACTIONS(4196), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264288] = 4,
    ACTIONS(9698), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264338] = 4,
    ACTIONS(9700), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264388] = 4,
    ACTIONS(3635), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264438] = 4,
    ACTIONS(9702), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264488] = 4,
    ACTIONS(9704), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264538] = 4,
    ACTIONS(9706), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264588] = 4,
    ACTIONS(9708), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264638] = 4,
    ACTIONS(9710), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264688] = 4,
    ACTIONS(9712), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264738] = 4,
    ACTIONS(9714), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264788] = 4,
    ACTIONS(9716), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264838] = 4,
    ACTIONS(4316), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [264888] = 27,
    ACTIONS(7979), 1,
      anon_sym_LBRACK,
    ACTIONS(7983), 1,
      anon_sym_or_return,
    ACTIONS(7985), 1,
      anon_sym_or_continue,
    ACTIONS(7989), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_DASH_GT,
    ACTIONS(8365), 1,
      anon_sym_PIPE,
    ACTIONS(8367), 1,
      anon_sym_PLUS,
    ACTIONS(8369), 1,
      anon_sym_DASH,
    ACTIONS(8371), 1,
      anon_sym_TILDE,
    ACTIONS(8373), 1,
      anon_sym_AMP,
    ACTIONS(8377), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8385), 1,
      anon_sym_DOT,
    ACTIONS(8439), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8445), 1,
      anon_sym_or_break,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7043), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8379), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8381), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8383), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8387), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8435), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8437), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8441), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8443), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8375), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(9718), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [264984] = 4,
    ACTIONS(9720), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [265034] = 4,
    ACTIONS(4396), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [265084] = 4,
    ACTIONS(9722), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3917), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(3912), 28,
      anon_sym_DASH_GT,
      anon_sym_LPAREN,
      anon_sym_if,
      anon_sym_when,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [265134] = 29,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(9724), 1,
      anon_sym_EQ,
    ACTIONS(9726), 1,
      anon_sym_COLON,
    ACTIONS(9728), 1,
      anon_sym_COLON_EQ,
    STATE(7393), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [265234] = 27,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(9732), 1,
      anon_sym_COMMA,
    STATE(7543), 1,
      aux_sym__simple_assignment_statement_repeat1,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(9730), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [265329] = 6,
    ACTIONS(6810), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [265382] = 6,
    ACTIONS(6447), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [265435] = 6,
    ACTIONS(7480), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [265488] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9734), 1,
      anon_sym_COMMA,
    ACTIONS(9736), 1,
      anon_sym_EQ,
    ACTIONS(9738), 1,
      anon_sym_RPAREN,
    STATE(7993), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [265585] = 6,
    ACTIONS(6617), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [265638] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9740), 1,
      anon_sym_COMMA,
    ACTIONS(9742), 1,
      anon_sym_EQ,
    ACTIONS(9744), 1,
      anon_sym_RPAREN,
    STATE(7766), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [265735] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9740), 1,
      anon_sym_COMMA,
    ACTIONS(9742), 1,
      anon_sym_EQ,
    ACTIONS(9744), 1,
      anon_sym_RPAREN,
    STATE(8234), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [265832] = 28,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(9746), 1,
      anon_sym_EQ,
    ACTIONS(9748), 1,
      anon_sym_COLON_EQ,
    STATE(7534), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [265929] = 6,
    ACTIONS(3880), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [265982] = 28,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(9724), 1,
      anon_sym_EQ,
    ACTIONS(9728), 1,
      anon_sym_COLON_EQ,
    STATE(7583), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [266079] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9734), 1,
      anon_sym_COMMA,
    ACTIONS(9736), 1,
      anon_sym_EQ,
    ACTIONS(9750), 1,
      anon_sym_RPAREN,
    STATE(7993), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [266176] = 6,
    ACTIONS(6756), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [266229] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9752), 1,
      anon_sym_COMMA,
    ACTIONS(9754), 1,
      anon_sym_EQ,
    ACTIONS(9756), 1,
      anon_sym_RPAREN,
    STATE(8370), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [266326] = 6,
    ACTIONS(6472), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [266379] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9758), 1,
      anon_sym_COMMA,
    ACTIONS(9760), 1,
      anon_sym_EQ,
    ACTIONS(9762), 1,
      anon_sym_RPAREN,
    STATE(8575), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [266476] = 6,
    ACTIONS(7832), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [266529] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9764), 1,
      anon_sym_COMMA,
    ACTIONS(9766), 1,
      anon_sym_EQ,
    ACTIONS(9768), 1,
      anon_sym_RPAREN,
    STATE(8610), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [266626] = 6,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(8031), 1,
      anon_sym_LPAREN,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [266679] = 28,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(9770), 1,
      anon_sym_EQ,
    ACTIONS(9772), 1,
      anon_sym_COLON_EQ,
    STATE(7584), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [266776] = 27,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(9732), 1,
      anon_sym_COMMA,
    STATE(7591), 1,
      aux_sym__simple_assignment_statement_repeat1,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(9774), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [266871] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9776), 1,
      anon_sym_COMMA,
    ACTIONS(9778), 1,
      anon_sym_EQ,
    ACTIONS(9780), 1,
      anon_sym_RPAREN,
    STATE(7881), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [266968] = 28,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(9782), 1,
      anon_sym_EQ,
    ACTIONS(9784), 1,
      anon_sym_COLON_EQ,
    STATE(7556), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [267065] = 28,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(9359), 1,
      anon_sym_EQ,
    ACTIONS(9363), 1,
      anon_sym_COLON_EQ,
    STATE(7629), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [267162] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9786), 1,
      anon_sym_COMMA,
    ACTIONS(9788), 1,
      anon_sym_EQ,
    ACTIONS(9790), 1,
      anon_sym_RPAREN,
    STATE(8009), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [267259] = 6,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(8457), 1,
      anon_sym_LPAREN,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [267312] = 28,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(9792), 1,
      anon_sym_SEMI,
    ACTIONS(9794), 1,
      anon_sym_do,
    STATE(7146), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [267409] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9796), 1,
      anon_sym_COMMA,
    ACTIONS(9798), 1,
      anon_sym_EQ,
    ACTIONS(9800), 1,
      anon_sym_RPAREN,
    STATE(8336), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [267506] = 6,
    ACTIONS(7173), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [267559] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9802), 1,
      anon_sym_COMMA,
    ACTIONS(9804), 1,
      anon_sym_EQ,
    ACTIONS(9806), 1,
      anon_sym_RPAREN,
    STATE(8507), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [267656] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9734), 1,
      anon_sym_COMMA,
    ACTIONS(9736), 1,
      anon_sym_EQ,
    ACTIONS(9738), 1,
      anon_sym_RPAREN,
    STATE(8334), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [267753] = 6,
    ACTIONS(6686), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [267806] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9808), 1,
      anon_sym_COMMA,
    ACTIONS(9810), 1,
      anon_sym_EQ,
    ACTIONS(9812), 1,
      anon_sym_RPAREN,
    STATE(8083), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [267903] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9814), 1,
      anon_sym_COMMA,
    ACTIONS(9816), 1,
      anon_sym_EQ,
    ACTIONS(9818), 1,
      anon_sym_RPAREN,
    STATE(8097), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [268000] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9820), 1,
      anon_sym_COMMA,
    ACTIONS(9822), 1,
      anon_sym_EQ,
    ACTIONS(9824), 1,
      anon_sym_RPAREN,
    STATE(8560), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [268097] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9826), 1,
      anon_sym_COMMA,
    ACTIONS(9828), 1,
      anon_sym_EQ,
    ACTIONS(9830), 1,
      anon_sym_RPAREN,
    STATE(7760), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [268194] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9832), 1,
      anon_sym_COMMA,
    ACTIONS(9834), 1,
      anon_sym_EQ,
    ACTIONS(9836), 1,
      anon_sym_RPAREN,
    STATE(8222), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [268291] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9740), 1,
      anon_sym_COMMA,
    ACTIONS(9742), 1,
      anon_sym_EQ,
    ACTIONS(9838), 1,
      anon_sym_RPAREN,
    STATE(8234), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [268388] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9814), 1,
      anon_sym_COMMA,
    ACTIONS(9816), 1,
      anon_sym_EQ,
    ACTIONS(9818), 1,
      anon_sym_RPAREN,
    STATE(8094), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [268485] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9840), 1,
      anon_sym_COMMA,
    ACTIONS(9842), 1,
      anon_sym_EQ,
    ACTIONS(9844), 1,
      anon_sym_RPAREN,
    STATE(8108), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [268582] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(9846), 18,
      anon_sym_package,
      anon_sym_foreign,
      anon_sym_import,
      anon_sym_using,
      anon_sym_when,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_cast,
      anon_sym_transmute,
      anon_sym_auto_cast,
      anon_sym_map,
      anon_sym_bit_set,
      anon_sym_matrix,
      anon_sym_distinct,
      anon_sym_true,
      anon_sym_false,
      sym_nil,
      sym_identifier,
    ACTIONS(1569), 19,
      sym_float,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_POUND_PLUS,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT,
      sym_number,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      anon_sym_SQUOTE,
      sym_uninitialized,
      sym_tag,
  [268629] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9820), 1,
      anon_sym_COMMA,
    ACTIONS(9822), 1,
      anon_sym_EQ,
    ACTIONS(9848), 1,
      anon_sym_RPAREN,
    STATE(8560), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [268726] = 27,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(9850), 1,
      anon_sym_COMMA,
    STATE(7668), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8813), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [268821] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9852), 1,
      anon_sym_COMMA,
    ACTIONS(9854), 1,
      anon_sym_EQ,
    ACTIONS(9856), 1,
      anon_sym_RPAREN,
    STATE(8172), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [268918] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9858), 1,
      anon_sym_COMMA,
    ACTIONS(9860), 1,
      anon_sym_EQ,
    ACTIONS(9862), 1,
      anon_sym_RPAREN,
    STATE(7880), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [269015] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9864), 1,
      anon_sym_COMMA,
    ACTIONS(9866), 1,
      anon_sym_EQ,
    ACTIONS(9868), 1,
      anon_sym_RPAREN,
    STATE(7989), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [269112] = 28,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_do,
    STATE(7146), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [269209] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9874), 1,
      anon_sym_COMMA,
    ACTIONS(9876), 1,
      anon_sym_EQ,
    ACTIONS(9878), 1,
      anon_sym_RPAREN,
    STATE(8196), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [269306] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9880), 1,
      anon_sym_COMMA,
    ACTIONS(9882), 1,
      anon_sym_EQ,
    ACTIONS(9884), 1,
      anon_sym_RPAREN,
    STATE(8489), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [269403] = 27,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(9732), 1,
      anon_sym_COMMA,
    STATE(7748), 1,
      aux_sym__simple_assignment_statement_repeat1,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(9886), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [269498] = 6,
    ACTIONS(7057), 1,
      anon_sym_LPAREN,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [269551] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9858), 1,
      anon_sym_COMMA,
    ACTIONS(9860), 1,
      anon_sym_EQ,
    ACTIONS(9888), 1,
      anon_sym_RPAREN,
    STATE(8181), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [269648] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9890), 1,
      anon_sym_COMMA,
    ACTIONS(9892), 1,
      anon_sym_EQ,
    ACTIONS(9894), 1,
      anon_sym_RPAREN,
    STATE(8368), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [269745] = 6,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(8297), 1,
      anon_sym_LPAREN,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [269798] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9820), 1,
      anon_sym_COMMA,
    ACTIONS(9822), 1,
      anon_sym_EQ,
    ACTIONS(9824), 1,
      anon_sym_RPAREN,
    STATE(8159), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [269895] = 6,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(8226), 1,
      anon_sym_LPAREN,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [269948] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9896), 1,
      anon_sym_COMMA,
    ACTIONS(9898), 1,
      anon_sym_EQ,
    ACTIONS(9900), 1,
      anon_sym_RPAREN,
    STATE(7966), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [270045] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9902), 1,
      anon_sym_COMMA,
    ACTIONS(9904), 1,
      anon_sym_EQ,
    ACTIONS(9906), 1,
      anon_sym_RPAREN,
    STATE(8313), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [270142] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9908), 1,
      anon_sym_COMMA,
    ACTIONS(9910), 1,
      anon_sym_EQ,
    ACTIONS(9912), 1,
      anon_sym_RPAREN,
    STATE(7905), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [270239] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9776), 1,
      anon_sym_COMMA,
    ACTIONS(9778), 1,
      anon_sym_EQ,
    ACTIONS(9914), 1,
      anon_sym_RPAREN,
    STATE(7881), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [270336] = 27,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(9850), 1,
      anon_sym_COMMA,
    STATE(7587), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8789), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [270431] = 6,
    ACTIONS(7907), 1,
      anon_sym_QMARK,
    ACTIONS(8468), 1,
      anon_sym_LPAREN,
    ACTIONS(7905), 2,
      anon_sym_if,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 9,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
    ACTIONS(69), 24,
      anon_sym_DASH_GT,
      anon_sym_in,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
      anon_sym_CARET,
  [270484] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9814), 1,
      anon_sym_COMMA,
    ACTIONS(9816), 1,
      anon_sym_EQ,
    ACTIONS(9916), 1,
      anon_sym_RPAREN,
    STATE(8094), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [270581] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9918), 1,
      anon_sym_COMMA,
    ACTIONS(9920), 1,
      anon_sym_EQ,
    ACTIONS(9922), 1,
      anon_sym_RPAREN,
    STATE(8117), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [270678] = 28,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9924), 1,
      anon_sym_COMMA,
    ACTIONS(9926), 1,
      anon_sym_EQ,
    ACTIONS(9928), 1,
      anon_sym_RPAREN,
    STATE(8158), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [270775] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9930), 1,
      anon_sym_RBRACE,
    ACTIONS(9932), 1,
      anon_sym_COMMA,
    STATE(7793), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [270869] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9934), 1,
      anon_sym_RBRACE,
    ACTIONS(9936), 1,
      anon_sym_COMMA,
    STATE(8099), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [270963] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9938), 1,
      anon_sym_COMMA,
    ACTIONS(9940), 1,
      anon_sym_RPAREN,
    STATE(8432), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271057] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9942), 1,
      anon_sym_RBRACE,
    ACTIONS(9944), 1,
      anon_sym_COMMA,
    STATE(8266), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271151] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8797), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7859), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271245] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(9948), 1,
      anon_sym_RBRACE,
    STATE(8145), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271339] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(9950), 1,
      anon_sym_RBRACE,
    STATE(8274), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271433] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9952), 1,
      anon_sym_RBRACE,
    ACTIONS(9954), 1,
      anon_sym_COMMA,
    STATE(8250), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271527] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9956), 1,
      anon_sym_RBRACE,
    ACTIONS(9958), 1,
      anon_sym_COMMA,
    STATE(8286), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271621] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9960), 1,
      anon_sym_RBRACE,
    ACTIONS(9962), 1,
      anon_sym_COMMA,
    STATE(8295), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271715] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9964), 1,
      anon_sym_RBRACE,
    ACTIONS(9966), 1,
      anon_sym_COMMA,
    STATE(8300), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271809] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9968), 1,
      anon_sym_RBRACE,
    ACTIONS(9970), 1,
      anon_sym_COMMA,
    STATE(8101), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271903] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9972), 1,
      anon_sym_RBRACE,
    ACTIONS(9974), 1,
      anon_sym_COMMA,
    STATE(8429), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [271997] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9976), 1,
      anon_sym_RBRACE,
    ACTIONS(9978), 1,
      anon_sym_COMMA,
    STATE(8259), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [272091] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9980), 1,
      anon_sym_RBRACE,
    ACTIONS(9982), 1,
      anon_sym_COMMA,
    STATE(8260), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [272185] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9984), 1,
      anon_sym_RBRACE,
    ACTIONS(9986), 1,
      anon_sym_COMMA,
    STATE(8346), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [272279] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8789), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7863), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [272373] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9988), 1,
      anon_sym_COMMA,
    ACTIONS(9990), 1,
      anon_sym_COLON,
    ACTIONS(9992), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [272467] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9994), 1,
      anon_sym_COMMA,
    ACTIONS(9996), 1,
      anon_sym_COLON,
    ACTIONS(9998), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [272561] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10000), 1,
      anon_sym_RBRACE,
    ACTIONS(10002), 1,
      anon_sym_COMMA,
    STATE(8357), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [272655] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10004), 1,
      anon_sym_COMMA,
    ACTIONS(10006), 1,
      anon_sym_RPAREN,
    STATE(8529), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [272749] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10008), 1,
      anon_sym_COMMA,
    ACTIONS(10010), 1,
      anon_sym_RPAREN,
    STATE(7932), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [272843] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10012), 1,
      anon_sym_RBRACE,
    ACTIONS(10014), 1,
      anon_sym_COMMA,
    STATE(8136), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [272937] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10016), 1,
      anon_sym_RBRACE,
    ACTIONS(10018), 1,
      anon_sym_COMMA,
    STATE(8128), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273031] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10020), 1,
      anon_sym_RBRACE,
    ACTIONS(10022), 1,
      anon_sym_COMMA,
    STATE(8509), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273125] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8783), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7848), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273219] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10024), 1,
      anon_sym_COMMA,
    ACTIONS(10026), 1,
      anon_sym_RPAREN,
    STATE(8139), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273313] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10028), 1,
      anon_sym_do,
    STATE(6978), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273407] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10030), 1,
      anon_sym_RBRACE,
    ACTIONS(10032), 1,
      anon_sym_COMMA,
    STATE(8261), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273501] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10034), 1,
      anon_sym_do,
    STATE(6984), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273595] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10036), 1,
      anon_sym_RBRACE,
    ACTIONS(10038), 1,
      anon_sym_COMMA,
    STATE(8534), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273689] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10040), 1,
      anon_sym_RBRACE,
    ACTIONS(10042), 1,
      anon_sym_COMMA,
    STATE(8262), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273783] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10044), 1,
      anon_sym_RBRACE,
    ACTIONS(10046), 1,
      anon_sym_COMMA,
    STATE(8549), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273877] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10048), 1,
      anon_sym_do,
    STATE(6943), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [273971] = 25,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7608), 3,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_do,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274061] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10050), 1,
      anon_sym_RBRACE,
    ACTIONS(10052), 1,
      anon_sym_COMMA,
    STATE(8419), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274155] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10054), 1,
      anon_sym_RBRACE,
    STATE(8135), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274249] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10056), 1,
      anon_sym_COMMA,
    ACTIONS(10058), 1,
      anon_sym_RPAREN,
    STATE(8518), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274343] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10060), 1,
      anon_sym_RBRACE,
    STATE(8037), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274437] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10062), 1,
      anon_sym_EQ,
    ACTIONS(7136), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274529] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10064), 1,
      anon_sym_RBRACE,
    STATE(8243), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274623] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10066), 1,
      anon_sym_RBRACE,
    ACTIONS(10068), 1,
      anon_sym_COMMA,
    STATE(8297), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274717] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10070), 1,
      anon_sym_do,
    STATE(7096), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274811] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10072), 1,
      anon_sym_COMMA,
    ACTIONS(10074), 1,
      anon_sym_COLON,
    ACTIONS(10076), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274905] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10078), 1,
      anon_sym_RBRACE,
    ACTIONS(10080), 1,
      anon_sym_COMMA,
    STATE(8151), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [274999] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10082), 1,
      anon_sym_RBRACE,
    ACTIONS(10084), 1,
      anon_sym_COMMA,
    STATE(8533), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [275093] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10086), 1,
      anon_sym_RBRACE,
    STATE(8032), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [275187] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10088), 1,
      anon_sym_RBRACE,
    ACTIONS(10090), 1,
      anon_sym_COMMA,
    STATE(7895), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [275281] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10092), 1,
      anon_sym_RBRACE,
    STATE(8523), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [275375] = 27,
    ACTIONS(6288), 1,
      anon_sym_RBRACE,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10094), 1,
      anon_sym_COMMA,
    STATE(8111), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [275469] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10096), 1,
      anon_sym_RBRACE,
    ACTIONS(10098), 1,
      anon_sym_COMMA,
    STATE(8279), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [275563] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10100), 1,
      anon_sym_RBRACE,
    STATE(8026), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [275657] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10102), 1,
      anon_sym_COMMA,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10106), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [275751] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10108), 1,
      anon_sym_RBRACE,
    ACTIONS(10110), 1,
      anon_sym_COMMA,
    STATE(8150), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [275845] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10112), 1,
      anon_sym_do,
    STATE(7042), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [275939] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10114), 1,
      anon_sym_COMMA,
    ACTIONS(10116), 1,
      anon_sym_COLON,
    ACTIONS(10118), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276033] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10120), 1,
      anon_sym_COMMA,
    ACTIONS(10122), 1,
      anon_sym_RPAREN,
    STATE(8127), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276127] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10124), 1,
      anon_sym_RBRACE,
    ACTIONS(10126), 1,
      anon_sym_COMMA,
    STATE(8428), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276221] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10128), 1,
      anon_sym_COMMA,
    ACTIONS(10130), 1,
      anon_sym_RPAREN,
    STATE(8021), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276315] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10132), 1,
      anon_sym_RBRACE,
    ACTIONS(10134), 1,
      anon_sym_COMMA,
    STATE(8076), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276409] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10136), 1,
      anon_sym_RBRACE,
    STATE(8241), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276503] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10138), 1,
      anon_sym_RBRACE,
    ACTIONS(10140), 1,
      anon_sym_COMMA,
    STATE(8084), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276597] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10142), 1,
      anon_sym_COMMA,
    ACTIONS(10144), 1,
      anon_sym_RPAREN,
    STATE(7782), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276691] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10146), 1,
      anon_sym_RBRACE,
    ACTIONS(10148), 1,
      anon_sym_COMMA,
    STATE(8027), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276785] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10150), 1,
      anon_sym_RBRACE,
    ACTIONS(10152), 1,
      anon_sym_COMMA,
    STATE(8090), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276879] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8779), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7899), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [276973] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8801), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7925), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [277067] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10154), 1,
      anon_sym_RBRACE,
    ACTIONS(10156), 1,
      anon_sym_COMMA,
    STATE(7901), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [277161] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10158), 1,
      anon_sym_COMMA,
    ACTIONS(10160), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [277255] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8809), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7941), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [277349] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10164), 1,
      anon_sym_COMMA,
    ACTIONS(10166), 1,
      anon_sym_COLON,
    ACTIONS(10168), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [277443] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10170), 1,
      anon_sym_COMMA,
    ACTIONS(10172), 1,
      anon_sym_RPAREN,
    STATE(7924), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [277537] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10174), 1,
      anon_sym_RBRACE,
    STATE(7792), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [277631] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10176), 1,
      anon_sym_COMMA,
    ACTIONS(10178), 1,
      anon_sym_RPAREN,
    STATE(8166), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [277725] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10180), 1,
      anon_sym_do,
    STATE(7044), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [277819] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10182), 1,
      anon_sym_RBRACE,
    ACTIONS(10184), 1,
      anon_sym_COMMA,
    STATE(7857), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [277913] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8813), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7783), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278007] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10186), 1,
      anon_sym_RBRACE,
    STATE(7942), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278101] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10188), 1,
      anon_sym_RBRACE,
    ACTIONS(10190), 1,
      anon_sym_COMMA,
    STATE(8242), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278195] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10192), 1,
      anon_sym_RBRACE,
    ACTIONS(10194), 1,
      anon_sym_COMMA,
    STATE(8475), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278289] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10196), 1,
      anon_sym_RBRACE,
    STATE(8421), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278383] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10198), 1,
      anon_sym_COMMA,
    ACTIONS(10200), 1,
      anon_sym_RPAREN,
    STATE(7797), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278477] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10202), 1,
      anon_sym_COMMA,
    ACTIONS(10204), 1,
      anon_sym_RPAREN,
    STATE(8254), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278571] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10206), 1,
      anon_sym_RBRACE,
    ACTIONS(10208), 1,
      anon_sym_COMMA,
    STATE(7914), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278665] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8799), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7943), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278759] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10210), 1,
      anon_sym_RBRACE,
    ACTIONS(10212), 1,
      anon_sym_COMMA,
    STATE(8445), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278853] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10214), 1,
      anon_sym_RBRACE,
    STATE(8536), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [278947] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10216), 1,
      anon_sym_RBRACE,
    ACTIONS(10218), 1,
      anon_sym_COMMA,
    STATE(8404), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279041] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10220), 1,
      anon_sym_do,
    STATE(7271), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279135] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10222), 1,
      anon_sym_COMMA,
    ACTIONS(10224), 1,
      anon_sym_COLON,
    STATE(7960), 1,
      aux_sym_switch_case_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279229] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10226), 1,
      anon_sym_RBRACE,
    ACTIONS(10228), 1,
      anon_sym_COMMA,
    STATE(8040), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279323] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10230), 1,
      anon_sym_RBRACE,
    STATE(7928), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279417] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10232), 1,
      anon_sym_RBRACE,
    ACTIONS(10234), 1,
      anon_sym_COMMA,
    STATE(8052), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279511] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10236), 1,
      anon_sym_RBRACE,
    ACTIONS(10238), 1,
      anon_sym_COMMA,
    STATE(7947), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279605] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10240), 1,
      anon_sym_COMMA,
    ACTIONS(10242), 1,
      anon_sym_RPAREN,
    STATE(8411), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279699] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10244), 1,
      anon_sym_RBRACE,
    ACTIONS(10246), 1,
      anon_sym_COMMA,
    STATE(7802), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279793] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10248), 1,
      anon_sym_COMMA,
    ACTIONS(10250), 1,
      anon_sym_RPAREN,
    STATE(8345), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279887] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8791), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7906), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [279981] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10252), 1,
      anon_sym_COMMA,
    ACTIONS(10254), 1,
      anon_sym_COLON,
    ACTIONS(10256), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [280075] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10258), 1,
      anon_sym_RBRACE,
    ACTIONS(10260), 1,
      anon_sym_COMMA,
    STATE(7909), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [280169] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10262), 1,
      anon_sym_RBRACE,
    STATE(7807), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [280263] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10264), 1,
      anon_sym_COMMA,
    ACTIONS(10266), 1,
      anon_sym_RPAREN,
    STATE(8245), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [280357] = 25,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(10268), 3,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_do,
  [280447] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10270), 1,
      anon_sym_RBRACE,
    ACTIONS(10272), 1,
      anon_sym_COMMA,
    STATE(7811), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [280541] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10274), 1,
      anon_sym_COMMA,
    ACTIONS(10276), 1,
      anon_sym_RPAREN,
    STATE(7922), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [280635] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10278), 1,
      anon_sym_RBRACE,
    ACTIONS(10280), 1,
      anon_sym_COMMA,
    STATE(7813), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [280729] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10282), 1,
      anon_sym_RBRACE,
    ACTIONS(10284), 1,
      anon_sym_COMMA,
    STATE(8041), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [280823] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10286), 1,
      anon_sym_RBRACE,
    ACTIONS(10288), 1,
      anon_sym_COMMA,
    STATE(7814), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [280917] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10290), 1,
      anon_sym_COMMA,
    ACTIONS(10292), 1,
      anon_sym_RPAREN,
    STATE(8283), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281011] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10294), 1,
      anon_sym_RBRACE,
    STATE(8461), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281105] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10296), 1,
      anon_sym_RBRACE,
    ACTIONS(10298), 1,
      anon_sym_COMMA,
    STATE(8042), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281199] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10300), 1,
      anon_sym_RBRACE,
    ACTIONS(10302), 1,
      anon_sym_COMMA,
    STATE(8033), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281293] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10304), 1,
      anon_sym_RBRACE,
    ACTIONS(10306), 1,
      anon_sym_COMMA,
    STATE(8539), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281387] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10308), 1,
      anon_sym_RBRACE,
    ACTIONS(10310), 1,
      anon_sym_COMMA,
    STATE(8541), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281481] = 27,
    ACTIONS(4479), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10312), 1,
      anon_sym_COMMA,
    STATE(8347), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281575] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10314), 1,
      anon_sym_RBRACE,
    ACTIONS(10316), 1,
      anon_sym_COMMA,
    STATE(7834), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281669] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10318), 1,
      anon_sym_RBRACE,
    ACTIONS(10320), 1,
      anon_sym_COMMA,
    STATE(7929), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281763] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10322), 1,
      anon_sym_RBRACE,
    ACTIONS(10324), 1,
      anon_sym_COMMA,
    STATE(8542), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281857] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10326), 1,
      anon_sym_RBRACE,
    ACTIONS(10328), 1,
      anon_sym_COMMA,
    STATE(7949), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [281951] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10330), 1,
      anon_sym_COMMA,
    ACTIONS(10332), 1,
      anon_sym_RPAREN,
    STATE(7822), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282045] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10334), 1,
      anon_sym_RBRACE,
    ACTIONS(10336), 1,
      anon_sym_COMMA,
    STATE(7839), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282139] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10338), 1,
      anon_sym_RBRACE,
    STATE(8002), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282233] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10340), 1,
      anon_sym_RBRACE,
    ACTIONS(10342), 1,
      anon_sym_COMMA,
    STATE(8276), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282327] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8805), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7923), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282421] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10344), 1,
      anon_sym_RBRACE,
    ACTIONS(10346), 1,
      anon_sym_COMMA,
    STATE(8143), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282515] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10348), 1,
      anon_sym_RBRACE,
    ACTIONS(10350), 1,
      anon_sym_COMMA,
    STATE(8513), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282609] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10352), 1,
      anon_sym_RBRACE,
    STATE(8440), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282703] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10354), 1,
      anon_sym_COMMA,
    ACTIONS(10356), 1,
      anon_sym_COLON,
    ACTIONS(10358), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282797] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10360), 1,
      anon_sym_COMMA,
    ACTIONS(10362), 1,
      anon_sym_COLON,
    ACTIONS(10364), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282891] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10366), 1,
      anon_sym_RBRACE,
    ACTIONS(10368), 1,
      anon_sym_COMMA,
    STATE(7939), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [282985] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10370), 1,
      anon_sym_RBRACE,
    ACTIONS(10372), 1,
      anon_sym_COMMA,
    STATE(8442), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [283079] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10374), 1,
      anon_sym_COMMA,
    ACTIONS(10376), 1,
      anon_sym_RPAREN,
    STATE(8474), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [283173] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10378), 1,
      anon_sym_RBRACE,
    ACTIONS(10380), 1,
      anon_sym_COMMA,
    STATE(8430), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [283267] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10382), 1,
      anon_sym_RBRACE,
    STATE(8023), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [283361] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10384), 1,
      anon_sym_do,
    STATE(6966), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [283455] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10386), 1,
      anon_sym_RBRACE,
    ACTIONS(10388), 1,
      anon_sym_COMMA,
    STATE(8149), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [283549] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10390), 1,
      anon_sym_RBRACE,
    ACTIONS(10392), 1,
      anon_sym_COMMA,
    STATE(8472), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [283643] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10394), 1,
      anon_sym_RBRACE,
    ACTIONS(10396), 1,
      anon_sym_COMMA,
    STATE(8476), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [283737] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10400), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10398), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [283829] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10402), 1,
      anon_sym_RBRACE,
    ACTIONS(10404), 1,
      anon_sym_COMMA,
    STATE(8426), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [283923] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10406), 1,
      anon_sym_COMMA,
    ACTIONS(10408), 1,
      anon_sym_RPAREN,
    STATE(7801), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284017] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10410), 1,
      anon_sym_RBRACE,
    ACTIONS(10412), 1,
      anon_sym_COMMA,
    STATE(7841), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284111] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10414), 1,
      anon_sym_COMMA,
    ACTIONS(10416), 1,
      anon_sym_RPAREN,
    STATE(8233), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284205] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10418), 1,
      anon_sym_do,
    STATE(6969), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284299] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10420), 1,
      anon_sym_COMMA,
    ACTIONS(10422), 1,
      anon_sym_COLON,
    ACTIONS(10424), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284393] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10426), 1,
      anon_sym_COMMA,
    ACTIONS(10428), 1,
      anon_sym_COLON,
    ACTIONS(10430), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284487] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10432), 1,
      anon_sym_COMMA,
    ACTIONS(10434), 1,
      anon_sym_RPAREN,
    STATE(8383), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284581] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10436), 1,
      anon_sym_COMMA,
    ACTIONS(10438), 1,
      anon_sym_RPAREN,
    STATE(8394), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284675] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10440), 1,
      anon_sym_RBRACE,
    STATE(8403), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284769] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10442), 1,
      anon_sym_RBRACE,
    STATE(8049), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284863] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10444), 1,
      anon_sym_COMMA,
    ACTIONS(10446), 1,
      anon_sym_COLON,
    ACTIONS(10448), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [284957] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10450), 1,
      anon_sym_RBRACE,
    ACTIONS(10452), 1,
      anon_sym_COMMA,
    STATE(8100), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285051] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10454), 1,
      anon_sym_RBRACE,
    ACTIONS(10456), 1,
      anon_sym_COMMA,
    STATE(8569), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285145] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10458), 1,
      anon_sym_COMMA,
    ACTIONS(10460), 1,
      anon_sym_RPAREN,
    STATE(8218), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285239] = 27,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8811), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7781), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285333] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10462), 1,
      anon_sym_RBRACE,
    ACTIONS(10464), 1,
      anon_sym_COMMA,
    STATE(7875), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285427] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10466), 1,
      anon_sym_do,
    STATE(7036), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285521] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10468), 1,
      anon_sym_RBRACE,
    STATE(8615), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285615] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10470), 1,
      anon_sym_RBRACE,
    ACTIONS(10472), 1,
      anon_sym_COMMA,
    STATE(8205), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285709] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10474), 1,
      anon_sym_RBRACE,
    ACTIONS(10476), 1,
      anon_sym_COMMA,
    STATE(8477), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285803] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10478), 1,
      anon_sym_do,
    STATE(6992), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285897] = 27,
    ACTIONS(6279), 1,
      anon_sym_RBRACE,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10480), 1,
      anon_sym_COMMA,
    STATE(7874), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [285991] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10482), 1,
      anon_sym_COMMA,
    ACTIONS(10484), 1,
      anon_sym_RPAREN,
    STATE(8088), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [286085] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
    ACTIONS(10486), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [286175] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10488), 1,
      anon_sym_RBRACE,
    ACTIONS(10490), 1,
      anon_sym_COMMA,
    STATE(8524), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [286269] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10492), 1,
      anon_sym_RBRACE,
    ACTIONS(10494), 1,
      anon_sym_COMMA,
    STATE(7784), 1,
      aux_sym_map_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [286363] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10496), 1,
      anon_sym_RBRACE,
    STATE(8424), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [286457] = 27,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10498), 1,
      anon_sym_do,
    STATE(6996), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [286551] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10500), 1,
      anon_sym_RBRACE,
    ACTIONS(10502), 1,
      anon_sym_COMMA,
    STATE(7789), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [286645] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10504), 1,
      anon_sym_RBRACE,
    ACTIONS(10506), 1,
      anon_sym_COMMA,
    STATE(8248), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [286739] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10508), 1,
      anon_sym_COMMA,
    ACTIONS(10510), 1,
      anon_sym_RPAREN,
    STATE(8613), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [286833] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10512), 1,
      anon_sym_RBRACE,
    STATE(8255), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [286927] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10514), 1,
      anon_sym_COMMA,
    ACTIONS(10516), 1,
      anon_sym_RPAREN,
    STATE(8030), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287021] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10518), 1,
      anon_sym_RBRACE,
    ACTIONS(10520), 1,
      anon_sym_COMMA,
    STATE(7959), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287115] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10522), 1,
      anon_sym_RBRACE,
    STATE(7772), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287209] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10524), 1,
      anon_sym_RBRACE,
    ACTIONS(10526), 1,
      anon_sym_COMMA,
    STATE(8247), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287303] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10528), 1,
      anon_sym_RBRACE,
    ACTIONS(10530), 1,
      anon_sym_COMMA,
    STATE(7791), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287397] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10532), 1,
      anon_sym_RBRACE,
    ACTIONS(10534), 1,
      anon_sym_COMMA,
    STATE(7785), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287491] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10536), 1,
      anon_sym_RBRACE,
    ACTIONS(10538), 1,
      anon_sym_COMMA,
    STATE(7948), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287585] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(10540), 1,
      anon_sym_RBRACE,
    STATE(7866), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287679] = 27,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10542), 1,
      anon_sym_RBRACE,
    ACTIONS(10544), 1,
      anon_sym_COMMA,
    STATE(7862), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287773] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10546), 1,
      anon_sym_SEMI,
    ACTIONS(10548), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287864] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10550), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [287953] = 25,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10552), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [288042] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10554), 1,
      anon_sym_SEMI,
    ACTIONS(10556), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [288133] = 5,
    ACTIONS(6808), 1,
      sym_identifier,
    ACTIONS(6810), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [288182] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10558), 1,
      anon_sym_SEMI,
    ACTIONS(10560), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [288273] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10562), 1,
      anon_sym_SEMI,
    ACTIONS(10564), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [288364] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10566), 1,
      anon_sym_SEMI,
    ACTIONS(10568), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [288455] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10570), 1,
      anon_sym_SEMI,
    ACTIONS(10572), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [288546] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10574), 1,
      anon_sym_SEMI,
    ACTIONS(10576), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [288637] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10578), 1,
      anon_sym_SEMI,
    ACTIONS(10580), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [288728] = 5,
    ACTIONS(7830), 1,
      sym_identifier,
    ACTIONS(8297), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [288777] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10582), 1,
      anon_sym_SEMI,
    ACTIONS(10584), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [288868] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10586), 1,
      anon_sym_SEMI,
    ACTIONS(10588), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [288959] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10590), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [289048] = 5,
    ACTIONS(7171), 1,
      sym_identifier,
    ACTIONS(7173), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [289097] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10592), 1,
      anon_sym_SEMI,
    ACTIONS(10594), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [289188] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10596), 1,
      anon_sym_SEMI,
    ACTIONS(10598), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [289279] = 5,
    ACTIONS(6684), 1,
      sym_identifier,
    ACTIONS(6756), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [289328] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10600), 1,
      anon_sym_SEMI,
    ACTIONS(10602), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [289419] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10604), 1,
      anon_sym_SEMI,
    ACTIONS(10606), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [289510] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10608), 1,
      anon_sym_SEMI,
    ACTIONS(10610), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [289601] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10612), 1,
      anon_sym_SEMI,
    ACTIONS(10614), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [289692] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10616), 1,
      anon_sym_SEMI,
    ACTIONS(10618), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [289783] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10620), 1,
      anon_sym_SEMI,
    ACTIONS(10622), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [289874] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10624), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [289963] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10626), 1,
      anon_sym_SEMI,
    ACTIONS(10628), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [290054] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10630), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [290143] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10632), 1,
      anon_sym_SEMI,
    ACTIONS(10634), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [290234] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10636), 1,
      anon_sym_SEMI,
    ACTIONS(10638), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [290325] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10640), 1,
      anon_sym_SEMI,
    ACTIONS(10642), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [290416] = 5,
    ACTIONS(7055), 1,
      sym_identifier,
    ACTIONS(7057), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [290465] = 5,
    ACTIONS(21), 1,
      anon_sym_AT,
    STATE(6202), 2,
      sym_attribute,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(10644), 16,
      anon_sym_foreign,
      anon_sym_import,
      anon_sym_using,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_cast,
      anon_sym_transmute,
      anon_sym_auto_cast,
      anon_sym_map,
      anon_sym_bit_set,
      anon_sym_matrix,
      anon_sym_distinct,
      anon_sym_true,
      anon_sym_false,
      sym_nil,
      sym_identifier,
    ACTIONS(10646), 16,
      sym_float,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT,
      sym_number,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      anon_sym_SQUOTE,
      sym_uninitialized,
      sym_tag,
  [290514] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10648), 1,
      anon_sym_SEMI,
    ACTIONS(10650), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [290605] = 5,
    ACTIONS(6684), 1,
      sym_identifier,
    ACTIONS(6686), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [290654] = 25,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(4466), 2,
      anon_sym_LBRACE,
      anon_sym_COMMA,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [290743] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10652), 1,
      anon_sym_SEMI,
    ACTIONS(10654), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [290834] = 5,
    ACTIONS(7478), 1,
      sym_identifier,
    ACTIONS(7480), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [290883] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10656), 1,
      anon_sym_SEMI,
    ACTIONS(10658), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [290974] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10660), 1,
      anon_sym_SEMI,
    ACTIONS(10662), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [291065] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10664), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [291154] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10666), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [291243] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10668), 1,
      anon_sym_SEMI,
    ACTIONS(10670), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [291334] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10672), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [291423] = 5,
    ACTIONS(3878), 1,
      sym_identifier,
    ACTIONS(3880), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [291472] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10674), 1,
      anon_sym_SEMI,
    ACTIONS(10676), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [291563] = 5,
    ACTIONS(8224), 1,
      sym_identifier,
    ACTIONS(8226), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [291612] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10678), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [291701] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10680), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [291790] = 5,
    ACTIONS(6470), 1,
      sym_identifier,
    ACTIONS(6472), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [291839] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10682), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [291928] = 25,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8581), 1,
      anon_sym_DASH_GT,
    ACTIONS(8583), 1,
      anon_sym_PLUS,
    ACTIONS(8585), 1,
      anon_sym_DASH,
    ACTIONS(8587), 1,
      anon_sym_TILDE,
    ACTIONS(8589), 1,
      anon_sym_AMP,
    ACTIONS(8591), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8599), 1,
      anon_sym_DOT,
    ACTIONS(8603), 1,
      anon_sym_PIPE,
    ACTIONS(8609), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8617), 1,
      anon_sym_or_break,
    ACTIONS(8593), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8595), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8597), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8601), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8605), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(8607), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8611), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8613), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8883), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8615), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [292017] = 25,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10684), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [292106] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10686), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [292195] = 5,
    ACTIONS(10692), 1,
      anon_sym_AT,
    STATE(6202), 2,
      sym_attribute,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(10688), 16,
      anon_sym_foreign,
      anon_sym_import,
      anon_sym_using,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_cast,
      anon_sym_transmute,
      anon_sym_auto_cast,
      anon_sym_map,
      anon_sym_bit_set,
      anon_sym_matrix,
      anon_sym_distinct,
      anon_sym_true,
      anon_sym_false,
      sym_nil,
      sym_identifier,
    ACTIONS(10690), 16,
      sym_float,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT,
      sym_number,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      anon_sym_SQUOTE,
      sym_uninitialized,
      sym_tag,
  [292244] = 5,
    ACTIONS(8029), 1,
      sym_identifier,
    ACTIONS(8031), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [292293] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10695), 1,
      anon_sym_SEMI,
    ACTIONS(10697), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [292384] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(10699), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [292473] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10701), 1,
      anon_sym_SEMI,
    ACTIONS(10703), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [292564] = 5,
    ACTIONS(6445), 1,
      sym_identifier,
    ACTIONS(6447), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [292613] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10705), 1,
      anon_sym_SEMI,
    ACTIONS(10707), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [292704] = 5,
    ACTIONS(6445), 1,
      sym_identifier,
    ACTIONS(6617), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [292753] = 26,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10709), 1,
      anon_sym_SEMI,
    ACTIONS(10711), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [292844] = 5,
    ACTIONS(8455), 1,
      sym_identifier,
    ACTIONS(8457), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(73), 15,
      anon_sym_PIPE,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_AMP,
      anon_sym_or_else,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT,
      anon_sym_not_in,
      anon_sym_or_return,
      anon_sym_or_continue,
      anon_sym_or_break,
    ACTIONS(69), 18,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_AMP_TILDE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
      anon_sym_CARET,
  [292893] = 26,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    STATE(7185), 1,
      sym_block,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [292984] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9404), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293072] = 25,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(10713), 1,
      anon_sym_LBRACE,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293160] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10715), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293248] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10717), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293336] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9534), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293424] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9690), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293512] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9456), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293600] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10719), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293688] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9688), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293776] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10721), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293864] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10723), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [293952] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9438), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294040] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10725), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294128] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9607), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294216] = 25,
    ACTIONS(4106), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294304] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10727), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294392] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10729), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294480] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9698), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294568] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9500), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294656] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10731), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294744] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10733), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294832] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9540), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [294920] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10735), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295008] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10737), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295096] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10739), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295184] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10741), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295272] = 25,
    ACTIONS(4396), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295360] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9488), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295448] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10743), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295536] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10745), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295624] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9484), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295712] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10747), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295800] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9458), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295888] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10749), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [295976] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10751), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296064] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9542), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296152] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10753), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296240] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9686), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296328] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10755), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296416] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10757), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296504] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9548), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296592] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10759), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296680] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10761), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296768] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10763), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296856] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10765), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [296944] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9708), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297032] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10767), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297120] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10769), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297208] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9597), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297296] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10771), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297384] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10773), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297472] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9506), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297560] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9504), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297648] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10775), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297736] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10777), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297824] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10779), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [297912] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9550), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298000] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9722), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298088] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10781), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298176] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9714), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298264] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10783), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298352] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10785), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298440] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9474), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298528] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10787), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298616] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10789), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298704] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10791), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298792] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10793), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298880] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10795), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [298968] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10797), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299056] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10799), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299144] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10801), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299232] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10803), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299320] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10805), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299408] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10807), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299496] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9554), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299584] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10809), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299672] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9720), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299760] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10811), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299848] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9657), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [299936] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10813), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300024] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9414), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300112] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10815), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300200] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10817), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300288] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10819), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300376] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10821), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300464] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10823), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300552] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10825), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300640] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10827), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300728] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10829), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300816] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10831), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300904] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10833), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [300992] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10835), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301080] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10837), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301168] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9486), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301256] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9570), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301344] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10839), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301432] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10841), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301520] = 25,
    ACTIONS(4136), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301608] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10843), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301696] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10845), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301784] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10847), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301872] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10849), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [301960] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9416), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302048] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10851), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302136] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10853), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302224] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10855), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302312] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10857), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302400] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10859), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302488] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10861), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302576] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10863), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302664] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10865), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302752] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9546), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302840] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9436), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [302928] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9510), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303016] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10867), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303104] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10869), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303192] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10871), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303280] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10873), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303368] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10875), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303456] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9712), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303544] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10877), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303632] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9568), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303720] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10879), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303808] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10881), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303896] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10883), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [303984] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10885), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304072] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10887), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304160] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10889), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304248] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10891), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304336] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10893), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304424] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9576), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304512] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10895), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304600] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9572), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304688] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10897), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304776] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10899), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304864] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9578), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [304952] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10901), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305040] = 25,
    ACTIONS(3565), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305128] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10903), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305216] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10905), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305304] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9582), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305392] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10907), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305480] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10909), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305568] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10911), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305656] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10913), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305744] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10915), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305832] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10917), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [305920] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10919), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306008] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10921), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306096] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9566), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306184] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10923), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306272] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9406), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306360] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10925), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306448] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9399), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306536] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10927), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306624] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10929), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306712] = 25,
    ACTIONS(4166), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306800] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10931), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306888] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10933), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [306976] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10935), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307064] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10937), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307152] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10939), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307240] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10941), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307328] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10943), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307416] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9584), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307504] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10945), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307592] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10947), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307680] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10949), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307768] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9586), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307856] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10951), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [307944] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10953), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308032] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9472), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308120] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10955), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308208] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10957), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308296] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9591), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308384] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10959), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308472] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10961), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308560] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10963), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308648] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10965), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308736] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9536), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308824] = 25,
    ACTIONS(4376), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [308912] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9512), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309000] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10967), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309088] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9593), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309176] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10969), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309264] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10971), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309352] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9524), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309440] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10973), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309528] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9418), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309616] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9562), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309704] = 25,
    ACTIONS(4016), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309792] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10975), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309880] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10977), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [309968] = 25,
    ACTIONS(4316), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310056] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10979), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310144] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10981), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310232] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10983), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310320] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10985), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310408] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10987), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310496] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9603), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310584] = 25,
    ACTIONS(3722), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310672] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9605), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310760] = 25,
    ACTIONS(4434), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310848] = 25,
    ACTIONS(3862), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [310936] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10989), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311024] = 25,
    ACTIONS(3792), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311112] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10991), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311200] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9552), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311288] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10993), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311376] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10995), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311464] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9609), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311552] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10997), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311640] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9613), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311728] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(10999), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311816] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9426), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311904] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11001), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [311992] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9615), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312080] = 25,
    ACTIONS(3541), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312168] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11003), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312256] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9428), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312344] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11005), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312432] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9514), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312520] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9502), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312608] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9619), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312696] = 25,
    ACTIONS(4226), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312784] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9673), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312872] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11007), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [312960] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9430), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313048] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11009), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313136] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9408), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313224] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9621), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313312] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11011), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313400] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9625), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313488] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9623), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313576] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9432), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313664] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11013), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313752] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9627), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313840] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9516), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [313928] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9629), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314016] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9631), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314104] = 25,
    ACTIONS(3936), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314192] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11015), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314280] = 25,
    ACTIONS(3896), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314368] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11017), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314456] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11019), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314544] = 25,
    ACTIONS(4256), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314632] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11021), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314720] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11023), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314808] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9633), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314896] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9556), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [314984] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11025), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315072] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11027), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315160] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11029), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315248] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11031), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315336] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9422), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315424] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11033), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315512] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9635), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315600] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9440), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315688] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11035), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315776] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9637), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315864] = 25,
    ACTIONS(3996), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [315952] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9642), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316040] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9518), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316128] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9424), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316216] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11037), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316304] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9564), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316392] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9442), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316480] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11039), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316568] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11041), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316656] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9647), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316744] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9462), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316832] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11043), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [316920] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9444), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317008] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9520), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317096] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11045), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317184] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9508), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317272] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11047), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317360] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9446), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317448] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11049), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317536] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11051), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317624] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9434), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317712] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9526), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317800] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11053), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317888] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11055), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [317976] = 25,
    ACTIONS(4286), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318064] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11057), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318152] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11059), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318240] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11061), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318328] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11063), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318416] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11065), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318504] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11067), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318592] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11069), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318680] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9671), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318768] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9659), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318856] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9448), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [318944] = 25,
    ACTIONS(8489), 1,
      anon_sym_DASH_GT,
    ACTIONS(8491), 1,
      anon_sym_DOT,
    ACTIONS(8493), 1,
      anon_sym_LBRACK,
    ACTIONS(8521), 1,
      anon_sym_PIPE,
    ACTIONS(8523), 1,
      anon_sym_PLUS,
    ACTIONS(8525), 1,
      anon_sym_DASH,
    ACTIONS(8527), 1,
      anon_sym_TILDE,
    ACTIONS(8529), 1,
      anon_sym_AMP,
    ACTIONS(8533), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8541), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8549), 1,
      anon_sym_or_return,
    ACTIONS(8551), 1,
      anon_sym_or_continue,
    ACTIONS(8553), 1,
      anon_sym_or_break,
    ACTIONS(8555), 1,
      anon_sym_CARET,
    ACTIONS(11071), 1,
      anon_sym_LBRACE,
    ACTIONS(8495), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8531), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8535), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8537), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8543), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8545), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8547), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8647), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8539), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319032] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9454), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319120] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11073), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319208] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9664), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319296] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11075), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319384] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11077), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319472] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11079), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319560] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9522), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319648] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11081), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319736] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9611), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319824] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11083), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [319912] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9580), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320000] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11085), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320088] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9450), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320176] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9669), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320264] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11087), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320352] = 25,
    ACTIONS(4531), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320440] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9476), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320528] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11089), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320616] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11091), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320704] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9678), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320792] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9397), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320880] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11093), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [320968] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11095), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321056] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11097), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321144] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11099), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321232] = 25,
    ACTIONS(4046), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321320] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11101), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321408] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11103), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321496] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9482), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321584] = 25,
    ACTIONS(3832), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321672] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11105), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321760] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11107), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321848] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9460), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [321936] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9652), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322024] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11109), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322112] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11111), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322200] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11113), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322288] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11115), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322376] = 25,
    ACTIONS(4605), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322464] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11117), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322552] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11119), 1,
      anon_sym_RPAREN,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322640] = 25,
    ACTIONS(4196), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322728] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11121), 1,
      anon_sym_EQ,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322816] = 25,
    ACTIONS(3695), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322904] = 25,
    ACTIONS(3966), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [322992] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11123), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323080] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9464), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323168] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11125), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323256] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9700), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323344] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11127), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323432] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11129), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323520] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11131), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323608] = 25,
    ACTIONS(3635), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323696] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9468), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323784] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11133), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323872] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9702), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [323960] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11135), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324048] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9601), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324136] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11137), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324224] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11139), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324312] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9470), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324400] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11141), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324488] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9704), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324576] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9530), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324664] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9544), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324752] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9706), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324840] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9420), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [324928] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9574), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325016] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9595), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325104] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9710), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325192] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11143), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325280] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9599), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325368] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8985), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325456] = 25,
    ACTIONS(4346), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325544] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11145), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325632] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11147), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325720] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11149), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325808] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11151), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325896] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11153), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [325984] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11155), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326072] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11157), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326160] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11159), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326248] = 25,
    ACTIONS(3762), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326336] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9716), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326424] = 25,
    ACTIONS(3595), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326512] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11161), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326600] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11163), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326688] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11165), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326776] = 25,
    ACTIONS(4076), 1,
      anon_sym_RBRACK,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326864] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9538), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [326952] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11167), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327040] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11169), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327128] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11171), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327216] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9617), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327304] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11173), 1,
      anon_sym_COMMA,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327392] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9532), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327480] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9478), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327568] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11175), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327656] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11177), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327744] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11179), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327832] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(9480), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [327920] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11181), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [328008] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11183), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [328096] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11185), 1,
      anon_sym_else,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [328184] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11187), 1,
      anon_sym_COLON,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [328272] = 25,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(11189), 1,
      anon_sym_RBRACK,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [328360] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11191), 16,
      anon_sym_foreign,
      anon_sym_import,
      anon_sym_using,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_cast,
      anon_sym_transmute,
      anon_sym_auto_cast,
      anon_sym_map,
      anon_sym_bit_set,
      anon_sym_matrix,
      anon_sym_distinct,
      anon_sym_true,
      anon_sym_false,
      sym_nil,
      sym_identifier,
    ACTIONS(11193), 17,
      sym_float,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT,
      sym_number,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      anon_sym_SQUOTE,
      sym_uninitialized,
      sym_tag,
  [328403] = 24,
    ACTIONS(8004), 1,
      anon_sym_DASH_GT,
    ACTIONS(8006), 1,
      anon_sym_DOT,
    ACTIONS(8008), 1,
      anon_sym_LBRACK,
    ACTIONS(8049), 1,
      anon_sym_PIPE,
    ACTIONS(8051), 1,
      anon_sym_PLUS,
    ACTIONS(8053), 1,
      anon_sym_DASH,
    ACTIONS(8055), 1,
      anon_sym_TILDE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8069), 1,
      anon_sym_AMP_TILDE,
    ACTIONS(8077), 1,
      anon_sym_or_return,
    ACTIONS(8079), 1,
      anon_sym_or_continue,
    ACTIONS(8081), 1,
      anon_sym_or_break,
    ACTIONS(8083), 1,
      anon_sym_CARET,
    ACTIONS(8010), 2,
      anon_sym_DOT_DOT_EQ,
      anon_sym_DOT_DOT_LT,
    ACTIONS(8059), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or_else,
    ACTIONS(8063), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(8065), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8071), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8073), 2,
      anon_sym_STAR,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(8075), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(8139), 2,
      anon_sym_in,
      anon_sym_not_in,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8067), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_TILDE_EQ,
  [328488] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11195), 16,
      anon_sym_foreign,
      anon_sym_import,
      anon_sym_using,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_cast,
      anon_sym_transmute,
      anon_sym_auto_cast,
      anon_sym_map,
      anon_sym_bit_set,
      anon_sym_matrix,
      anon_sym_distinct,
      anon_sym_true,
      anon_sym_false,
      sym_nil,
      sym_identifier,
    ACTIONS(11197), 17,
      sym_float,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT,
      sym_number,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      anon_sym_SQUOTE,
      sym_uninitialized,
      sym_tag,
  [328531] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11199), 16,
      anon_sym_foreign,
      anon_sym_import,
      anon_sym_using,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_cast,
      anon_sym_transmute,
      anon_sym_auto_cast,
      anon_sym_map,
      anon_sym_bit_set,
      anon_sym_matrix,
      anon_sym_distinct,
      anon_sym_true,
      anon_sym_false,
      sym_nil,
      sym_identifier,
    ACTIONS(11201), 17,
      sym_float,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT,
      sym_number,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      anon_sym_SQUOTE,
      sym_uninitialized,
      sym_tag,
  [328574] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11203), 16,
      anon_sym_foreign,
      anon_sym_import,
      anon_sym_using,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_cast,
      anon_sym_transmute,
      anon_sym_auto_cast,
      anon_sym_map,
      anon_sym_bit_set,
      anon_sym_matrix,
      anon_sym_distinct,
      anon_sym_true,
      anon_sym_false,
      sym_nil,
      sym_identifier,
    ACTIONS(11205), 17,
      sym_float,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT,
      sym_number,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      anon_sym_SQUOTE,
      sym_uninitialized,
      sym_tag,
  [328617] = 3,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11207), 16,
      anon_sym_foreign,
      anon_sym_import,
      anon_sym_using,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_cast,
      anon_sym_transmute,
      anon_sym_auto_cast,
      anon_sym_map,
      anon_sym_bit_set,
      anon_sym_matrix,
      anon_sym_distinct,
      anon_sym_true,
      anon_sym_false,
      sym_nil,
      sym_identifier,
    ACTIONS(11209), 17,
      sym_float,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_DOT_DOT,
      sym_number,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      anon_sym_SQUOTE,
      sym_uninitialized,
      sym_tag,
  [328660] = 17,
    ACTIONS(659), 1,
      anon_sym_LBRACE,
    ACTIONS(671), 1,
      anon_sym_LBRACK,
    ACTIONS(681), 1,
      anon_sym_bit_set,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(693), 1,
      anon_sym_SQUOTE,
    ACTIONS(697), 1,
      sym_nil,
    ACTIONS(11211), 1,
      sym_identifier,
    ACTIONS(11213), 1,
      anon_sym_map,
    ACTIONS(11215), 1,
      anon_sym_matrix,
    STATE(8806), 1,
      sym_literal,
    STATE(8881), 1,
      sym_field_identifier,
    ACTIONS(695), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(687), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4202), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
  [328724] = 17,
    ACTIONS(147), 1,
      anon_sym_bit_set,
    ACTIONS(155), 1,
      anon_sym_DQUOTE,
    ACTIONS(157), 1,
      anon_sym_BQUOTE,
    ACTIONS(159), 1,
      anon_sym_SQUOTE,
    ACTIONS(163), 1,
      sym_nil,
    ACTIONS(167), 1,
      anon_sym_LBRACE,
    ACTIONS(177), 1,
      anon_sym_LBRACK,
    ACTIONS(11217), 1,
      sym_identifier,
    ACTIONS(11219), 1,
      anon_sym_map,
    ACTIONS(11221), 1,
      anon_sym_matrix,
    STATE(821), 1,
      sym_literal,
    STATE(8892), 1,
      sym_field_identifier,
    ACTIONS(161), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(715), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(153), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(772), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
  [328788] = 17,
    ACTIONS(511), 1,
      anon_sym_LBRACE,
    ACTIONS(523), 1,
      anon_sym_LBRACK,
    ACTIONS(533), 1,
      anon_sym_bit_set,
    ACTIONS(541), 1,
      anon_sym_DQUOTE,
    ACTIONS(543), 1,
      anon_sym_BQUOTE,
    ACTIONS(545), 1,
      anon_sym_SQUOTE,
    ACTIONS(549), 1,
      sym_nil,
    ACTIONS(11223), 1,
      sym_identifier,
    ACTIONS(11225), 1,
      anon_sym_map,
    ACTIONS(11227), 1,
      anon_sym_matrix,
    STATE(3050), 1,
      sym_literal,
    STATE(8694), 1,
      sym_field_identifier,
    ACTIONS(547), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3109), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(539), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(3146), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
  [328852] = 17,
    ACTIONS(555), 1,
      anon_sym_LBRACE,
    ACTIONS(567), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_bit_set,
    ACTIONS(585), 1,
      anon_sym_DQUOTE,
    ACTIONS(587), 1,
      anon_sym_BQUOTE,
    ACTIONS(589), 1,
      anon_sym_SQUOTE,
    ACTIONS(593), 1,
      sym_nil,
    ACTIONS(11229), 1,
      sym_identifier,
    ACTIONS(11231), 1,
      anon_sym_map,
    ACTIONS(11233), 1,
      anon_sym_matrix,
    STATE(3287), 1,
      sym_literal,
    STATE(8759), 1,
      sym_field_identifier,
    ACTIONS(591), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3374), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(583), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(3315), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
  [328916] = 17,
    ACTIONS(635), 1,
      anon_sym_bit_set,
    ACTIONS(643), 1,
      anon_sym_DQUOTE,
    ACTIONS(645), 1,
      anon_sym_BQUOTE,
    ACTIONS(647), 1,
      anon_sym_SQUOTE,
    ACTIONS(651), 1,
      sym_nil,
    ACTIONS(703), 1,
      anon_sym_LBRACE,
    ACTIONS(713), 1,
      anon_sym_LBRACK,
    ACTIONS(11235), 1,
      sym_identifier,
    ACTIONS(11237), 1,
      anon_sym_map,
    ACTIONS(11239), 1,
      anon_sym_matrix,
    STATE(3572), 1,
      sym_literal,
    STATE(8824), 1,
      sym_field_identifier,
    ACTIONS(649), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(3584), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(641), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(3577), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
  [328980] = 17,
    ACTIONS(213), 1,
      anon_sym_LBRACE,
    ACTIONS(223), 1,
      anon_sym_LBRACK,
    ACTIONS(233), 1,
      anon_sym_bit_set,
    ACTIONS(241), 1,
      anon_sym_DQUOTE,
    ACTIONS(243), 1,
      anon_sym_BQUOTE,
    ACTIONS(245), 1,
      anon_sym_SQUOTE,
    ACTIONS(249), 1,
      sym_nil,
    ACTIONS(11241), 1,
      sym_identifier,
    ACTIONS(11243), 1,
      anon_sym_map,
    ACTIONS(11245), 1,
      anon_sym_matrix,
    STATE(2316), 1,
      sym_literal,
    STATE(8628), 1,
      sym_field_identifier,
    ACTIONS(247), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(2481), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(239), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(2397), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
  [329044] = 17,
    ACTIONS(1317), 1,
      anon_sym_LBRACE,
    ACTIONS(1329), 1,
      anon_sym_LBRACK,
    ACTIONS(1339), 1,
      anon_sym_bit_set,
    ACTIONS(1347), 1,
      anon_sym_DQUOTE,
    ACTIONS(1349), 1,
      anon_sym_BQUOTE,
    ACTIONS(1351), 1,
      anon_sym_SQUOTE,
    ACTIONS(1355), 1,
      sym_nil,
    ACTIONS(11247), 1,
      sym_identifier,
    ACTIONS(11249), 1,
      anon_sym_map,
    ACTIONS(11251), 1,
      anon_sym_matrix,
    STATE(4291), 1,
      sym_literal,
    STATE(8653), 1,
      sym_field_identifier,
    ACTIONS(1353), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(4418), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(1345), 3,
      sym_float,
      sym_number,
      sym_uninitialized,
    STATE(4415), 7,
      sym_struct,
      sym_map,
      sym_bit_set,
      sym_matrix,
      sym_string,
      sym_character,
      sym_boolean,
  [329108] = 5,
    ACTIONS(7610), 1,
      anon_sym_COLON,
    ACTIONS(11253), 1,
      anon_sym_COMMA,
    STATE(6628), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7608), 16,
      anon_sym_COLON_COLON,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [329141] = 5,
    ACTIONS(7610), 1,
      anon_sym_COLON,
    ACTIONS(11256), 1,
      anon_sym_COMMA,
    STATE(6629), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7608), 16,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
      anon_sym_in,
  [329174] = 7,
    ACTIONS(6822), 1,
      anon_sym_COMMA,
    ACTIONS(9726), 1,
      anon_sym_COLON,
    ACTIONS(11261), 1,
      anon_sym_in,
    STATE(6629), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(9728), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11259), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [329211] = 7,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    ACTIONS(9361), 1,
      anon_sym_COLON,
    ACTIONS(11263), 1,
      anon_sym_COLON_COLON,
    STATE(6628), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(9363), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11265), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [329248] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7294), 1,
      sym_uninitialized,
    ACTIONS(7296), 1,
      sym_tag,
    ACTIONS(11267), 1,
      anon_sym_DASH_GT,
    ACTIONS(11269), 1,
      anon_sym_where,
    STATE(3357), 1,
      sym_where_clause,
    STATE(3883), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [329290] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11275), 1,
      anon_sym_RPAREN,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329338] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11285), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329386] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11287), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329434] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7271), 1,
      sym_uninitialized,
    ACTIONS(7273), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11289), 1,
      anon_sym_DASH_GT,
    STATE(3424), 1,
      sym_where_clause,
    STATE(3987), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [329476] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11291), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329524] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11293), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329572] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11295), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(7861), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329620] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11297), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8071), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329668] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11299), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329716] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11301), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8492), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329764] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7369), 1,
      sym_uninitialized,
    ACTIONS(7371), 1,
      sym_tag,
    ACTIONS(11303), 1,
      anon_sym_DASH_GT,
    ACTIONS(11305), 1,
      anon_sym_where,
    STATE(3503), 1,
      sym_where_clause,
    STATE(3582), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 10,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [329806] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11307), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329854] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11309), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8340), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329902] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11311), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [329950] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7014), 1,
      sym_uninitialized,
    ACTIONS(7016), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11313), 1,
      anon_sym_DASH_GT,
    STATE(3157), 1,
      sym_where_clause,
    STATE(3306), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [329992] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7363), 1,
      sym_uninitialized,
    ACTIONS(7365), 1,
      sym_tag,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11315), 1,
      anon_sym_DASH_GT,
    STATE(3500), 1,
      sym_where_clause,
    STATE(3576), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 10,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330034] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7020), 1,
      sym_uninitialized,
    ACTIONS(7022), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11317), 1,
      anon_sym_DASH_GT,
    STATE(3161), 1,
      sym_where_clause,
    STATE(3334), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330076] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11319), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8495), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [330124] = 6,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    ACTIONS(9726), 1,
      anon_sym_COLON,
    STATE(6628), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(9728), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11259), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [330158] = 6,
    ACTIONS(3483), 1,
      anon_sym_SLASH,
    ACTIONS(11321), 1,
      anon_sym_COLON,
    ACTIONS(11323), 1,
      anon_sym_DOT2,
    STATE(3322), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3481), 14,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [330192] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11325), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [330240] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11327), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [330288] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11329), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8197), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [330336] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11331), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [330384] = 13,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    ACTIONS(11333), 1,
      anon_sym_RPAREN,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [330432] = 10,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      sym_uninitialized,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(11337), 1,
      sym_tag,
    STATE(3174), 1,
      sym_where_clause,
    STATE(3408), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330473] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7393), 1,
      sym_uninitialized,
    ACTIONS(7395), 1,
      sym_tag,
    ACTIONS(11305), 1,
      anon_sym_where,
    STATE(3519), 1,
      sym_where_clause,
    STATE(3598), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 10,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330512] = 5,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    STATE(6628), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(9784), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11339), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_PIPE_PIPE_EQ,
      anon_sym_AMP_AMP_EQ,
      anon_sym_AMP_TILDE_EQ,
  [330543] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6988), 1,
      sym_uninitialized,
    ACTIONS(6990), 1,
      sym_tag,
    ACTIONS(11341), 1,
      anon_sym_DASH_GT,
    ACTIONS(11343), 1,
      anon_sym_where,
    STATE(3004), 1,
      sym_where_clause,
    STATE(3155), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [330584] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6994), 1,
      sym_uninitialized,
    ACTIONS(6996), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11345), 1,
      anon_sym_DASH_GT,
    STATE(2963), 1,
      sym_where_clause,
    STATE(3163), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [330625] = 10,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7065), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(11347), 1,
      sym_tag,
    STATE(3311), 1,
      sym_where_clause,
    STATE(3914), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330666] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7065), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11347), 1,
      sym_tag,
    STATE(3311), 1,
      sym_where_clause,
    STATE(3914), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330705] = 10,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7117), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(11349), 1,
      sym_tag,
    STATE(3367), 1,
      sym_where_clause,
    STATE(3805), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330746] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7117), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11349), 1,
      sym_tag,
    STATE(3367), 1,
      sym_where_clause,
    STATE(3805), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330785] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7117), 1,
      sym_uninitialized,
    ACTIONS(7121), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    STATE(3367), 1,
      sym_where_clause,
    STATE(3805), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330824] = 10,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7123), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(11351), 1,
      sym_tag,
    STATE(3420), 1,
      sym_where_clause,
    STATE(3962), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330865] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7123), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11351), 1,
      sym_tag,
    STATE(3420), 1,
      sym_where_clause,
    STATE(3962), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330904] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7123), 1,
      sym_uninitialized,
    ACTIONS(7127), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    STATE(3420), 1,
      sym_where_clause,
    STATE(3962), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330943] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(7132), 1,
      sym_uninitialized,
    ACTIONS(7134), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    STATE(3214), 1,
      sym_where_clause,
    STATE(3906), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [330982] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7152), 1,
      sym_uninitialized,
    ACTIONS(7154), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11353), 1,
      anon_sym_DASH_GT,
    STATE(3358), 1,
      sym_where_clause,
    STATE(3984), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [331023] = 10,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7034), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(11355), 1,
      sym_tag,
    STATE(3164), 1,
      sym_where_clause,
    STATE(3356), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331064] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7034), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11355), 1,
      sym_tag,
    STATE(3164), 1,
      sym_where_clause,
    STATE(3356), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331103] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6958), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11357), 1,
      sym_tag,
    STATE(3168), 1,
      sym_where_clause,
    STATE(3388), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331142] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6958), 1,
      sym_uninitialized,
    ACTIONS(6960), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    STATE(3168), 1,
      sym_where_clause,
    STATE(3388), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331181] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11337), 1,
      sym_tag,
    STATE(3174), 1,
      sym_where_clause,
    STATE(3408), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331220] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      sym_uninitialized,
    ACTIONS(7026), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    STATE(3174), 1,
      sym_where_clause,
    STATE(3408), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331259] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(7047), 1,
      sym_uninitialized,
    ACTIONS(7049), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    STATE(3177), 1,
      sym_where_clause,
    STATE(3425), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 10,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331298] = 12,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11271), 1,
      sym_identifier,
    ACTIONS(11273), 1,
      anon_sym_using,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11283), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    STATE(8641), 2,
      sym_parameter,
      sym_default_parameter,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(7495), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [331343] = 6,
    ACTIONS(3483), 1,
      anon_sym_SLASH,
    ACTIONS(11359), 1,
      anon_sym_COLON,
    ACTIONS(11361), 1,
      anon_sym_DOT2,
    STATE(2994), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3481), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [331376] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7158), 1,
      sym_uninitialized,
    ACTIONS(7160), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11363), 1,
      anon_sym_DASH_GT,
    STATE(3277), 1,
      sym_where_clause,
    STATE(3992), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [331417] = 10,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7377), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(11367), 1,
      sym_tag,
    STATE(3509), 1,
      sym_where_clause,
    STATE(3588), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 9,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331458] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7377), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11367), 1,
      sym_tag,
    STATE(3509), 1,
      sym_where_clause,
    STATE(3588), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 10,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331497] = 10,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7381), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(11369), 1,
      sym_tag,
    STATE(3511), 1,
      sym_where_clause,
    STATE(3594), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 9,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331538] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7381), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11369), 1,
      sym_tag,
    STATE(3511), 1,
      sym_where_clause,
    STATE(3594), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 10,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331577] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7381), 1,
      sym_uninitialized,
    ACTIONS(7385), 1,
      sym_tag,
    ACTIONS(11305), 1,
      anon_sym_where,
    STATE(3511), 1,
      sym_where_clause,
    STATE(3594), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 10,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331616] = 10,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7387), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(11371), 1,
      sym_tag,
    STATE(3516), 1,
      sym_where_clause,
    STATE(3597), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 9,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331657] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7387), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11371), 1,
      sym_tag,
    STATE(3516), 1,
      sym_where_clause,
    STATE(3597), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 10,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331696] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(7357), 1,
      anon_sym_LBRACE,
    ACTIONS(7387), 1,
      sym_uninitialized,
    ACTIONS(7391), 1,
      sym_tag,
    ACTIONS(11305), 1,
      anon_sym_where,
    STATE(3516), 1,
      sym_where_clause,
    STATE(3597), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 10,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331735] = 10,
    ACTIONS(6942), 1,
      anon_sym_LBRACE,
    ACTIONS(6958), 1,
      sym_uninitialized,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(11357), 1,
      sym_tag,
    STATE(3168), 1,
      sym_where_clause,
    STATE(3388), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331776] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7201), 1,
      sym_uninitialized,
    ACTIONS(7203), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11373), 1,
      anon_sym_DASH_GT,
    STATE(3453), 1,
      sym_where_clause,
    STATE(3848), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [331816] = 10,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(11377), 1,
      sym_tag,
    STATE(2958), 1,
      sym_where_clause,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [331856] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11377), 1,
      sym_tag,
    STATE(2958), 1,
      sym_where_clause,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [331894] = 10,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(11379), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [331934] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11379), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [331972] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6919), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332010] = 10,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(11381), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332050] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11381), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332088] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(6974), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332126] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6954), 1,
      sym_uninitialized,
    ACTIONS(6956), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    STATE(2985), 1,
      sym_where_clause,
    STATE(3200), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332164] = 5,
    ACTIONS(4460), 1,
      anon_sym_SLASH,
    ACTIONS(7882), 1,
      anon_sym_COMMA,
    STATE(6703), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4456), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [332194] = 5,
    ACTIONS(4471), 1,
      anon_sym_SLASH,
    ACTIONS(11383), 1,
      anon_sym_COMMA,
    STATE(6703), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4466), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [332224] = 10,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(11386), 1,
      sym_tag,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332264] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11386), 1,
      sym_tag,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332302] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(7185), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332340] = 6,
    ACTIONS(3483), 1,
      anon_sym_SLASH,
    ACTIONS(11388), 1,
      anon_sym_COLON,
    ACTIONS(11390), 1,
      anon_sym_DOT2,
    STATE(2872), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3481), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [332372] = 10,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7167), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(11392), 1,
      sym_tag,
    STATE(3313), 1,
      sym_where_clause,
    STATE(3985), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332412] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7167), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11392), 1,
      sym_tag,
    STATE(3313), 1,
      sym_where_clause,
    STATE(3985), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332450] = 10,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7508), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(11394), 1,
      sym_tag,
    STATE(3793), 1,
      sym_where_clause,
    STATE(4511), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [332490] = 10,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7583), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(11396), 1,
      sym_tag,
    STATE(3745), 1,
      sym_where_clause,
    STATE(4520), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [332530] = 5,
    ACTIONS(4460), 1,
      anon_sym_SLASH,
    ACTIONS(7785), 1,
      anon_sym_COMMA,
    STATE(6714), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4456), 13,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [332560] = 10,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(11398), 1,
      sym_tag,
    STATE(3741), 1,
      sym_where_clause,
    STATE(4528), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [332600] = 5,
    ACTIONS(4471), 1,
      anon_sym_SLASH,
    ACTIONS(11400), 1,
      anon_sym_COMMA,
    STATE(6714), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4466), 13,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [332630] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7187), 1,
      sym_uninitialized,
    ACTIONS(7189), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    STATE(3385), 1,
      sym_where_clause,
    STATE(3857), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332668] = 10,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(11403), 1,
      sym_tag,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332708] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11403), 1,
      sym_tag,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332746] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(7179), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 9,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [332784] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7195), 1,
      sym_uninitialized,
    ACTIONS(7197), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11405), 1,
      anon_sym_DASH_GT,
    STATE(3452), 1,
      sym_where_clause,
    STATE(3933), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [332824] = 5,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(11407), 1,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5005), 12,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [332853] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7209), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11409), 1,
      sym_tag,
    STATE(3479), 1,
      sym_where_clause,
    STATE(3854), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [332890] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7209), 1,
      sym_uninitialized,
    ACTIONS(7213), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    STATE(3479), 1,
      sym_where_clause,
    STATE(3854), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [332927] = 10,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7215), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(11411), 1,
      sym_tag,
    STATE(3491), 1,
      sym_where_clause,
    STATE(3897), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [332966] = 9,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7496), 1,
      sym_uninitialized,
    ACTIONS(7498), 1,
      sym_tag,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11413), 1,
      anon_sym_DASH_GT,
    STATE(3750), 1,
      sym_where_clause,
    STATE(4669), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333003] = 5,
    ACTIONS(4471), 1,
      anon_sym_SLASH,
    ACTIONS(11415), 1,
      anon_sym_COMMA,
    STATE(6725), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4466), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [333032] = 11,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11277), 1,
      anon_sym_DOLLAR,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11418), 1,
      sym_identifier,
    ACTIONS(11420), 1,
      anon_sym_using,
    ACTIONS(11422), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(8219), 6,
      sym__param_header,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [333073] = 9,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7502), 1,
      sym_uninitialized,
    ACTIONS(7504), 1,
      sym_tag,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11424), 1,
      anon_sym_DASH_GT,
    STATE(3770), 1,
      sym_where_clause,
    STATE(4650), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333110] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7215), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11411), 1,
      sym_tag,
    STATE(3491), 1,
      sym_where_clause,
    STATE(3897), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333147] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7215), 1,
      sym_uninitialized,
    ACTIONS(7219), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    STATE(3491), 1,
      sym_where_clause,
    STATE(3897), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333184] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7221), 1,
      sym_uninitialized,
    ACTIONS(7223), 1,
      sym_tag,
    ACTIONS(11269), 1,
      anon_sym_where,
    STATE(3498), 1,
      sym_where_clause,
    STATE(3978), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333221] = 4,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 13,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333248] = 4,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333275] = 5,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(11426), 1,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5005), 12,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333304] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7205), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11428), 1,
      sym_tag,
    STATE(3465), 1,
      sym_where_clause,
    STATE(3819), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333341] = 4,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 13,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333368] = 4,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 13,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333395] = 5,
    ACTIONS(4460), 1,
      anon_sym_SLASH,
    ACTIONS(8218), 1,
      anon_sym_COMMA,
    STATE(6725), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4456), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [333424] = 4,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333451] = 4,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333478] = 4,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333505] = 4,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 13,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333532] = 10,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7209), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(11409), 1,
      sym_tag,
    STATE(3479), 1,
      sym_where_clause,
    STATE(3854), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333571] = 4,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 13,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333598] = 4,
    ACTIONS(7373), 1,
      anon_sym_LPAREN,
    ACTIONS(11365), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 13,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
      sym_uninitialized,
      sym_tag,
  [333625] = 10,
    ACTIONS(7028), 1,
      anon_sym_LPAREN,
    ACTIONS(7191), 1,
      anon_sym_LBRACE,
    ACTIONS(7205), 1,
      sym_uninitialized,
    ACTIONS(11269), 1,
      anon_sym_where,
    ACTIONS(11335), 1,
      anon_sym_SLASH,
    ACTIONS(11428), 1,
      sym_tag,
    STATE(3465), 1,
      sym_where_clause,
    STATE(3819), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333664] = 8,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7643), 1,
      sym_uninitialized,
    ACTIONS(7645), 1,
      sym_tag,
    ACTIONS(11305), 1,
      anon_sym_where,
    STATE(3725), 1,
      sym_where_clause,
    STATE(4531), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333698] = 11,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11430), 1,
      sym_identifier,
    ACTIONS(11432), 1,
      anon_sym_using,
    ACTIONS(11434), 1,
      anon_sym_DOLLAR,
    ACTIONS(11436), 1,
      anon_sym_LBRACK,
    ACTIONS(11438), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(8038), 5,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [333738] = 4,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [333764] = 4,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [333790] = 6,
    ACTIONS(11440), 1,
      anon_sym_LBRACE,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(6636), 1,
      sym_parameters,
    STATE(8719), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [333820] = 8,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7508), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11394), 1,
      sym_tag,
    STATE(3793), 1,
      sym_where_clause,
    STATE(4511), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333854] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(11446), 1,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5005), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [333882] = 6,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    ACTIONS(11448), 1,
      anon_sym_LBRACE,
    STATE(6636), 1,
      sym_parameters,
    STATE(8719), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [333912] = 8,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7583), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11396), 1,
      sym_tag,
    STATE(3745), 1,
      sym_where_clause,
    STATE(4520), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333946] = 8,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7583), 1,
      sym_uninitialized,
    ACTIONS(7590), 1,
      sym_tag,
    ACTIONS(11305), 1,
      anon_sym_where,
    STATE(3745), 1,
      sym_where_clause,
    STATE(4520), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [333980] = 6,
    ACTIONS(3483), 1,
      anon_sym_SLASH,
    ACTIONS(11450), 1,
      anon_sym_COLON,
    ACTIONS(11452), 1,
      anon_sym_DOT2,
    STATE(3934), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3481), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [334010] = 4,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [334036] = 4,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [334062] = 8,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      sym_uninitialized,
    ACTIONS(11305), 1,
      anon_sym_where,
    ACTIONS(11398), 1,
      sym_tag,
    STATE(3741), 1,
      sym_where_clause,
    STATE(4528), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [334096] = 11,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11434), 1,
      anon_sym_DOLLAR,
    ACTIONS(11436), 1,
      anon_sym_LBRACK,
    ACTIONS(11438), 1,
      sym_tag,
    ACTIONS(11454), 1,
      sym_identifier,
    ACTIONS(11456), 1,
      anon_sym_using,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(8038), 5,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [334136] = 8,
    ACTIONS(7492), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      sym_uninitialized,
    ACTIONS(7638), 1,
      sym_tag,
    ACTIONS(11305), 1,
      anon_sym_where,
    STATE(3741), 1,
      sym_where_clause,
    STATE(4528), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [334170] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7860), 1,
      sym_uninitialized,
    ACTIONS(7862), 1,
      sym_tag,
    ACTIONS(11458), 1,
      anon_sym_DASH_GT,
    ACTIONS(11460), 1,
      anon_sym_where,
    STATE(4158), 1,
      sym_where_clause,
    STATE(4304), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [334208] = 4,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      sym_uninitialized,
      sym_tag,
  [334234] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7852), 1,
      sym_uninitialized,
    ACTIONS(7854), 1,
      sym_tag,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11462), 1,
      anon_sym_DASH_GT,
    STATE(4264), 1,
      sym_where_clause,
    STATE(4302), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [334272] = 5,
    ACTIONS(11464), 1,
      anon_sym_LPAREN,
    STATE(6764), 1,
      sym_parameters,
    STATE(8906), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334299] = 5,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(6636), 1,
      sym_parameters,
    STATE(8719), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334326] = 5,
    ACTIONS(11466), 1,
      anon_sym_LPAREN,
    STATE(551), 1,
      sym_parameters,
    STATE(8750), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334353] = 5,
    ACTIONS(11468), 1,
      anon_sym_LPAREN,
    STATE(1397), 1,
      sym_parameters,
    STATE(8797), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334380] = 5,
    ACTIONS(11470), 1,
      anon_sym_LPAREN,
    STATE(3450), 1,
      sym_parameters,
    STATE(8804), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334407] = 5,
    ACTIONS(11470), 1,
      anon_sym_LPAREN,
    STATE(3248), 1,
      sym_parameters,
    STATE(8834), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334434] = 5,
    ACTIONS(11464), 1,
      anon_sym_LPAREN,
    STATE(3862), 1,
      sym_parameters,
    STATE(8852), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334461] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11474), 1,
      anon_sym_DASH_GT,
    ACTIONS(11476), 1,
      sym_uninitialized,
    ACTIONS(11478), 1,
      sym_tag,
    STATE(6923), 1,
      sym_where_clause,
    STATE(7135), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [334498] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6810), 1,
      sym_parameters,
    STATE(8879), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334525] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(7006), 1,
      sym_uninitialized,
    ACTIONS(7008), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11482), 1,
      anon_sym_DASH_GT,
    STATE(3260), 1,
      sym_where_clause,
    STATE(3769), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [334562] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6661), 1,
      sym_parameters,
    STATE(8634), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334589] = 5,
    ACTIONS(11466), 1,
      anon_sym_LPAREN,
    STATE(534), 1,
      sym_parameters,
    STATE(8645), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334616] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(2980), 1,
      sym_parameters,
    STATE(8623), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334643] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(2972), 1,
      sym_parameters,
    STATE(8905), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334670] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6781), 1,
      sym_parameters,
    STATE(8800), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334697] = 5,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(3086), 1,
      sym_parameters,
    STATE(8909), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334724] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6988), 1,
      sym_uninitialized,
    ACTIONS(6990), 1,
      sym_tag,
    ACTIONS(11484), 1,
      anon_sym_DASH_GT,
    ACTIONS(11486), 1,
      anon_sym_where,
    STATE(3004), 1,
      sym_where_clause,
    STATE(3155), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [334761] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6994), 1,
      sym_uninitialized,
    ACTIONS(6996), 1,
      sym_tag,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11488), 1,
      anon_sym_DASH_GT,
    STATE(2963), 1,
      sym_where_clause,
    STATE(3163), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [334798] = 5,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(2989), 1,
      sym_parameters,
    STATE(8651), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334825] = 10,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11438), 1,
      sym_tag,
    ACTIONS(11490), 1,
      sym_identifier,
    ACTIONS(11492), 1,
      anon_sym_DOLLAR,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(8170), 5,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [334862] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11494), 1,
      anon_sym_DASH_GT,
    ACTIONS(11496), 1,
      sym_uninitialized,
    ACTIONS(11498), 1,
      sym_tag,
    STATE(6929), 1,
      sym_where_clause,
    STATE(7144), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [334899] = 10,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11438), 1,
      sym_tag,
    ACTIONS(11492), 1,
      anon_sym_DOLLAR,
    ACTIONS(11500), 1,
      sym_identifier,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(8170), 5,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [334936] = 5,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(6719), 1,
      sym_parameters,
    STATE(8931), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334963] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(3059), 1,
      sym_parameters,
    STATE(8794), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [334990] = 10,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7152), 1,
      sym_uninitialized,
    ACTIONS(7154), 1,
      sym_tag,
    ACTIONS(11502), 1,
      anon_sym_DASH_GT,
    ACTIONS(11504), 1,
      anon_sym_where,
    STATE(3358), 1,
      sym_where_clause,
    STATE(3984), 1,
      sym_block,
    ACTIONS(3445), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [335027] = 10,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7158), 1,
      sym_uninitialized,
    ACTIONS(7160), 1,
      sym_tag,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11506), 1,
      anon_sym_DASH_GT,
    STATE(3277), 1,
      sym_where_clause,
    STATE(3992), 1,
      sym_block,
    ACTIONS(3455), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [335064] = 5,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(3107), 1,
      sym_parameters,
    STATE(8621), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335091] = 5,
    ACTIONS(11468), 1,
      anon_sym_LPAREN,
    STATE(2337), 1,
      sym_parameters,
    STATE(8626), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335118] = 10,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11434), 1,
      anon_sym_DOLLAR,
    ACTIONS(11438), 1,
      sym_tag,
    ACTIONS(11454), 1,
      sym_identifier,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(8038), 5,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [335155] = 10,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6988), 1,
      sym_uninitialized,
    ACTIONS(6990), 1,
      sym_tag,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11508), 1,
      anon_sym_DASH_GT,
    STATE(3004), 1,
      sym_where_clause,
    STATE(3155), 1,
      sym_block,
    ACTIONS(3445), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [335192] = 10,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6994), 1,
      sym_uninitialized,
    ACTIONS(6996), 1,
      sym_tag,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11510), 1,
      anon_sym_DASH_GT,
    STATE(2963), 1,
      sym_where_clause,
    STATE(3163), 1,
      sym_block,
    ACTIONS(3455), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [335229] = 5,
    ACTIONS(11470), 1,
      anon_sym_LPAREN,
    STATE(6724), 1,
      sym_parameters,
    STATE(8697), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335256] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6794), 1,
      sym_parameters,
    STATE(8681), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335283] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(4059), 1,
      sym_parameters,
    STATE(8684), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335310] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6842), 1,
      sym_parameters,
    STATE(8691), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335337] = 5,
    ACTIONS(11464), 1,
      anon_sym_LPAREN,
    STATE(6772), 1,
      sym_parameters,
    STATE(8705), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335364] = 6,
    ACTIONS(11390), 1,
      anon_sym_DOT2,
    ACTIONS(11512), 1,
      anon_sym_COLON,
    STATE(2872), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3483), 3,
      anon_sym_where,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3481), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [335393] = 5,
    ACTIONS(11468), 1,
      anon_sym_LPAREN,
    STATE(1305), 1,
      sym_parameters,
    STATE(8880), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335420] = 5,
    ACTIONS(11466), 1,
      anon_sym_LPAREN,
    STATE(563), 1,
      sym_parameters,
    STATE(8882), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335447] = 10,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11430), 1,
      sym_identifier,
    ACTIONS(11434), 1,
      anon_sym_DOLLAR,
    ACTIONS(11438), 1,
      sym_tag,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(8038), 5,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [335484] = 5,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(6647), 1,
      sym_parameters,
    STATE(8805), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335511] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6789), 1,
      sym_parameters,
    STATE(8801), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335538] = 6,
    ACTIONS(3483), 1,
      anon_sym_SLASH,
    ACTIONS(11390), 1,
      anon_sym_DOT2,
    ACTIONS(11514), 1,
      anon_sym_COLON,
    STATE(2872), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3481), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
      sym_uninitialized,
      sym_tag,
  [335567] = 5,
    ACTIONS(11470), 1,
      anon_sym_LPAREN,
    STATE(3471), 1,
      sym_parameters,
    STATE(8713), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335594] = 5,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6672), 1,
      sym_parameters,
    STATE(8723), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335621] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6966), 1,
      sym_uninitialized,
    ACTIONS(6968), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11516), 1,
      anon_sym_DASH_GT,
    STATE(3240), 1,
      sym_where_clause,
    STATE(3749), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [335658] = 5,
    ACTIONS(11470), 1,
      anon_sym_LPAREN,
    STATE(6648), 1,
      sym_parameters,
    STATE(8886), 1,
      sym_calling_convention,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11442), 10,
      anon_sym_DQUOTEodin_DQUOTE,
      anon_sym_DQUOTEcontextless_DQUOTE,
      anon_sym_DQUOTEstdcall_DQUOTE,
      anon_sym_DQUOTEstd_DQUOTE,
      anon_sym_DQUOTEcdecl_DQUOTE,
      anon_sym_DQUOTEc_DQUOTE,
      anon_sym_DQUOTEfastcall_DQUOTE,
      anon_sym_DQUOTEfast_DQUOTE,
      anon_sym_DQUOTEnone_DQUOTE,
      anon_sym_DQUOTEsystem_DQUOTE,
  [335685] = 10,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7868), 1,
      sym_uninitialized,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(11520), 1,
      sym_tag,
    STATE(4163), 1,
      sym_where_clause,
    STATE(4310), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [335722] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7868), 1,
      sym_uninitialized,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11520), 1,
      sym_tag,
    STATE(4163), 1,
      sym_where_clause,
    STATE(4310), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [335757] = 10,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7872), 1,
      sym_uninitialized,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(11522), 1,
      sym_tag,
    STATE(4164), 1,
      sym_where_clause,
    STATE(4316), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [335794] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7872), 1,
      sym_uninitialized,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11522), 1,
      sym_tag,
    STATE(4164), 1,
      sym_where_clause,
    STATE(4316), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [335829] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7872), 1,
      sym_uninitialized,
    ACTIONS(7876), 1,
      sym_tag,
    ACTIONS(11460), 1,
      anon_sym_where,
    STATE(4164), 1,
      sym_where_clause,
    STATE(4316), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [335864] = 10,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(7878), 1,
      sym_uninitialized,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(11524), 1,
      sym_tag,
    STATE(4171), 1,
      sym_where_clause,
    STATE(4323), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [335901] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7878), 1,
      sym_uninitialized,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11524), 1,
      sym_tag,
    STATE(4171), 1,
      sym_where_clause,
    STATE(4323), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [335936] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7878), 1,
      sym_uninitialized,
    ACTIONS(7884), 1,
      sym_tag,
    ACTIONS(11460), 1,
      anon_sym_where,
    STATE(4171), 1,
      sym_where_clause,
    STATE(4323), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [335971] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(7846), 1,
      anon_sym_LBRACE,
    ACTIONS(7886), 1,
      sym_uninitialized,
    ACTIONS(7888), 1,
      sym_tag,
    ACTIONS(11460), 1,
      anon_sym_where,
    STATE(4179), 1,
      sym_where_clause,
    STATE(4327), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [336006] = 11,
    ACTIONS(3388), 1,
      sym_identifier,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(11528), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [336044] = 9,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(7179), 1,
      sym_tag,
    ACTIONS(11504), 1,
      anon_sym_where,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3374), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336078] = 10,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6911), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(11530), 1,
      sym_tag,
    STATE(3281), 1,
      sym_where_clause,
    STATE(3730), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [336114] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6911), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11530), 1,
      sym_tag,
    STATE(3281), 1,
      sym_where_clause,
    STATE(3730), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336148] = 11,
    ACTIONS(3388), 1,
      sym_identifier,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(11532), 1,
      sym_tag,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [336186] = 9,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11532), 1,
      sym_tag,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3388), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336220] = 9,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(7185), 1,
      sym_tag,
    ACTIONS(11504), 1,
      anon_sym_where,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3388), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336254] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6911), 1,
      sym_uninitialized,
    ACTIONS(6913), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    STATE(3281), 1,
      sym_where_clause,
    STATE(3730), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336288] = 9,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7187), 1,
      sym_uninitialized,
    ACTIONS(7189), 1,
      sym_tag,
    ACTIONS(11504), 1,
      anon_sym_where,
    STATE(3385), 1,
      sym_where_clause,
    STATE(3857), 1,
      sym_block,
    ACTIONS(3402), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336322] = 10,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(11534), 1,
      sym_uninitialized,
    ACTIONS(11536), 1,
      sym_tag,
    STATE(6917), 1,
      sym_where_clause,
    STATE(7175), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [336358] = 10,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6936), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(11538), 1,
      sym_tag,
    STATE(3273), 1,
      sym_where_clause,
    STATE(3790), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [336394] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11534), 1,
      sym_uninitialized,
    ACTIONS(11536), 1,
      sym_tag,
    STATE(6917), 1,
      sym_where_clause,
    STATE(7175), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [336428] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6936), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11538), 1,
      sym_tag,
    STATE(3273), 1,
      sym_where_clause,
    STATE(3790), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336462] = 11,
    ACTIONS(3427), 1,
      sym_identifier,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(11540), 1,
      sym_tag,
    STATE(2958), 1,
      sym_where_clause,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [336500] = 11,
    ACTIONS(3374), 1,
      sym_identifier,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(11542), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [336538] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11540), 1,
      sym_tag,
    STATE(2958), 1,
      sym_where_clause,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3427), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336572] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11542), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3374), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336606] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6919), 1,
      sym_tag,
    ACTIONS(11504), 1,
      anon_sym_where,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3374), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336640] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11528), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3388), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336674] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(6974), 1,
      sym_tag,
    ACTIONS(11504), 1,
      anon_sym_where,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3388), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336708] = 9,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6954), 1,
      sym_uninitialized,
    ACTIONS(6956), 1,
      sym_tag,
    ACTIONS(11504), 1,
      anon_sym_where,
    STATE(2985), 1,
      sym_where_clause,
    STATE(3200), 1,
      sym_block,
    ACTIONS(3402), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336742] = 10,
    ACTIONS(3445), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7152), 1,
      sym_uninitialized,
    ACTIONS(7154), 1,
      sym_tag,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11544), 1,
      anon_sym_DASH_GT,
    STATE(3358), 1,
      sym_where_clause,
    STATE(3984), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3439), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [336778] = 10,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7158), 1,
      sym_uninitialized,
    ACTIONS(7160), 1,
      sym_tag,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11546), 1,
      anon_sym_DASH_GT,
    STATE(3277), 1,
      sym_where_clause,
    STATE(3992), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [336814] = 11,
    ACTIONS(3374), 1,
      sym_identifier,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(11548), 1,
      sym_tag,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [336852] = 9,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11548), 1,
      sym_tag,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3374), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [336886] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11550), 1,
      sym_tag,
    STATE(2958), 1,
      sym_where_clause,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [336920] = 10,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(11552), 1,
      sym_uninitialized,
    ACTIONS(11554), 1,
      sym_tag,
    STATE(6914), 1,
      sym_where_clause,
    STATE(7181), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [336956] = 10,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(11558), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_when,
  [336992] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11558), 1,
      sym_tag,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [337026] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6917), 1,
      sym_uninitialized,
    ACTIONS(6919), 1,
      sym_tag,
    ACTIONS(11486), 1,
      anon_sym_where,
    STATE(2974), 1,
      sym_where_clause,
    STATE(3185), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [337060] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11552), 1,
      sym_uninitialized,
    ACTIONS(11554), 1,
      sym_tag,
    STATE(6914), 1,
      sym_where_clause,
    STATE(7181), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [337094] = 10,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(11560), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_when,
  [337130] = 9,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11438), 1,
      sym_tag,
    ACTIONS(11454), 1,
      sym_identifier,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(8038), 5,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [337164] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11560), 1,
      sym_tag,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [337198] = 10,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(6927), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11375), 1,
      anon_sym_SLASH,
    ACTIONS(11562), 1,
      sym_tag,
    STATE(3285), 1,
      sym_where_clause,
    STATE(3732), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [337234] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      sym_uninitialized,
    ACTIONS(6974), 1,
      sym_tag,
    ACTIONS(11486), 1,
      anon_sym_where,
    STATE(3009), 1,
      sym_where_clause,
    STATE(3195), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [337268] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6927), 1,
      sym_uninitialized,
    ACTIONS(11343), 1,
      anon_sym_where,
    ACTIONS(11562), 1,
      sym_tag,
    STATE(3285), 1,
      sym_where_clause,
    STATE(3732), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [337302] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(6927), 1,
      sym_uninitialized,
    ACTIONS(6970), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    STATE(3285), 1,
      sym_where_clause,
    STATE(3732), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [337336] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6954), 1,
      sym_uninitialized,
    ACTIONS(6956), 1,
      sym_tag,
    ACTIONS(11486), 1,
      anon_sym_where,
    STATE(2985), 1,
      sym_where_clause,
    STATE(3200), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [337370] = 10,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(11564), 1,
      sym_uninitialized,
    ACTIONS(11566), 1,
      sym_tag,
    STATE(6913), 1,
      sym_where_clause,
    STATE(7159), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [337406] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11564), 1,
      sym_uninitialized,
    ACTIONS(11566), 1,
      sym_tag,
    STATE(6913), 1,
      sym_where_clause,
    STATE(7159), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [337440] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(6907), 1,
      anon_sym_LBRACE,
    ACTIONS(7041), 1,
      sym_uninitialized,
    ACTIONS(7043), 1,
      sym_tag,
    ACTIONS(11343), 1,
      anon_sym_where,
    STATE(3290), 1,
      sym_where_clause,
    STATE(3715), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [337474] = 9,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11438), 1,
      sym_tag,
    ACTIONS(11490), 1,
      sym_identifier,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(8170), 5,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [337508] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11552), 1,
      sym_uninitialized,
    ACTIONS(11568), 1,
      sym_tag,
    STATE(6914), 1,
      sym_where_clause,
    STATE(7181), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [337542] = 5,
    ACTIONS(4471), 1,
      anon_sym_SLASH,
    ACTIONS(11570), 1,
      anon_sym_COMMA,
    STATE(6865), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4466), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [337568] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11534), 1,
      sym_uninitialized,
    ACTIONS(11573), 1,
      sym_tag,
    STATE(6917), 1,
      sym_where_clause,
    STATE(7175), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [337602] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(11460), 1,
      anon_sym_where,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11575), 1,
      sym_uninitialized,
    ACTIONS(11577), 1,
      sym_tag,
    STATE(6919), 1,
      sym_where_clause,
    STATE(7186), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [337636] = 9,
    ACTIONS(1465), 1,
      anon_sym_proc,
    ACTIONS(2932), 1,
      anon_sym_CARET,
    ACTIONS(11279), 1,
      anon_sym_LBRACK,
    ACTIONS(11281), 1,
      anon_sym_DOT_DOT,
    ACTIONS(11438), 1,
      sym_tag,
    ACTIONS(11579), 1,
      sym_identifier,
    STATE(3930), 1,
      sym_procedure,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    STATE(8005), 5,
      sym_pointer_type,
      sym_variadic_type,
      sym_array_type,
      sym_field_type,
      sym__procedure_type,
  [337670] = 5,
    ACTIONS(4460), 1,
      anon_sym_SLASH,
    ACTIONS(8447), 1,
      anon_sym_COMMA,
    STATE(6865), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4456), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [337696] = 11,
    ACTIONS(3427), 1,
      sym_identifier,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7167), 1,
      sym_uninitialized,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(11581), 1,
      sym_tag,
    STATE(3313), 1,
      sym_where_clause,
    STATE(3985), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 3,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [337734] = 9,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7167), 1,
      sym_uninitialized,
    ACTIONS(11504), 1,
      anon_sym_where,
    ACTIONS(11581), 1,
      sym_tag,
    STATE(3313), 1,
      sym_where_clause,
    STATE(3985), 1,
      sym_block,
    ACTIONS(3427), 2,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [337768] = 10,
    ACTIONS(6915), 1,
      anon_sym_LBRACE,
    ACTIONS(6921), 1,
      sym_uninitialized,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11550), 1,
      sym_tag,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    STATE(2958), 1,
      sym_where_clause,
    STATE(3179), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_when,
  [337804] = 10,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7167), 1,
      sym_uninitialized,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(11583), 1,
      sym_tag,
    STATE(3313), 1,
      sym_where_clause,
    STATE(3985), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_when,
  [337839] = 4,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [337862] = 4,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [337885] = 4,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [337908] = 4,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [337931] = 5,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(11585), 1,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5005), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [337956] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [337979] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338002] = 9,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7167), 1,
      sym_uninitialized,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11583), 1,
      sym_tag,
    STATE(3313), 1,
      sym_where_clause,
    STATE(3985), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [338035] = 10,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(11589), 1,
      sym_tag,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_when,
  [338070] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11589), 1,
      sym_tag,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [338103] = 9,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7175), 1,
      sym_uninitialized,
    ACTIONS(7179), 1,
      sym_tag,
    ACTIONS(11486), 1,
      anon_sym_where,
    STATE(3415), 1,
      sym_where_clause,
    STATE(3963), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [338136] = 5,
    ACTIONS(8659), 1,
      anon_sym_COMMA,
    STATE(6886), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4460), 3,
      anon_sym_where,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(4456), 6,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [338161] = 5,
    ACTIONS(11591), 1,
      anon_sym_COMMA,
    STATE(6886), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4471), 3,
      anon_sym_where,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(4466), 6,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [338186] = 5,
    ACTIONS(4460), 1,
      anon_sym_SLASH,
    ACTIONS(8640), 1,
      anon_sym_COMMA,
    STATE(6888), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4456), 8,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
      sym_uninitialized,
      sym_tag,
  [338211] = 5,
    ACTIONS(4471), 1,
      anon_sym_SLASH,
    ACTIONS(11594), 1,
      anon_sym_COMMA,
    STATE(6888), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4466), 8,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
      sym_uninitialized,
      sym_tag,
  [338236] = 10,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(11597), 1,
      sym_tag,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_when,
  [338271] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(11486), 1,
      anon_sym_where,
    ACTIONS(11597), 1,
      sym_tag,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [338304] = 9,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7181), 1,
      sym_uninitialized,
    ACTIONS(7185), 1,
      sym_tag,
    ACTIONS(11486), 1,
      anon_sym_where,
    STATE(3426), 1,
      sym_where_clause,
    STATE(3989), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [338337] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338360] = 9,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(7148), 1,
      anon_sym_LBRACE,
    ACTIONS(7187), 1,
      sym_uninitialized,
    ACTIONS(7189), 1,
      sym_tag,
    ACTIONS(11486), 1,
      anon_sym_where,
    STATE(3385), 1,
      sym_where_clause,
    STATE(3857), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [338393] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338416] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 9,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338439] = 4,
    ACTIONS(7864), 1,
      anon_sym_LPAREN,
    ACTIONS(11518), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
      sym_uninitialized,
      sym_tag,
  [338462] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [338484] = 5,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(11601), 1,
      anon_sym_LBRACE,
    ACTIONS(11603), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338508] = 5,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(11607), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11605), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338532] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [338554] = 5,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(8357), 1,
      anon_sym_LBRACE,
    ACTIONS(11603), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338578] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [338600] = 5,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(8357), 1,
      anon_sym_LBRACE,
    ACTIONS(11603), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338624] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [338646] = 6,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    STATE(7034), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11609), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338672] = 4,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(11603), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338694] = 4,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_when,
      sym_uninitialized,
      sym_tag,
  [338716] = 4,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_when,
      sym_uninitialized,
      sym_tag,
  [338738] = 4,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_when,
      sym_uninitialized,
      sym_tag,
  [338760] = 4,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(11603), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338782] = 4,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_when,
      sym_uninitialized,
      sym_tag,
  [338804] = 5,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(11601), 1,
      anon_sym_LBRACE,
    ACTIONS(11603), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338828] = 7,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11534), 1,
      sym_uninitialized,
    ACTIONS(11573), 1,
      sym_tag,
    STATE(7175), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [338856] = 7,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11575), 1,
      sym_uninitialized,
    ACTIONS(11577), 1,
      sym_tag,
    STATE(7186), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [338884] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(5105), 2,
      anon_sym_where,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [338908] = 6,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    STATE(7030), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8785), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [338934] = 7,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11552), 1,
      sym_uninitialized,
    ACTIONS(11568), 1,
      sym_tag,
    STATE(7181), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [338962] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(4753), 2,
      anon_sym_where,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [338986] = 7,
    ACTIONS(4579), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11611), 1,
      sym_uninitialized,
    ACTIONS(11613), 1,
      sym_tag,
    STATE(7187), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4577), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [339014] = 6,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11446), 1,
      anon_sym_EQ,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(5009), 2,
      anon_sym_where,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5005), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [339040] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(5003), 2,
      anon_sym_where,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [339064] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 8,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [339086] = 7,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11496), 1,
      sym_uninitialized,
    ACTIONS(11498), 1,
      sym_tag,
    STATE(7144), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [339114] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11446), 1,
      anon_sym_EQ,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5005), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_RPAREN,
      anon_sym_when,
      sym_uninitialized,
      sym_tag,
  [339138] = 5,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(11615), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8783), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339162] = 4,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11556), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_when,
      sym_uninitialized,
      sym_tag,
  [339184] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(4963), 2,
      anon_sym_where,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [339208] = 6,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    STATE(7052), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8795), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339234] = 7,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11564), 1,
      sym_uninitialized,
    ACTIONS(11617), 1,
      sym_tag,
    STATE(7159), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [339262] = 5,
    ACTIONS(6923), 1,
      anon_sym_LPAREN,
    ACTIONS(11526), 1,
      anon_sym_SLASH,
    ACTIONS(5013), 2,
      anon_sym_where,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_uninitialized,
      sym_tag,
  [339286] = 4,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(11603), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339308] = 6,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    STATE(7023), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8815), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339334] = 4,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(11603), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339356] = 4,
    ACTIONS(7787), 1,
      anon_sym_LPAREN,
    ACTIONS(11603), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 8,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339378] = 5,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(11619), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8779), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339402] = 5,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(11623), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11621), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339426] = 6,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11534), 1,
      sym_uninitialized,
    STATE(7175), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [339451] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5055), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339472] = 5,
    ACTIONS(8683), 1,
      sym__nl_comma,
    ACTIONS(8709), 1,
      anon_sym_COMMA,
    STATE(6989), 1,
      aux_sym_return_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(2914), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339495] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7350), 1,
      sym_else_clause,
    STATE(6946), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11625), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339518] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7351), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11629), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339541] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7352), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11631), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339564] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7353), 1,
      sym_else_clause,
    STATE(6948), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11633), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339587] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7354), 1,
      sym_else_clause,
    STATE(6949), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11635), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339610] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7355), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11637), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339633] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7252), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11639), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339656] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7256), 1,
      sym_else_clause,
    STATE(6950), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11641), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339679] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7257), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11643), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339702] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7262), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11645), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339725] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7094), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11647), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339748] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339769] = 6,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11496), 1,
      sym_uninitialized,
    STATE(7144), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [339794] = 8,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    STATE(8896), 1,
      sym_string,
    ACTIONS(11649), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [339823] = 8,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    STATE(8770), 1,
      sym_string,
    ACTIONS(11655), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [339852] = 9,
    ACTIONS(3483), 1,
      anon_sym_SLASH,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(11657), 1,
      anon_sym_LPAREN,
    ACTIONS(11659), 1,
      anon_sym_DOT,
    ACTIONS(11661), 1,
      anon_sym_DOT2,
    STATE(3606), 1,
      aux_sym_field_type_repeat1,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3481), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [339883] = 5,
    ACTIONS(11665), 1,
      anon_sym_else,
    STATE(7237), 1,
      sym_else_clause,
    STATE(7006), 2,
      sym_else_when_clause,
      aux_sym_when_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11663), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339906] = 5,
    ACTIONS(11665), 1,
      anon_sym_else,
    STATE(7334), 1,
      sym_else_clause,
    STATE(7006), 2,
      sym_else_when_clause,
      aux_sym_when_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11667), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [339929] = 5,
    ACTIONS(8681), 1,
      anon_sym_COMMA,
    ACTIONS(8683), 1,
      sym__nl_comma,
    STATE(6939), 1,
      aux_sym_return_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(717), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [339952] = 8,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    STATE(8900), 1,
      sym_string,
    ACTIONS(11669), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [339981] = 5,
    ACTIONS(8683), 1,
      sym__nl_comma,
    ACTIONS(11671), 1,
      anon_sym_COMMA,
    STATE(6989), 1,
      aux_sym_return_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(2940), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340004] = 5,
    ACTIONS(11665), 1,
      anon_sym_else,
    STATE(7237), 1,
      sym_else_clause,
    STATE(6957), 2,
      sym_else_when_clause,
      aux_sym_when_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11663), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340027] = 8,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    STATE(8839), 1,
      sym_string,
    ACTIONS(11673), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [340056] = 6,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11575), 1,
      sym_uninitialized,
    STATE(7186), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [340081] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5095), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340102] = 6,
    ACTIONS(4579), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11611), 1,
      sym_uninitialized,
    STATE(7187), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4577), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [340127] = 5,
    ACTIONS(11665), 1,
      anon_sym_else,
    STATE(7127), 1,
      sym_else_clause,
    STATE(6956), 2,
      sym_else_when_clause,
      aux_sym_when_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11675), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340150] = 5,
    ACTIONS(8683), 1,
      sym__nl_comma,
    ACTIONS(8709), 1,
      anon_sym_COMMA,
    STATE(6960), 1,
      aux_sym_return_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(2914), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340173] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7137), 1,
      sym_else_clause,
    STATE(6974), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11677), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340196] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7130), 1,
      sym_else_clause,
    STATE(6982), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11679), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340219] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7131), 1,
      sym_else_clause,
    STATE(6986), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11681), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340242] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340263] = 6,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11564), 1,
      sym_uninitialized,
    STATE(7159), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [340288] = 8,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    STATE(8635), 1,
      sym_string,
    ACTIONS(11683), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [340317] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7133), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11685), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340340] = 8,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    STATE(8715), 1,
      sym_string,
    ACTIONS(11687), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [340369] = 6,
    ACTIONS(4587), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11689), 1,
      sym_uninitialized,
    STATE(7190), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4585), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [340394] = 7,
    ACTIONS(3483), 1,
      anon_sym_SLASH,
    ACTIONS(11661), 1,
      anon_sym_DOT2,
    ACTIONS(11691), 1,
      anon_sym_COLON,
    ACTIONS(11693), 1,
      anon_sym_COLON_EQ,
    STATE(3606), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3481), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_when,
  [340421] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7249), 1,
      sym_else_clause,
    STATE(6941), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11695), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340444] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7250), 1,
      sym_else_clause,
    STATE(6942), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11697), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340467] = 8,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    STATE(8699), 1,
      sym_string,
    ACTIONS(11699), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [340496] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5081), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340517] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7251), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11701), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340540] = 8,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    STATE(8667), 1,
      sym_string,
    ACTIONS(11703), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [340569] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7258), 1,
      sym_else_clause,
    STATE(6945), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11705), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340592] = 8,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    STATE(8843), 1,
      sym_string,
    ACTIONS(11707), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [340621] = 5,
    ACTIONS(11627), 1,
      anon_sym_else,
    STATE(7264), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11709), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340644] = 6,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(11472), 1,
      anon_sym_LBRACE,
    ACTIONS(11552), 1,
      sym_uninitialized,
    STATE(7181), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [340669] = 4,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11711), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340690] = 4,
    STATE(6989), 1,
      aux_sym_return_statement_repeat1,
    ACTIONS(11713), 2,
      sym__nl_comma,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8807), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340711] = 4,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7003), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8789), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340731] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7352), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11631), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340753] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7258), 1,
      sym_else_clause,
    STATE(7005), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11705), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340775] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7094), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11647), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340797] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8807), 8,
      sym__newline,
      sym__nl_comma,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340813] = 5,
    ACTIONS(3435), 1,
      anon_sym_SLASH,
    ACTIONS(11718), 1,
      anon_sym_DOT2,
    STATE(7039), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3433), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [340835] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7353), 1,
      sym_else_clause,
    STATE(7049), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11633), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340857] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7013), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8799), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340877] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7025), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8799), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340897] = 4,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7019), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8795), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340917] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7008), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8797), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340937] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7354), 1,
      sym_else_clause,
    STATE(7050), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11635), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [340959] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7012), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8811), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340979] = 4,
    ACTIONS(11720), 1,
      anon_sym_COMMA,
    STATE(7003), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7608), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [340999] = 5,
    ACTIONS(3549), 1,
      anon_sym_SLASH,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    STATE(4032), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3547), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [341021] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7355), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11637), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341043] = 4,
    ACTIONS(11727), 1,
      anon_sym_else,
    STATE(7006), 2,
      sym_else_when_clause,
      aux_sym_when_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11725), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341063] = 4,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7052), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8795), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341083] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7025), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8791), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341103] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7137), 1,
      sym_else_clause,
    STATE(7031), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11677), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341125] = 4,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7003), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11730), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341145] = 5,
    ACTIONS(3483), 1,
      anon_sym_SLASH,
    ACTIONS(11718), 1,
      anon_sym_DOT2,
    STATE(6995), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3481), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [341167] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7025), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8797), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341187] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7025), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11732), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341207] = 4,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7030), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8785), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341227] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7251), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11701), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341249] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(6998), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8801), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341269] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7025), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8801), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341289] = 5,
    ACTIONS(11734), 1,
      anon_sym_else,
    STATE(7237), 1,
      sym_else_clause,
    STATE(7006), 2,
      sym_else_when_clause,
      aux_sym_when_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11663), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341311] = 4,
    ACTIONS(11736), 1,
      anon_sym_COMMA,
    STATE(7019), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(9185), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341331] = 5,
    ACTIONS(11734), 1,
      anon_sym_else,
    STATE(7334), 1,
      sym_else_clause,
    STATE(7006), 2,
      sym_else_when_clause,
      aux_sym_when_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11667), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341353] = 4,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7003), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11739), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341373] = 4,
    ACTIONS(11743), 1,
      anon_sym_else,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11741), 5,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341393] = 4,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7019), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11609), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341413] = 4,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(6999), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8803), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341433] = 4,
    ACTIONS(11746), 1,
      anon_sym_COMMA,
    STATE(7025), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8883), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341453] = 4,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7003), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8805), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341473] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7017), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8791), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341493] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7264), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11709), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341515] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7131), 1,
      sym_else_clause,
    STATE(7028), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11681), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341537] = 4,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7019), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8815), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341557] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7133), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11685), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341579] = 5,
    ACTIONS(4477), 1,
      anon_sym_SLASH,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    STATE(4032), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4475), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [341601] = 4,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7003), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8809), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341621] = 4,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7019), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11749), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341641] = 5,
    ACTIONS(4464), 1,
      anon_sym_SLASH,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    STATE(4032), 1,
      aux_sym_struct_type_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4462), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [341663] = 5,
    ACTIONS(11734), 1,
      anon_sym_else,
    STATE(7127), 1,
      sym_else_clause,
    STATE(7018), 2,
      sym_else_when_clause,
      aux_sym_when_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11675), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341685] = 5,
    ACTIONS(11734), 1,
      anon_sym_else,
    STATE(7237), 1,
      sym_else_clause,
    STATE(7020), 2,
      sym_else_when_clause,
      aux_sym_when_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11663), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341707] = 4,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7023), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8815), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341727] = 5,
    ACTIONS(3410), 1,
      anon_sym_SLASH,
    ACTIONS(11751), 1,
      anon_sym_DOT2,
    STATE(7039), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3408), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [341749] = 3,
    ACTIONS(11754), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5139), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341767] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7350), 1,
      sym_else_clause,
    STATE(7047), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11625), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341789] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7130), 1,
      sym_else_clause,
    STATE(7015), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11679), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341811] = 4,
    ACTIONS(8781), 1,
      anon_sym_COMMA,
    STATE(7003), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8779), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341831] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7249), 1,
      sym_else_clause,
    STATE(7051), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11695), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341853] = 3,
    ACTIONS(11756), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4759), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [341871] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7250), 1,
      sym_else_clause,
    STATE(6991), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11697), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341893] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7252), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11639), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341915] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7256), 1,
      sym_else_clause,
    STATE(6993), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11641), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341937] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7257), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11643), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341959] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7262), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11645), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [341981] = 5,
    ACTIONS(11716), 1,
      anon_sym_else,
    STATE(7351), 1,
      sym_else_clause,
    STATE(7022), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11629), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [342003] = 4,
    ACTIONS(8787), 1,
      anon_sym_COMMA,
    STATE(7019), 1,
      aux_sym_const_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8785), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342023] = 6,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(11607), 1,
      anon_sym_EQ,
    ACTIONS(11758), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11605), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [342046] = 7,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    ACTIONS(11762), 1,
      anon_sym_RBRACE,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342071] = 7,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    ACTIONS(11764), 1,
      anon_sym_RBRACE,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342096] = 8,
    ACTIONS(11766), 1,
      anon_sym_LBRACE,
    ACTIONS(11768), 1,
      anon_sym_where,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11772), 1,
      sym_tag,
    STATE(7510), 1,
      sym_polymorphic_parameters,
    STATE(7516), 1,
      aux_sym_struct_declaration_repeat1,
    STATE(9412), 1,
      sym_where_clause,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342123] = 7,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE,
    ACTIONS(11774), 1,
      sym_identifier,
    ACTIONS(11776), 1,
      anon_sym_LBRACE,
    STATE(7234), 1,
      sym_string,
    STATE(4019), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342148] = 7,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    ACTIONS(11778), 1,
      anon_sym_RBRACE,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342173] = 7,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE,
    ACTIONS(11780), 1,
      sym_identifier,
    ACTIONS(11782), 1,
      anon_sym_LBRACE,
    STATE(7203), 1,
      sym_string,
    STATE(4019), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342198] = 5,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(8462), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [342219] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [342238] = 6,
    ACTIONS(7911), 1,
      anon_sym_LPAREN,
    ACTIONS(11587), 1,
      anon_sym_SLASH,
    ACTIONS(11623), 1,
      anon_sym_EQ,
    ACTIONS(11786), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11621), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [342261] = 7,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    ACTIONS(11788), 1,
      anon_sym_RBRACE,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342286] = 4,
    ACTIONS(11792), 1,
      sym_identifier,
    ACTIONS(11794), 2,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11790), 4,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [342305] = 3,
    ACTIONS(3410), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3408), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT2,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [342322] = 7,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE,
    ACTIONS(11796), 1,
      sym_identifier,
    ACTIONS(11798), 1,
      anon_sym_LBRACE,
    STATE(7269), 1,
      sym_string,
    STATE(4019), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342347] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8883), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342362] = 8,
    ACTIONS(11768), 1,
      anon_sym_where,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11772), 1,
      sym_tag,
    ACTIONS(11800), 1,
      anon_sym_LBRACE,
    STATE(7389), 1,
      sym_polymorphic_parameters,
    STATE(7398), 1,
      aux_sym_struct_declaration_repeat1,
    STATE(9421), 1,
      sym_where_clause,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342389] = 7,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    ACTIONS(11802), 1,
      anon_sym_RBRACE,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342414] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [342433] = 7,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    ACTIONS(11804), 1,
      anon_sym_RBRACE,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342458] = 7,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    ACTIONS(11806), 1,
      anon_sym_RBRACE,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342483] = 7,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    ACTIONS(11808), 1,
      anon_sym_RBRACE,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342508] = 7,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    ACTIONS(11810), 1,
      anon_sym_RBRACE,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342533] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(9185), 7,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342548] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [342567] = 7,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    ACTIONS(11812), 1,
      anon_sym_RBRACE,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342592] = 5,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(11814), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [342613] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [342632] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [342651] = 4,
    ACTIONS(11818), 1,
      sym_identifier,
    ACTIONS(11820), 2,
      anon_sym_else,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11816), 4,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [342670] = 5,
    ACTIONS(7610), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7608), 4,
      anon_sym_COLON_COLON,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_SEMI,
  [342691] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11825), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342705] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11827), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342719] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11829), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342733] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11831), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342747] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11833), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342761] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11835), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342775] = 7,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4262), 1,
      aux_sym_struct_type_repeat2,
    STATE(7588), 1,
      sym_polymorphic_parameters,
    STATE(7614), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342799] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11839), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_identifier,
  [342817] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11839), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_identifier,
  [342835] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11841), 1,
      anon_sym_COMMA,
    ACTIONS(11843), 1,
      anon_sym_RPAREN,
    ACTIONS(11845), 1,
      anon_sym_when,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    STATE(7768), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342859] = 7,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3681), 1,
      aux_sym_struct_type_repeat2,
    STATE(7545), 1,
      sym_polymorphic_parameters,
    STATE(7642), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342883] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11849), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342897] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11851), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342911] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11853), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342925] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11855), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342945] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11855), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [342965] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11859), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342979] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11861), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [342993] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11863), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343007] = 3,
    ACTIONS(5097), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5095), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [343023] = 5,
    ACTIONS(7610), 1,
      anon_sym_COLON,
    ACTIONS(11865), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(7608), 3,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON,
      anon_sym_COLON_EQ,
  [343043] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5095), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [343061] = 7,
    ACTIONS(5930), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(1269), 1,
      aux_sym_struct_type_repeat2,
    STATE(7566), 1,
      sym_polymorphic_parameters,
    STATE(7692), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [343085] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11868), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343099] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11870), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343113] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11872), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343127] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11874), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343141] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11876), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343155] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11878), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343169] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11880), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343183] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11882), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343197] = 7,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4159), 1,
      aux_sym_struct_type_repeat2,
    STATE(7641), 1,
      sym_polymorphic_parameters,
    STATE(7643), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [343221] = 3,
    ACTIONS(4719), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4717), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [343237] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11884), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343251] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11886), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343265] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11888), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343279] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(11890), 1,
      anon_sym_COMMA,
    ACTIONS(11892), 1,
      anon_sym_RPAREN,
    ACTIONS(11894), 1,
      anon_sym_when,
    STATE(7870), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [343303] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11896), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343317] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11898), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343331] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11900), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343345] = 7,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3596), 1,
      aux_sym_struct_type_repeat2,
    STATE(7565), 1,
      aux_sym_struct_type_repeat1,
    STATE(7648), 1,
      sym_polymorphic_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [343369] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11902), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343383] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(11904), 1,
      anon_sym_COMMA,
    ACTIONS(11906), 1,
      anon_sym_RPAREN,
    ACTIONS(11908), 1,
      anon_sym_when,
    STATE(8102), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [343407] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11910), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343421] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11663), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343435] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11912), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343449] = 3,
    ACTIONS(911), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [343465] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11701), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343479] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11709), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343493] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11914), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343507] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11916), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343521] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11918), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343535] = 3,
    ACTIONS(3455), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3451), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [343551] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11920), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343565] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11685), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343579] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11922), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343593] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11924), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343607] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11926), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343621] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11928), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343635] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11930), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343649] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11932), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343663] = 3,
    ACTIONS(3427), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3425), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [343679] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11934), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343693] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11936), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343707] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11938), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343721] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11940), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343735] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11942), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343749] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7294), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(11944), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [343769] = 7,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(11946), 1,
      anon_sym_LBRACE,
    STATE(2986), 1,
      aux_sym_struct_type_repeat2,
    STATE(7532), 1,
      sym_polymorphic_parameters,
    STATE(7536), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [343793] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11948), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343807] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11950), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343821] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11952), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343835] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(11954), 1,
      anon_sym_COMMA,
    ACTIONS(11956), 1,
      anon_sym_RPAREN,
    ACTIONS(11958), 1,
      anon_sym_when,
    STATE(7983), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [343859] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11960), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343873] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11962), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343887] = 6,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(11964), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11966), 1,
      anon_sym_COLON,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(9748), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [343909] = 3,
    ACTIONS(3374), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3368), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [343925] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11968), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(11970), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [343945] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11973), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343959] = 3,
    ACTIONS(773), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [343975] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11975), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [343989] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6488), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344003] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11977), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344017] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11979), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344031] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11981), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344045] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11983), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344059] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11985), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344073] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11987), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344087] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11989), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344101] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11991), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344115] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11993), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344129] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11995), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344143] = 3,
    ACTIONS(3388), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3384), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344159] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11997), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344173] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11999), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344187] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11839), 1,
      anon_sym_SLASH,
    ACTIONS(12001), 1,
      sym_identifier,
    ACTIONS(12005), 1,
      anon_sym_EQ,
    ACTIONS(12003), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344209] = 7,
    ACTIONS(5930), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(1451), 1,
      aux_sym_struct_type_repeat2,
    STATE(7678), 1,
      sym_polymorphic_parameters,
    STATE(7684), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344233] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12007), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344247] = 3,
    ACTIONS(3402), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3400), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344263] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12009), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344277] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12011), 1,
      anon_sym_COMMA,
    ACTIONS(12013), 1,
      anon_sym_RPAREN,
    ACTIONS(12015), 1,
      anon_sym_when,
    STATE(7756), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344301] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5055), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [344319] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12017), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344333] = 3,
    ACTIONS(4579), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4577), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344349] = 3,
    ACTIONS(4587), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4585), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344365] = 6,
    ACTIONS(11661), 1,
      anon_sym_DOT2,
    ACTIONS(12021), 1,
      anon_sym_COLON,
    ACTIONS(12023), 1,
      anon_sym_COLON_EQ,
    STATE(3606), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(12019), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344387] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12025), 1,
      anon_sym_COMMA,
    ACTIONS(12027), 1,
      anon_sym_RPAREN,
    ACTIONS(12029), 1,
      anon_sym_when,
    STATE(8085), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344411] = 3,
    ACTIONS(4951), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4949), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344427] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12031), 1,
      anon_sym_COMMA,
    ACTIONS(12033), 1,
      anon_sym_RPAREN,
    ACTIONS(12035), 1,
      anon_sym_when,
    STATE(7937), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344451] = 3,
    ACTIONS(5084), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5081), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344467] = 7,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3728), 1,
      aux_sym_struct_type_repeat2,
    STATE(7740), 1,
      sym_polymorphic_parameters,
    STATE(7742), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344491] = 6,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(12037), 1,
      sym_identifier,
    STATE(8268), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344513] = 6,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(12039), 1,
      sym_identifier,
    STATE(8174), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344535] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12041), 1,
      anon_sym_COMMA,
    ACTIONS(12043), 1,
      anon_sym_RPAREN,
    ACTIONS(12045), 1,
      anon_sym_when,
    STATE(8075), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344559] = 6,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE,
    ACTIONS(12047), 1,
      anon_sym_LBRACE,
    STATE(7084), 1,
      sym_string,
    STATE(4019), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344581] = 3,
    ACTIONS(4955), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4953), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344597] = 3,
    ACTIONS(3483), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3481), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344613] = 6,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE,
    ACTIONS(12049), 1,
      anon_sym_LBRACE,
    STATE(7213), 1,
      sym_string,
    STATE(4019), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344635] = 4,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344653] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12051), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344667] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12053), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344681] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12055), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344701] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7310), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12057), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344721] = 3,
    ACTIONS(874), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344737] = 6,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(12059), 1,
      sym_identifier,
    STATE(7828), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344759] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12061), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344773] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12063), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344787] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12057), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344807] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12065), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344821] = 3,
    ACTIONS(4685), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4683), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344837] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12067), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344851] = 6,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(11760), 1,
      sym_identifier,
    STATE(8720), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [344873] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12069), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344887] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12071), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344901] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12073), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344915] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12075), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344929] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12077), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344943] = 3,
    ACTIONS(4991), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4989), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344959] = 4,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [344977] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12079), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [344991] = 4,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345009] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12081), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345023] = 6,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(12083), 1,
      sym_identifier,
    STATE(8007), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345045] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7322), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12085), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345065] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12087), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345079] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12089), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345093] = 6,
    ACTIONS(11661), 1,
      anon_sym_DOT2,
    ACTIONS(12093), 1,
      anon_sym_COLON,
    ACTIONS(12095), 1,
      anon_sym_COLON_EQ,
    STATE(3606), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(12091), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345115] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12097), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345129] = 7,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3605), 1,
      aux_sym_struct_type_repeat2,
    STATE(7582), 1,
      sym_polymorphic_parameters,
    STATE(7598), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345153] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12099), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345167] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12101), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345181] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12103), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345195] = 3,
    ACTIONS(895), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345211] = 7,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12105), 1,
      anon_sym_LBRACE,
    STATE(3035), 1,
      aux_sym_struct_type_repeat2,
    STATE(7592), 1,
      sym_polymorphic_parameters,
    STATE(7593), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345235] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11667), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345249] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7327), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12085), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345269] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12107), 1,
      anon_sym_COMMA,
    ACTIONS(12109), 1,
      anon_sym_RPAREN,
    ACTIONS(12111), 1,
      anon_sym_when,
    STATE(8189), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345293] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12113), 1,
      anon_sym_COMMA,
    ACTIONS(12115), 1,
      anon_sym_RPAREN,
    ACTIONS(12117), 1,
      anon_sym_when,
    STATE(8216), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345317] = 6,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(12119), 1,
      sym_identifier,
    STATE(8110), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345339] = 7,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12121), 1,
      anon_sym_LBRACE,
    STATE(662), 1,
      aux_sym_struct_type_repeat2,
    STATE(7630), 1,
      sym_polymorphic_parameters,
    STATE(7637), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345363] = 3,
    ACTIONS(5037), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5035), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345379] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12123), 1,
      anon_sym_COMMA,
    ACTIONS(12125), 1,
      anon_sym_RPAREN,
    ACTIONS(12127), 1,
      anon_sym_when,
    STATE(7994), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345403] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12129), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345417] = 4,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345435] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12131), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345449] = 3,
    ACTIONS(4711), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4709), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345465] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11629), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345479] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11631), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345493] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12133), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345507] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12135), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345521] = 6,
    ACTIONS(53), 1,
      anon_sym_DQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE,
    ACTIONS(12137), 1,
      anon_sym_LBRACE,
    STATE(7232), 1,
      sym_string,
    STATE(4019), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345543] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11839), 1,
      anon_sym_SLASH,
    ACTIONS(12139), 1,
      sym_identifier,
    ACTIONS(12143), 1,
      anon_sym_EQ,
    ACTIONS(12141), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345565] = 3,
    ACTIONS(4691), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4689), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345581] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11647), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345595] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12145), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345609] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11637), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345623] = 3,
    ACTIONS(5129), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5127), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345639] = 3,
    ACTIONS(5133), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5131), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345655] = 3,
    ACTIONS(5137), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5135), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345671] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12147), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345685] = 3,
    ACTIONS(5141), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5139), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345701] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12149), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345715] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12151), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345729] = 3,
    ACTIONS(5239), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5237), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [345745] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12153), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345759] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12155), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345773] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12157), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345787] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12159), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345801] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12161), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345815] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12163), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345829] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12165), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345843] = 7,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(2678), 1,
      aux_sym_struct_type_repeat2,
    STATE(7561), 1,
      sym_polymorphic_parameters,
    STATE(7562), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345867] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12167), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345881] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12169), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345895] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12171), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345909] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12173), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [345923] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12175), 1,
      anon_sym_COMMA,
    ACTIONS(12177), 1,
      anon_sym_RPAREN,
    ACTIONS(12179), 1,
      anon_sym_when,
    STATE(8324), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [345947] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11839), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_identifier,
  [345965] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11839), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_identifier,
  [345983] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11839), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
      sym_identifier,
  [346001] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12181), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346015] = 3,
    ACTIONS(5243), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5241), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346031] = 3,
    ACTIONS(5247), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5245), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346047] = 3,
    ACTIONS(5251), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5249), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346063] = 3,
    ACTIONS(5255), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5253), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346079] = 4,
    ACTIONS(11651), 1,
      anon_sym_LPAREN,
    ACTIONS(11653), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 4,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346097] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12183), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346111] = 3,
    ACTIONS(5061), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5059), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346127] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12185), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346141] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12187), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346155] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7204), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12189), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346175] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12189), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346195] = 7,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12191), 1,
      anon_sym_LBRACE,
    STATE(1468), 1,
      aux_sym_struct_type_repeat2,
    STATE(7615), 1,
      sym_polymorphic_parameters,
    STATE(7618), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346219] = 3,
    ACTIONS(5057), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5055), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346235] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7210), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12193), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346255] = 3,
    ACTIONS(4727), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4725), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346271] = 3,
    ACTIONS(4737), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4735), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346287] = 3,
    ACTIONS(4741), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4739), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346303] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12195), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346317] = 3,
    ACTIONS(4745), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4743), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346333] = 3,
    ACTIONS(4761), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4759), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346349] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12197), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346363] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12199), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346377] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12201), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346391] = 3,
    ACTIONS(4789), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4787), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346407] = 3,
    ACTIONS(4797), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4795), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346423] = 3,
    ACTIONS(4805), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4803), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346439] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12203), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346459] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(767), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [346477] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12205), 1,
      anon_sym_COMMA,
    ACTIONS(12207), 1,
      anon_sym_RPAREN,
    ACTIONS(12209), 1,
      anon_sym_when,
    STATE(8182), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346501] = 7,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(7035), 1,
      aux_sym_struct_type_repeat2,
    STATE(7632), 1,
      sym_polymorphic_parameters,
    STATE(7633), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346525] = 3,
    ACTIONS(4809), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4807), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346541] = 3,
    ACTIONS(4813), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4811), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346557] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12211), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346571] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7097), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12213), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346591] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12215), 1,
      anon_sym_COMMA,
    ACTIONS(12217), 1,
      anon_sym_RPAREN,
    ACTIONS(12219), 1,
      anon_sym_when,
    STATE(8482), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346615] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12221), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346629] = 3,
    ACTIONS(4817), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4815), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346645] = 3,
    ACTIONS(4857), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4855), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346661] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12213), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346681] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7098), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12213), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346701] = 3,
    ACTIONS(4861), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4859), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346717] = 3,
    ACTIONS(4865), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4863), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346733] = 6,
    ACTIONS(11661), 1,
      anon_sym_DOT2,
    ACTIONS(12225), 1,
      anon_sym_COLON,
    ACTIONS(12227), 1,
      anon_sym_COLON_EQ,
    STATE(3606), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(12223), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346755] = 5,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(12213), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346775] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12229), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346789] = 3,
    ACTIONS(812), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346805] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12231), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346819] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12233), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346833] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12235), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346847] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12237), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346861] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12239), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346875] = 7,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4230), 1,
      aux_sym_struct_type_repeat2,
    STATE(7715), 1,
      sym_polymorphic_parameters,
    STATE(7723), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [346899] = 3,
    ACTIONS(4703), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4701), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [346915] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12241), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346929] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12243), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346943] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12245), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346957] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12247), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346971] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12249), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [346985] = 7,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12251), 1,
      anon_sym_LBRACE,
    STATE(3443), 1,
      aux_sym_struct_type_repeat2,
    STATE(7702), 1,
      sym_polymorphic_parameters,
    STATE(7703), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347009] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12253), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [347023] = 3,
    ACTIONS(4947), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4945), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_BQUOTE,
  [347039] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12255), 1,
      anon_sym_COMMA,
    ACTIONS(12257), 1,
      anon_sym_RPAREN,
    ACTIONS(12259), 1,
      anon_sym_when,
    STATE(8570), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347063] = 7,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(2584), 1,
      aux_sym_struct_type_repeat2,
    STATE(7718), 1,
      sym_polymorphic_parameters,
    STATE(7721), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347087] = 6,
    ACTIONS(689), 1,
      anon_sym_DQUOTE,
    ACTIONS(691), 1,
      anon_sym_BQUOTE,
    ACTIONS(12261), 1,
      sym_identifier,
    STATE(8263), 1,
      sym_string,
    STATE(4035), 2,
      sym__string_literal,
      sym__raw_string_literal,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347109] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12263), 1,
      anon_sym_COMMA,
    ACTIONS(12265), 1,
      anon_sym_RPAREN,
    ACTIONS(12267), 1,
      anon_sym_when,
    STATE(8540), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347133] = 7,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(12269), 1,
      anon_sym_COMMA,
    ACTIONS(12271), 1,
      anon_sym_RPAREN,
    ACTIONS(12273), 1,
      anon_sym_when,
    STATE(8360), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347157] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11639), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [347171] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12275), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [347185] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12277), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [347199] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11643), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [347213] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11645), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [347227] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12279), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [347241] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12281), 6,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_case,
  [347255] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [347273] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12285), 1,
      anon_sym_RPAREN,
    STATE(8212), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347294] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12287), 1,
      anon_sym_RBRACE,
    ACTIONS(12289), 1,
      anon_sym_COMMA,
    STATE(8467), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347315] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12291), 1,
      anon_sym_RBRACE,
    ACTIONS(12293), 1,
      anon_sym_COMMA,
    STATE(7896), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347336] = 5,
    ACTIONS(12295), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7380), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347355] = 5,
    ACTIONS(12295), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347374] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4945), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [347391] = 6,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(11964), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11966), 1,
      anon_sym_COLON,
    ACTIONS(12297), 1,
      anon_sym_COLON_EQ,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347412] = 4,
    ACTIONS(12299), 1,
      anon_sym_COMMA,
    STATE(7025), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3511), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [347429] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12301), 1,
      anon_sym_RPAREN,
    STATE(7900), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347450] = 6,
    ACTIONS(12303), 1,
      anon_sym_COMMA,
    ACTIONS(12305), 1,
      anon_sym_COLON,
    ACTIONS(12307), 1,
      anon_sym_RPAREN,
    STATE(7705), 1,
      aux_sym_parameter_repeat1,
    STATE(8657), 1,
      sym__param_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347471] = 4,
    ACTIONS(895), 1,
      anon_sym_SLASH,
    ACTIONS(8462), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [347488] = 5,
    ACTIONS(12309), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347507] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12311), 1,
      anon_sym_RBRACE,
    ACTIONS(12313), 1,
      anon_sym_COMMA,
    STATE(8109), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347528] = 5,
    ACTIONS(12315), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7387), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347547] = 5,
    ACTIONS(12315), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347566] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5081), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [347583] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12319), 1,
      anon_sym_RBRACE,
    ACTIONS(12321), 1,
      anon_sym_using,
    STATE(8281), 1,
      sym_struct_member,
    STATE(8956), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347604] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12323), 1,
      anon_sym_RPAREN,
    STATE(8112), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347625] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12327), 1,
      anon_sym_RBRACE,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    STATE(8632), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347646] = 5,
    ACTIONS(12333), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7369), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347665] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12335), 1,
      anon_sym_RBRACE,
    ACTIONS(12337), 1,
      anon_sym_COMMA,
    STATE(8147), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347686] = 5,
    ACTIONS(12339), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347705] = 5,
    ACTIONS(12341), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347724] = 5,
    ACTIONS(12343), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7417), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347743] = 5,
    ACTIONS(12343), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347762] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12345), 1,
      anon_sym_RPAREN,
    STATE(8160), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347783] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12347), 1,
      anon_sym_RBRACE,
    ACTIONS(12349), 1,
      anon_sym_COMMA,
    STATE(7816), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347804] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(871), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [347821] = 4,
    ACTIONS(8793), 1,
      anon_sym_COMMA,
    STATE(7012), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8811), 3,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [347838] = 5,
    ACTIONS(12351), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347857] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    ACTIONS(12353), 1,
      anon_sym_RBRACE,
    STATE(7838), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347878] = 6,
    ACTIONS(11768), 1,
      anon_sym_where,
    ACTIONS(11772), 1,
      sym_tag,
    ACTIONS(12355), 1,
      anon_sym_LBRACE,
    STATE(7471), 1,
      aux_sym_struct_declaration_repeat1,
    STATE(9364), 1,
      sym_where_clause,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347899] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12357), 1,
      anon_sym_RBRACE,
    ACTIONS(12359), 1,
      anon_sym_COMMA,
    STATE(8059), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347920] = 5,
    ACTIONS(12361), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7382), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347939] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    ACTIONS(12363), 1,
      anon_sym_RBRACE,
    STATE(8632), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347960] = 5,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(12365), 1,
      anon_sym_COLON,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(9772), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [347979] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    ACTIONS(12363), 1,
      anon_sym_RBRACE,
    STATE(8548), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348000] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12367), 1,
      anon_sym_RPAREN,
    STATE(7819), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348021] = 5,
    ACTIONS(12369), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348040] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12371), 1,
      anon_sym_RPAREN,
    STATE(7752), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348061] = 6,
    ACTIONS(11768), 1,
      anon_sym_where,
    ACTIONS(11772), 1,
      sym_tag,
    ACTIONS(12355), 1,
      anon_sym_LBRACE,
    STATE(7600), 1,
      aux_sym_struct_declaration_repeat1,
    STATE(9364), 1,
      sym_where_clause,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348082] = 4,
    ACTIONS(9412), 1,
      anon_sym_COMMA,
    STATE(7402), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(9410), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [348099] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(9113), 1,
      anon_sym_RBRACE,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12373), 1,
      anon_sym_COMMA,
    STATE(8553), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348120] = 5,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(7826), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(4751), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348139] = 4,
    ACTIONS(9558), 1,
      anon_sym_COMMA,
    STATE(7025), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3366), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [348156] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12375), 1,
      anon_sym_RPAREN,
    STATE(8089), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348177] = 4,
    ACTIONS(11661), 1,
      anon_sym_DOT2,
    STATE(3606), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12091), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [348194] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    ACTIONS(12377), 1,
      anon_sym_RBRACE,
    STATE(8632), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348215] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    ACTIONS(12379), 1,
      anon_sym_RBRACE,
    STATE(8632), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348236] = 4,
    ACTIONS(911), 1,
      anon_sym_SLASH,
    ACTIONS(11814), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(909), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [348253] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(893), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [348270] = 4,
    ACTIONS(4761), 1,
      anon_sym_SLASH,
    ACTIONS(12381), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4759), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [348287] = 5,
    ACTIONS(12383), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7426), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348306] = 5,
    ACTIONS(12385), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7529), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348325] = 4,
    ACTIONS(9558), 1,
      anon_sym_COMMA,
    STATE(7523), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3366), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [348342] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12387), 1,
      anon_sym_RBRACE,
    STATE(8281), 1,
      sym_struct_member,
    STATE(9542), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348363] = 5,
    ACTIONS(12389), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7420), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348382] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12391), 1,
      anon_sym_RBRACE,
    STATE(8281), 1,
      sym_struct_member,
    STATE(9134), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348403] = 5,
    ACTIONS(12385), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348422] = 5,
    ACTIONS(12393), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348441] = 5,
    ACTIONS(12395), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7429), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348460] = 5,
    ACTIONS(12397), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7428), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348479] = 5,
    ACTIONS(12397), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348498] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12399), 1,
      anon_sym_COMMA,
    ACTIONS(12401), 1,
      anon_sym_RPAREN,
    STATE(8050), 1,
      aux_sym_polymorphic_parameters_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348519] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12403), 1,
      anon_sym_RBRACE,
    ACTIONS(12405), 1,
      anon_sym_COMMA,
    STATE(8209), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348540] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12407), 1,
      anon_sym_RBRACE,
    STATE(8281), 1,
      sym_struct_member,
    STATE(9532), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348561] = 5,
    ACTIONS(12409), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7445), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348580] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(8831), 1,
      anon_sym_RBRACE,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12411), 1,
      anon_sym_COMMA,
    STATE(7890), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348601] = 5,
    ACTIONS(12409), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348620] = 5,
    ACTIONS(12413), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7436), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348639] = 5,
    ACTIONS(12415), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348658] = 5,
    ACTIONS(12413), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348677] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12417), 1,
      anon_sym_RBRACE,
    ACTIONS(12419), 1,
      anon_sym_COMMA,
    STATE(8056), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348698] = 5,
    ACTIONS(12421), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348717] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12423), 1,
      anon_sym_RBRACE,
    ACTIONS(12425), 1,
      anon_sym_COMMA,
    STATE(8290), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348738] = 4,
    ACTIONS(11661), 1,
      anon_sym_DOT2,
    STATE(3606), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12223), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [348755] = 5,
    ACTIONS(12427), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7431), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348774] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12429), 1,
      anon_sym_RPAREN,
    STATE(8065), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348795] = 5,
    ACTIONS(12431), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348814] = 5,
    ACTIONS(12433), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348833] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12435), 1,
      anon_sym_RPAREN,
    STATE(8306), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348854] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    ACTIONS(12437), 1,
      anon_sym_RBRACE,
    STATE(8632), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348875] = 5,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(8783), 1,
      anon_sym_SEMI,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12439), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348894] = 5,
    ACTIONS(12441), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7452), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348913] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12443), 1,
      anon_sym_RBRACE,
    STATE(8281), 1,
      sym_struct_member,
    STATE(9165), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348934] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5103), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_when,
  [348951] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4751), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_when,
  [348968] = 5,
    ACTIONS(12445), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [348987] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12447), 1,
      anon_sym_RPAREN,
    STATE(8478), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349008] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12449), 1,
      anon_sym_RBRACE,
    ACTIONS(12451), 1,
      anon_sym_COMMA,
    STATE(8497), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349029] = 5,
    ACTIONS(12453), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7470), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349048] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(4961), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_when,
  [349065] = 4,
    ACTIONS(9452), 1,
      anon_sym_COMMA,
    STATE(7365), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3509), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [349082] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5011), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_when,
  [349099] = 5,
    ACTIONS(12453), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349118] = 5,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(11605), 1,
      anon_sym_SEMI,
    ACTIONS(12455), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349137] = 5,
    ACTIONS(12457), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7461), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349156] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12459), 1,
      anon_sym_RBRACE,
    STATE(8281), 1,
      sym_struct_member,
    STATE(9602), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349177] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12461), 1,
      anon_sym_RPAREN,
    STATE(8607), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349198] = 5,
    ACTIONS(12463), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7416), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349217] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12465), 1,
      anon_sym_RBRACE,
    ACTIONS(12467), 1,
      anon_sym_COMMA,
    STATE(8003), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349238] = 5,
    ACTIONS(12469), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349257] = 5,
    ACTIONS(12471), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7466), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349276] = 5,
    ACTIONS(12471), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349295] = 5,
    ACTIONS(12473), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7513), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349314] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12475), 1,
      anon_sym_RPAREN,
    STATE(8006), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349335] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12477), 1,
      anon_sym_RBRACE,
    ACTIONS(12479), 1,
      anon_sym_COMMA,
    STATE(8359), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349356] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12481), 1,
      anon_sym_RPAREN,
    STATE(8365), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349377] = 5,
    ACTIONS(12483), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349396] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12327), 1,
      anon_sym_RBRACE,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    STATE(8118), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349417] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    ACTIONS(12485), 1,
      anon_sym_RBRACE,
    STATE(7763), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349438] = 5,
    ACTIONS(12487), 1,
      sym_identifier,
    ACTIONS(12491), 1,
      anon_sym_where,
    ACTIONS(12493), 1,
      sym_number,
    ACTIONS(12489), 2,
      anon_sym_LBRACE,
      sym_tag,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349457] = 5,
    ACTIONS(12495), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349476] = 6,
    ACTIONS(11768), 1,
      anon_sym_where,
    ACTIONS(11772), 1,
      sym_tag,
    ACTIONS(12497), 1,
      anon_sym_LBRACE,
    STATE(7600), 1,
      aux_sym_struct_declaration_repeat1,
    STATE(9416), 1,
      sym_where_clause,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349497] = 5,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(8779), 1,
      anon_sym_SEMI,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12499), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349516] = 5,
    ACTIONS(12501), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7484), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349535] = 5,
    ACTIONS(12503), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7506), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349554] = 4,
    ACTIONS(11661), 1,
      anon_sym_DOT2,
    STATE(3606), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12505), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [349571] = 6,
    ACTIONS(9361), 1,
      anon_sym_COLON,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(9498), 1,
      anon_sym_COLON_EQ,
    ACTIONS(11263), 1,
      anon_sym_COLON_COLON,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349592] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12507), 1,
      anon_sym_RBRACE,
    ACTIONS(12509), 1,
      anon_sym_COMMA,
    STATE(8309), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349613] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12511), 1,
      anon_sym_RBRACE,
    ACTIONS(12513), 1,
      anon_sym_COMMA,
    STATE(8612), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349634] = 5,
    ACTIONS(12515), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7486), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349653] = 4,
    ACTIONS(5141), 1,
      anon_sym_SLASH,
    ACTIONS(12517), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5139), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [349670] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12519), 1,
      anon_sym_RBRACE,
    STATE(8281), 1,
      sym_struct_member,
    STATE(9245), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349691] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12521), 1,
      anon_sym_RBRACE,
    STATE(8281), 1,
      sym_struct_member,
    STATE(9280), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349712] = 5,
    ACTIONS(12523), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7499), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349731] = 5,
    ACTIONS(12523), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349750] = 5,
    ACTIONS(12525), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7493), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349769] = 5,
    ACTIONS(12525), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349788] = 5,
    ACTIONS(12427), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349807] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(8833), 1,
      anon_sym_RBRACE,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12527), 1,
      anon_sym_COMMA,
    STATE(8124), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349828] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12529), 1,
      anon_sym_RBRACE,
    ACTIONS(12531), 1,
      anon_sym_COMMA,
    STATE(8500), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349849] = 5,
    ACTIONS(12533), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7372), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349868] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12535), 1,
      anon_sym_RPAREN,
    STATE(8502), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349889] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12537), 1,
      anon_sym_RBRACE,
    ACTIONS(12539), 1,
      anon_sym_COMMA,
    STATE(8217), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349910] = 5,
    ACTIONS(12541), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349929] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12543), 1,
      anon_sym_RPAREN,
    STATE(8337), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349950] = 6,
    ACTIONS(12303), 1,
      anon_sym_COMMA,
    ACTIONS(12305), 1,
      anon_sym_COLON,
    ACTIONS(12545), 1,
      anon_sym_RPAREN,
    STATE(7367), 1,
      aux_sym_parameter_repeat1,
    STATE(8811), 1,
      sym__param_type,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349971] = 5,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12547), 1,
      anon_sym_EQ,
    ACTIONS(5005), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [349990] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12399), 1,
      anon_sym_COMMA,
    ACTIONS(12549), 1,
      anon_sym_RPAREN,
    STATE(8251), 1,
      aux_sym_polymorphic_parameters_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350011] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12551), 1,
      anon_sym_RPAREN,
    STATE(8226), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350032] = 5,
    ACTIONS(12553), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350051] = 5,
    ACTIONS(12309), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7437), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350070] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12555), 1,
      anon_sym_RBRACE,
    STATE(8281), 1,
      sym_struct_member,
    STATE(9250), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350091] = 5,
    ACTIONS(12557), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7396), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350110] = 4,
    ACTIONS(11661), 1,
      anon_sym_DOT2,
    STATE(3606), 1,
      aux_sym_field_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12019), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [350127] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(809), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [350144] = 5,
    ACTIONS(12559), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7379), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350163] = 5,
    ACTIONS(12559), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350182] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    ACTIONS(12561), 1,
      anon_sym_RBRACE,
    STATE(8632), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350203] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12399), 1,
      anon_sym_COMMA,
    ACTIONS(12563), 1,
      anon_sym_RPAREN,
    STATE(8505), 1,
      aux_sym_polymorphic_parameters_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350224] = 6,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    ACTIONS(12561), 1,
      anon_sym_RBRACE,
    STATE(7911), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350245] = 6,
    ACTIONS(11768), 1,
      anon_sym_where,
    ACTIONS(11772), 1,
      sym_tag,
    ACTIONS(11800), 1,
      anon_sym_LBRACE,
    STATE(7398), 1,
      aux_sym_struct_declaration_repeat1,
    STATE(9421), 1,
      sym_where_clause,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350266] = 5,
    ACTIONS(12565), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7519), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350285] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(9131), 1,
      anon_sym_RBRACE,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12567), 1,
      anon_sym_COMMA,
    STATE(7951), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350306] = 5,
    ACTIONS(12557), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350325] = 5,
    ACTIONS(12569), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7527), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350344] = 5,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(11621), 1,
      anon_sym_SEMI,
    ACTIONS(12571), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350363] = 6,
    ACTIONS(11768), 1,
      anon_sym_where,
    ACTIONS(11772), 1,
      sym_tag,
    ACTIONS(11800), 1,
      anon_sym_LBRACE,
    STATE(7600), 1,
      aux_sym_struct_declaration_repeat1,
    STATE(9421), 1,
      sym_where_clause,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350384] = 5,
    ACTIONS(12573), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7487), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350403] = 5,
    ACTIONS(12575), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7524), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350422] = 5,
    ACTIONS(12575), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350441] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12577), 1,
      anon_sym_RBRACE,
    STATE(8281), 1,
      sym_struct_member,
    STATE(9332), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350462] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12579), 1,
      anon_sym_RBRACE,
    ACTIONS(12581), 1,
      anon_sym_COMMA,
    STATE(8593), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350483] = 6,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12583), 1,
      anon_sym_RPAREN,
    STATE(8605), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350504] = 4,
    ACTIONS(9452), 1,
      anon_sym_COMMA,
    STATE(7025), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(3509), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [350521] = 5,
    ACTIONS(12585), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350540] = 5,
    ACTIONS(12587), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7362), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350559] = 5,
    ACTIONS(12589), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7459), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350578] = 5,
    ACTIONS(12589), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350597] = 6,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12591), 1,
      anon_sym_RBRACE,
    STATE(8281), 1,
      sym_struct_member,
    STATE(9227), 1,
      sym__struct_members,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350618] = 5,
    ACTIONS(12593), 1,
      anon_sym_RBRACE,
    STATE(40), 1,
      sym__separator,
    STATE(7160), 1,
      aux_sym_block_repeat1,
    ACTIONS(11857), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350637] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(5001), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_when,
  [350654] = 5,
    ACTIONS(12595), 1,
      anon_sym_RBRACE,
    ACTIONS(12597), 1,
      anon_sym_COMMA,
    ACTIONS(12599), 1,
      anon_sym_EQ,
    STATE(8498), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350672] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(11946), 1,
      anon_sym_LBRACE,
    STATE(3001), 1,
      aux_sym_struct_type_repeat2,
    STATE(7568), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350690] = 5,
    ACTIONS(9734), 1,
      anon_sym_COMMA,
    ACTIONS(12601), 1,
      anon_sym_EQ,
    ACTIONS(12603), 1,
      anon_sym_RPAREN,
    STATE(8326), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350708] = 4,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(12605), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350724] = 4,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(9363), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350740] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(11946), 1,
      anon_sym_LBRACE,
    STATE(3001), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350758] = 5,
    ACTIONS(12607), 1,
      anon_sym_DQUOTE,
    ACTIONS(12611), 1,
      sym_comment,
    STATE(7697), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12609), 2,
      sym_string_content,
      sym_escape_sequence,
  [350776] = 5,
    ACTIONS(12613), 1,
      anon_sym_LBRACE,
    ACTIONS(12615), 1,
      anon_sym_LPAREN,
    ACTIONS(12617), 1,
      anon_sym_DOT,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350794] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12619), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [350812] = 4,
    ACTIONS(12623), 1,
      anon_sym_RBRACE,
    ACTIONS(12625), 1,
      anon_sym_case,
    STATE(7622), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350828] = 4,
    ACTIONS(12625), 1,
      anon_sym_case,
    ACTIONS(12627), 1,
      anon_sym_RBRACE,
    STATE(7613), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350844] = 5,
    ACTIONS(9820), 1,
      anon_sym_COMMA,
    ACTIONS(9824), 1,
      anon_sym_RPAREN,
    ACTIONS(12629), 1,
      anon_sym_EQ,
    STATE(8558), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350862] = 4,
    ACTIONS(9732), 1,
      anon_sym_COMMA,
    STATE(7547), 1,
      aux_sym__simple_assignment_statement_repeat1,
    ACTIONS(9886), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350878] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12631), 1,
      anon_sym_DQUOTE,
    STATE(7552), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12633), 2,
      sym_string_content,
      sym_escape_sequence,
  [350896] = 5,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3690), 1,
      aux_sym_struct_type_repeat2,
    STATE(7575), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350914] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12635), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350930] = 4,
    ACTIONS(12637), 1,
      anon_sym_COMMA,
    STATE(7547), 1,
      aux_sym__simple_assignment_statement_repeat1,
    ACTIONS(10268), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350946] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(11968), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [350958] = 5,
    ACTIONS(12617), 1,
      anon_sym_DOT,
    ACTIONS(12640), 1,
      anon_sym_LBRACE,
    ACTIONS(12642), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350976] = 4,
    ACTIONS(12644), 1,
      anon_sym_COMMA,
    STATE(7550), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(7608), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [350992] = 5,
    ACTIONS(9840), 1,
      anon_sym_COMMA,
    ACTIONS(9844), 1,
      anon_sym_RPAREN,
    ACTIONS(12647), 1,
      anon_sym_EQ,
    STATE(8107), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351010] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12649), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [351028] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12651), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351044] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12653), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [351062] = 5,
    ACTIONS(12617), 1,
      anon_sym_DOT,
    ACTIONS(12655), 1,
      anon_sym_LBRACE,
    ACTIONS(12657), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351080] = 4,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(12659), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351096] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12661), 1,
      anon_sym_DQUOTE,
    STATE(7571), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12663), 2,
      sym_string_content,
      sym_escape_sequence,
  [351114] = 5,
    ACTIONS(12665), 1,
      anon_sym_RBRACE,
    ACTIONS(12667), 1,
      anon_sym_COMMA,
    ACTIONS(12669), 1,
      anon_sym_EQ,
    STATE(8371), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351132] = 5,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(11657), 1,
      anon_sym_LPAREN,
    ACTIONS(12617), 1,
      anon_sym_DOT,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351150] = 5,
    ACTIONS(9858), 1,
      anon_sym_COMMA,
    ACTIONS(9888), 1,
      anon_sym_RPAREN,
    ACTIONS(12671), 1,
      anon_sym_EQ,
    STATE(7879), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351168] = 5,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(2681), 1,
      aux_sym_struct_type_repeat2,
    STATE(7580), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351186] = 5,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(2681), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351204] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12673), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351220] = 5,
    ACTIONS(12675), 1,
      anon_sym_RBRACE,
    ACTIONS(12677), 1,
      anon_sym_COMMA,
    ACTIONS(12679), 1,
      anon_sym_EQ,
    STATE(7824), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351238] = 5,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3686), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351256] = 5,
    ACTIONS(5930), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(1270), 1,
      aux_sym_struct_type_repeat2,
    STATE(7573), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351274] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12681), 1,
      anon_sym_DQUOTE,
    STATE(7597), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12683), 2,
      sym_string_content,
      sym_escape_sequence,
  [351292] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(11946), 1,
      anon_sym_LBRACE,
    STATE(3015), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351310] = 5,
    ACTIONS(12685), 1,
      anon_sym_RBRACE,
    ACTIONS(12687), 1,
      anon_sym_COMMA,
    ACTIONS(12689), 1,
      anon_sym_EQ,
    STATE(8001), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351328] = 5,
    ACTIONS(9814), 1,
      anon_sym_COMMA,
    ACTIONS(9818), 1,
      anon_sym_RPAREN,
    ACTIONS(12691), 1,
      anon_sym_EQ,
    STATE(8093), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351346] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12693), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [351364] = 5,
    ACTIONS(12695), 1,
      anon_sym_RBRACE,
    ACTIONS(12697), 1,
      anon_sym_COMMA,
    ACTIONS(12699), 1,
      anon_sym_EQ,
    STATE(8579), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351382] = 5,
    ACTIONS(5930), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(1272), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351400] = 5,
    ACTIONS(4779), 1,
      anon_sym_import,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(12701), 1,
      sym_identifier,
    STATE(7166), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351418] = 5,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3704), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351436] = 5,
    ACTIONS(9874), 1,
      anon_sym_COMMA,
    ACTIONS(9878), 1,
      anon_sym_RPAREN,
    ACTIONS(12703), 1,
      anon_sym_EQ,
    STATE(8195), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351454] = 5,
    ACTIONS(12617), 1,
      anon_sym_DOT,
    ACTIONS(12705), 1,
      anon_sym_LBRACE,
    ACTIONS(12707), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351472] = 5,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(2568), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351490] = 4,
    ACTIONS(12625), 1,
      anon_sym_case,
    ACTIONS(12709), 1,
      anon_sym_RBRACE,
    STATE(7622), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351506] = 5,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(2688), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351524] = 5,
    ACTIONS(12711), 1,
      anon_sym_RBRACE,
    ACTIONS(12713), 1,
      anon_sym_COMMA,
    ACTIONS(12715), 1,
      anon_sym_EQ,
    STATE(8356), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351542] = 5,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3707), 1,
      aux_sym_struct_type_repeat2,
    STATE(7690), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351560] = 4,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(9772), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351576] = 4,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(12717), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351592] = 5,
    ACTIONS(9820), 1,
      anon_sym_COMMA,
    ACTIONS(12629), 1,
      anon_sym_EQ,
    ACTIONS(12719), 1,
      anon_sym_RPAREN,
    STATE(8142), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351610] = 5,
    ACTIONS(9752), 1,
      anon_sym_COMMA,
    ACTIONS(9756), 1,
      anon_sym_RPAREN,
    ACTIONS(12721), 1,
      anon_sym_EQ,
    STATE(8369), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351628] = 4,
    ACTIONS(9850), 1,
      anon_sym_COMMA,
    STATE(7550), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(11730), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351644] = 5,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4251), 1,
      aux_sym_struct_type_repeat2,
    STATE(7626), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351662] = 5,
    ACTIONS(9786), 1,
      anon_sym_COMMA,
    ACTIONS(9790), 1,
      anon_sym_RPAREN,
    ACTIONS(12723), 1,
      anon_sym_EQ,
    STATE(8008), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351680] = 5,
    ACTIONS(12725), 1,
      anon_sym_RBRACE,
    ACTIONS(12727), 1,
      anon_sym_COMMA,
    ACTIONS(12729), 1,
      anon_sym_EQ,
    STATE(8039), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351698] = 4,
    ACTIONS(9732), 1,
      anon_sym_COMMA,
    STATE(7547), 1,
      aux_sym__simple_assignment_statement_repeat1,
    ACTIONS(12731), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351714] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12105), 1,
      anon_sym_LBRACE,
    STATE(3041), 1,
      aux_sym_struct_type_repeat2,
    STATE(7639), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351732] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12105), 1,
      anon_sym_LBRACE,
    STATE(3041), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351750] = 5,
    ACTIONS(12733), 1,
      anon_sym_RBRACE,
    ACTIONS(12735), 1,
      anon_sym_COMMA,
    ACTIONS(12737), 1,
      anon_sym_EQ,
    STATE(8606), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351768] = 5,
    ACTIONS(12739), 1,
      anon_sym_RBRACE,
    ACTIONS(12741), 1,
      anon_sym_COMMA,
    ACTIONS(12743), 1,
      anon_sym_EQ,
    STATE(8389), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351786] = 5,
    ACTIONS(5930), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(1448), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351804] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12745), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [351822] = 5,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3707), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351840] = 5,
    ACTIONS(12747), 1,
      anon_sym_RBRACE,
    ACTIONS(12749), 1,
      anon_sym_COMMA,
    ACTIONS(12751), 1,
      anon_sym_EQ,
    STATE(8293), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351858] = 4,
    ACTIONS(12755), 1,
      sym_tag,
    STATE(7600), 1,
      aux_sym_struct_declaration_repeat1,
    ACTIONS(12753), 2,
      anon_sym_LBRACE,
      anon_sym_where,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351874] = 5,
    ACTIONS(12758), 1,
      anon_sym_RBRACE,
    ACTIONS(12760), 1,
      anon_sym_COMMA,
    ACTIONS(12762), 1,
      anon_sym_EQ,
    STATE(7778), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351892] = 5,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(12764), 1,
      sym_identifier,
    ACTIONS(12766), 1,
      anon_sym_import,
    STATE(7278), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351910] = 5,
    ACTIONS(9740), 1,
      anon_sym_COMMA,
    ACTIONS(9744), 1,
      anon_sym_RPAREN,
    ACTIONS(12768), 1,
      anon_sym_EQ,
    STATE(7765), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351928] = 5,
    ACTIONS(9826), 1,
      anon_sym_COMMA,
    ACTIONS(9830), 1,
      anon_sym_RPAREN,
    ACTIONS(12770), 1,
      anon_sym_EQ,
    STATE(7759), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351946] = 4,
    ACTIONS(12625), 1,
      anon_sym_case,
    ACTIONS(12772), 1,
      anon_sym_RBRACE,
    STATE(7622), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351962] = 4,
    ACTIONS(12625), 1,
      anon_sym_case,
    ACTIONS(12774), 1,
      anon_sym_RBRACE,
    STATE(7713), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351978] = 5,
    ACTIONS(10192), 1,
      anon_sym_RBRACE,
    ACTIONS(10194), 1,
      anon_sym_COMMA,
    ACTIONS(12776), 1,
      anon_sym_EQ,
    STATE(8475), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [351996] = 5,
    ACTIONS(12778), 1,
      anon_sym_RBRACE,
    ACTIONS(12780), 1,
      anon_sym_COMMA,
    ACTIONS(12782), 1,
      anon_sym_EQ,
    STATE(7889), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352014] = 5,
    ACTIONS(12784), 1,
      anon_sym_RBRACE,
    ACTIONS(12786), 1,
      anon_sym_COMMA,
    ACTIONS(12788), 1,
      anon_sym_EQ,
    STATE(8018), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352032] = 5,
    ACTIONS(9896), 1,
      anon_sym_COMMA,
    ACTIONS(9900), 1,
      anon_sym_RPAREN,
    ACTIONS(12790), 1,
      anon_sym_EQ,
    STATE(7931), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352050] = 5,
    ACTIONS(12792), 1,
      anon_sym_RBRACE,
    ACTIONS(12794), 1,
      anon_sym_COMMA,
    ACTIONS(12796), 1,
      anon_sym_EQ,
    STATE(8125), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352068] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12798), 1,
      anon_sym_DQUOTE,
    STATE(7635), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12800), 2,
      sym_string_content,
      sym_escape_sequence,
  [352086] = 4,
    ACTIONS(12625), 1,
      anon_sym_case,
    ACTIONS(12802), 1,
      anon_sym_RBRACE,
    STATE(7622), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352102] = 5,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4251), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352120] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12191), 1,
      anon_sym_LBRACE,
    STATE(1470), 1,
      aux_sym_struct_type_repeat2,
    STATE(7647), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352138] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12804), 1,
      anon_sym_DQUOTE,
    STATE(7625), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12806), 2,
      sym_string_content,
      sym_escape_sequence,
  [352156] = 4,
    ACTIONS(12617), 1,
      anon_sym_DOT,
    STATE(7631), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(12808), 2,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352172] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12191), 1,
      anon_sym_LBRACE,
    STATE(1470), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352190] = 5,
    ACTIONS(12617), 1,
      anon_sym_DOT,
    ACTIONS(12810), 1,
      anon_sym_LBRACE,
    ACTIONS(12812), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352208] = 5,
    ACTIONS(9740), 1,
      anon_sym_COMMA,
    ACTIONS(9744), 1,
      anon_sym_RPAREN,
    ACTIONS(12768), 1,
      anon_sym_EQ,
    STATE(8232), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352226] = 5,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(12814), 1,
      anon_sym_RBRACE,
    STATE(8853), 1,
      sym_struct_member,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352244] = 4,
    ACTIONS(12816), 1,
      anon_sym_RBRACE,
    ACTIONS(12818), 1,
      anon_sym_case,
    STATE(7622), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352260] = 5,
    ACTIONS(12821), 1,
      anon_sym_RBRACE,
    ACTIONS(12823), 1,
      anon_sym_COMMA,
    ACTIONS(12825), 1,
      anon_sym_EQ,
    STATE(8141), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352278] = 4,
    ACTIONS(12625), 1,
      anon_sym_case,
    ACTIONS(12827), 1,
      anon_sym_RBRACE,
    STATE(7737), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352294] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12829), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [352312] = 5,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4039), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352330] = 5,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(12831), 1,
      anon_sym_do,
    ACTIONS(12833), 1,
      anon_sym_when,
    STATE(7265), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352348] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12835), 1,
      anon_sym_DQUOTE,
    STATE(7701), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12837), 2,
      sym_string_content,
      sym_escape_sequence,
  [352366] = 4,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(9748), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352382] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12121), 1,
      anon_sym_LBRACE,
    STATE(670), 1,
      aux_sym_struct_type_repeat2,
    STATE(7681), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352400] = 4,
    ACTIONS(12841), 1,
      anon_sym_DOT,
    STATE(7631), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(12839), 2,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352416] = 5,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(7032), 1,
      aux_sym_struct_type_repeat2,
    STATE(7649), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352434] = 5,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(7032), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352452] = 5,
    ACTIONS(9734), 1,
      anon_sym_COMMA,
    ACTIONS(9738), 1,
      anon_sym_RPAREN,
    ACTIONS(12601), 1,
      anon_sym_EQ,
    STATE(7985), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352470] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12844), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [352488] = 5,
    ACTIONS(9880), 1,
      anon_sym_COMMA,
    ACTIONS(9884), 1,
      anon_sym_RPAREN,
    ACTIONS(12846), 1,
      anon_sym_EQ,
    STATE(8488), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352506] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12121), 1,
      anon_sym_LBRACE,
    STATE(670), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352524] = 5,
    ACTIONS(9776), 1,
      anon_sym_COMMA,
    ACTIONS(9780), 1,
      anon_sym_RPAREN,
    ACTIONS(12848), 1,
      anon_sym_EQ,
    STATE(7869), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352542] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12105), 1,
      anon_sym_LBRACE,
    STATE(3044), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352560] = 5,
    ACTIONS(9864), 1,
      anon_sym_COMMA,
    ACTIONS(9868), 1,
      anon_sym_RPAREN,
    ACTIONS(12850), 1,
      anon_sym_EQ,
    STATE(7988), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352578] = 5,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4054), 1,
      aux_sym_struct_type_repeat2,
    STATE(7746), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352596] = 5,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3690), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352614] = 5,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4054), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352632] = 5,
    ACTIONS(12852), 1,
      anon_sym_RBRACE,
    ACTIONS(12854), 1,
      anon_sym_COMMA,
    ACTIONS(12856), 1,
      anon_sym_EQ,
    STATE(8206), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352650] = 5,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3718), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352668] = 5,
    ACTIONS(9740), 1,
      anon_sym_COMMA,
    ACTIONS(12768), 1,
      anon_sym_EQ,
    ACTIONS(12858), 1,
      anon_sym_RPAREN,
    STATE(7764), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352686] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12191), 1,
      anon_sym_LBRACE,
    STATE(1474), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352704] = 5,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3686), 1,
      aux_sym_struct_type_repeat2,
    STATE(7739), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352722] = 5,
    ACTIONS(11723), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(7004), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352740] = 5,
    ACTIONS(9858), 1,
      anon_sym_COMMA,
    ACTIONS(9888), 1,
      anon_sym_RPAREN,
    ACTIONS(12671), 1,
      anon_sym_EQ,
    STATE(8180), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352758] = 5,
    ACTIONS(9820), 1,
      anon_sym_COMMA,
    ACTIONS(9824), 1,
      anon_sym_RPAREN,
    ACTIONS(12629), 1,
      anon_sym_EQ,
    STATE(8558), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352776] = 5,
    ACTIONS(9796), 1,
      anon_sym_COMMA,
    ACTIONS(9800), 1,
      anon_sym_RPAREN,
    ACTIONS(12860), 1,
      anon_sym_EQ,
    STATE(8335), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352794] = 5,
    ACTIONS(12862), 1,
      anon_sym_RBRACE,
    ACTIONS(12864), 1,
      anon_sym_COMMA,
    ACTIONS(12866), 1,
      anon_sym_EQ,
    STATE(7997), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352812] = 5,
    ACTIONS(12868), 1,
      anon_sym_RBRACE,
    ACTIONS(12870), 1,
      anon_sym_COMMA,
    ACTIONS(12872), 1,
      anon_sym_EQ,
    STATE(8213), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352830] = 5,
    ACTIONS(9802), 1,
      anon_sym_COMMA,
    ACTIONS(9806), 1,
      anon_sym_RPAREN,
    ACTIONS(12874), 1,
      anon_sym_EQ,
    STATE(8506), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352848] = 4,
    ACTIONS(12625), 1,
      anon_sym_case,
    ACTIONS(12876), 1,
      anon_sym_RBRACE,
    STATE(7622), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352864] = 5,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(12878), 1,
      anon_sym_LBRACE,
    ACTIONS(12880), 1,
      sym_tag,
    STATE(8798), 1,
      sym_polymorphic_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352882] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12882), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [352894] = 5,
    ACTIONS(9832), 1,
      anon_sym_COMMA,
    ACTIONS(9836), 1,
      anon_sym_RPAREN,
    ACTIONS(12884), 1,
      anon_sym_EQ,
    STATE(8221), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352912] = 5,
    ACTIONS(12886), 1,
      anon_sym_RBRACE,
    ACTIONS(12888), 1,
      anon_sym_COMMA,
    ACTIONS(12890), 1,
      anon_sym_EQ,
    STATE(7757), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352930] = 5,
    ACTIONS(9814), 1,
      anon_sym_COMMA,
    ACTIONS(9818), 1,
      anon_sym_RPAREN,
    ACTIONS(12691), 1,
      anon_sym_EQ,
    STATE(8093), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352948] = 3,
    ACTIONS(12894), 1,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12892), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [352962] = 5,
    ACTIONS(12896), 1,
      anon_sym_RBRACE,
    ACTIONS(12898), 1,
      anon_sym_COMMA,
    ACTIONS(12900), 1,
      anon_sym_EQ,
    STATE(8515), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352980] = 5,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(12902), 1,
      anon_sym_if,
    ACTIONS(12904), 1,
      anon_sym_do,
    STATE(7265), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [352998] = 5,
    ACTIONS(9820), 1,
      anon_sym_COMMA,
    ACTIONS(9824), 1,
      anon_sym_RPAREN,
    ACTIONS(12629), 1,
      anon_sym_EQ,
    STATE(8146), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353016] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(6488), 4,
      sym__newline,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_case,
  [353028] = 5,
    ACTIONS(12906), 1,
      anon_sym_RBRACE,
    ACTIONS(12908), 1,
      anon_sym_COMMA,
    ACTIONS(12910), 1,
      anon_sym_EQ,
    STATE(8200), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353046] = 4,
    ACTIONS(9850), 1,
      anon_sym_COMMA,
    STATE(7550), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(8789), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353062] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12912), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353078] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(12914), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353094] = 5,
    ACTIONS(12916), 1,
      anon_sym_RBRACE,
    ACTIONS(12918), 1,
      anon_sym_COMMA,
    ACTIONS(12920), 1,
      anon_sym_EQ,
    STATE(8106), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353112] = 5,
    ACTIONS(12922), 1,
      anon_sym_RBRACE,
    ACTIONS(12924), 1,
      anon_sym_COMMA,
    ACTIONS(12926), 1,
      anon_sym_EQ,
    STATE(8235), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353130] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12928), 1,
      anon_sym_DQUOTE,
    STATE(7714), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12930), 2,
      sym_string_content,
      sym_escape_sequence,
  [353148] = 5,
    ACTIONS(9734), 1,
      anon_sym_COMMA,
    ACTIONS(9738), 1,
      anon_sym_RPAREN,
    ACTIONS(12601), 1,
      anon_sym_EQ,
    STATE(7985), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353166] = 4,
    ACTIONS(12932), 1,
      ts_builtin_sym_end,
    STATE(5942), 1,
      sym__separator,
    ACTIONS(12934), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353182] = 4,
    ACTIONS(12936), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(12892), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353198] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12939), 1,
      anon_sym_DQUOTE,
    STATE(7539), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12941), 2,
      sym_string_content,
      sym_escape_sequence,
  [353216] = 5,
    ACTIONS(5930), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(1285), 1,
      aux_sym_struct_type_repeat2,
    STATE(7596), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353234] = 5,
    ACTIONS(9924), 1,
      anon_sym_COMMA,
    ACTIONS(9928), 1,
      anon_sym_RPAREN,
    ACTIONS(12943), 1,
      anon_sym_EQ,
    STATE(8155), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353252] = 4,
    ACTIONS(1567), 1,
      ts_builtin_sym_end,
    STATE(5942), 1,
      sym__separator,
    ACTIONS(12934), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353268] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12121), 1,
      anon_sym_LBRACE,
    STATE(567), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353286] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12945), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12947), 2,
      sym_string_content,
      sym_escape_sequence,
  [353304] = 5,
    ACTIONS(12950), 1,
      anon_sym_RBRACE,
    ACTIONS(12952), 1,
      anon_sym_COMMA,
    ACTIONS(12954), 1,
      anon_sym_EQ,
    STATE(8044), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353322] = 5,
    ACTIONS(5930), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(1285), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353340] = 5,
    ACTIONS(12956), 1,
      anon_sym_RBRACE,
    ACTIONS(12958), 1,
      anon_sym_COMMA,
    ACTIONS(12960), 1,
      anon_sym_EQ,
    STATE(8230), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353358] = 5,
    ACTIONS(9984), 1,
      anon_sym_RBRACE,
    ACTIONS(9986), 1,
      anon_sym_COMMA,
    ACTIONS(12962), 1,
      anon_sym_EQ,
    STATE(8346), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353376] = 4,
    ACTIONS(12625), 1,
      anon_sym_case,
    ACTIONS(12964), 1,
      anon_sym_RBRACE,
    STATE(7656), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353392] = 5,
    ACTIONS(9776), 1,
      anon_sym_COMMA,
    ACTIONS(9780), 1,
      anon_sym_RPAREN,
    ACTIONS(12848), 1,
      anon_sym_EQ,
    STATE(7869), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353410] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12966), 1,
      anon_sym_DQUOTE,
    STATE(7696), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12968), 2,
      sym_string_content,
      sym_escape_sequence,
  [353428] = 5,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3574), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353446] = 5,
    ACTIONS(12970), 1,
      anon_sym_RBRACE,
    ACTIONS(12972), 1,
      anon_sym_COMMA,
    ACTIONS(12974), 1,
      anon_sym_EQ,
    STATE(8282), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353464] = 5,
    ACTIONS(5930), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(1270), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353482] = 5,
    ACTIONS(9776), 1,
      anon_sym_COMMA,
    ACTIONS(12848), 1,
      anon_sym_EQ,
    ACTIONS(12976), 1,
      anon_sym_RPAREN,
    STATE(7908), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353500] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12978), 1,
      anon_sym_DQUOTE,
    STATE(7712), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12980), 2,
      sym_string_content,
      sym_escape_sequence,
  [353518] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12982), 1,
      anon_sym_DQUOTE,
    STATE(7710), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12984), 2,
      sym_string_content,
      sym_escape_sequence,
  [353536] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12986), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [353554] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(12988), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [353572] = 5,
    ACTIONS(9890), 1,
      anon_sym_COMMA,
    ACTIONS(9894), 1,
      anon_sym_RPAREN,
    ACTIONS(12990), 1,
      anon_sym_EQ,
    STATE(8354), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353590] = 5,
    ACTIONS(12992), 1,
      anon_sym_RBRACE,
    ACTIONS(12994), 1,
      anon_sym_COMMA,
    ACTIONS(12996), 1,
      anon_sym_EQ,
    STATE(7810), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353608] = 5,
    ACTIONS(9814), 1,
      anon_sym_COMMA,
    ACTIONS(12691), 1,
      anon_sym_EQ,
    ACTIONS(12998), 1,
      anon_sym_RPAREN,
    STATE(8068), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353626] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13000), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [353644] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12251), 1,
      anon_sym_LBRACE,
    STATE(3460), 1,
      aux_sym_struct_type_repeat2,
    STATE(7717), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353662] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12251), 1,
      anon_sym_LBRACE,
    STATE(3460), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353680] = 5,
    ACTIONS(13002), 1,
      anon_sym_RBRACE,
    ACTIONS(13004), 1,
      anon_sym_COMMA,
    ACTIONS(13006), 1,
      anon_sym_EQ,
    STATE(8493), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353698] = 4,
    ACTIONS(13008), 1,
      anon_sym_COMMA,
    STATE(7705), 1,
      aux_sym_parameter_repeat1,
    ACTIONS(13011), 2,
      anon_sym_COLON,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353714] = 5,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    ACTIONS(13013), 1,
      anon_sym_RBRACE,
    STATE(8853), 1,
      sym_struct_member,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353732] = 5,
    ACTIONS(9852), 1,
      anon_sym_COMMA,
    ACTIONS(9856), 1,
      anon_sym_RPAREN,
    ACTIONS(13015), 1,
      anon_sym_EQ,
    STATE(8171), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353750] = 5,
    ACTIONS(9808), 1,
      anon_sym_COMMA,
    ACTIONS(9812), 1,
      anon_sym_RPAREN,
    ACTIONS(13017), 1,
      anon_sym_EQ,
    STATE(8082), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353768] = 5,
    ACTIONS(9908), 1,
      anon_sym_COMMA,
    ACTIONS(9912), 1,
      anon_sym_RPAREN,
    ACTIONS(13019), 1,
      anon_sym_EQ,
    STATE(7904), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353786] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13021), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [353804] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13023), 1,
      anon_sym_DQUOTE,
    STATE(7554), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(13025), 2,
      sym_string_content,
      sym_escape_sequence,
  [353822] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13027), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [353840] = 4,
    ACTIONS(12625), 1,
      anon_sym_case,
    ACTIONS(13029), 1,
      anon_sym_RBRACE,
    STATE(7622), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353856] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13031), 1,
      anon_sym_DQUOTE,
    STATE(7682), 1,
      aux_sym__string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
    ACTIONS(12621), 2,
      sym_string_content,
      sym_escape_sequence,
  [353874] = 5,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4237), 1,
      aux_sym_struct_type_repeat2,
    STATE(7741), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353892] = 5,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(12831), 1,
      anon_sym_do,
    ACTIONS(12902), 1,
      anon_sym_if,
    STATE(7265), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353910] = 5,
    ACTIONS(11837), 1,
      sym_tag,
    ACTIONS(12251), 1,
      anon_sym_LBRACE,
    STATE(3470), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353928] = 5,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(2590), 1,
      aux_sym_struct_type_repeat2,
    STATE(7578), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353946] = 5,
    ACTIONS(13033), 1,
      anon_sym_RBRACE,
    ACTIONS(13035), 1,
      anon_sym_COMMA,
    ACTIONS(13037), 1,
      anon_sym_EQ,
    STATE(8588), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353964] = 5,
    ACTIONS(11770), 1,
      anon_sym_LPAREN,
    ACTIONS(13039), 1,
      anon_sym_LBRACE,
    ACTIONS(13041), 1,
      sym_tag,
    STATE(8677), 1,
      sym_polymorphic_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [353982] = 5,
    ACTIONS(6694), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(2590), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354000] = 5,
    ACTIONS(12617), 1,
      anon_sym_DOT,
    ACTIONS(13043), 1,
      anon_sym_LBRACE,
    ACTIONS(13045), 1,
      anon_sym_LPAREN,
    STATE(7617), 1,
      aux_sym_field_identifier_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354018] = 5,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4237), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354036] = 5,
    ACTIONS(12325), 1,
      sym_identifier,
    ACTIONS(12329), 1,
      anon_sym_using,
    ACTIONS(12331), 1,
      sym_tag,
    STATE(8632), 1,
      sym_field,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354054] = 5,
    ACTIONS(13047), 1,
      anon_sym_RBRACE,
    ACTIONS(13049), 1,
      anon_sym_COMMA,
    ACTIONS(13051), 1,
      anon_sym_EQ,
    STATE(8072), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354072] = 5,
    ACTIONS(13053), 1,
      anon_sym_RBRACE,
    ACTIONS(13055), 1,
      anon_sym_COMMA,
    ACTIONS(13057), 1,
      anon_sym_EQ,
    STATE(8490), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354090] = 5,
    ACTIONS(9764), 1,
      anon_sym_COMMA,
    ACTIONS(9768), 1,
      anon_sym_RPAREN,
    ACTIONS(13059), 1,
      anon_sym_EQ,
    STATE(8609), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354108] = 5,
    ACTIONS(9734), 1,
      anon_sym_COMMA,
    ACTIONS(9738), 1,
      anon_sym_RPAREN,
    ACTIONS(12601), 1,
      anon_sym_EQ,
    STATE(8328), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354126] = 5,
    ACTIONS(13061), 1,
      anon_sym_RBRACE,
    ACTIONS(13063), 1,
      anon_sym_COMMA,
    ACTIONS(13065), 1,
      anon_sym_EQ,
    STATE(8236), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354144] = 5,
    ACTIONS(9902), 1,
      anon_sym_COMMA,
    ACTIONS(9906), 1,
      anon_sym_RPAREN,
    ACTIONS(13067), 1,
      anon_sym_EQ,
    STATE(8312), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354162] = 5,
    ACTIONS(9758), 1,
      anon_sym_COMMA,
    ACTIONS(9762), 1,
      anon_sym_RPAREN,
    ACTIONS(13069), 1,
      anon_sym_EQ,
    STATE(8574), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354180] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13071), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354196] = 5,
    ACTIONS(9740), 1,
      anon_sym_COMMA,
    ACTIONS(9744), 1,
      anon_sym_RPAREN,
    ACTIONS(12768), 1,
      anon_sym_EQ,
    STATE(8232), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354214] = 5,
    ACTIONS(9918), 1,
      anon_sym_COMMA,
    ACTIONS(9922), 1,
      anon_sym_RPAREN,
    ACTIONS(13073), 1,
      anon_sym_EQ,
    STATE(8116), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354232] = 5,
    ACTIONS(9858), 1,
      anon_sym_COMMA,
    ACTIONS(12671), 1,
      anon_sym_EQ,
    ACTIONS(13075), 1,
      anon_sym_RPAREN,
    STATE(8177), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354250] = 5,
    ACTIONS(9814), 1,
      anon_sym_COMMA,
    ACTIONS(9818), 1,
      anon_sym_RPAREN,
    ACTIONS(12691), 1,
      anon_sym_EQ,
    STATE(8070), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354268] = 4,
    ACTIONS(12625), 1,
      anon_sym_case,
    ACTIONS(13077), 1,
      anon_sym_RBRACE,
    STATE(7622), 2,
      sym_switch_case,
      aux_sym_switch_statement_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354284] = 5,
    ACTIONS(13079), 1,
      anon_sym_RBRACE,
    ACTIONS(13081), 1,
      anon_sym_COMMA,
    ACTIONS(13083), 1,
      anon_sym_EQ,
    STATE(8164), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354302] = 5,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3571), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354320] = 5,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3743), 1,
      aux_sym_struct_type_repeat2,
    STATE(7645), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354338] = 5,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4246), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354356] = 5,
    ACTIONS(7683), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(3743), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354374] = 5,
    ACTIONS(13085), 1,
      anon_sym_RBRACE,
    ACTIONS(13087), 1,
      anon_sym_COMMA,
    ACTIONS(13089), 1,
      anon_sym_EQ,
    STATE(8457), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354392] = 5,
    ACTIONS(13091), 1,
      anon_sym_RBRACE,
    ACTIONS(13093), 1,
      anon_sym_COMMA,
    ACTIONS(13095), 1,
      anon_sym_EQ,
    STATE(7917), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354410] = 4,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(9728), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354426] = 5,
    ACTIONS(7915), 1,
      anon_sym_LBRACE,
    ACTIONS(11837), 1,
      sym_tag,
    STATE(4031), 1,
      aux_sym_struct_type_repeat2,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354444] = 5,
    ACTIONS(13097), 1,
      anon_sym_RBRACE,
    ACTIONS(13099), 1,
      anon_sym_COMMA,
    ACTIONS(13101), 1,
      anon_sym_EQ,
    STATE(7894), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354462] = 4,
    ACTIONS(9732), 1,
      anon_sym_COMMA,
    STATE(7547), 1,
      aux_sym__simple_assignment_statement_repeat1,
    ACTIONS(9774), 2,
      anon_sym_LBRACE,
      anon_sym_do,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354478] = 5,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(12833), 1,
      anon_sym_when,
    ACTIONS(12904), 1,
      anon_sym_do,
    STATE(7265), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354496] = 5,
    ACTIONS(10176), 1,
      anon_sym_COMMA,
    ACTIONS(13103), 1,
      anon_sym_EQ,
    ACTIONS(13105), 1,
      anon_sym_RPAREN,
    STATE(8390), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354514] = 4,
    ACTIONS(5506), 1,
      anon_sym_RBRACE,
    ACTIONS(13107), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354529] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(13109), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354544] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13111), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354559] = 4,
    ACTIONS(8883), 1,
      anon_sym_SEMI,
    ACTIONS(13113), 1,
      anon_sym_COMMA,
    STATE(7754), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354574] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13116), 1,
      anon_sym_BQUOTE,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [354591] = 4,
    ACTIONS(8705), 1,
      anon_sym_RPAREN,
    ACTIONS(13120), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354606] = 4,
    ACTIONS(13122), 1,
      anon_sym_RBRACE,
    ACTIONS(13124), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354621] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13126), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354636] = 4,
    ACTIONS(13128), 1,
      anon_sym_COMMA,
    ACTIONS(13130), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354651] = 4,
    ACTIONS(13132), 1,
      anon_sym_COMMA,
    ACTIONS(13134), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354666] = 4,
    ACTIONS(5526), 1,
      anon_sym_RBRACE,
    ACTIONS(13136), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354681] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13138), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354696] = 4,
    ACTIONS(12353), 1,
      anon_sym_RBRACE,
    ACTIONS(13140), 1,
      anon_sym_COMMA,
    STATE(7887), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354711] = 4,
    ACTIONS(13142), 1,
      anon_sym_COMMA,
    ACTIONS(13144), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354726] = 4,
    ACTIONS(13146), 1,
      anon_sym_COMMA,
    ACTIONS(13148), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354741] = 4,
    ACTIONS(13150), 1,
      anon_sym_COMMA,
    ACTIONS(13152), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354756] = 4,
    ACTIONS(12635), 1,
      anon_sym_RBRACE,
    ACTIONS(13154), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354771] = 4,
    ACTIONS(8743), 1,
      anon_sym_RPAREN,
    ACTIONS(13157), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354786] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13159), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354801] = 4,
    ACTIONS(6621), 1,
      anon_sym_LBRACE,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354816] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13161), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354831] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13163), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354846] = 4,
    ACTIONS(5374), 1,
      anon_sym_RBRACE,
    ACTIONS(13165), 1,
      anon_sym_COMMA,
    STATE(7790), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354861] = 4,
    ACTIONS(5374), 1,
      anon_sym_RBRACE,
    ACTIONS(13165), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354876] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13167), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354891] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13169), 1,
      anon_sym_BQUOTE,
    ACTIONS(13171), 1,
      sym__raw_string_content,
    STATE(8564), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [354908] = 4,
    ACTIONS(8797), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7859), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354923] = 4,
    ACTIONS(13173), 1,
      anon_sym_RBRACE,
    ACTIONS(13175), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354938] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13177), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354953] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13179), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354968] = 4,
    ACTIONS(8797), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7754), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354983] = 4,
    ACTIONS(13181), 1,
      anon_sym_COMMA,
    ACTIONS(13183), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [354998] = 4,
    ACTIONS(8789), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355013] = 4,
    ACTIONS(5962), 1,
      anon_sym_RBRACE,
    ACTIONS(13185), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355028] = 4,
    ACTIONS(13187), 1,
      anon_sym_RBRACE,
    ACTIONS(13189), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355043] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12367), 1,
      anon_sym_RPAREN,
    STATE(7819), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355058] = 4,
    ACTIONS(7678), 1,
      anon_sym_LBRACE,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355073] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13191), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355088] = 4,
    ACTIONS(5964), 1,
      anon_sym_RBRACE,
    ACTIONS(13193), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355103] = 4,
    ACTIONS(5376), 1,
      anon_sym_RBRACE,
    ACTIONS(13195), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355118] = 4,
    ACTIONS(13197), 1,
      anon_sym_RBRACE,
    ACTIONS(13199), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355133] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13201), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355148] = 4,
    ACTIONS(13203), 1,
      anon_sym_RBRACE,
    ACTIONS(13205), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355163] = 4,
    ACTIONS(12651), 1,
      anon_sym_RPAREN,
    ACTIONS(13207), 1,
      anon_sym_COMMA,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355178] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13210), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355193] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13212), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355208] = 4,
    ACTIONS(13214), 1,
      anon_sym_COMMA,
    ACTIONS(13216), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355223] = 4,
    ACTIONS(5376), 1,
      anon_sym_RBRACE,
    ACTIONS(13195), 1,
      anon_sym_COMMA,
    STATE(7806), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355238] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13218), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355253] = 3,
    STATE(5942), 1,
      sym__separator,
    ACTIONS(12934), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355266] = 4,
    ACTIONS(13220), 1,
      anon_sym_COMMA,
    ACTIONS(13222), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355281] = 4,
    ACTIONS(13224), 1,
      anon_sym_RBRACE,
    ACTIONS(13226), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355296] = 4,
    ACTIONS(5378), 1,
      anon_sym_RBRACE,
    ACTIONS(13228), 1,
      anon_sym_COMMA,
    STATE(8590), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355311] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13230), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355326] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13232), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355341] = 4,
    ACTIONS(5380), 1,
      anon_sym_RBRACE,
    ACTIONS(13234), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355356] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13236), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355371] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(13238), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [355382] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13240), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355397] = 4,
    ACTIONS(13242), 1,
      anon_sym_RBRACE,
    ACTIONS(13244), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355412] = 4,
    ACTIONS(6040), 1,
      anon_sym_RBRACE,
    ACTIONS(13246), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355427] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(13248), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [355438] = 4,
    ACTIONS(6042), 1,
      anon_sym_RBRACE,
    ACTIONS(13250), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355453] = 4,
    ACTIONS(13252), 1,
      anon_sym_RBRACE,
    ACTIONS(13254), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355468] = 4,
    ACTIONS(13256), 1,
      anon_sym_RBRACE,
    ACTIONS(13258), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355483] = 4,
    ACTIONS(9115), 1,
      anon_sym_RBRACE,
    ACTIONS(13261), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355498] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12753), 3,
      anon_sym_LBRACE,
      anon_sym_where,
      sym_tag,
  [355509] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(13263), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [355526] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(13265), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355541] = 4,
    ACTIONS(5143), 1,
      anon_sym_LBRACE,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355556] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13267), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355571] = 4,
    ACTIONS(13269), 1,
      anon_sym_COMMA,
    ACTIONS(13271), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355586] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(8357), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355601] = 4,
    ACTIONS(13273), 1,
      anon_sym_RBRACE,
    ACTIONS(13275), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355616] = 4,
    ACTIONS(5526), 1,
      anon_sym_RBRACE,
    ACTIONS(13136), 1,
      anon_sym_COMMA,
    STATE(7865), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355631] = 4,
    ACTIONS(11802), 1,
      anon_sym_RBRACE,
    ACTIONS(13277), 1,
      anon_sym_COMMA,
    STATE(8011), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355646] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13279), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355661] = 4,
    ACTIONS(13281), 1,
      anon_sym_RBRACE,
    ACTIONS(13283), 1,
      anon_sym_COMMA,
    STATE(8105), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355676] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13285), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355691] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13287), 1,
      anon_sym_BQUOTE,
    ACTIONS(13289), 1,
      sym__raw_string_content,
    STATE(7840), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [355708] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(8168), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355723] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13291), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355738] = 4,
    ACTIONS(5388), 1,
      anon_sym_RBRACE,
    ACTIONS(13293), 1,
      anon_sym_COMMA,
    STATE(7842), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355753] = 4,
    ACTIONS(13295), 1,
      anon_sym_RBRACE,
    ACTIONS(13297), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355768] = 4,
    ACTIONS(13299), 1,
      anon_sym_RBRACE,
    ACTIONS(13301), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355783] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13304), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355798] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13306), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355813] = 4,
    ACTIONS(12327), 1,
      anon_sym_RBRACE,
    ACTIONS(13308), 1,
      anon_sym_COMMA,
    STATE(8113), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355828] = 4,
    ACTIONS(13310), 1,
      anon_sym_RBRACE,
    ACTIONS(13312), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355843] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(13314), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [355860] = 4,
    ACTIONS(13316), 1,
      anon_sym_RBRACE,
    ACTIONS(13318), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355875] = 4,
    ACTIONS(5390), 1,
      anon_sym_RBRACE,
    ACTIONS(13320), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355890] = 4,
    ACTIONS(5288), 1,
      anon_sym_RBRACE,
    ACTIONS(13322), 1,
      anon_sym_COMMA,
    STATE(8010), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355905] = 4,
    ACTIONS(6590), 1,
      anon_sym_LBRACE,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355920] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13324), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355935] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13326), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355950] = 4,
    ACTIONS(11890), 1,
      anon_sym_COMMA,
    ACTIONS(11892), 1,
      anon_sym_RPAREN,
    STATE(7870), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355965] = 4,
    ACTIONS(8779), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355980] = 4,
    ACTIONS(13328), 1,
      anon_sym_RBRACE,
    ACTIONS(13330), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [355995] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13333), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356010] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13335), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356025] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13337), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356040] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(7826), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356055] = 4,
    ACTIONS(5390), 1,
      anon_sym_RBRACE,
    ACTIONS(13320), 1,
      anon_sym_COMMA,
    STATE(7882), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356070] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13339), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356085] = 4,
    ACTIONS(8791), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7906), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356100] = 4,
    ACTIONS(13341), 1,
      anon_sym_RBRACE,
    ACTIONS(13343), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356115] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(13345), 1,
      anon_sym_do,
    STATE(7161), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356130] = 4,
    ACTIONS(8791), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7754), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356145] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12375), 1,
      anon_sym_RPAREN,
    STATE(8089), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356160] = 4,
    ACTIONS(13347), 1,
      anon_sym_COMMA,
    ACTIONS(13349), 1,
      anon_sym_RPAREN,
    STATE(7888), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356175] = 4,
    ACTIONS(13351), 1,
      anon_sym_RBRACE,
    ACTIONS(13353), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356190] = 4,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(11730), 1,
      anon_sym_SEMI,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356205] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13355), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356220] = 4,
    ACTIONS(5528), 1,
      anon_sym_RBRACE,
    ACTIONS(13357), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356235] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13359), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356250] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(8214), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356265] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13361), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356280] = 4,
    ACTIONS(13363), 1,
      anon_sym_COMMA,
    ACTIONS(13365), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356295] = 4,
    ACTIONS(8775), 1,
      anon_sym_RPAREN,
    ACTIONS(13367), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356310] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13369), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356325] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13371), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356340] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13373), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356355] = 4,
    ACTIONS(6288), 1,
      anon_sym_RBRACE,
    ACTIONS(10094), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356370] = 4,
    ACTIONS(10206), 1,
      anon_sym_RBRACE,
    ACTIONS(10208), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356385] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12301), 1,
      anon_sym_RPAREN,
    STATE(7900), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356400] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13375), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356415] = 4,
    ACTIONS(13377), 1,
      anon_sym_COMMA,
    ACTIONS(13379), 1,
      anon_sym_COLON,
    STATE(8152), 1,
      aux_sym_field_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356430] = 4,
    ACTIONS(13381), 1,
      anon_sym_COMMA,
    ACTIONS(13383), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356445] = 4,
    ACTIONS(13385), 1,
      anon_sym_COMMA,
    ACTIONS(13387), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356460] = 4,
    ACTIONS(13389), 1,
      anon_sym_COMMA,
    ACTIONS(13391), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356475] = 4,
    ACTIONS(5392), 1,
      anon_sym_RBRACE,
    ACTIONS(13393), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356490] = 4,
    ACTIONS(13395), 1,
      sym_identifier,
    ACTIONS(13397), 1,
      anon_sym_using,
    ACTIONS(13399), 1,
      sym_tag,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356505] = 4,
    ACTIONS(13377), 1,
      anon_sym_COMMA,
    ACTIONS(13379), 1,
      anon_sym_COLON,
    STATE(8163), 1,
      aux_sym_field_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356520] = 4,
    ACTIONS(5518), 1,
      anon_sym_RBRACE,
    ACTIONS(13401), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356535] = 4,
    ACTIONS(12377), 1,
      anon_sym_RBRACE,
    ACTIONS(13403), 1,
      anon_sym_COMMA,
    STATE(8179), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356550] = 4,
    ACTIONS(12327), 1,
      anon_sym_RBRACE,
    ACTIONS(13308), 1,
      anon_sym_COMMA,
    STATE(8179), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356565] = 4,
    ACTIONS(11299), 1,
      anon_sym_RPAREN,
    ACTIONS(13405), 1,
      anon_sym_COMMA,
    STATE(8193), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356580] = 4,
    ACTIONS(12862), 1,
      anon_sym_RBRACE,
    ACTIONS(12864), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356595] = 4,
    ACTIONS(8833), 1,
      anon_sym_RBRACE,
    ACTIONS(12527), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356610] = 4,
    ACTIONS(5394), 1,
      anon_sym_RBRACE,
    ACTIONS(13407), 1,
      anon_sym_COMMA,
    STATE(7913), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356625] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13409), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356640] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13411), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356655] = 4,
    ACTIONS(13413), 1,
      anon_sym_RBRACE,
    ACTIONS(13415), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356670] = 4,
    ACTIONS(6230), 1,
      anon_sym_RBRACE,
    ACTIONS(13417), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356685] = 4,
    ACTIONS(9019), 1,
      anon_sym_RBRACE,
    ACTIONS(13419), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356700] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13421), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356715] = 4,
    ACTIONS(5330), 1,
      anon_sym_RBRACE,
    ACTIONS(13423), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356730] = 4,
    ACTIONS(8805), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356745] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(13425), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356760] = 4,
    ACTIONS(6232), 1,
      anon_sym_RBRACE,
    ACTIONS(13427), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356775] = 4,
    ACTIONS(8801), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7925), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356790] = 3,
    STATE(2108), 1,
      sym__separator,
    ACTIONS(13429), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356803] = 4,
    ACTIONS(13431), 1,
      anon_sym_COMMA,
    ACTIONS(13433), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356818] = 4,
    ACTIONS(13435), 1,
      anon_sym_COMMA,
    ACTIONS(13437), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356833] = 4,
    ACTIONS(8801), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7754), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356848] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(13439), 1,
      anon_sym_do,
    STATE(7112), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356863] = 4,
    ACTIONS(13441), 1,
      anon_sym_COMMA,
    ACTIONS(13443), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356878] = 4,
    ACTIONS(13445), 1,
      anon_sym_RBRACE,
    ACTIONS(13447), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356893] = 3,
    ACTIONS(13451), 1,
      sym_number,
    ACTIONS(13449), 2,
      anon_sym_LBRACE,
      sym_tag,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356906] = 4,
    ACTIONS(12377), 1,
      anon_sym_RBRACE,
    ACTIONS(13403), 1,
      anon_sym_COMMA,
    STATE(8517), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356921] = 4,
    ACTIONS(5396), 1,
      anon_sym_RBRACE,
    ACTIONS(13453), 1,
      anon_sym_COMMA,
    STATE(7927), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356936] = 4,
    ACTIONS(5396), 1,
      anon_sym_RBRACE,
    ACTIONS(13453), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356951] = 4,
    ACTIONS(13455), 1,
      anon_sym_RBRACE,
    ACTIONS(13457), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356966] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13459), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356981] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13461), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [356996] = 4,
    ACTIONS(13463), 1,
      anon_sym_RBRACE,
    ACTIONS(13465), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357011] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13467), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357026] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13469), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357041] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13471), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357056] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(7781), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357071] = 4,
    ACTIONS(13473), 1,
      anon_sym_COMMA,
    ACTIONS(13475), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357086] = 4,
    ACTIONS(8809), 1,
      anon_sym_SEMI,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357101] = 4,
    ACTIONS(13477), 1,
      anon_sym_COMMA,
    ACTIONS(13479), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357116] = 4,
    ACTIONS(8799), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7754), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357131] = 4,
    ACTIONS(8799), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7943), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357146] = 4,
    ACTIONS(5398), 1,
      anon_sym_RBRACE,
    ACTIONS(13481), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357161] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13483), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357176] = 4,
    ACTIONS(13485), 1,
      anon_sym_RBRACE,
    ACTIONS(13487), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357191] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13489), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357206] = 4,
    ACTIONS(13491), 1,
      anon_sym_COMMA,
    ACTIONS(13493), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357221] = 4,
    ACTIONS(13495), 1,
      anon_sym_COMMA,
    ACTIONS(13497), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357236] = 4,
    ACTIONS(5398), 1,
      anon_sym_RBRACE,
    ACTIONS(13481), 1,
      anon_sym_COMMA,
    STATE(7940), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357251] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13499), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357266] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13501), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357281] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(13503), 1,
      anon_sym_do,
    STATE(7276), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357296] = 4,
    ACTIONS(8689), 1,
      anon_sym_RPAREN,
    ACTIONS(13505), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357311] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13507), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357326] = 4,
    ACTIONS(13509), 1,
      anon_sym_RBRACE,
    ACTIONS(13511), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357341] = 4,
    ACTIONS(5400), 1,
      anon_sym_RBRACE,
    ACTIONS(13513), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357356] = 4,
    ACTIONS(8907), 1,
      anon_sym_COMMA,
    ACTIONS(11739), 1,
      anon_sym_SEMI,
    STATE(7082), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357371] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13515), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357386] = 4,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    ACTIONS(11732), 1,
      anon_sym_SEMI,
    STATE(7754), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357401] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(13517), 1,
      anon_sym_do,
    STATE(7283), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357416] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13519), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357431] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13521), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357446] = 4,
    ACTIONS(6060), 1,
      anon_sym_RBRACE,
    ACTIONS(13523), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357461] = 4,
    ACTIONS(6062), 1,
      anon_sym_RBRACE,
    ACTIONS(13525), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357476] = 4,
    ACTIONS(13527), 1,
      anon_sym_RBRACE,
    ACTIONS(13529), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357491] = 3,
    STATE(1949), 1,
      sym__separator,
    ACTIONS(13531), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357504] = 4,
    ACTIONS(9177), 1,
      anon_sym_RBRACE,
    ACTIONS(13533), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357519] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13535), 1,
      anon_sym_BQUOTE,
    ACTIONS(13537), 1,
      sym__raw_string_content,
    STATE(7961), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [357536] = 4,
    ACTIONS(5406), 1,
      anon_sym_RBRACE,
    ACTIONS(13539), 1,
      anon_sym_COMMA,
    STATE(7965), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357551] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13541), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357566] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13543), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357581] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13545), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357596] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13547), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357611] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13549), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357626] = 4,
    ACTIONS(13551), 1,
      anon_sym_RBRACE,
    ACTIONS(13553), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357641] = 4,
    ACTIONS(10222), 1,
      anon_sym_COMMA,
    ACTIONS(13555), 1,
      anon_sym_COLON,
    STATE(8393), 1,
      aux_sym_switch_case_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357656] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(13557), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [357673] = 4,
    ACTIONS(10222), 1,
      anon_sym_COMMA,
    ACTIONS(13559), 1,
      anon_sym_COLON,
    STATE(8393), 1,
      aux_sym_switch_case_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357688] = 4,
    ACTIONS(11307), 1,
      anon_sym_RPAREN,
    ACTIONS(13561), 1,
      anon_sym_COMMA,
    STATE(8193), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357703] = 4,
    ACTIONS(11904), 1,
      anon_sym_COMMA,
    ACTIONS(11906), 1,
      anon_sym_RPAREN,
    STATE(8102), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357718] = 4,
    ACTIONS(5408), 1,
      anon_sym_RBRACE,
    ACTIONS(13563), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357733] = 4,
    ACTIONS(13565), 1,
      anon_sym_COMMA,
    ACTIONS(13567), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357748] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13569), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357763] = 4,
    ACTIONS(12123), 1,
      anon_sym_COMMA,
    ACTIONS(12125), 1,
      anon_sym_RPAREN,
    STATE(7994), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357778] = 4,
    ACTIONS(5328), 1,
      anon_sym_RBRACE,
    ACTIONS(13571), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357793] = 4,
    ACTIONS(11954), 1,
      anon_sym_COMMA,
    ACTIONS(11956), 1,
      anon_sym_RPAREN,
    STATE(7983), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357808] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13573), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357823] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13575), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357838] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(13577), 1,
      anon_sym_do,
    STATE(7136), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357853] = 4,
    ACTIONS(5508), 1,
      anon_sym_RBRACE,
    ACTIONS(13579), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357868] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13581), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357883] = 4,
    ACTIONS(5408), 1,
      anon_sym_RBRACE,
    ACTIONS(13563), 1,
      anon_sym_COMMA,
    STATE(7992), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357898] = 4,
    ACTIONS(5510), 1,
      anon_sym_RBRACE,
    ACTIONS(13583), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357913] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13585), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357928] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12461), 1,
      anon_sym_RPAREN,
    STATE(8607), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357943] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11601), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357958] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13587), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357973] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13589), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [357988] = 4,
    ACTIONS(8693), 1,
      anon_sym_RPAREN,
    ACTIONS(13591), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358003] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13593), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358018] = 4,
    ACTIONS(13595), 1,
      anon_sym_COMMA,
    ACTIONS(13597), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358033] = 4,
    ACTIONS(5518), 1,
      anon_sym_RBRACE,
    ACTIONS(13401), 1,
      anon_sym_COMMA,
    STATE(8175), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358048] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12475), 1,
      anon_sym_RPAREN,
    STATE(8006), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358063] = 4,
    ACTIONS(13599), 1,
      anon_sym_COMMA,
    ACTIONS(13601), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358078] = 4,
    ACTIONS(13603), 1,
      anon_sym_COMMA,
    ACTIONS(13605), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358093] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(13607), 1,
      anon_sym_do,
    STATE(7148), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358108] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13609), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358123] = 4,
    ACTIONS(5410), 1,
      anon_sym_RBRACE,
    ACTIONS(13611), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358138] = 4,
    ACTIONS(13613), 1,
      anon_sym_COMMA,
    ACTIONS(13615), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358153] = 4,
    ACTIONS(8711), 1,
      anon_sym_RPAREN,
    ACTIONS(13617), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358168] = 4,
    ACTIONS(10222), 1,
      anon_sym_COMMA,
    ACTIONS(10224), 1,
      anon_sym_COLON,
    STATE(7962), 1,
      aux_sym_switch_case_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358183] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13619), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358198] = 4,
    ACTIONS(10192), 1,
      anon_sym_RBRACE,
    ACTIONS(10194), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358213] = 4,
    ACTIONS(5412), 1,
      anon_sym_RBRACE,
    ACTIONS(13621), 1,
      anon_sym_COMMA,
    STATE(8015), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358228] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13623), 1,
      anon_sym_BQUOTE,
    ACTIONS(13625), 1,
      sym__raw_string_content,
    STATE(8017), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [358245] = 4,
    ACTIONS(5346), 1,
      anon_sym_RBRACE,
    ACTIONS(13627), 1,
      anon_sym_COMMA,
    STATE(8025), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358260] = 4,
    ACTIONS(13629), 1,
      anon_sym_RBRACE,
    ACTIONS(13631), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358275] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13633), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358290] = 4,
    ACTIONS(9043), 1,
      anon_sym_RBRACE,
    ACTIONS(13635), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358305] = 4,
    ACTIONS(11778), 1,
      anon_sym_RBRACE,
    ACTIONS(13637), 1,
      anon_sym_COMMA,
    STATE(8011), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358320] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12505), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [358331] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(13639), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358346] = 4,
    ACTIONS(13641), 1,
      anon_sym_RBRACE,
    ACTIONS(13643), 1,
      anon_sym_COMMA,
    STATE(8115), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358361] = 4,
    ACTIONS(13645), 1,
      anon_sym_COMMA,
    ACTIONS(13647), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358376] = 4,
    ACTIONS(13649), 1,
      anon_sym_COMMA,
    ACTIONS(13651), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358391] = 4,
    ACTIONS(5270), 1,
      anon_sym_RBRACE,
    ACTIONS(13653), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358406] = 4,
    ACTIONS(13655), 1,
      anon_sym_RBRACE,
    ACTIONS(13657), 1,
      anon_sym_COMMA,
    STATE(8011), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358421] = 3,
    ACTIONS(12005), 1,
      anon_sym_EQ,
    ACTIONS(12003), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358434] = 4,
    ACTIONS(5332), 1,
      anon_sym_RBRACE,
    ACTIONS(13660), 1,
      anon_sym_COMMA,
    STATE(8207), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358449] = 4,
    ACTIONS(5414), 1,
      anon_sym_RBRACE,
    ACTIONS(13662), 1,
      anon_sym_COMMA,
    STATE(8024), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358464] = 4,
    ACTIONS(5414), 1,
      anon_sym_RBRACE,
    ACTIONS(13662), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358479] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12429), 1,
      anon_sym_RPAREN,
    STATE(8065), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358494] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(13664), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [358511] = 4,
    ACTIONS(13666), 1,
      anon_sym_RBRACE,
    ACTIONS(13668), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358526] = 4,
    ACTIONS(11808), 1,
      anon_sym_RBRACE,
    ACTIONS(13670), 1,
      anon_sym_COMMA,
    STATE(8011), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358541] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13672), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358556] = 4,
    ACTIONS(13674), 1,
      anon_sym_COMMA,
    ACTIONS(13676), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358571] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(9197), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358586] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13678), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358601] = 4,
    ACTIONS(5416), 1,
      anon_sym_RBRACE,
    ACTIONS(13680), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358616] = 4,
    ACTIONS(5348), 1,
      anon_sym_RBRACE,
    ACTIONS(13682), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358631] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13684), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358646] = 4,
    ACTIONS(13686), 1,
      anon_sym_RBRACE,
    ACTIONS(13688), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358661] = 4,
    ACTIONS(5298), 1,
      anon_sym_RBRACE,
    ACTIONS(13690), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358676] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13692), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358691] = 4,
    ACTIONS(13694), 1,
      anon_sym_COMMA,
    ACTIONS(13696), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358706] = 4,
    ACTIONS(5416), 1,
      anon_sym_RBRACE,
    ACTIONS(13680), 1,
      anon_sym_COMMA,
    STATE(8035), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358721] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13698), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358736] = 4,
    ACTIONS(13700), 1,
      anon_sym_RBRACE,
    ACTIONS(13702), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358751] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(13706), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358766] = 4,
    ACTIONS(5420), 1,
      anon_sym_RBRACE,
    ACTIONS(13708), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358781] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13710), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358796] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13712), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358811] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12019), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [358822] = 4,
    ACTIONS(13714), 1,
      anon_sym_RBRACE,
    ACTIONS(13716), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358837] = 4,
    ACTIONS(6080), 1,
      anon_sym_RBRACE,
    ACTIONS(13718), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358852] = 4,
    ACTIONS(6082), 1,
      anon_sym_RBRACE,
    ACTIONS(13720), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358867] = 4,
    ACTIONS(13722), 1,
      anon_sym_RBRACE,
    ACTIONS(13724), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358882] = 4,
    ACTIONS(12317), 1,
      sym_identifier,
    ACTIONS(12321), 1,
      anon_sym_using,
    STATE(8853), 1,
      sym_struct_member,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358897] = 4,
    ACTIONS(13726), 1,
      anon_sym_RBRACE,
    ACTIONS(13728), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358912] = 4,
    ACTIONS(12025), 1,
      anon_sym_COMMA,
    ACTIONS(12027), 1,
      anon_sym_RPAREN,
    STATE(8085), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358927] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13730), 1,
      anon_sym_BQUOTE,
    ACTIONS(13732), 1,
      sym__raw_string_content,
    STATE(8053), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [358944] = 4,
    ACTIONS(5426), 1,
      anon_sym_RBRACE,
    ACTIONS(13734), 1,
      anon_sym_COMMA,
    STATE(8057), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358959] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(13736), 3,
      anon_sym_LBRACE,
      anon_sym_where,
      sym_tag,
  [358970] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13738), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [358985] = 4,
    ACTIONS(12399), 1,
      anon_sym_COMMA,
    ACTIONS(12563), 1,
      anon_sym_RPAREN,
    STATE(8510), 1,
      aux_sym_polymorphic_parameters_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359000] = 4,
    ACTIONS(12031), 1,
      anon_sym_COMMA,
    ACTIONS(12033), 1,
      anon_sym_RPAREN,
    STATE(7937), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359015] = 4,
    ACTIONS(13740), 1,
      anon_sym_RBRACE,
    ACTIONS(13742), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359030] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(13744), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [359047] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13746), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359062] = 4,
    ACTIONS(11291), 1,
      anon_sym_RPAREN,
    ACTIONS(13748), 1,
      anon_sym_COMMA,
    STATE(8193), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359077] = 4,
    ACTIONS(9125), 1,
      anon_sym_RBRACE,
    ACTIONS(13750), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359092] = 4,
    ACTIONS(5428), 1,
      anon_sym_RBRACE,
    ACTIONS(13752), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359107] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13754), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359122] = 4,
    ACTIONS(8885), 1,
      anon_sym_RBRACE,
    ACTIONS(13756), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359137] = 4,
    ACTIONS(5348), 1,
      anon_sym_RBRACE,
    ACTIONS(13682), 1,
      anon_sym_COMMA,
    STATE(8098), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359152] = 4,
    ACTIONS(12041), 1,
      anon_sym_COMMA,
    ACTIONS(12043), 1,
      anon_sym_RPAREN,
    STATE(8075), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359167] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(13758), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359182] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13760), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359197] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(13762), 1,
      anon_sym_RPAREN,
    STATE(8073), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359212] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(13764), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359227] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13766), 1,
      anon_sym_BQUOTE,
    ACTIONS(13768), 1,
      sym__raw_string_content,
    STATE(7818), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [359244] = 4,
    ACTIONS(5428), 1,
      anon_sym_RBRACE,
    ACTIONS(13752), 1,
      anon_sym_COMMA,
    STATE(8087), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359259] = 4,
    ACTIONS(13770), 1,
      anon_sym_COMMA,
    ACTIONS(13772), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359274] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13774), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359289] = 4,
    ACTIONS(13776), 1,
      anon_sym_COMMA,
    ACTIONS(13778), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359304] = 4,
    ACTIONS(13780), 1,
      anon_sym_COMMA,
    ACTIONS(13782), 1,
      anon_sym_RPAREN,
    STATE(8114), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359319] = 4,
    ACTIONS(13784), 1,
      anon_sym_RBRACE,
    ACTIONS(13786), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359334] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(13788), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359349] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13790), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359364] = 4,
    ACTIONS(8737), 1,
      anon_sym_RPAREN,
    ACTIONS(13792), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359379] = 4,
    ACTIONS(13794), 1,
      anon_sym_RBRACE,
    ACTIONS(13796), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359394] = 4,
    ACTIONS(5326), 1,
      anon_sym_RBRACE,
    ACTIONS(13798), 1,
      anon_sym_COMMA,
    STATE(7969), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359409] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13800), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359424] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13802), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359439] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13804), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359454] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12323), 1,
      anon_sym_RPAREN,
    STATE(8112), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359469] = 4,
    ACTIONS(13806), 1,
      anon_sym_COMMA,
    ACTIONS(13808), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359484] = 4,
    ACTIONS(13810), 1,
      anon_sym_COMMA,
    ACTIONS(13812), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359499] = 4,
    ACTIONS(13814), 1,
      anon_sym_RBRACE,
    ACTIONS(13816), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359514] = 4,
    ACTIONS(8731), 1,
      anon_sym_RPAREN,
    ACTIONS(13818), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359529] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13820), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359544] = 4,
    ACTIONS(5430), 1,
      anon_sym_RBRACE,
    ACTIONS(13822), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359559] = 4,
    ACTIONS(13824), 1,
      anon_sym_COMMA,
    ACTIONS(13826), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359574] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(13828), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359589] = 4,
    ACTIONS(13830), 1,
      anon_sym_RBRACE,
    ACTIONS(13832), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359604] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12345), 1,
      anon_sym_RPAREN,
    STATE(8160), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359619] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13834), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359634] = 4,
    ACTIONS(13836), 1,
      anon_sym_COMMA,
    ACTIONS(13838), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359649] = 4,
    ACTIONS(13840), 1,
      anon_sym_COMMA,
    ACTIONS(13842), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359664] = 4,
    ACTIONS(13844), 1,
      anon_sym_COMMA,
    ACTIONS(13846), 1,
      anon_sym_COLON,
    STATE(8431), 1,
      aux_sym_struct_member_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359679] = 4,
    ACTIONS(5298), 1,
      anon_sym_RBRACE,
    ACTIONS(13690), 1,
      anon_sym_COMMA,
    STATE(8538), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359694] = 4,
    ACTIONS(13848), 1,
      anon_sym_COMMA,
    ACTIONS(13850), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359709] = 4,
    ACTIONS(5350), 1,
      anon_sym_RBRACE,
    ACTIONS(13852), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359724] = 4,
    ACTIONS(6204), 1,
      anon_sym_RBRACE,
    ACTIONS(13854), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359739] = 4,
    ACTIONS(13856), 1,
      anon_sym_RBRACE,
    ACTIONS(13858), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359754] = 4,
    ACTIONS(6206), 1,
      anon_sym_RBRACE,
    ACTIONS(13860), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359769] = 4,
    ACTIONS(8763), 1,
      anon_sym_RPAREN,
    ACTIONS(13862), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359784] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13864), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359799] = 4,
    ACTIONS(5432), 1,
      anon_sym_RBRACE,
    ACTIONS(13866), 1,
      anon_sym_COMMA,
    STATE(8121), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359814] = 4,
    ACTIONS(11762), 1,
      anon_sym_RBRACE,
    ACTIONS(13868), 1,
      anon_sym_COMMA,
    STATE(8011), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359829] = 4,
    ACTIONS(13870), 1,
      anon_sym_RBRACE,
    ACTIONS(13872), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359844] = 4,
    ACTIONS(13874), 1,
      anon_sym_COMMA,
    ACTIONS(13876), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359859] = 4,
    ACTIONS(13878), 1,
      anon_sym_COMMA,
    ACTIONS(13880), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359874] = 4,
    ACTIONS(9105), 1,
      anon_sym_RBRACE,
    ACTIONS(13882), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359889] = 4,
    ACTIONS(11788), 1,
      anon_sym_RBRACE,
    ACTIONS(13884), 1,
      anon_sym_COMMA,
    STATE(8004), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359904] = 4,
    ACTIONS(5909), 1,
      anon_sym_RBRACE,
    ACTIONS(13886), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359919] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(13888), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359934] = 4,
    ACTIONS(12363), 1,
      anon_sym_RBRACE,
    ACTIONS(13890), 1,
      anon_sym_COMMA,
    STATE(8179), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359949] = 4,
    ACTIONS(11325), 1,
      anon_sym_RPAREN,
    ACTIONS(13892), 1,
      anon_sym_COMMA,
    STATE(8193), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359964] = 4,
    ACTIONS(11804), 1,
      anon_sym_RBRACE,
    ACTIONS(13894), 1,
      anon_sym_COMMA,
    STATE(8011), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359979] = 4,
    ACTIONS(13896), 1,
      anon_sym_COMMA,
    ACTIONS(13898), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [359994] = 4,
    ACTIONS(13900), 1,
      anon_sym_COMMA,
    ACTIONS(13902), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360009] = 4,
    ACTIONS(12363), 1,
      anon_sym_RBRACE,
    ACTIONS(13890), 1,
      anon_sym_COMMA,
    STATE(8547), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360024] = 4,
    ACTIONS(12011), 1,
      anon_sym_COMMA,
    ACTIONS(12013), 1,
      anon_sym_RPAREN,
    STATE(7756), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360039] = 4,
    ACTIONS(5434), 1,
      anon_sym_RBRACE,
    ACTIONS(13904), 1,
      anon_sym_COMMA,
    STATE(8133), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360054] = 4,
    ACTIONS(5434), 1,
      anon_sym_RBRACE,
    ACTIONS(13904), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360069] = 4,
    ACTIONS(13906), 1,
      anon_sym_COMMA,
    ACTIONS(13909), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360084] = 4,
    ACTIONS(12205), 1,
      anon_sym_COMMA,
    ACTIONS(12207), 1,
      anon_sym_RPAREN,
    STATE(8182), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360099] = 4,
    ACTIONS(9113), 1,
      anon_sym_RBRACE,
    ACTIONS(12373), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360114] = 4,
    ACTIONS(13911), 1,
      anon_sym_RBRACE,
    ACTIONS(13913), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360129] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13915), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360144] = 4,
    ACTIONS(13917), 1,
      anon_sym_COMMA,
    ACTIONS(13919), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360159] = 4,
    ACTIONS(13921), 1,
      anon_sym_RBRACE,
    ACTIONS(13923), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360174] = 4,
    ACTIONS(5354), 1,
      anon_sym_RBRACE,
    ACTIONS(13925), 1,
      anon_sym_COMMA,
    STATE(8187), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360189] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12543), 1,
      anon_sym_RPAREN,
    STATE(8337), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360204] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13927), 1,
      anon_sym_BQUOTE,
    ACTIONS(13929), 1,
      sym__raw_string_content,
    STATE(8148), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [360221] = 4,
    ACTIONS(5306), 1,
      anon_sym_RBRACE,
    ACTIONS(13931), 1,
      anon_sym_COMMA,
    STATE(8154), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360236] = 4,
    ACTIONS(5436), 1,
      anon_sym_RBRACE,
    ACTIONS(13933), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360251] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(8462), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360266] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13935), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360281] = 4,
    ACTIONS(13937), 1,
      anon_sym_RBRACE,
    ACTIONS(13939), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360296] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13941), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360311] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(13943), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360326] = 4,
    ACTIONS(13945), 1,
      anon_sym_COMMA,
    ACTIONS(13947), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360341] = 4,
    ACTIONS(5436), 1,
      anon_sym_RBRACE,
    ACTIONS(13933), 1,
      anon_sym_COMMA,
    STATE(8144), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360356] = 4,
    ACTIONS(13949), 1,
      anon_sym_RBRACE,
    ACTIONS(13951), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360371] = 4,
    ACTIONS(13953), 1,
      anon_sym_COMMA,
    ACTIONS(13955), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360386] = 4,
    ACTIONS(13957), 1,
      anon_sym_RBRACE,
    ACTIONS(13959), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360401] = 4,
    ACTIONS(5438), 1,
      anon_sym_RBRACE,
    ACTIONS(13961), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360416] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(13963), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360431] = 4,
    ACTIONS(13965), 1,
      anon_sym_COMMA,
    ACTIONS(13967), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360446] = 4,
    ACTIONS(9029), 1,
      anon_sym_RBRACE,
    ACTIONS(13969), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360461] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(13971), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [360478] = 4,
    ACTIONS(6102), 1,
      anon_sym_RBRACE,
    ACTIONS(13973), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360493] = 4,
    ACTIONS(6104), 1,
      anon_sym_RBRACE,
    ACTIONS(13975), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360508] = 4,
    ACTIONS(13977), 1,
      anon_sym_RBRACE,
    ACTIONS(13979), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360523] = 4,
    ACTIONS(13377), 1,
      anon_sym_COMMA,
    ACTIONS(13981), 1,
      anon_sym_COLON,
    STATE(8163), 1,
      aux_sym_field_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360538] = 4,
    ACTIONS(13377), 1,
      anon_sym_COMMA,
    ACTIONS(13981), 1,
      anon_sym_COLON,
    STATE(8567), 1,
      aux_sym_field_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360553] = 4,
    ACTIONS(5308), 1,
      anon_sym_RBRACE,
    ACTIONS(13983), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360568] = 4,
    ACTIONS(13985), 1,
      anon_sym_COMMA,
    ACTIONS(13987), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360583] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13989), 1,
      anon_sym_BQUOTE,
    ACTIONS(13991), 1,
      sym__raw_string_content,
    STATE(8162), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [360600] = 4,
    ACTIONS(5444), 1,
      anon_sym_RBRACE,
    ACTIONS(13993), 1,
      anon_sym_COMMA,
    STATE(8167), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360615] = 4,
    ACTIONS(13995), 1,
      anon_sym_COMMA,
    ACTIONS(13997), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360630] = 4,
    ACTIONS(13999), 1,
      anon_sym_COMMA,
    ACTIONS(14001), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360645] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(14003), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360660] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(11814), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360675] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(14005), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [360692] = 4,
    ACTIONS(14007), 1,
      anon_sym_COMMA,
    ACTIONS(14010), 1,
      anon_sym_COLON,
    STATE(8163), 1,
      aux_sym_field_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360707] = 4,
    ACTIONS(14012), 1,
      anon_sym_RBRACE,
    ACTIONS(14014), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360722] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14016), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360737] = 4,
    ACTIONS(10176), 1,
      anon_sym_COMMA,
    ACTIONS(14018), 1,
      anon_sym_RPAREN,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360752] = 4,
    ACTIONS(5446), 1,
      anon_sym_RBRACE,
    ACTIONS(14020), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360767] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14022), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360782] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14024), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360797] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12091), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [360808] = 4,
    ACTIONS(14026), 1,
      anon_sym_COMMA,
    ACTIONS(14028), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360823] = 4,
    ACTIONS(14030), 1,
      anon_sym_COMMA,
    ACTIONS(14032), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360838] = 4,
    ACTIONS(12107), 1,
      anon_sym_COMMA,
    ACTIONS(12109), 1,
      anon_sym_RPAREN,
    STATE(8189), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360853] = 4,
    ACTIONS(11778), 1,
      anon_sym_RBRACE,
    ACTIONS(13637), 1,
      anon_sym_COMMA,
    STATE(7826), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360868] = 4,
    ACTIONS(5520), 1,
      anon_sym_RBRACE,
    ACTIONS(14034), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360883] = 4,
    ACTIONS(12113), 1,
      anon_sym_COMMA,
    ACTIONS(12115), 1,
      anon_sym_RPAREN,
    STATE(8216), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360898] = 4,
    ACTIONS(14036), 1,
      anon_sym_COMMA,
    ACTIONS(14038), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360913] = 4,
    ACTIONS(5446), 1,
      anon_sym_RBRACE,
    ACTIONS(14020), 1,
      anon_sym_COMMA,
    STATE(8198), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360928] = 4,
    ACTIONS(14040), 1,
      anon_sym_RBRACE,
    ACTIONS(14042), 1,
      anon_sym_COMMA,
    STATE(8179), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360943] = 4,
    ACTIONS(14045), 1,
      anon_sym_COMMA,
    ACTIONS(14047), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360958] = 4,
    ACTIONS(14049), 1,
      anon_sym_COMMA,
    ACTIONS(14051), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360973] = 4,
    ACTIONS(8719), 1,
      anon_sym_RPAREN,
    ACTIONS(14053), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [360988] = 4,
    ACTIONS(5308), 1,
      anon_sym_RBRACE,
    ACTIONS(13983), 1,
      anon_sym_COMMA,
    STATE(8237), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361003] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14055), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361018] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14057), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361033] = 4,
    ACTIONS(5356), 1,
      anon_sym_RBRACE,
    ACTIONS(14059), 1,
      anon_sym_COMMA,
    STATE(8238), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361048] = 4,
    ACTIONS(5356), 1,
      anon_sym_RBRACE,
    ACTIONS(14059), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361063] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14061), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361078] = 4,
    ACTIONS(8701), 1,
      anon_sym_RPAREN,
    ACTIONS(14063), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361093] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14065), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361108] = 4,
    ACTIONS(7422), 1,
      anon_sym_LBRACE,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361123] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14067), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361138] = 4,
    ACTIONS(14069), 1,
      anon_sym_COMMA,
    ACTIONS(14072), 1,
      anon_sym_RPAREN,
    STATE(8193), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361153] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12285), 1,
      anon_sym_RPAREN,
    STATE(8212), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361168] = 4,
    ACTIONS(14074), 1,
      anon_sym_COMMA,
    ACTIONS(14076), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361183] = 4,
    ACTIONS(14078), 1,
      anon_sym_COMMA,
    ACTIONS(14080), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361198] = 4,
    ACTIONS(14082), 1,
      anon_sym_COMMA,
    ACTIONS(14084), 1,
      anon_sym_RPAREN,
    STATE(8258), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361213] = 4,
    ACTIONS(5448), 1,
      anon_sym_RBRACE,
    ACTIONS(14086), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361228] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12551), 1,
      anon_sym_RPAREN,
    STATE(8226), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361243] = 4,
    ACTIONS(14088), 1,
      anon_sym_RBRACE,
    ACTIONS(14090), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361258] = 4,
    ACTIONS(5328), 1,
      anon_sym_RBRACE,
    ACTIONS(13571), 1,
      anon_sym_COMMA,
    STATE(7898), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361273] = 4,
    ACTIONS(5334), 1,
      anon_sym_RBRACE,
    ACTIONS(14092), 1,
      anon_sym_COMMA,
    STATE(8382), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361288] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14094), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361303] = 4,
    ACTIONS(5450), 1,
      anon_sym_RBRACE,
    ACTIONS(14096), 1,
      anon_sym_COMMA,
    STATE(8225), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361318] = 4,
    ACTIONS(10542), 1,
      anon_sym_RBRACE,
    ACTIONS(10544), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361333] = 4,
    ACTIONS(14098), 1,
      anon_sym_RBRACE,
    ACTIONS(14100), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361348] = 4,
    ACTIONS(5334), 1,
      anon_sym_RBRACE,
    ACTIONS(14092), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361363] = 4,
    ACTIONS(11788), 1,
      anon_sym_RBRACE,
    ACTIONS(13884), 1,
      anon_sym_COMMA,
    STATE(8011), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361378] = 4,
    ACTIONS(9013), 1,
      anon_sym_RBRACE,
    ACTIONS(14102), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361393] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14104), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361408] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(14106), 3,
      anon_sym_LBRACE,
      anon_sym_where,
      sym_tag,
  [361419] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(14108), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361434] = 4,
    ACTIONS(14110), 1,
      anon_sym_RBRACE,
    ACTIONS(14112), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361449] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14114), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361464] = 4,
    ACTIONS(5522), 1,
      anon_sym_RBRACE,
    ACTIONS(14116), 1,
      anon_sym_COMMA,
    STATE(8469), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361479] = 4,
    ACTIONS(8739), 1,
      anon_sym_RPAREN,
    ACTIONS(14118), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361494] = 4,
    ACTIONS(9183), 1,
      anon_sym_RBRACE,
    ACTIONS(14120), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361509] = 4,
    ACTIONS(14122), 1,
      anon_sym_COMMA,
    ACTIONS(14124), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361524] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(13011), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RPAREN,
  [361535] = 4,
    ACTIONS(14126), 1,
      anon_sym_COMMA,
    ACTIONS(14129), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361550] = 4,
    ACTIONS(14131), 1,
      anon_sym_COMMA,
    ACTIONS(14133), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361565] = 4,
    ACTIONS(14135), 1,
      anon_sym_COMMA,
    ACTIONS(14137), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361580] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14139), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361595] = 4,
    ACTIONS(5452), 1,
      anon_sym_RBRACE,
    ACTIONS(14141), 1,
      anon_sym_COMMA,
    STATE(8616), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361610] = 4,
    ACTIONS(5452), 1,
      anon_sym_RBRACE,
    ACTIONS(14141), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361625] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(14143), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361640] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14145), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361655] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12435), 1,
      anon_sym_RPAREN,
    STATE(8306), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361670] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14147), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361685] = 4,
    ACTIONS(14149), 1,
      anon_sym_RBRACE,
    ACTIONS(14151), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361700] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14153), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361715] = 4,
    ACTIONS(14155), 1,
      anon_sym_COMMA,
    ACTIONS(14157), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361730] = 4,
    ACTIONS(14159), 1,
      anon_sym_COMMA,
    ACTIONS(14161), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361745] = 4,
    ACTIONS(14163), 1,
      anon_sym_COMMA,
    ACTIONS(14165), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361760] = 4,
    ACTIONS(14167), 1,
      anon_sym_RBRACE,
    ACTIONS(14169), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361775] = 4,
    ACTIONS(14171), 1,
      anon_sym_RBRACE,
    ACTIONS(14173), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361790] = 4,
    ACTIONS(5310), 1,
      anon_sym_RBRACE,
    ACTIONS(14175), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361805] = 4,
    ACTIONS(5358), 1,
      anon_sym_RBRACE,
    ACTIONS(14177), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361820] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14179), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361835] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14181), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361850] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14183), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361865] = 4,
    ACTIONS(14185), 1,
      anon_sym_RBRACE,
    ACTIONS(14187), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361880] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14189), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361895] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14191), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361910] = 4,
    ACTIONS(14193), 1,
      anon_sym_COMMA,
    ACTIONS(14195), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361925] = 4,
    ACTIONS(5454), 1,
      anon_sym_RBRACE,
    ACTIONS(14197), 1,
      anon_sym_COMMA,
    STATE(8252), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361940] = 4,
    ACTIONS(14199), 1,
      anon_sym_RBRACE,
    ACTIONS(14201), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361955] = 4,
    ACTIONS(14203), 1,
      anon_sym_RBRACE,
    ACTIONS(14205), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361970] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14207), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [361985] = 4,
    ACTIONS(14209), 1,
      anon_sym_RBRACE,
    ACTIONS(14211), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362000] = 4,
    ACTIONS(12399), 1,
      anon_sym_COMMA,
    ACTIONS(14213), 1,
      anon_sym_RPAREN,
    STATE(8510), 1,
      aux_sym_polymorphic_parameters_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362015] = 4,
    ACTIONS(5456), 1,
      anon_sym_RBRACE,
    ACTIONS(14215), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362030] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14217), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362045] = 4,
    ACTIONS(14219), 1,
      anon_sym_COMMA,
    ACTIONS(14221), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362060] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14223), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362075] = 4,
    ACTIONS(5358), 1,
      anon_sym_RBRACE,
    ACTIONS(14177), 1,
      anon_sym_COMMA,
    STATE(8269), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362090] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14225), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362105] = 4,
    ACTIONS(11275), 1,
      anon_sym_RPAREN,
    ACTIONS(14227), 1,
      anon_sym_COMMA,
    STATE(8193), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362120] = 4,
    ACTIONS(6122), 1,
      anon_sym_RBRACE,
    ACTIONS(14229), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362135] = 4,
    ACTIONS(6124), 1,
      anon_sym_RBRACE,
    ACTIONS(14231), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362150] = 4,
    ACTIONS(14233), 1,
      anon_sym_RBRACE,
    ACTIONS(14235), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362165] = 4,
    ACTIONS(14237), 1,
      anon_sym_RBRACE,
    ACTIONS(14239), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362180] = 4,
    ACTIONS(14241), 1,
      anon_sym_RBRACE,
    ACTIONS(14243), 1,
      anon_sym_COMMA,
    STATE(8019), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362195] = 4,
    ACTIONS(5286), 1,
      anon_sym_RBRACE,
    ACTIONS(14245), 1,
      anon_sym_COMMA,
    STATE(8435), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362210] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(14247), 1,
      anon_sym_BQUOTE,
    ACTIONS(14249), 1,
      sym__raw_string_content,
    STATE(8278), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [362227] = 4,
    ACTIONS(14251), 1,
      anon_sym_RBRACE,
    ACTIONS(14253), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362242] = 4,
    ACTIONS(5462), 1,
      anon_sym_RBRACE,
    ACTIONS(14255), 1,
      anon_sym_COMMA,
    STATE(8285), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362257] = 4,
    ACTIONS(14257), 1,
      anon_sym_RBRACE,
    ACTIONS(14259), 1,
      anon_sym_COMMA,
    STATE(8208), 1,
      aux_sym_import_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362272] = 4,
    ACTIONS(5360), 1,
      anon_sym_RBRACE,
    ACTIONS(14261), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362287] = 4,
    ACTIONS(5312), 1,
      anon_sym_RBRACE,
    ACTIONS(14263), 1,
      anon_sym_COMMA,
    STATE(8358), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362302] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14265), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362317] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14267), 1,
      anon_sym_RPAREN,
    STATE(8273), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362332] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14269), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362347] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14271), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362362] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14273), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362377] = 4,
    ACTIONS(5922), 1,
      anon_sym_RBRACE,
    ACTIONS(14275), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362392] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14277), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362407] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(14279), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [362424] = 4,
    ACTIONS(14281), 1,
      anon_sym_RBRACE,
    ACTIONS(14283), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362439] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14285), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362454] = 4,
    ACTIONS(14287), 1,
      anon_sym_RBRACE,
    ACTIONS(14289), 1,
      anon_sym_COMMA,
    STATE(8446), 1,
      aux_sym__struct_members_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362469] = 4,
    ACTIONS(14291), 1,
      anon_sym_RBRACE,
    ACTIONS(14293), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362484] = 4,
    ACTIONS(14295), 1,
      anon_sym_COMMA,
    ACTIONS(14297), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362499] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14299), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362514] = 4,
    ACTIONS(5464), 1,
      anon_sym_RBRACE,
    ACTIONS(14301), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362529] = 4,
    ACTIONS(6022), 1,
      anon_sym_RBRACE,
    ACTIONS(14303), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362544] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14305), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362559] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14307), 1,
      anon_sym_RPAREN,
    STATE(8289), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362574] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14309), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362589] = 4,
    ACTIONS(9151), 1,
      anon_sym_RBRACE,
    ACTIONS(14311), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362604] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14313), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362619] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14315), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362634] = 4,
    ACTIONS(14317), 1,
      anon_sym_RBRACE,
    ACTIONS(14319), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362649] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14321), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362664] = 4,
    ACTIONS(6024), 1,
      anon_sym_RBRACE,
    ACTIONS(14323), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362679] = 4,
    ACTIONS(14325), 1,
      anon_sym_COMMA,
    ACTIONS(14327), 1,
      anon_sym_COLON,
    STATE(8484), 1,
      aux_sym_polymorphic_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362694] = 4,
    ACTIONS(5924), 1,
      anon_sym_RBRACE,
    ACTIONS(14329), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362709] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(14331), 1,
      anon_sym_BQUOTE,
    ACTIONS(14333), 1,
      sym__raw_string_content,
    STATE(7755), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [362726] = 4,
    ACTIONS(12175), 1,
      anon_sym_COMMA,
    ACTIONS(12177), 1,
      anon_sym_RPAREN,
    STATE(8324), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362741] = 4,
    ACTIONS(14335), 1,
      anon_sym_RBRACE,
    ACTIONS(14337), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362756] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14339), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362771] = 4,
    ACTIONS(5464), 1,
      anon_sym_RBRACE,
    ACTIONS(14301), 1,
      anon_sym_COMMA,
    STATE(8338), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362786] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14341), 1,
      anon_sym_RPAREN,
    STATE(8304), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362801] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14343), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362816] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14345), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362831] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(14347), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362846] = 4,
    ACTIONS(14325), 1,
      anon_sym_COMMA,
    ACTIONS(14349), 1,
      anon_sym_COLON,
    STATE(8323), 1,
      aux_sym_polymorphic_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362861] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14351), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362876] = 4,
    ACTIONS(9187), 1,
      anon_sym_RBRACE,
    ACTIONS(14353), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362891] = 4,
    ACTIONS(5516), 1,
      anon_sym_RBRACE,
    ACTIONS(14355), 1,
      anon_sym_COMMA,
    STATE(7885), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362906] = 4,
    ACTIONS(12269), 1,
      anon_sym_COMMA,
    ACTIONS(12271), 1,
      anon_sym_RPAREN,
    STATE(8360), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362921] = 4,
    ACTIONS(14357), 1,
      anon_sym_COMMA,
    ACTIONS(14359), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362936] = 4,
    ACTIONS(14361), 1,
      anon_sym_COMMA,
    ACTIONS(14363), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362951] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(14365), 3,
      anon_sym_LBRACE,
      anon_sym_where,
      sym_tag,
  [362962] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14367), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362977] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(14369), 1,
      anon_sym_do,
    STATE(7132), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [362992] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14371), 1,
      anon_sym_RPAREN,
    STATE(8318), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363007] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14373), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363022] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14375), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363037] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14377), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363052] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14379), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363067] = 4,
    ACTIONS(14325), 1,
      anon_sym_COMMA,
    ACTIONS(14349), 1,
      anon_sym_COLON,
    STATE(8568), 1,
      aux_sym_polymorphic_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363082] = 4,
    ACTIONS(14325), 1,
      anon_sym_COMMA,
    ACTIONS(14381), 1,
      anon_sym_COLON,
    STATE(8568), 1,
      aux_sym_polymorphic_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363097] = 4,
    ACTIONS(8725), 1,
      anon_sym_RPAREN,
    ACTIONS(14383), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363112] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14385), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363127] = 4,
    ACTIONS(14387), 1,
      anon_sym_COMMA,
    ACTIONS(14389), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363142] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14391), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363157] = 4,
    ACTIONS(14393), 1,
      anon_sym_COMMA,
    ACTIONS(14395), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363172] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14397), 1,
      anon_sym_RPAREN,
    STATE(8330), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363187] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14399), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363202] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14401), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363217] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14403), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363232] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12481), 1,
      anon_sym_RPAREN,
    STATE(8365), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363247] = 4,
    ACTIONS(14405), 1,
      anon_sym_COMMA,
    ACTIONS(14407), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363262] = 4,
    ACTIONS(14409), 1,
      anon_sym_COMMA,
    ACTIONS(14411), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363277] = 4,
    ACTIONS(14413), 1,
      anon_sym_COMMA,
    ACTIONS(14415), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363292] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(14417), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363307] = 4,
    ACTIONS(5466), 1,
      anon_sym_RBRACE,
    ACTIONS(14419), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363322] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14421), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363337] = 4,
    ACTIONS(14423), 1,
      anon_sym_COMMA,
    ACTIONS(14425), 1,
      anon_sym_RPAREN,
    STATE(7963), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363352] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14427), 1,
      anon_sym_RPAREN,
    STATE(8342), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363367] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14429), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363382] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14431), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363397] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14433), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363412] = 4,
    ACTIONS(14435), 1,
      anon_sym_COMMA,
    ACTIONS(14437), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363427] = 4,
    ACTIONS(10470), 1,
      anon_sym_RBRACE,
    ACTIONS(10472), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363442] = 4,
    ACTIONS(4456), 1,
      anon_sym_LBRACE,
    ACTIONS(10312), 1,
      anon_sym_COMMA,
    STATE(8410), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363457] = 4,
    ACTIONS(5468), 1,
      anon_sym_RBRACE,
    ACTIONS(14439), 1,
      anon_sym_COMMA,
    STATE(8381), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363472] = 4,
    ACTIONS(5314), 1,
      anon_sym_RBRACE,
    ACTIONS(14441), 1,
      anon_sym_COMMA,
    STATE(8415), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363487] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14443), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363502] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14445), 1,
      anon_sym_RPAREN,
    STATE(8352), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363517] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14447), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363532] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14449), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363547] = 4,
    ACTIONS(14451), 1,
      anon_sym_COMMA,
    ACTIONS(14453), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363562] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14455), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363577] = 4,
    ACTIONS(14457), 1,
      anon_sym_RBRACE,
    ACTIONS(14459), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363592] = 4,
    ACTIONS(14461), 1,
      anon_sym_RBRACE,
    ACTIONS(14463), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363607] = 4,
    ACTIONS(5314), 1,
      anon_sym_RBRACE,
    ACTIONS(14441), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363622] = 4,
    ACTIONS(8999), 1,
      anon_sym_RBRACE,
    ACTIONS(14465), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363637] = 4,
    ACTIONS(8687), 1,
      anon_sym_RPAREN,
    ACTIONS(14467), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363652] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14469), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363667] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14471), 1,
      anon_sym_RPAREN,
    STATE(8363), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363682] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14473), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363697] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14475), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363712] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(14477), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363727] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14479), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363742] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14481), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363757] = 4,
    ACTIONS(14483), 1,
      anon_sym_COMMA,
    ACTIONS(14485), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363772] = 4,
    ACTIONS(14487), 1,
      anon_sym_COMMA,
    ACTIONS(14489), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363787] = 4,
    ACTIONS(14491), 1,
      anon_sym_COMMA,
    ACTIONS(14493), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363802] = 4,
    ACTIONS(14495), 1,
      anon_sym_RBRACE,
    ACTIONS(14497), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363817] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14499), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363832] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(14501), 1,
      anon_sym_BQUOTE,
    ACTIONS(14503), 1,
      sym__raw_string_content,
    STATE(8417), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [363849] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14505), 1,
      anon_sym_RPAREN,
    STATE(8375), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363864] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14507), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363879] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14509), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363894] = 4,
    ACTIONS(5366), 1,
      anon_sym_RBRACE,
    ACTIONS(14511), 1,
      anon_sym_COMMA,
    STATE(8439), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363909] = 4,
    ACTIONS(5470), 1,
      anon_sym_RBRACE,
    ACTIONS(14513), 1,
      anon_sym_COMMA,
    STATE(8401), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363924] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14515), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363939] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14517), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363954] = 4,
    ACTIONS(5470), 1,
      anon_sym_RBRACE,
    ACTIONS(14513), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363969] = 4,
    ACTIONS(5336), 1,
      anon_sym_RBRACE,
    ACTIONS(14519), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363984] = 4,
    ACTIONS(14521), 1,
      anon_sym_COMMA,
    ACTIONS(14523), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [363999] = 4,
    ACTIONS(8811), 1,
      anon_sym_SEMI,
    ACTIONS(9946), 1,
      anon_sym_COMMA,
    STATE(7781), 1,
      aux_sym_variable_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364014] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14525), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364029] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14527), 1,
      anon_sym_RPAREN,
    STATE(8387), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364044] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14529), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364059] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14531), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364074] = 4,
    ACTIONS(14533), 1,
      anon_sym_RBRACE,
    ACTIONS(14535), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364089] = 4,
    ACTIONS(10176), 1,
      anon_sym_COMMA,
    ACTIONS(14537), 1,
      anon_sym_RPAREN,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364104] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14539), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364119] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14541), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364134] = 4,
    ACTIONS(14543), 1,
      anon_sym_COMMA,
    ACTIONS(14546), 1,
      anon_sym_COLON,
    STATE(8393), 1,
      aux_sym_switch_case_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364149] = 4,
    ACTIONS(14548), 1,
      anon_sym_COMMA,
    ACTIONS(14550), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364164] = 4,
    ACTIONS(13844), 1,
      anon_sym_COMMA,
    ACTIONS(14552), 1,
      anon_sym_COLON,
    STATE(8499), 1,
      aux_sym_struct_member_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364179] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14554), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364194] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14556), 1,
      anon_sym_RPAREN,
    STATE(8034), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364209] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14558), 1,
      anon_sym_RPAREN,
    STATE(8399), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364224] = 4,
    ACTIONS(13704), 1,
      anon_sym_COMMA,
    ACTIONS(14560), 1,
      anon_sym_RPAREN,
    STATE(8122), 1,
      aux_sym_struct_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364239] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14562), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364254] = 4,
    ACTIONS(5472), 1,
      anon_sym_RBRACE,
    ACTIONS(14564), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364269] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14566), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364284] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14568), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364299] = 4,
    ACTIONS(14570), 1,
      anon_sym_RBRACE,
    ACTIONS(14572), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364314] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12447), 1,
      anon_sym_RPAREN,
    STATE(8478), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364329] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14574), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364344] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14576), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364359] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14578), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364374] = 4,
    ACTIONS(5292), 1,
      anon_sym_RBRACE,
    ACTIONS(14580), 1,
      anon_sym_COMMA,
    STATE(8028), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364389] = 4,
    ACTIONS(4466), 1,
      anon_sym_LBRACE,
    ACTIONS(14582), 1,
      anon_sym_COMMA,
    STATE(8410), 1,
      aux_sym_where_clause_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364404] = 4,
    ACTIONS(14585), 1,
      anon_sym_COMMA,
    ACTIONS(14587), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364419] = 4,
    ACTIONS(5472), 1,
      anon_sym_RBRACE,
    ACTIONS(14564), 1,
      anon_sym_COMMA,
    STATE(8422), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364434] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14589), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364449] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(12839), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
  [364460] = 4,
    ACTIONS(5316), 1,
      anon_sym_RBRACE,
    ACTIONS(14591), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364475] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14593), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364490] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(14595), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [364507] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14597), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364522] = 4,
    ACTIONS(14599), 1,
      anon_sym_RBRACE,
    ACTIONS(14601), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364537] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14603), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364552] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14605), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364567] = 4,
    ACTIONS(5474), 1,
      anon_sym_RBRACE,
    ACTIONS(14607), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364582] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14609), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364597] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14611), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364612] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14613), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364627] = 4,
    ACTIONS(14615), 1,
      anon_sym_RBRACE,
    ACTIONS(14617), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364642] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14619), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364657] = 4,
    ACTIONS(6142), 1,
      anon_sym_RBRACE,
    ACTIONS(14621), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364672] = 4,
    ACTIONS(6144), 1,
      anon_sym_RBRACE,
    ACTIONS(14623), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364687] = 4,
    ACTIONS(14625), 1,
      anon_sym_RBRACE,
    ACTIONS(14627), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364702] = 4,
    ACTIONS(13844), 1,
      anon_sym_COMMA,
    ACTIONS(14552), 1,
      anon_sym_COLON,
    STATE(8520), 1,
      aux_sym_struct_member_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364717] = 4,
    ACTIONS(14629), 1,
      anon_sym_COMMA,
    ACTIONS(14631), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364732] = 4,
    ACTIONS(5316), 1,
      anon_sym_RBRACE,
    ACTIONS(14591), 1,
      anon_sym_COMMA,
    STATE(8447), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364747] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14633), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364762] = 4,
    ACTIONS(5292), 1,
      anon_sym_RBRACE,
    ACTIONS(14580), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364777] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(9169), 1,
      anon_sym_LBRACE,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364792] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(14635), 1,
      anon_sym_BQUOTE,
    ACTIONS(14637), 1,
      sym__raw_string_content,
    STATE(8443), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [364809] = 4,
    ACTIONS(5480), 1,
      anon_sym_RBRACE,
    ACTIONS(14639), 1,
      anon_sym_COMMA,
    STATE(8449), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364824] = 4,
    ACTIONS(5368), 1,
      anon_sym_RBRACE,
    ACTIONS(14641), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364839] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14643), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364854] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14645), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364869] = 4,
    ACTIONS(14647), 1,
      anon_sym_RBRACE,
    ACTIONS(14649), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364884] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(14651), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [364901] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14653), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364916] = 4,
    ACTIONS(14655), 1,
      anon_sym_RBRACE,
    ACTIONS(14657), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364931] = 4,
    ACTIONS(12814), 1,
      anon_sym_RBRACE,
    ACTIONS(14659), 1,
      anon_sym_COMMA,
    STATE(8546), 1,
      aux_sym__struct_members_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364946] = 4,
    ACTIONS(5318), 1,
      anon_sym_RBRACE,
    ACTIONS(14661), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364961] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(14663), 1,
      anon_sym_do,
    STATE(7112), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364976] = 4,
    ACTIONS(5482), 1,
      anon_sym_RBRACE,
    ACTIONS(14665), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [364991] = 4,
    ACTIONS(5524), 1,
      anon_sym_RBRACE,
    ACTIONS(14667), 1,
      anon_sym_COMMA,
    STATE(7761), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365006] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14669), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365021] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14671), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365036] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(14673), 1,
      anon_sym_do,
    STATE(7161), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365051] = 4,
    ACTIONS(12263), 1,
      anon_sym_COMMA,
    ACTIONS(12265), 1,
      anon_sym_RPAREN,
    STATE(8540), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365066] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14675), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365081] = 4,
    ACTIONS(12215), 1,
      anon_sym_COMMA,
    ACTIONS(12217), 1,
      anon_sym_RPAREN,
    STATE(8482), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365096] = 4,
    ACTIONS(14677), 1,
      anon_sym_RBRACE,
    ACTIONS(14679), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365111] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14681), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365126] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(14683), 1,
      anon_sym_do,
    STATE(7136), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365141] = 4,
    ACTIONS(14325), 1,
      anon_sym_COMMA,
    ACTIONS(14685), 1,
      anon_sym_COLON,
    STATE(8557), 1,
      aux_sym_polymorphic_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365156] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14687), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365171] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(14689), 1,
      anon_sym_do,
    STATE(7148), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365186] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14691), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365201] = 4,
    ACTIONS(5482), 1,
      anon_sym_RBRACE,
    ACTIONS(14665), 1,
      anon_sym_COMMA,
    STATE(8491), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365216] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(14693), 1,
      anon_sym_do,
    STATE(7276), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365231] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(14695), 1,
      anon_sym_do,
    STATE(7283), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365246] = 4,
    ACTIONS(8891), 1,
      anon_sym_RBRACE,
    ACTIONS(14697), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365261] = 4,
    ACTIONS(14699), 1,
      anon_sym_LBRACE,
    ACTIONS(14701), 1,
      sym_tag,
    STATE(8468), 1,
      aux_sym_struct_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365276] = 4,
    ACTIONS(5524), 1,
      anon_sym_RBRACE,
    ACTIONS(14667), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365291] = 4,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    ACTIONS(14704), 1,
      anon_sym_do,
    STATE(7132), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365306] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14706), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365321] = 4,
    ACTIONS(5944), 1,
      anon_sym_RBRACE,
    ACTIONS(14708), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365336] = 4,
    ACTIONS(5368), 1,
      anon_sym_RBRACE,
    ACTIONS(14641), 1,
      anon_sym_COMMA,
    STATE(8565), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365351] = 4,
    ACTIONS(14710), 1,
      anon_sym_COMMA,
    ACTIONS(14712), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365366] = 4,
    ACTIONS(9984), 1,
      anon_sym_RBRACE,
    ACTIONS(9986), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365381] = 4,
    ACTIONS(5946), 1,
      anon_sym_RBRACE,
    ACTIONS(14714), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365396] = 4,
    ACTIONS(14716), 1,
      anon_sym_RBRACE,
    ACTIONS(14718), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365411] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(14720), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365426] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14722), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365441] = 4,
    ACTIONS(5336), 1,
      anon_sym_RBRACE,
    ACTIONS(14519), 1,
      anon_sym_COMMA,
    STATE(8578), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365456] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14724), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365471] = 4,
    ACTIONS(8741), 1,
      anon_sym_RPAREN,
    ACTIONS(14726), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365486] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14728), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365501] = 4,
    ACTIONS(14325), 1,
      anon_sym_COMMA,
    ACTIONS(14685), 1,
      anon_sym_COLON,
    STATE(8568), 1,
      aux_sym_polymorphic_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365516] = 3,
    ACTIONS(14730), 1,
      anon_sym_EQ,
    ACTIONS(10699), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365529] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12535), 1,
      anon_sym_RPAREN,
    STATE(8502), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365544] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14732), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365559] = 4,
    ACTIONS(14734), 1,
      anon_sym_COMMA,
    ACTIONS(14736), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365574] = 4,
    ACTIONS(14738), 1,
      anon_sym_COMMA,
    ACTIONS(14740), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365589] = 4,
    ACTIONS(14742), 1,
      anon_sym_RBRACE,
    ACTIONS(14744), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365604] = 4,
    ACTIONS(5484), 1,
      anon_sym_RBRACE,
    ACTIONS(14746), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365619] = 4,
    ACTIONS(14748), 1,
      anon_sym_COMMA,
    ACTIONS(14750), 1,
      anon_sym_RPAREN,
    STATE(8055), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365634] = 4,
    ACTIONS(14752), 1,
      anon_sym_RBRACE,
    ACTIONS(14754), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365649] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14756), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365664] = 4,
    ACTIONS(14758), 1,
      anon_sym_COMMA,
    ACTIONS(14760), 1,
      anon_sym_RPAREN,
    STATE(8572), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365679] = 4,
    ACTIONS(5486), 1,
      anon_sym_RBRACE,
    ACTIONS(14762), 1,
      anon_sym_COMMA,
    STATE(8512), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365694] = 4,
    ACTIONS(9041), 1,
      anon_sym_RBRACE,
    ACTIONS(14764), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365709] = 4,
    ACTIONS(14766), 1,
      anon_sym_RBRACE,
    ACTIONS(14768), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365724] = 4,
    ACTIONS(13844), 1,
      anon_sym_COMMA,
    ACTIONS(14770), 1,
      anon_sym_COLON,
    STATE(8520), 1,
      aux_sym_struct_member_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365739] = 4,
    ACTIONS(9097), 1,
      anon_sym_RBRACE,
    ACTIONS(14772), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365754] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14774), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365769] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(14776), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365784] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14778), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365799] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(14780), 3,
      anon_sym_LBRACE,
      anon_sym_where,
      sym_tag,
  [365810] = 4,
    ACTIONS(12399), 1,
      anon_sym_COMMA,
    ACTIONS(12549), 1,
      anon_sym_RPAREN,
    STATE(8510), 1,
      aux_sym_polymorphic_parameters_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365825] = 4,
    ACTIONS(14782), 1,
      anon_sym_COMMA,
    ACTIONS(14784), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365840] = 4,
    ACTIONS(14786), 1,
      anon_sym_COMMA,
    ACTIONS(14788), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365855] = 4,
    ACTIONS(14325), 1,
      anon_sym_COMMA,
    ACTIONS(14790), 1,
      anon_sym_COLON,
    STATE(8322), 1,
      aux_sym_polymorphic_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365870] = 4,
    ACTIONS(14792), 1,
      anon_sym_RBRACE,
    ACTIONS(14794), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365885] = 4,
    ACTIONS(14796), 1,
      anon_sym_COMMA,
    ACTIONS(14799), 1,
      anon_sym_RPAREN,
    STATE(8510), 1,
      aux_sym_polymorphic_parameters_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365900] = 4,
    ACTIONS(5488), 1,
      anon_sym_RBRACE,
    ACTIONS(14801), 1,
      anon_sym_COMMA,
    STATE(8522), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365915] = 4,
    ACTIONS(5488), 1,
      anon_sym_RBRACE,
    ACTIONS(14801), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365930] = 4,
    ACTIONS(14803), 1,
      anon_sym_RBRACE,
    ACTIONS(14805), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365945] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14807), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365960] = 4,
    ACTIONS(14809), 1,
      anon_sym_RBRACE,
    ACTIONS(14811), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365975] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14813), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [365990] = 4,
    ACTIONS(12379), 1,
      anon_sym_RBRACE,
    ACTIONS(14815), 1,
      anon_sym_COMMA,
    STATE(8179), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366005] = 4,
    ACTIONS(14817), 1,
      anon_sym_COMMA,
    ACTIONS(14819), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366020] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14821), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366035] = 4,
    ACTIONS(14823), 1,
      anon_sym_COMMA,
    ACTIONS(14826), 1,
      anon_sym_COLON,
    STATE(8520), 1,
      aux_sym_struct_member_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366050] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14828), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366065] = 4,
    ACTIONS(5490), 1,
      anon_sym_RBRACE,
    ACTIONS(14830), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366080] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14832), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366095] = 4,
    ACTIONS(14834), 1,
      anon_sym_RBRACE,
    ACTIONS(14836), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366110] = 4,
    ACTIONS(12912), 1,
      anon_sym_RPAREN,
    ACTIONS(14838), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366125] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14841), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366140] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14843), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366155] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14845), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366170] = 4,
    ACTIONS(14847), 1,
      anon_sym_COMMA,
    ACTIONS(14849), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366185] = 4,
    ACTIONS(5490), 1,
      anon_sym_RBRACE,
    ACTIONS(14830), 1,
      anon_sym_COMMA,
    STATE(8535), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366200] = 2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
    ACTIONS(8475), 3,
      sym__newline,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [366211] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14851), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366226] = 4,
    ACTIONS(14853), 1,
      anon_sym_RBRACE,
    ACTIONS(14855), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366241] = 4,
    ACTIONS(14857), 1,
      anon_sym_RBRACE,
    ACTIONS(14859), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366256] = 4,
    ACTIONS(5492), 1,
      anon_sym_RBRACE,
    ACTIONS(14861), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366271] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(14863), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366286] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14865), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366301] = 4,
    ACTIONS(5300), 1,
      anon_sym_RBRACE,
    ACTIONS(14867), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366316] = 4,
    ACTIONS(6164), 1,
      anon_sym_RBRACE,
    ACTIONS(14869), 1,
      anon_sym_COMMA,
    STATE(7835), 1,
      aux_sym_map_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366331] = 4,
    ACTIONS(8753), 1,
      anon_sym_RPAREN,
    ACTIONS(14871), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366346] = 4,
    ACTIONS(6166), 1,
      anon_sym_RBRACE,
    ACTIONS(14873), 1,
      anon_sym_COMMA,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366361] = 4,
    ACTIONS(14875), 1,
      anon_sym_RBRACE,
    ACTIONS(14877), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366376] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14879), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366391] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(14881), 1,
      anon_sym_BQUOTE,
    ACTIONS(14883), 1,
      sym__raw_string_content,
    STATE(8550), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [366408] = 4,
    ACTIONS(5498), 1,
      anon_sym_RBRACE,
    ACTIONS(14885), 1,
      anon_sym_COMMA,
    STATE(8554), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366423] = 4,
    ACTIONS(14887), 1,
      anon_sym_RBRACE,
    ACTIONS(14889), 1,
      anon_sym_COMMA,
    STATE(8546), 1,
      aux_sym__struct_members_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366438] = 4,
    ACTIONS(12561), 1,
      anon_sym_RBRACE,
    ACTIONS(14892), 1,
      anon_sym_COMMA,
    STATE(8179), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366453] = 4,
    ACTIONS(12561), 1,
      anon_sym_RBRACE,
    ACTIONS(14892), 1,
      anon_sym_COMMA,
    STATE(7886), 1,
      aux_sym_struct_declaration_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366468] = 4,
    ACTIONS(14894), 1,
      anon_sym_RBRACE,
    ACTIONS(14896), 1,
      anon_sym_COMMA,
    STATE(7849), 1,
      aux_sym_bit_field_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366483] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(14898), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [366500] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14900), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366515] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14902), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366530] = 4,
    ACTIONS(9131), 1,
      anon_sym_RBRACE,
    ACTIONS(12567), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366545] = 4,
    ACTIONS(5500), 1,
      anon_sym_RBRACE,
    ACTIONS(14904), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366560] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12371), 1,
      anon_sym_RPAREN,
    STATE(7752), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366575] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14906), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366590] = 4,
    ACTIONS(14325), 1,
      anon_sym_COMMA,
    ACTIONS(14908), 1,
      anon_sym_COLON,
    STATE(8568), 1,
      aux_sym_polymorphic_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366605] = 4,
    ACTIONS(14910), 1,
      anon_sym_COMMA,
    ACTIONS(14912), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366620] = 4,
    ACTIONS(12255), 1,
      anon_sym_COMMA,
    ACTIONS(12257), 1,
      anon_sym_RPAREN,
    STATE(8570), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366635] = 4,
    ACTIONS(14914), 1,
      anon_sym_COMMA,
    ACTIONS(14916), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366650] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14918), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366665] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(14920), 1,
      anon_sym_BQUOTE,
    ACTIONS(14922), 1,
      sym__raw_string_content,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [366682] = 4,
    ACTIONS(5500), 1,
      anon_sym_RBRACE,
    ACTIONS(14904), 1,
      anon_sym_COMMA,
    STATE(8577), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366697] = 5,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(13118), 1,
      sym__raw_string_content,
    ACTIONS(14925), 1,
      anon_sym_BQUOTE,
    STATE(8562), 1,
      aux_sym__raw_string_literal_repeat1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [366714] = 4,
    ACTIONS(5370), 1,
      anon_sym_RBRACE,
    ACTIONS(14927), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366729] = 4,
    ACTIONS(5508), 1,
      anon_sym_RBRACE,
    ACTIONS(13579), 1,
      anon_sym_COMMA,
    STATE(7977), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366744] = 4,
    ACTIONS(13377), 1,
      anon_sym_COMMA,
    ACTIONS(14929), 1,
      anon_sym_COLON,
    STATE(8163), 1,
      aux_sym_field_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366759] = 4,
    ACTIONS(14931), 1,
      anon_sym_COMMA,
    ACTIONS(14934), 1,
      anon_sym_COLON,
    STATE(8568), 1,
      aux_sym_polymorphic_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366774] = 4,
    ACTIONS(14936), 1,
      anon_sym_RBRACE,
    ACTIONS(14938), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366789] = 4,
    ACTIONS(8769), 1,
      anon_sym_RPAREN,
    ACTIONS(14940), 1,
      anon_sym_COMMA,
    STATE(8525), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366804] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14942), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366819] = 4,
    ACTIONS(11333), 1,
      anon_sym_RPAREN,
    ACTIONS(14944), 1,
      anon_sym_COMMA,
    STATE(8193), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366834] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(12583), 1,
      anon_sym_RPAREN,
    STATE(8605), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366849] = 4,
    ACTIONS(14946), 1,
      anon_sym_COMMA,
    ACTIONS(14948), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366864] = 4,
    ACTIONS(14950), 1,
      anon_sym_COMMA,
    ACTIONS(14952), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366879] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14954), 1,
      anon_sym_PIPE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366894] = 4,
    ACTIONS(5502), 1,
      anon_sym_RBRACE,
    ACTIONS(14956), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366909] = 4,
    ACTIONS(5338), 1,
      anon_sym_RBRACE,
    ACTIONS(14958), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366924] = 4,
    ACTIONS(14960), 1,
      anon_sym_RBRACE,
    ACTIONS(14962), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366939] = 4,
    ACTIONS(7453), 1,
      anon_sym_LBRACE,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366954] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14964), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366969] = 4,
    ACTIONS(8045), 1,
      anon_sym_LPAREN,
    ACTIONS(11599), 1,
      anon_sym_SLASH,
    ACTIONS(14966), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366984] = 4,
    ACTIONS(5504), 1,
      anon_sym_RBRACE,
    ACTIONS(14968), 1,
      anon_sym_COMMA,
    STATE(7751), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [366999] = 4,
    ACTIONS(5372), 1,
      anon_sym_RBRACE,
    ACTIONS(14970), 1,
      anon_sym_COMMA,
    STATE(7774), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367014] = 4,
    ACTIONS(11841), 1,
      anon_sym_COMMA,
    ACTIONS(11843), 1,
      anon_sym_RPAREN,
    STATE(7768), 1,
      aux_sym_tuple_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367029] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14972), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367044] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14974), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367059] = 4,
    ACTIONS(14976), 1,
      anon_sym_RBRACE,
    ACTIONS(14978), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367074] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14980), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367089] = 4,
    ACTIONS(5288), 1,
      anon_sym_RBRACE,
    ACTIONS(13322), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367104] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14982), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367119] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14984), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367134] = 4,
    ACTIONS(9195), 1,
      anon_sym_RBRACE,
    ACTIONS(14986), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367149] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14988), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367164] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14990), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367179] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14992), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367194] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14994), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367209] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14996), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367224] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(14998), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367239] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(15000), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367254] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(15002), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367269] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(15004), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367284] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(15006), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367299] = 4,
    ACTIONS(7734), 1,
      anon_sym_LPAREN,
    ACTIONS(11784), 1,
      anon_sym_SLASH,
    ACTIONS(15008), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367314] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(15010), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367329] = 4,
    ACTIONS(15012), 1,
      anon_sym_RBRACE,
    ACTIONS(15014), 1,
      anon_sym_COMMA,
    STATE(7676), 1,
      aux_sym_enum_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367344] = 4,
    ACTIONS(12283), 1,
      anon_sym_COMMA,
    ACTIONS(15016), 1,
      anon_sym_RPAREN,
    STATE(7794), 1,
      aux_sym_polymorphic_type_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367359] = 4,
    ACTIONS(13377), 1,
      anon_sym_COMMA,
    ACTIONS(15018), 1,
      anon_sym_COLON,
    STATE(7884), 1,
      aux_sym_field_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367374] = 4,
    ACTIONS(15020), 1,
      anon_sym_COMMA,
    ACTIONS(15022), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367389] = 4,
    ACTIONS(15024), 1,
      anon_sym_COMMA,
    ACTIONS(15026), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367404] = 3,
    ACTIONS(15028), 1,
      anon_sym_EQ,
    ACTIONS(10398), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367417] = 4,
    ACTIONS(9141), 1,
      anon_sym_RBRACE,
    ACTIONS(15030), 1,
      anon_sym_COMMA,
    STATE(7767), 1,
      aux_sym_union_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367432] = 4,
    ACTIONS(15032), 1,
      anon_sym_COMMA,
    ACTIONS(15034), 1,
      anon_sym_RPAREN,
    STATE(8220), 1,
      aux_sym_call_expression_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367447] = 4,
    ACTIONS(5506), 1,
      anon_sym_RBRACE,
    ACTIONS(13107), 1,
      anon_sym_COMMA,
    STATE(7974), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367462] = 4,
    ACTIONS(9490), 1,
      anon_sym_COMMA,
    ACTIONS(15036), 1,
      anon_sym_RBRACE,
    STATE(7103), 1,
      aux_sym_overloaded_procedure_declaration_repeat1,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367477] = 4,
    ACTIONS(5454), 1,
      anon_sym_RBRACE,
    ACTIONS(14197), 1,
      anon_sym_COMMA,
    STATE(7815), 1,
      aux_sym_struct_repeat2,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367492] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15040), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367504] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15044), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367516] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15046), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367528] = 3,
    ACTIONS(15048), 1,
      sym_identifier,
    ACTIONS(15050), 1,
      anon_sym_using,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367540] = 3,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(3193), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367552] = 2,
    ACTIONS(14010), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367562] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(2981), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367574] = 3,
    ACTIONS(13527), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367586] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15052), 1,
      aux_sym_character_token1,
    ACTIONS(15054), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [367600] = 3,
    ACTIONS(11468), 1,
      anon_sym_LPAREN,
    STATE(2338), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367612] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15056), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367624] = 3,
    ACTIONS(12810), 1,
      anon_sym_LBRACE,
    ACTIONS(12812), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367636] = 3,
    ACTIONS(10562), 1,
      anon_sym_SEMI,
    ACTIONS(10564), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367648] = 3,
    ACTIONS(7740), 1,
      anon_sym_LBRACE,
    ACTIONS(15058), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367660] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15060), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367672] = 2,
    ACTIONS(14040), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367682] = 3,
    ACTIONS(14012), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367694] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6662), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367706] = 2,
    ACTIONS(11687), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367716] = 3,
    ACTIONS(10518), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367728] = 3,
    ACTIONS(13551), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367740] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15062), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367752] = 3,
    ACTIONS(10674), 1,
      anon_sym_SEMI,
    ACTIONS(10676), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367764] = 3,
    ACTIONS(10596), 1,
      anon_sym_SEMI,
    ACTIONS(10598), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367776] = 2,
    ACTIONS(14072), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367786] = 3,
    ACTIONS(10524), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367798] = 3,
    ACTIONS(15064), 1,
      sym_identifier,
    ACTIONS(15066), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367810] = 3,
    ACTIONS(14088), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367822] = 3,
    ACTIONS(11466), 1,
      anon_sym_LPAREN,
    STATE(535), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367834] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15068), 1,
      aux_sym_character_token1,
    ACTIONS(15070), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [367848] = 3,
    ACTIONS(10470), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367860] = 2,
    ACTIONS(10682), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367870] = 3,
    ACTIONS(10542), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367882] = 3,
    ACTIONS(14098), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367894] = 3,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(2990), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367906] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15072), 1,
      aux_sym_character_token1,
    ACTIONS(15074), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [367920] = 3,
    ACTIONS(13043), 1,
      anon_sym_LBRACE,
    ACTIONS(13045), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367932] = 3,
    ACTIONS(14110), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367944] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15076), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367956] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15078), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367968] = 2,
    ACTIONS(15080), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367978] = 2,
    ACTIONS(13256), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [367988] = 3,
    ACTIONS(10612), 1,
      anon_sym_SEMI,
    ACTIONS(10614), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368000] = 3,
    ACTIONS(10370), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368012] = 3,
    ACTIONS(14171), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368024] = 3,
    ACTIONS(10504), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368036] = 3,
    ACTIONS(10188), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368048] = 3,
    ACTIONS(14149), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368060] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15082), 1,
      aux_sym_character_token1,
    ACTIONS(15084), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [368074] = 3,
    ACTIONS(14167), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368086] = 2,
    ACTIONS(11669), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368096] = 3,
    ACTIONS(10709), 1,
      anon_sym_SEMI,
    ACTIONS(10711), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368108] = 3,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    STATE(7278), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368120] = 3,
    ACTIONS(14185), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368132] = 3,
    ACTIONS(9952), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368144] = 3,
    ACTIONS(14199), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368156] = 3,
    ACTIONS(14203), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368168] = 3,
    ACTIONS(9942), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368180] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15086), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368192] = 3,
    ACTIONS(14209), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368204] = 3,
    ACTIONS(15088), 1,
      anon_sym_LBRACE,
    ACTIONS(15090), 1,
      sym_tag,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368216] = 3,
    ACTIONS(10040), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368228] = 2,
    ACTIONS(15092), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368238] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15094), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368250] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6795), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368262] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15096), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368274] = 3,
    ACTIONS(14237), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368286] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(4060), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368298] = 3,
    ACTIONS(14233), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368310] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15098), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368322] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15100), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368334] = 3,
    ACTIONS(14251), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368346] = 3,
    ACTIONS(10705), 1,
      anon_sym_SEMI,
    ACTIONS(10707), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368358] = 3,
    ACTIONS(15102), 1,
      sym_identifier,
    ACTIONS(15104), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368370] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6843), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368382] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15106), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368394] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15108), 1,
      aux_sym_character_token1,
    ACTIONS(15110), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [368408] = 3,
    ACTIONS(12705), 1,
      anon_sym_LBRACE,
    ACTIONS(12707), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368420] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15112), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368432] = 3,
    ACTIONS(14281), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368444] = 3,
    ACTIONS(11470), 1,
      anon_sym_LPAREN,
    STATE(6727), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368456] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15114), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368468] = 2,
    ACTIONS(11707), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368478] = 3,
    ACTIONS(14317), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368490] = 3,
    ACTIONS(14291), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368502] = 3,
    ACTIONS(6281), 1,
      anon_sym_LBRACE,
    ACTIONS(15116), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368514] = 3,
    ACTIONS(15118), 1,
      sym_identifier,
    ACTIONS(15120), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368526] = 3,
    ACTIONS(10192), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368538] = 3,
    ACTIONS(11464), 1,
      anon_sym_LPAREN,
    STATE(6785), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368550] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15122), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368562] = 3,
    ACTIONS(13252), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368574] = 3,
    ACTIONS(10206), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368586] = 2,
    ACTIONS(12651), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368596] = 3,
    ACTIONS(13629), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368608] = 3,
    ACTIONS(14335), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368620] = 3,
    ACTIONS(13351), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368632] = 3,
    ACTIONS(11470), 1,
      anon_sym_LPAREN,
    STATE(3472), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368644] = 3,
    ACTIONS(15124), 1,
      sym_identifier,
    ACTIONS(15126), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368656] = 2,
    ACTIONS(15128), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368666] = 3,
    ACTIONS(10546), 1,
      anon_sym_SEMI,
    ACTIONS(10548), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368678] = 3,
    ACTIONS(10656), 1,
      anon_sym_SEMI,
    ACTIONS(10658), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368690] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15130), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368702] = 3,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(6632), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368714] = 2,
    ACTIONS(13655), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368724] = 3,
    ACTIONS(15132), 1,
      sym_identifier,
    ACTIONS(15134), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368736] = 2,
    ACTIONS(13909), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368746] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6682), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368758] = 3,
    ACTIONS(15136), 1,
      sym_identifier,
    ACTIONS(15138), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368770] = 3,
    ACTIONS(15140), 1,
      sym_identifier,
    ACTIONS(15142), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368782] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15144), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368794] = 3,
    ACTIONS(10582), 1,
      anon_sym_SEMI,
    ACTIONS(10584), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368806] = 3,
    ACTIONS(10652), 1,
      anon_sym_SEMI,
    ACTIONS(10654), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368818] = 3,
    ACTIONS(10146), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368830] = 3,
    ACTIONS(13666), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368842] = 3,
    ACTIONS(15146), 1,
      sym_identifier,
    ACTIONS(15148), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368854] = 3,
    ACTIONS(10450), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368866] = 2,
    ACTIONS(14699), 2,
      anon_sym_LBRACE,
      sym_tag,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368876] = 3,
    ACTIONS(12778), 1,
      anon_sym_RBRACE,
    ACTIONS(15150), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368888] = 3,
    ACTIONS(14461), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368900] = 3,
    ACTIONS(15152), 1,
      sym_identifier,
    ACTIONS(15154), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368912] = 3,
    ACTIONS(10182), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368924] = 3,
    ACTIONS(13187), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368936] = 3,
    ACTIONS(14457), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368948] = 3,
    ACTIONS(13197), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368960] = 3,
    ACTIONS(13686), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368972] = 3,
    ACTIONS(15156), 1,
      sym_identifier,
    ACTIONS(15158), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368984] = 3,
    ACTIONS(10300), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [368996] = 2,
    ACTIONS(10680), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369006] = 3,
    ACTIONS(10314), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369018] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15160), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369030] = 3,
    ACTIONS(12862), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369042] = 3,
    ACTIONS(10402), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369054] = 3,
    ACTIONS(14495), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369066] = 3,
    ACTIONS(11466), 1,
      anon_sym_LPAREN,
    STATE(538), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369078] = 3,
    ACTIONS(15162), 1,
      sym_identifier,
    ACTIONS(15164), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369090] = 3,
    ACTIONS(13714), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369102] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15166), 1,
      aux_sym_character_token1,
    ACTIONS(15168), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [369116] = 3,
    ACTIONS(10695), 1,
      anon_sym_SEMI,
    ACTIONS(10697), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369128] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15170), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369140] = 3,
    ACTIONS(13700), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369152] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15172), 1,
      aux_sym_character_token1,
    ACTIONS(15174), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [369166] = 3,
    ACTIONS(15176), 1,
      sym_identifier,
    ACTIONS(15178), 1,
      anon_sym_DOLLAR,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369178] = 3,
    ACTIONS(12640), 1,
      anon_sym_LBRACE,
    ACTIONS(12642), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369190] = 3,
    ACTIONS(13273), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369202] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15180), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369214] = 3,
    ACTIONS(15182), 1,
      sym_identifier,
    ACTIONS(15184), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369226] = 3,
    ACTIONS(10216), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369238] = 3,
    ACTIONS(14533), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369250] = 2,
    ACTIONS(15186), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369260] = 3,
    ACTIONS(8155), 1,
      anon_sym_LBRACE,
    ACTIONS(15188), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369272] = 3,
    ACTIONS(13722), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369284] = 3,
    ACTIONS(6820), 1,
      anon_sym_LBRACE,
    STATE(7202), 1,
      sym_block,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369296] = 3,
    ACTIONS(13726), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369308] = 2,
    ACTIONS(11673), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369318] = 3,
    ACTIONS(15190), 1,
      sym_identifier,
    ACTIONS(15192), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369330] = 3,
    ACTIONS(15194), 1,
      sym_identifier,
    ACTIONS(15196), 1,
      anon_sym_using,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369342] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15198), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369354] = 2,
    ACTIONS(15200), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369364] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15202), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369376] = 3,
    ACTIONS(14570), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369388] = 3,
    ACTIONS(15204), 1,
      sym_identifier,
    ACTIONS(15206), 1,
      anon_sym_DOLLAR,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369400] = 3,
    ACTIONS(10050), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369412] = 3,
    ACTIONS(13413), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369424] = 3,
    ACTIONS(15208), 1,
      sym_identifier,
    ACTIONS(15210), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369436] = 3,
    ACTIONS(13740), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369448] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15212), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369460] = 3,
    ACTIONS(14599), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369472] = 3,
    ACTIONS(13203), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369484] = 3,
    ACTIONS(14615), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369496] = 3,
    ACTIONS(10348), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369508] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15214), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369520] = 3,
    ACTIONS(10210), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369532] = 3,
    ACTIONS(6751), 1,
      anon_sym_LBRACE,
    ACTIONS(15216), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369544] = 3,
    ACTIONS(15218), 1,
      sym_identifier,
    ACTIONS(15220), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369556] = 3,
    ACTIONS(14625), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369568] = 3,
    ACTIONS(13295), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369580] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15222), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369592] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(3060), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369604] = 3,
    ACTIONS(13856), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369616] = 3,
    ACTIONS(14647), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369628] = 3,
    ACTIONS(11468), 1,
      anon_sym_LPAREN,
    STATE(1399), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369640] = 3,
    ACTIONS(13039), 1,
      anon_sym_LBRACE,
    ACTIONS(13041), 1,
      sym_tag,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369652] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15224), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369664] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6782), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369676] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6790), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369688] = 3,
    ACTIONS(10244), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369700] = 3,
    ACTIONS(14655), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369712] = 3,
    ACTIONS(11470), 1,
      anon_sym_LPAREN,
    STATE(3451), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369724] = 3,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(6649), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369736] = 2,
    ACTIONS(5023), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369746] = 3,
    ACTIONS(10454), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369758] = 3,
    ACTIONS(14677), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369770] = 3,
    ACTIONS(10132), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369782] = 3,
    ACTIONS(13784), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369794] = 2,
    ACTIONS(12307), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369804] = 3,
    ACTIONS(9984), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369816] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15226), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369828] = 3,
    ACTIONS(13794), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369840] = 3,
    ACTIONS(15228), 1,
      sym_identifier,
    ACTIONS(15230), 1,
      anon_sym_DOLLAR,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369852] = 3,
    ACTIONS(13445), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369864] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15232), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369876] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15234), 1,
      aux_sym_character_token1,
    ACTIONS(15236), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [369890] = 3,
    ACTIONS(14716), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369902] = 3,
    ACTIONS(10334), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369914] = 3,
    ACTIONS(10648), 1,
      anon_sym_SEMI,
    ACTIONS(10650), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369926] = 3,
    ACTIONS(10138), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369938] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15238), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369950] = 3,
    ACTIONS(12655), 1,
      anon_sym_LBRACE,
    ACTIONS(12657), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369962] = 3,
    ACTIONS(10668), 1,
      anon_sym_SEMI,
    ACTIONS(10670), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369974] = 3,
    ACTIONS(10020), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369986] = 3,
    ACTIONS(14742), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [369998] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15240), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370010] = 3,
    ACTIONS(13814), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370022] = 3,
    ACTIONS(14752), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370034] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15242), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370046] = 3,
    ACTIONS(14792), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370058] = 3,
    ACTIONS(13455), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370070] = 3,
    ACTIONS(11470), 1,
      anon_sym_LPAREN,
    STATE(3249), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370082] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15244), 1,
      aux_sym_character_token1,
    ACTIONS(15246), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [370096] = 3,
    ACTIONS(14766), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370108] = 3,
    ACTIONS(10554), 1,
      anon_sym_SEMI,
    ACTIONS(10556), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370120] = 2,
    ACTIONS(14826), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370130] = 2,
    ACTIONS(11683), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370140] = 3,
    ACTIONS(13830), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370152] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15248), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370164] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15250), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370176] = 2,
    ACTIONS(15252), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370186] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15254), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370198] = 3,
    ACTIONS(14803), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370210] = 3,
    ACTIONS(10488), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370222] = 3,
    ACTIONS(14809), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370234] = 3,
    ACTIONS(10318), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370246] = 2,
    ACTIONS(12912), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370256] = 3,
    ACTIONS(13463), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370268] = 3,
    ACTIONS(10036), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370280] = 3,
    ACTIONS(11464), 1,
      anon_sym_LPAREN,
    STATE(3866), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370292] = 2,
    ACTIONS(14887), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370302] = 3,
    ACTIONS(13310), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370314] = 3,
    ACTIONS(14834), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370326] = 3,
    ACTIONS(15256), 1,
      anon_sym_LBRACE,
    ACTIONS(15258), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370338] = 3,
    ACTIONS(10082), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370350] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15260), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370362] = 3,
    ACTIONS(10192), 1,
      anon_sym_RBRACE,
    ACTIONS(15262), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370374] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15264), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370386] = 3,
    ACTIONS(14857), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370398] = 3,
    ACTIONS(13870), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370410] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15266), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370422] = 3,
    ACTIONS(14853), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370434] = 3,
    ACTIONS(9930), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370446] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15268), 1,
      aux_sym_character_token1,
    ACTIONS(15270), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [370460] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15272), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370472] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15274), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370484] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15276), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370496] = 3,
    ACTIONS(15278), 1,
      anon_sym_LBRACE,
    ACTIONS(15280), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370508] = 3,
    ACTIONS(14875), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370520] = 3,
    ACTIONS(13921), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370532] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15282), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370544] = 3,
    ACTIONS(14894), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370556] = 3,
    ACTIONS(13316), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370568] = 3,
    ACTIONS(10660), 1,
      anon_sym_SEMI,
    ACTIONS(10662), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370580] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15284), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370592] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15286), 1,
      aux_sym_character_token1,
    ACTIONS(15288), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [370606] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(6774), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370618] = 3,
    ACTIONS(11468), 1,
      anon_sym_LPAREN,
    STATE(1306), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370630] = 3,
    ACTIONS(7707), 1,
      anon_sym_LBRACE,
    ACTIONS(11657), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370642] = 3,
    ACTIONS(11466), 1,
      anon_sym_LPAREN,
    STATE(564), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370654] = 3,
    ACTIONS(10574), 1,
      anon_sym_SEMI,
    ACTIONS(10576), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370666] = 3,
    ACTIONS(13242), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370678] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15290), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370690] = 3,
    ACTIONS(11470), 1,
      anon_sym_LPAREN,
    STATE(6643), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370702] = 3,
    ACTIONS(13485), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370714] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15292), 1,
      aux_sym_character_token1,
    ACTIONS(15294), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [370728] = 3,
    ACTIONS(13173), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370740] = 3,
    ACTIONS(10012), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370752] = 3,
    ACTIONS(13911), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370764] = 3,
    ACTIONS(12613), 1,
      anon_sym_LBRACE,
    ACTIONS(12615), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370776] = 2,
    ACTIONS(14934), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370786] = 3,
    ACTIONS(10366), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370798] = 2,
    ACTIONS(15296), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370808] = 2,
    ACTIONS(11703), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370818] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15298), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370830] = 3,
    ACTIONS(10532), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370842] = 3,
    ACTIONS(14936), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370854] = 2,
    ACTIONS(11699), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370864] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15300), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370876] = 3,
    ACTIONS(10566), 1,
      anon_sym_SEMI,
    ACTIONS(10568), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370888] = 3,
    ACTIONS(14960), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370900] = 3,
    ACTIONS(10232), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370912] = 3,
    ACTIONS(11480), 1,
      anon_sym_LPAREN,
    STATE(2987), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370924] = 3,
    ACTIONS(11464), 1,
      anon_sym_LPAREN,
    STATE(6762), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370936] = 3,
    ACTIONS(12862), 1,
      anon_sym_RBRACE,
    ACTIONS(15302), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370948] = 3,
    ACTIONS(13949), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370960] = 3,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(3087), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370972] = 3,
    ACTIONS(13122), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370984] = 3,
    ACTIONS(13937), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [370996] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15304), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371008] = 3,
    ACTIONS(10344), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371020] = 3,
    ACTIONS(15306), 1,
      sym_identifier,
    ACTIONS(15308), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371032] = 3,
    ACTIONS(14976), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371044] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15310), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371056] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15312), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371068] = 2,
    ACTIONS(8883), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371078] = 3,
    ACTIONS(13957), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371090] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15314), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371102] = 3,
    ACTIONS(13509), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371114] = 3,
    ACTIONS(15316), 1,
      sym_identifier,
    ACTIONS(15318), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371126] = 3,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(15320), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371138] = 3,
    ACTIONS(13224), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371150] = 3,
    ACTIONS(15012), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371162] = 3,
    ACTIONS(15322), 1,
      sym_identifier,
    ACTIONS(15324), 1,
      anon_sym_using,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371174] = 4,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15326), 1,
      aux_sym_character_token1,
    ACTIONS(15328), 1,
      sym_escape_sequence,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [371188] = 3,
    ACTIONS(13977), 1,
      anon_sym_RBRACE,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371200] = 3,
    ACTIONS(13341), 1,
      anon_sym_RBRACE,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371212] = 3,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(15330), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371224] = 3,
    ACTIONS(11444), 1,
      anon_sym_LPAREN,
    STATE(6692), 1,
      sym_parameters,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371236] = 2,
    ACTIONS(10949), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371245] = 2,
    ACTIONS(15332), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371254] = 2,
    ACTIONS(9720), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371263] = 2,
    ACTIONS(9428), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371272] = 2,
    ACTIONS(15334), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371281] = 2,
    ACTIONS(15336), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371290] = 2,
    ACTIONS(15338), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371299] = 2,
    ACTIONS(15340), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371308] = 2,
    ACTIONS(15342), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371317] = 2,
    ACTIONS(15344), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371326] = 2,
    ACTIONS(3966), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371335] = 2,
    ACTIONS(11029), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371344] = 2,
    ACTIONS(9397), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371353] = 2,
    ACTIONS(15346), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371362] = 2,
    ACTIONS(15348), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371371] = 2,
    ACTIONS(4196), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371380] = 2,
    ACTIONS(15350), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371389] = 2,
    ACTIONS(9554), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371398] = 2,
    ACTIONS(10767), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371407] = 2,
    ACTIONS(9508), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371416] = 2,
    ACTIONS(15352), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371425] = 2,
    ACTIONS(13375), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371434] = 2,
    ACTIONS(13230), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371443] = 2,
    ACTIONS(15354), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371452] = 2,
    ACTIONS(15356), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371461] = 2,
    ACTIONS(15358), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371470] = 2,
    ACTIONS(15360), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371479] = 2,
    ACTIONS(15362), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371488] = 2,
    ACTIONS(15364), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371497] = 2,
    ACTIONS(15366), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371506] = 2,
    ACTIONS(9621), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371515] = 2,
    ACTIONS(13339), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371524] = 2,
    ACTIONS(15368), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371533] = 2,
    ACTIONS(15370), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371542] = 2,
    ACTIONS(10759), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371551] = 2,
    ACTIONS(9478), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371560] = 2,
    ACTIONS(15372), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371569] = 2,
    ACTIONS(3792), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371578] = 2,
    ACTIONS(4136), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371587] = 2,
    ACTIONS(15374), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371596] = 2,
    ACTIONS(9460), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371605] = 2,
    ACTIONS(15376), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371614] = 2,
    ACTIONS(9700), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371623] = 2,
    ACTIONS(11601), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371632] = 2,
    ACTIONS(15378), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371641] = 2,
    ACTIONS(15380), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371650] = 2,
    ACTIONS(9562), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371659] = 2,
    ACTIONS(15382), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371668] = 2,
    ACTIONS(15384), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371677] = 2,
    ACTIONS(15386), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371686] = 2,
    ACTIONS(15388), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371695] = 2,
    ACTIONS(10777), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371704] = 2,
    ACTIONS(3565), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371713] = 2,
    ACTIONS(9702), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371722] = 2,
    ACTIONS(15390), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371731] = 2,
    ACTIONS(10775), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371740] = 2,
    ACTIONS(12517), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371749] = 2,
    ACTIONS(10989), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371758] = 2,
    ACTIONS(10853), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371767] = 2,
    ACTIONS(9704), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371776] = 2,
    ACTIONS(9566), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371785] = 2,
    ACTIONS(15392), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371794] = 2,
    ACTIONS(9542), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371803] = 2,
    ACTIONS(15394), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371812] = 2,
    ACTIONS(15396), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371821] = 2,
    ACTIONS(15398), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371830] = 2,
    ACTIONS(9448), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371839] = 2,
    ACTIONS(15400), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371848] = 2,
    ACTIONS(9504), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371857] = 2,
    ACTIONS(15402), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371866] = 2,
    ACTIONS(15404), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371875] = 2,
    ACTIONS(15406), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371884] = 2,
    ACTIONS(15408), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371893] = 2,
    ACTIONS(10999), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371902] = 2,
    ACTIONS(3722), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371911] = 2,
    ACTIONS(9642), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371920] = 2,
    ACTIONS(10861), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371929] = 2,
    ACTIONS(15410), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371938] = 2,
    ACTIONS(10763), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371947] = 2,
    ACTIONS(9570), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371956] = 2,
    ACTIONS(9623), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371965] = 2,
    ACTIONS(9706), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371974] = 2,
    ACTIONS(15412), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371983] = 2,
    ACTIONS(9568), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [371992] = 2,
    ACTIONS(15414), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372001] = 2,
    ACTIONS(9430), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372010] = 2,
    ACTIONS(15416), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372019] = 2,
    ACTIONS(15418), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372028] = 2,
    ACTIONS(15420), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372037] = 2,
    ACTIONS(13573), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372046] = 2,
    ACTIONS(15422), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372055] = 2,
    ACTIONS(15424), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372064] = 2,
    ACTIONS(15426), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372073] = 2,
    ACTIONS(9510), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372082] = 2,
    ACTIONS(15428), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372091] = 2,
    ACTIONS(15430), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372100] = 2,
    ACTIONS(15432), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372109] = 2,
    ACTIONS(10789), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372118] = 2,
    ACTIONS(4106), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372127] = 2,
    ACTIONS(15434), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372136] = 2,
    ACTIONS(15436), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372145] = 2,
    ACTIONS(10959), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372154] = 2,
    ACTIONS(15438), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372163] = 2,
    ACTIONS(15440), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372172] = 2,
    ACTIONS(9512), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372181] = 2,
    ACTIONS(15442), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372190] = 2,
    ACTIONS(9408), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372199] = 2,
    ACTIONS(15444), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372208] = 2,
    ACTIONS(15446), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372217] = 2,
    ACTIONS(9627), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372226] = 2,
    ACTIONS(4316), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372235] = 2,
    ACTIONS(15448), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372244] = 2,
    ACTIONS(15450), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372253] = 2,
    ACTIONS(15452), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372262] = 2,
    ACTIONS(3635), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372271] = 2,
    ACTIONS(9464), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372280] = 2,
    ACTIONS(11009), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372289] = 2,
    ACTIONS(15454), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372298] = 2,
    ACTIONS(10847), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372307] = 2,
    ACTIONS(15456), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372316] = 2,
    ACTIONS(3541), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372325] = 2,
    ACTIONS(15458), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372334] = 2,
    ACTIONS(15460), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372343] = 2,
    ACTIONS(15462), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372352] = 2,
    ACTIONS(15464), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372361] = 2,
    ACTIONS(13581), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372370] = 2,
    ACTIONS(15466), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372379] = 2,
    ACTIONS(9516), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372388] = 2,
    ACTIONS(15468), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372397] = 2,
    ACTIONS(12381), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372406] = 2,
    ACTIONS(9629), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372415] = 2,
    ACTIONS(15470), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372424] = 2,
    ACTIONS(15472), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372433] = 2,
    ACTIONS(15474), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372442] = 2,
    ACTIONS(15476), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372451] = 2,
    ACTIONS(15478), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372460] = 2,
    ACTIONS(9518), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372469] = 2,
    ACTIONS(12833), 1,
      anon_sym_when,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372478] = 2,
    ACTIONS(15480), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372487] = 2,
    ACTIONS(10809), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372496] = 2,
    ACTIONS(15482), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372505] = 2,
    ACTIONS(10893), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372514] = 2,
    ACTIONS(9414), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372523] = 2,
    ACTIONS(15484), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372532] = 2,
    ACTIONS(15486), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372541] = 2,
    ACTIONS(6621), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372550] = 2,
    ACTIONS(9520), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372559] = 2,
    ACTIONS(9631), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372568] = 2,
    ACTIONS(15488), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372577] = 2,
    ACTIONS(15490), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372586] = 2,
    ACTIONS(15088), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372595] = 2,
    ACTIONS(15492), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372604] = 2,
    ACTIONS(15494), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372613] = 2,
    ACTIONS(15496), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372622] = 2,
    ACTIONS(15498), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372631] = 2,
    ACTIONS(15500), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372640] = 2,
    ACTIONS(10821), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372649] = 2,
    ACTIONS(9440), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372658] = 2,
    ACTIONS(9688), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372667] = 2,
    ACTIONS(9576), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372676] = 2,
    ACTIONS(9522), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372685] = 2,
    ACTIONS(9480), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372694] = 2,
    ACTIONS(15502), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372703] = 2,
    ACTIONS(15504), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372712] = 2,
    ACTIONS(3595), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372721] = 2,
    ACTIONS(15506), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372730] = 2,
    ACTIONS(15508), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372739] = 2,
    ACTIONS(15510), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372748] = 2,
    ACTIONS(15512), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372757] = 2,
    ACTIONS(10837), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372766] = 2,
    ACTIONS(15514), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372775] = 2,
    ACTIONS(15516), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372784] = 2,
    ACTIONS(15518), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372793] = 2,
    ACTIONS(15520), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372802] = 2,
    ACTIONS(9609), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372811] = 2,
    ACTIONS(15522), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372820] = 2,
    ACTIONS(9472), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372829] = 2,
    ACTIONS(15524), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372838] = 2,
    ACTIONS(15526), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372847] = 2,
    ACTIONS(15528), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372856] = 2,
    ACTIONS(10875), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372865] = 2,
    ACTIONS(13409), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372874] = 2,
    ACTIONS(15530), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372883] = 2,
    ACTIONS(9546), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372892] = 2,
    ACTIONS(15532), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372901] = 2,
    ACTIONS(15534), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372910] = 2,
    ACTIONS(15536), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372919] = 2,
    ACTIONS(15538), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372928] = 2,
    ACTIONS(15540), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372937] = 2,
    ACTIONS(15542), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372946] = 2,
    ACTIONS(10891), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372955] = 2,
    ACTIONS(15544), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372964] = 2,
    ACTIONS(15546), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372973] = 2,
    ACTIONS(4256), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372982] = 2,
    ACTIONS(15548), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [372991] = 2,
    ACTIONS(15550), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373000] = 2,
    ACTIONS(15552), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373009] = 2,
    ACTIONS(10899), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373018] = 2,
    ACTIONS(15554), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373027] = 2,
    ACTIONS(15556), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373036] = 2,
    ACTIONS(15558), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373045] = 2,
    ACTIONS(10905), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373054] = 2,
    ACTIONS(15560), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373063] = 2,
    ACTIONS(9652), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373072] = 2,
    ACTIONS(15562), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373081] = 2,
    ACTIONS(10911), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373090] = 2,
    ACTIONS(9607), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373099] = 2,
    ACTIONS(15564), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373108] = 2,
    ACTIONS(15566), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373117] = 2,
    ACTIONS(10925), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373126] = 2,
    ACTIONS(15568), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373135] = 2,
    ACTIONS(9710), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373144] = 2,
    ACTIONS(15570), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373153] = 2,
    ACTIONS(10917), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373162] = 2,
    ACTIONS(9603), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373171] = 2,
    ACTIONS(9690), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373180] = 2,
    ACTIONS(15572), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373189] = 2,
    ACTIONS(10921), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373198] = 2,
    ACTIONS(15574), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373207] = 2,
    ACTIONS(13541), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373216] = 2,
    ACTIONS(15576), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373225] = 2,
    ACTIONS(10923), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373234] = 2,
    ACTIONS(9432), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373243] = 2,
    ACTIONS(15578), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373252] = 2,
    ACTIONS(15580), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373261] = 2,
    ACTIONS(10927), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373270] = 2,
    ACTIONS(9597), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373279] = 2,
    ACTIONS(4346), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373288] = 2,
    ACTIONS(15582), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373297] = 2,
    ACTIONS(10929), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373306] = 2,
    ACTIONS(9578), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373315] = 2,
    ACTIONS(15584), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373324] = 2,
    ACTIONS(10935), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373333] = 2,
    ACTIONS(15586), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373342] = 2,
    ACTIONS(15588), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373351] = 2,
    ACTIONS(10931), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373360] = 2,
    ACTIONS(11756), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373369] = 2,
    ACTIONS(15590), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373378] = 2,
    ACTIONS(10939), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373387] = 2,
    ACTIONS(3695), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373396] = 2,
    ACTIONS(15592), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373405] = 2,
    ACTIONS(10953), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373414] = 2,
    ACTIONS(15594), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373423] = 2,
    ACTIONS(11165), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373432] = 2,
    ACTIONS(15596), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373441] = 2,
    ACTIONS(15598), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373450] = 2,
    ACTIONS(15600), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373459] = 2,
    ACTIONS(13039), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373468] = 2,
    ACTIONS(9548), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373477] = 2,
    ACTIONS(13421), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373486] = 2,
    ACTIONS(15602), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373495] = 2,
    ACTIONS(15604), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373504] = 2,
    ACTIONS(15606), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373513] = 2,
    ACTIONS(15608), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373522] = 2,
    ACTIONS(15610), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373531] = 2,
    ACTIONS(15612), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373540] = 2,
    ACTIONS(15614), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373549] = 2,
    ACTIONS(9633), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373558] = 2,
    ACTIONS(10863), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373567] = 2,
    ACTIONS(15616), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373576] = 2,
    ACTIONS(15618), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373585] = 2,
    ACTIONS(15620), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373594] = 2,
    ACTIONS(15038), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373603] = 2,
    ACTIONS(15622), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373612] = 2,
    ACTIONS(15624), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373621] = 2,
    ACTIONS(10749), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373630] = 2,
    ACTIONS(9468), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373639] = 2,
    ACTIONS(9426), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373648] = 2,
    ACTIONS(9502), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373657] = 2,
    ACTIONS(9613), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373666] = 2,
    ACTIONS(11133), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373675] = 2,
    ACTIONS(15626), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373684] = 2,
    ACTIONS(10985), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373693] = 2,
    ACTIONS(15628), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373702] = 2,
    ACTIONS(15630), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373711] = 2,
    ACTIONS(15632), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373720] = 2,
    ACTIONS(11003), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373729] = 2,
    ACTIONS(9526), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373738] = 2,
    ACTIONS(4434), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373747] = 2,
    ACTIONS(12902), 1,
      anon_sym_if,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373756] = 2,
    ACTIONS(15634), 1,
      anon_sym_enum,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373765] = 2,
    ACTIONS(9635), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373774] = 2,
    ACTIONS(15636), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373783] = 2,
    ACTIONS(3936), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373792] = 2,
    ACTIONS(9530), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373801] = 2,
    ACTIONS(15638), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373810] = 2,
    ACTIONS(15640), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373819] = 2,
    ACTIONS(10799), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373828] = 2,
    ACTIONS(15642), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373837] = 2,
    ACTIONS(9611), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373846] = 2,
    ACTIONS(9538), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373855] = 2,
    ACTIONS(11754), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373864] = 2,
    ACTIONS(15644), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373873] = 2,
    ACTIONS(15646), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373882] = 2,
    ACTIONS(9673), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373891] = 2,
    ACTIONS(15648), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373900] = 2,
    ACTIONS(11145), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373909] = 2,
    ACTIONS(9582), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373918] = 2,
    ACTIONS(15650), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373927] = 2,
    ACTIONS(9484), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373936] = 2,
    ACTIONS(4376), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373945] = 2,
    ACTIONS(9714), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373954] = 3,
    ACTIONS(12611), 1,
      sym_comment,
    ACTIONS(15652), 1,
      aux_sym_build_tag_token1,
    ACTIONS(3), 2,
      sym__backslash,
      sym_block_comment,
  [373965] = 2,
    ACTIONS(9470), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373974] = 2,
    ACTIONS(15654), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373983] = 2,
    ACTIONS(15656), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [373992] = 2,
    ACTIONS(9444), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374001] = 2,
    ACTIONS(4605), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374010] = 2,
    ACTIONS(9476), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374019] = 2,
    ACTIONS(9406), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374028] = 2,
    ACTIONS(15658), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374037] = 2,
    ACTIONS(15660), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374046] = 2,
    ACTIONS(15662), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374055] = 2,
    ACTIONS(15664), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374064] = 2,
    ACTIONS(9524), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374073] = 2,
    ACTIONS(9556), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374082] = 2,
    ACTIONS(11055), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374091] = 2,
    ACTIONS(8357), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374100] = 2,
    ACTIONS(15666), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374109] = 2,
    ACTIONS(15668), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374118] = 2,
    ACTIONS(13333), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374127] = 2,
    ACTIONS(9637), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374136] = 2,
    ACTIONS(8168), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374145] = 2,
    ACTIONS(9462), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374154] = 2,
    ACTIONS(9544), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374163] = 2,
    ACTIONS(15670), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374172] = 2,
    ACTIONS(15672), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374181] = 2,
    ACTIONS(15674), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374190] = 2,
    ACTIONS(15676), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374199] = 2,
    ACTIONS(9564), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374208] = 2,
    ACTIONS(11083), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374217] = 2,
    ACTIONS(15678), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374226] = 2,
    ACTIONS(15680), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374235] = 2,
    ACTIONS(9599), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374244] = 2,
    ACTIONS(15682), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374253] = 2,
    ACTIONS(11089), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374262] = 2,
    ACTIONS(9580), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374271] = 2,
    ACTIONS(15684), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374280] = 2,
    ACTIONS(9442), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374289] = 2,
    ACTIONS(9482), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374298] = 2,
    ACTIONS(9601), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374307] = 2,
    ACTIONS(9534), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374316] = 2,
    ACTIONS(15042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374325] = 2,
    ACTIONS(13240), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374334] = 2,
    ACTIONS(11135), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374343] = 2,
    ACTIONS(15686), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374352] = 2,
    ACTIONS(11047), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374361] = 2,
    ACTIONS(15688), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374370] = 2,
    ACTIONS(15690), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374379] = 2,
    ACTIONS(15692), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374388] = 2,
    ACTIONS(4166), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374397] = 2,
    ACTIONS(15694), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374406] = 2,
    ACTIONS(15696), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374415] = 2,
    ACTIONS(13547), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374424] = 2,
    ACTIONS(9532), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374433] = 2,
    ACTIONS(9647), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374442] = 2,
    ACTIONS(15698), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374451] = 2,
    ACTIONS(15700), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374460] = 2,
    ACTIONS(15702), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374469] = 2,
    ACTIONS(4396), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374478] = 2,
    ACTIONS(9506), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374487] = 2,
    ACTIONS(15704), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374496] = 2,
    ACTIONS(11113), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374505] = 2,
    ACTIONS(9550), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374514] = 2,
    ACTIONS(9722), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374523] = 2,
    ACTIONS(15706), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374532] = 2,
    ACTIONS(10991), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374541] = 2,
    ACTIONS(15708), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374550] = 2,
    ACTIONS(15710), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374559] = 2,
    ACTIONS(9436), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374568] = 2,
    ACTIONS(15712), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374577] = 2,
    ACTIONS(9416), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374586] = 2,
    ACTIONS(11035), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374595] = 2,
    ACTIONS(15714), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374604] = 2,
    ACTIONS(15716), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374613] = 2,
    ACTIONS(11147), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374622] = 2,
    ACTIONS(15718), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374631] = 2,
    ACTIONS(9615), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374640] = 2,
    ACTIONS(11814), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374649] = 2,
    ACTIONS(15720), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374658] = 2,
    ACTIONS(15722), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374667] = 2,
    ACTIONS(15724), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374676] = 2,
    ACTIONS(15726), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374685] = 2,
    ACTIONS(15728), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374694] = 2,
    ACTIONS(15730), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374703] = 2,
    ACTIONS(11039), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374712] = 2,
    ACTIONS(9708), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374721] = 2,
    ACTIONS(15732), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374730] = 2,
    ACTIONS(13459), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374739] = 2,
    ACTIONS(15734), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374748] = 2,
    ACTIONS(9574), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374757] = 2,
    ACTIONS(15736), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374766] = 2,
    ACTIONS(15738), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374775] = 2,
    ACTIONS(9404), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374784] = 2,
    ACTIONS(15740), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374793] = 2,
    ACTIONS(9584), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374802] = 2,
    ACTIONS(15742), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374811] = 2,
    ACTIONS(15744), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374820] = 2,
    ACTIONS(11045), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374829] = 2,
    ACTIONS(15746), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374838] = 2,
    ACTIONS(15748), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374847] = 2,
    ACTIONS(15750), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374856] = 2,
    ACTIONS(15752), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374865] = 2,
    ACTIONS(15754), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374874] = 2,
    ACTIONS(9422), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374883] = 2,
    ACTIONS(15756), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374892] = 2,
    ACTIONS(13306), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374901] = 2,
    ACTIONS(9657), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374910] = 2,
    ACTIONS(15758), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374919] = 2,
    ACTIONS(15760), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374928] = 2,
    ACTIONS(11143), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374937] = 2,
    ACTIONS(11053), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374946] = 2,
    ACTIONS(15762), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374955] = 2,
    ACTIONS(10745), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374964] = 2,
    ACTIONS(15764), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374973] = 2,
    ACTIONS(15766), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374982] = 2,
    ACTIONS(15768), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [374991] = 2,
    ACTIONS(15770), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375000] = 2,
    ACTIONS(9399), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375009] = 2,
    ACTIONS(9424), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375018] = 2,
    ACTIONS(15772), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375027] = 2,
    ACTIONS(4286), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375036] = 2,
    ACTIONS(15774), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375045] = 2,
    ACTIONS(15776), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375054] = 2,
    ACTIONS(11069), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375063] = 2,
    ACTIONS(13467), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375072] = 2,
    ACTIONS(9586), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375081] = 2,
    ACTIONS(9552), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375090] = 2,
    ACTIONS(15778), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375099] = 2,
    ACTIONS(15780), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375108] = 2,
    ACTIONS(10741), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375117] = 2,
    ACTIONS(15782), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375126] = 2,
    ACTIONS(12497), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375135] = 2,
    ACTIONS(15784), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375144] = 2,
    ACTIONS(9686), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375153] = 2,
    ACTIONS(15786), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375162] = 2,
    ACTIONS(9712), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375171] = 2,
    ACTIONS(11077), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375180] = 2,
    ACTIONS(9450), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375189] = 2,
    ACTIONS(9434), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375198] = 2,
    ACTIONS(9591), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375207] = 2,
    ACTIONS(15788), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375216] = 2,
    ACTIONS(9671), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375225] = 2,
    ACTIONS(15790), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375234] = 2,
    ACTIONS(15792), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375243] = 2,
    ACTIONS(9617), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375252] = 2,
    ACTIONS(15794), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375261] = 2,
    ACTIONS(9659), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375270] = 2,
    ACTIONS(11085), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375279] = 2,
    ACTIONS(9595), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375288] = 2,
    ACTIONS(15796), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375297] = 2,
    ACTIONS(9540), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375306] = 2,
    ACTIONS(15798), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375315] = 2,
    ACTIONS(15800), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375324] = 2,
    ACTIONS(15802), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375333] = 2,
    ACTIONS(9309), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375342] = 2,
    ACTIONS(11109), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375351] = 2,
    ACTIONS(15804), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375360] = 2,
    ACTIONS(15806), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375369] = 2,
    ACTIONS(11091), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375378] = 2,
    ACTIONS(10945), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375387] = 2,
    ACTIONS(15808), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375396] = 2,
    ACTIONS(9619), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375405] = 2,
    ACTIONS(15810), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375414] = 2,
    ACTIONS(9488), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375423] = 2,
    ACTIONS(15812), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375432] = 2,
    ACTIONS(15814), 1,
      anon_sym_enum,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375441] = 2,
    ACTIONS(15816), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375450] = 2,
    ACTIONS(15818), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375459] = 2,
    ACTIONS(9446), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375468] = 2,
    ACTIONS(11095), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375477] = 2,
    ACTIONS(15820), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375486] = 2,
    ACTIONS(15822), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375495] = 2,
    ACTIONS(9605), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375504] = 2,
    ACTIONS(15824), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375513] = 2,
    ACTIONS(15826), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375522] = 2,
    ACTIONS(3896), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375531] = 2,
    ACTIONS(9593), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375540] = 2,
    ACTIONS(15828), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375549] = 2,
    ACTIONS(15830), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375558] = 2,
    ACTIONS(11800), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375567] = 2,
    ACTIONS(11105), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375576] = 2,
    ACTIONS(9698), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375585] = 2,
    ACTIONS(15832), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375594] = 2,
    ACTIONS(15834), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375603] = 2,
    ACTIONS(15836), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375612] = 2,
    ACTIONS(15838), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375621] = 2,
    ACTIONS(14900), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375630] = 2,
    ACTIONS(15840), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375639] = 2,
    ACTIONS(12355), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375648] = 2,
    ACTIONS(15842), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375657] = 2,
    ACTIONS(3762), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375666] = 2,
    ACTIONS(11115), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375675] = 2,
    ACTIONS(15844), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375684] = 2,
    ACTIONS(15846), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375693] = 2,
    ACTIONS(15848), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375702] = 2,
    ACTIONS(15850), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375711] = 2,
    ACTIONS(15852), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375720] = 2,
    ACTIONS(15854), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375729] = 2,
    ACTIONS(15856), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375738] = 2,
    ACTIONS(15858), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375747] = 2,
    ACTIONS(4531), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375756] = 2,
    ACTIONS(15860), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375765] = 2,
    ACTIONS(15862), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375774] = 2,
    ACTIONS(15864), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375783] = 2,
    ACTIONS(15866), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375792] = 2,
    ACTIONS(9514), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375801] = 2,
    ACTIONS(15868), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375810] = 2,
    ACTIONS(15870), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375819] = 2,
    ACTIONS(15872), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375828] = 2,
    ACTIONS(15874), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375837] = 2,
    ACTIONS(15876), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375846] = 2,
    ACTIONS(15878), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375855] = 2,
    ACTIONS(15880), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375864] = 2,
    ACTIONS(9536), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375873] = 2,
    ACTIONS(4226), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375882] = 2,
    ACTIONS(15882), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375891] = 2,
    ACTIONS(15884), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375900] = 2,
    ACTIONS(15886), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375909] = 2,
    ACTIONS(15888), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375918] = 2,
    ACTIONS(15890), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375927] = 2,
    ACTIONS(15892), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375936] = 2,
    ACTIONS(15894), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375945] = 2,
    ACTIONS(15896), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375954] = 2,
    ACTIONS(15898), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375963] = 2,
    ACTIONS(15900), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375972] = 2,
    ACTIONS(15902), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375981] = 2,
    ACTIONS(15904), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375990] = 2,
    ACTIONS(15906), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [375999] = 2,
    ACTIONS(15908), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376008] = 2,
    ACTIONS(15910), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376017] = 2,
    ACTIONS(9454), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376026] = 2,
    ACTIONS(15912), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376035] = 2,
    ACTIONS(10757), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376044] = 2,
    ACTIONS(9664), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376053] = 2,
    ACTIONS(14918), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376062] = 2,
    ACTIONS(15914), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376071] = 2,
    ACTIONS(15916), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376080] = 2,
    ACTIONS(15918), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376089] = 2,
    ACTIONS(3862), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376098] = 2,
    ACTIONS(3996), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376107] = 2,
    ACTIONS(11173), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376116] = 2,
    ACTIONS(15920), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376125] = 2,
    ACTIONS(15922), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376134] = 2,
    ACTIONS(15924), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376143] = 2,
    ACTIONS(15926), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376152] = 2,
    ACTIONS(15928), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376161] = 2,
    ACTIONS(9458), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376170] = 2,
    ACTIONS(15930), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376179] = 2,
    ACTIONS(15932), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376188] = 2,
    ACTIONS(15934), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376197] = 2,
    ACTIONS(9456), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376206] = 2,
    ACTIONS(15936), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376215] = 2,
    ACTIONS(15938), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376224] = 2,
    ACTIONS(15940), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376233] = 2,
    ACTIONS(15942), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376242] = 2,
    ACTIONS(9716), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376251] = 2,
    ACTIONS(15944), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376260] = 2,
    ACTIONS(15946), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376269] = 2,
    ACTIONS(15948), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376278] = 2,
    ACTIONS(15950), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376287] = 2,
    ACTIONS(15952), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376296] = 2,
    ACTIONS(11087), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376305] = 2,
    ACTIONS(15954), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376314] = 2,
    ACTIONS(15956), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376323] = 2,
    ACTIONS(15958), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376332] = 2,
    ACTIONS(15960), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376341] = 2,
    ACTIONS(15962), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376350] = 2,
    ACTIONS(15964), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376359] = 2,
    ACTIONS(15966), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376368] = 2,
    ACTIONS(15968), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376377] = 2,
    ACTIONS(13371), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376386] = 2,
    ACTIONS(15970), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376395] = 2,
    ACTIONS(15972), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376404] = 2,
    ACTIONS(15974), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376413] = 2,
    ACTIONS(15976), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376422] = 2,
    ACTIONS(15978), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376431] = 2,
    ACTIONS(15980), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376440] = 2,
    ACTIONS(15982), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376449] = 2,
    ACTIONS(15984), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376458] = 2,
    ACTIONS(15986), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376467] = 2,
    ACTIONS(15988), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376476] = 2,
    ACTIONS(15990), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376485] = 2,
    ACTIONS(15992), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376494] = 2,
    ACTIONS(15994), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376503] = 2,
    ACTIONS(15996), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376512] = 2,
    ACTIONS(15998), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376521] = 2,
    ACTIONS(16000), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376530] = 2,
    ACTIONS(16002), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376539] = 2,
    ACTIONS(16004), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376548] = 2,
    ACTIONS(16006), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376557] = 2,
    ACTIONS(16008), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376566] = 2,
    ACTIONS(16010), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376575] = 2,
    ACTIONS(16012), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376584] = 2,
    ACTIONS(16014), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376593] = 2,
    ACTIONS(16016), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376602] = 2,
    ACTIONS(16018), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376611] = 2,
    ACTIONS(16020), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376620] = 2,
    ACTIONS(16022), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376629] = 2,
    ACTIONS(16024), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376638] = 2,
    ACTIONS(16026), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376647] = 2,
    ACTIONS(9625), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376656] = 2,
    ACTIONS(16028), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376665] = 2,
    ACTIONS(11049), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376674] = 2,
    ACTIONS(16030), 1,
      anon_sym_SEMI,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376683] = 2,
    ACTIONS(16032), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376692] = 2,
    ACTIONS(16034), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376701] = 2,
    ACTIONS(9474), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376710] = 2,
    ACTIONS(16036), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376719] = 2,
    ACTIONS(16038), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376728] = 2,
    ACTIONS(16040), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376737] = 2,
    ACTIONS(16042), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376746] = 2,
    ACTIONS(16044), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376755] = 2,
    ACTIONS(9669), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376764] = 2,
    ACTIONS(16046), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376773] = 2,
    ACTIONS(16048), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376782] = 2,
    ACTIONS(16050), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376791] = 2,
    ACTIONS(16052), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376800] = 2,
    ACTIONS(16054), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376809] = 2,
    ACTIONS(16056), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376818] = 2,
    ACTIONS(16058), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376827] = 2,
    ACTIONS(16060), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376836] = 2,
    ACTIONS(10811), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376845] = 2,
    ACTIONS(16062), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376854] = 2,
    ACTIONS(16064), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376863] = 2,
    ACTIONS(16066), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376872] = 2,
    ACTIONS(16068), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376881] = 2,
    ACTIONS(16070), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376890] = 2,
    ACTIONS(16072), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376899] = 2,
    ACTIONS(16074), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376908] = 2,
    ACTIONS(16076), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376917] = 2,
    ACTIONS(16078), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376926] = 2,
    ACTIONS(16080), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376935] = 2,
    ACTIONS(16082), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376944] = 2,
    ACTIONS(16084), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376953] = 2,
    ACTIONS(16086), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376962] = 2,
    ACTIONS(16088), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376971] = 2,
    ACTIONS(16090), 1,
      anon_sym_COLON,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376980] = 2,
    ACTIONS(13167), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376989] = 2,
    ACTIONS(9500), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [376998] = 2,
    ACTIONS(16092), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377007] = 2,
    ACTIONS(11013), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377016] = 2,
    ACTIONS(16094), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377025] = 2,
    ACTIONS(13499), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377034] = 2,
    ACTIONS(9418), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377043] = 2,
    ACTIONS(9420), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377052] = 2,
    ACTIONS(10715), 1,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377061] = 2,
    ACTIONS(16096), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377070] = 2,
    ACTIONS(16098), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377079] = 2,
    ACTIONS(16100), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377088] = 2,
    ACTIONS(3832), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377097] = 2,
    ACTIONS(16102), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377106] = 2,
    ACTIONS(16104), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377115] = 2,
    ACTIONS(16106), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377124] = 2,
    ACTIONS(9438), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377133] = 2,
    ACTIONS(16108), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377142] = 2,
    ACTIONS(4076), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377151] = 2,
    ACTIONS(16110), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377160] = 2,
    ACTIONS(9486), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377169] = 2,
    ACTIONS(16112), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377178] = 2,
    ACTIONS(4046), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377187] = 2,
    ACTIONS(16114), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377196] = 2,
    ACTIONS(4016), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377205] = 2,
    ACTIONS(16116), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377214] = 2,
    ACTIONS(16118), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377223] = 2,
    ACTIONS(16120), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377232] = 2,
    ACTIONS(16122), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377241] = 2,
    ACTIONS(16124), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377250] = 2,
    ACTIONS(16126), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377259] = 2,
    ACTIONS(9678), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377268] = 2,
    ACTIONS(16128), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377277] = 2,
    ACTIONS(16130), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377286] = 2,
    ACTIONS(8462), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377295] = 2,
    ACTIONS(16132), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377304] = 2,
    ACTIONS(16134), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377313] = 2,
    ACTIONS(16136), 1,
      sym_identifier,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377322] = 2,
    ACTIONS(13507), 1,
      anon_sym_LBRACE,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377331] = 2,
    ACTIONS(16138), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
  [377340] = 2,
    ACTIONS(9572), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym__backslash,
      sym_block_comment,
      sym_comment,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2212)] = 0,
  [SMALL_STATE(2213)] = 71,
  [SMALL_STATE(2214)] = 142,
  [SMALL_STATE(2215)] = 213,
  [SMALL_STATE(2216)] = 284,
  [SMALL_STATE(2217)] = 355,
  [SMALL_STATE(2218)] = 426,
  [SMALL_STATE(2219)] = 497,
  [SMALL_STATE(2220)] = 568,
  [SMALL_STATE(2221)] = 639,
  [SMALL_STATE(2222)] = 710,
  [SMALL_STATE(2223)] = 781,
  [SMALL_STATE(2224)] = 852,
  [SMALL_STATE(2225)] = 923,
  [SMALL_STATE(2226)] = 1038,
  [SMALL_STATE(2227)] = 1145,
  [SMALL_STATE(2228)] = 1224,
  [SMALL_STATE(2229)] = 1295,
  [SMALL_STATE(2230)] = 1366,
  [SMALL_STATE(2231)] = 1437,
  [SMALL_STATE(2232)] = 1508,
  [SMALL_STATE(2233)] = 1579,
  [SMALL_STATE(2234)] = 1650,
  [SMALL_STATE(2235)] = 1721,
  [SMALL_STATE(2236)] = 1792,
  [SMALL_STATE(2237)] = 1863,
  [SMALL_STATE(2238)] = 1934,
  [SMALL_STATE(2239)] = 2005,
  [SMALL_STATE(2240)] = 2076,
  [SMALL_STATE(2241)] = 2147,
  [SMALL_STATE(2242)] = 2218,
  [SMALL_STATE(2243)] = 2289,
  [SMALL_STATE(2244)] = 2368,
  [SMALL_STATE(2245)] = 2447,
  [SMALL_STATE(2246)] = 2518,
  [SMALL_STATE(2247)] = 2589,
  [SMALL_STATE(2248)] = 2660,
  [SMALL_STATE(2249)] = 2731,
  [SMALL_STATE(2250)] = 2802,
  [SMALL_STATE(2251)] = 2873,
  [SMALL_STATE(2252)] = 2944,
  [SMALL_STATE(2253)] = 3015,
  [SMALL_STATE(2254)] = 3086,
  [SMALL_STATE(2255)] = 3157,
  [SMALL_STATE(2256)] = 3228,
  [SMALL_STATE(2257)] = 3299,
  [SMALL_STATE(2258)] = 3370,
  [SMALL_STATE(2259)] = 3441,
  [SMALL_STATE(2260)] = 3512,
  [SMALL_STATE(2261)] = 3583,
  [SMALL_STATE(2262)] = 3662,
  [SMALL_STATE(2263)] = 3733,
  [SMALL_STATE(2264)] = 3804,
  [SMALL_STATE(2265)] = 3875,
  [SMALL_STATE(2266)] = 3946,
  [SMALL_STATE(2267)] = 4017,
  [SMALL_STATE(2268)] = 4088,
  [SMALL_STATE(2269)] = 4159,
  [SMALL_STATE(2270)] = 4230,
  [SMALL_STATE(2271)] = 4301,
  [SMALL_STATE(2272)] = 4372,
  [SMALL_STATE(2273)] = 4443,
  [SMALL_STATE(2274)] = 4514,
  [SMALL_STATE(2275)] = 4585,
  [SMALL_STATE(2276)] = 4656,
  [SMALL_STATE(2277)] = 4727,
  [SMALL_STATE(2278)] = 4798,
  [SMALL_STATE(2279)] = 4869,
  [SMALL_STATE(2280)] = 4940,
  [SMALL_STATE(2281)] = 5011,
  [SMALL_STATE(2282)] = 5082,
  [SMALL_STATE(2283)] = 5153,
  [SMALL_STATE(2284)] = 5224,
  [SMALL_STATE(2285)] = 5295,
  [SMALL_STATE(2286)] = 5366,
  [SMALL_STATE(2287)] = 5437,
  [SMALL_STATE(2288)] = 5508,
  [SMALL_STATE(2289)] = 5579,
  [SMALL_STATE(2290)] = 5650,
  [SMALL_STATE(2291)] = 5721,
  [SMALL_STATE(2292)] = 5792,
  [SMALL_STATE(2293)] = 5863,
  [SMALL_STATE(2294)] = 5934,
  [SMALL_STATE(2295)] = 6005,
  [SMALL_STATE(2296)] = 6076,
  [SMALL_STATE(2297)] = 6147,
  [SMALL_STATE(2298)] = 6218,
  [SMALL_STATE(2299)] = 6289,
  [SMALL_STATE(2300)] = 6364,
  [SMALL_STATE(2301)] = 6435,
  [SMALL_STATE(2302)] = 6506,
  [SMALL_STATE(2303)] = 6577,
  [SMALL_STATE(2304)] = 6648,
  [SMALL_STATE(2305)] = 6719,
  [SMALL_STATE(2306)] = 6790,
  [SMALL_STATE(2307)] = 6861,
  [SMALL_STATE(2308)] = 6932,
  [SMALL_STATE(2309)] = 7003,
  [SMALL_STATE(2310)] = 7074,
  [SMALL_STATE(2311)] = 7145,
  [SMALL_STATE(2312)] = 7216,
  [SMALL_STATE(2313)] = 7287,
  [SMALL_STATE(2314)] = 7358,
  [SMALL_STATE(2315)] = 7435,
  [SMALL_STATE(2316)] = 7506,
  [SMALL_STATE(2317)] = 7577,
  [SMALL_STATE(2318)] = 7648,
  [SMALL_STATE(2319)] = 7719,
  [SMALL_STATE(2320)] = 7790,
  [SMALL_STATE(2321)] = 7861,
  [SMALL_STATE(2322)] = 7932,
  [SMALL_STATE(2323)] = 8003,
  [SMALL_STATE(2324)] = 8074,
  [SMALL_STATE(2325)] = 8145,
  [SMALL_STATE(2326)] = 8216,
  [SMALL_STATE(2327)] = 8287,
  [SMALL_STATE(2328)] = 8358,
  [SMALL_STATE(2329)] = 8429,
  [SMALL_STATE(2330)] = 8500,
  [SMALL_STATE(2331)] = 8571,
  [SMALL_STATE(2332)] = 8642,
  [SMALL_STATE(2333)] = 8713,
  [SMALL_STATE(2334)] = 8784,
  [SMALL_STATE(2335)] = 8855,
  [SMALL_STATE(2336)] = 8926,
  [SMALL_STATE(2337)] = 8997,
  [SMALL_STATE(2338)] = 9082,
  [SMALL_STATE(2339)] = 9167,
  [SMALL_STATE(2340)] = 9238,
  [SMALL_STATE(2341)] = 9309,
  [SMALL_STATE(2342)] = 9380,
  [SMALL_STATE(2343)] = 9451,
  [SMALL_STATE(2344)] = 9522,
  [SMALL_STATE(2345)] = 9595,
  [SMALL_STATE(2346)] = 9682,
  [SMALL_STATE(2347)] = 9753,
  [SMALL_STATE(2348)] = 9824,
  [SMALL_STATE(2349)] = 9895,
  [SMALL_STATE(2350)] = 9978,
  [SMALL_STATE(2351)] = 10049,
  [SMALL_STATE(2352)] = 10120,
  [SMALL_STATE(2353)] = 10195,
  [SMALL_STATE(2354)] = 10266,
  [SMALL_STATE(2355)] = 10337,
  [SMALL_STATE(2356)] = 10408,
  [SMALL_STATE(2357)] = 10479,
  [SMALL_STATE(2358)] = 10550,
  [SMALL_STATE(2359)] = 10637,
  [SMALL_STATE(2360)] = 10708,
  [SMALL_STATE(2361)] = 10779,
  [SMALL_STATE(2362)] = 10850,
  [SMALL_STATE(2363)] = 10933,
  [SMALL_STATE(2364)] = 11016,
  [SMALL_STATE(2365)] = 11103,
  [SMALL_STATE(2366)] = 11186,
  [SMALL_STATE(2367)] = 11269,
  [SMALL_STATE(2368)] = 11352,
  [SMALL_STATE(2369)] = 11423,
  [SMALL_STATE(2370)] = 11494,
  [SMALL_STATE(2371)] = 11565,
  [SMALL_STATE(2372)] = 11636,
  [SMALL_STATE(2373)] = 11707,
  [SMALL_STATE(2374)] = 11778,
  [SMALL_STATE(2375)] = 11871,
  [SMALL_STATE(2376)] = 11942,
  [SMALL_STATE(2377)] = 12013,
  [SMALL_STATE(2378)] = 12084,
  [SMALL_STATE(2379)] = 12201,
  [SMALL_STATE(2380)] = 12272,
  [SMALL_STATE(2381)] = 12343,
  [SMALL_STATE(2382)] = 12414,
  [SMALL_STATE(2383)] = 12497,
  [SMALL_STATE(2384)] = 12568,
  [SMALL_STATE(2385)] = 12643,
  [SMALL_STATE(2386)] = 12714,
  [SMALL_STATE(2387)] = 12805,
  [SMALL_STATE(2388)] = 12876,
  [SMALL_STATE(2389)] = 12947,
  [SMALL_STATE(2390)] = 13036,
  [SMALL_STATE(2391)] = 13107,
  [SMALL_STATE(2392)] = 13178,
  [SMALL_STATE(2393)] = 13249,
  [SMALL_STATE(2394)] = 13320,
  [SMALL_STATE(2395)] = 13391,
  [SMALL_STATE(2396)] = 13494,
  [SMALL_STATE(2397)] = 13595,
  [SMALL_STATE(2398)] = 13666,
  [SMALL_STATE(2399)] = 13763,
  [SMALL_STATE(2400)] = 13858,
  [SMALL_STATE(2401)] = 13929,
  [SMALL_STATE(2402)] = 14000,
  [SMALL_STATE(2403)] = 14071,
  [SMALL_STATE(2404)] = 14142,
  [SMALL_STATE(2405)] = 14229,
  [SMALL_STATE(2406)] = 14344,
  [SMALL_STATE(2407)] = 14429,
  [SMALL_STATE(2408)] = 14500,
  [SMALL_STATE(2409)] = 14571,
  [SMALL_STATE(2410)] = 14642,
  [SMALL_STATE(2411)] = 14713,
  [SMALL_STATE(2412)] = 14792,
  [SMALL_STATE(2413)] = 14863,
  [SMALL_STATE(2414)] = 14934,
  [SMALL_STATE(2415)] = 15005,
  [SMALL_STATE(2416)] = 15076,
  [SMALL_STATE(2417)] = 15147,
  [SMALL_STATE(2418)] = 15262,
  [SMALL_STATE(2419)] = 15333,
  [SMALL_STATE(2420)] = 15404,
  [SMALL_STATE(2421)] = 15483,
  [SMALL_STATE(2422)] = 15562,
  [SMALL_STATE(2423)] = 15633,
  [SMALL_STATE(2424)] = 15704,
  [SMALL_STATE(2425)] = 15775,
  [SMALL_STATE(2426)] = 15846,
  [SMALL_STATE(2427)] = 15917,
  [SMALL_STATE(2428)] = 15996,
  [SMALL_STATE(2429)] = 16075,
  [SMALL_STATE(2430)] = 16146,
  [SMALL_STATE(2431)] = 16217,
  [SMALL_STATE(2432)] = 16288,
  [SMALL_STATE(2433)] = 16359,
  [SMALL_STATE(2434)] = 16430,
  [SMALL_STATE(2435)] = 16503,
  [SMALL_STATE(2436)] = 16574,
  [SMALL_STATE(2437)] = 16645,
  [SMALL_STATE(2438)] = 16738,
  [SMALL_STATE(2439)] = 16855,
  [SMALL_STATE(2440)] = 16938,
  [SMALL_STATE(2441)] = 17029,
  [SMALL_STATE(2442)] = 17118,
  [SMALL_STATE(2443)] = 17221,
  [SMALL_STATE(2444)] = 17322,
  [SMALL_STATE(2445)] = 17419,
  [SMALL_STATE(2446)] = 17514,
  [SMALL_STATE(2447)] = 17601,
  [SMALL_STATE(2448)] = 17686,
  [SMALL_STATE(2449)] = 17765,
  [SMALL_STATE(2450)] = 17880,
  [SMALL_STATE(2451)] = 17959,
  [SMALL_STATE(2452)] = 18030,
  [SMALL_STATE(2453)] = 18101,
  [SMALL_STATE(2454)] = 18172,
  [SMALL_STATE(2455)] = 18251,
  [SMALL_STATE(2456)] = 18366,
  [SMALL_STATE(2457)] = 18473,
  [SMALL_STATE(2458)] = 18544,
  [SMALL_STATE(2459)] = 18615,
  [SMALL_STATE(2460)] = 18694,
  [SMALL_STATE(2461)] = 18765,
  [SMALL_STATE(2462)] = 18836,
  [SMALL_STATE(2463)] = 18909,
  [SMALL_STATE(2464)] = 18980,
  [SMALL_STATE(2465)] = 19051,
  [SMALL_STATE(2466)] = 19122,
  [SMALL_STATE(2467)] = 19193,
  [SMALL_STATE(2468)] = 19264,
  [SMALL_STATE(2469)] = 19335,
  [SMALL_STATE(2470)] = 19406,
  [SMALL_STATE(2471)] = 19477,
  [SMALL_STATE(2472)] = 19548,
  [SMALL_STATE(2473)] = 19619,
  [SMALL_STATE(2474)] = 19690,
  [SMALL_STATE(2475)] = 19761,
  [SMALL_STATE(2476)] = 19832,
  [SMALL_STATE(2477)] = 19903,
  [SMALL_STATE(2478)] = 19978,
  [SMALL_STATE(2479)] = 20053,
  [SMALL_STATE(2480)] = 20124,
  [SMALL_STATE(2481)] = 20195,
  [SMALL_STATE(2482)] = 20266,
  [SMALL_STATE(2483)] = 20337,
  [SMALL_STATE(2484)] = 20412,
  [SMALL_STATE(2485)] = 20483,
  [SMALL_STATE(2486)] = 20554,
  [SMALL_STATE(2487)] = 20625,
  [SMALL_STATE(2488)] = 20696,
  [SMALL_STATE(2489)] = 20767,
  [SMALL_STATE(2490)] = 20838,
  [SMALL_STATE(2491)] = 20909,
  [SMALL_STATE(2492)] = 20980,
  [SMALL_STATE(2493)] = 21059,
  [SMALL_STATE(2494)] = 21134,
  [SMALL_STATE(2495)] = 21209,
  [SMALL_STATE(2496)] = 21280,
  [SMALL_STATE(2497)] = 21351,
  [SMALL_STATE(2498)] = 21426,
  [SMALL_STATE(2499)] = 21497,
  [SMALL_STATE(2500)] = 21568,
  [SMALL_STATE(2501)] = 21647,
  [SMALL_STATE(2502)] = 21718,
  [SMALL_STATE(2503)] = 21789,
  [SMALL_STATE(2504)] = 21860,
  [SMALL_STATE(2505)] = 21931,
  [SMALL_STATE(2506)] = 22008,
  [SMALL_STATE(2507)] = 22087,
  [SMALL_STATE(2508)] = 22166,
  [SMALL_STATE(2509)] = 22237,
  [SMALL_STATE(2510)] = 22308,
  [SMALL_STATE(2511)] = 22379,
  [SMALL_STATE(2512)] = 22450,
  [SMALL_STATE(2513)] = 22521,
  [SMALL_STATE(2514)] = 22592,
  [SMALL_STATE(2515)] = 22663,
  [SMALL_STATE(2516)] = 22734,
  [SMALL_STATE(2517)] = 22809,
  [SMALL_STATE(2518)] = 22880,
  [SMALL_STATE(2519)] = 22951,
  [SMALL_STATE(2520)] = 23022,
  [SMALL_STATE(2521)] = 23093,
  [SMALL_STATE(2522)] = 23168,
  [SMALL_STATE(2523)] = 23239,
  [SMALL_STATE(2524)] = 23310,
  [SMALL_STATE(2525)] = 23381,
  [SMALL_STATE(2526)] = 23456,
  [SMALL_STATE(2527)] = 23527,
  [SMALL_STATE(2528)] = 23598,
  [SMALL_STATE(2529)] = 23669,
  [SMALL_STATE(2530)] = 23746,
  [SMALL_STATE(2531)] = 23817,
  [SMALL_STATE(2532)] = 23891,
  [SMALL_STATE(2533)] = 24021,
  [SMALL_STATE(2534)] = 24151,
  [SMALL_STATE(2535)] = 24281,
  [SMALL_STATE(2536)] = 24411,
  [SMALL_STATE(2537)] = 24541,
  [SMALL_STATE(2538)] = 24671,
  [SMALL_STATE(2539)] = 24801,
  [SMALL_STATE(2540)] = 24931,
  [SMALL_STATE(2541)] = 25061,
  [SMALL_STATE(2542)] = 25135,
  [SMALL_STATE(2543)] = 25265,
  [SMALL_STATE(2544)] = 25339,
  [SMALL_STATE(2545)] = 25469,
  [SMALL_STATE(2546)] = 25599,
  [SMALL_STATE(2547)] = 25671,
  [SMALL_STATE(2548)] = 25801,
  [SMALL_STATE(2549)] = 25931,
  [SMALL_STATE(2550)] = 26007,
  [SMALL_STATE(2551)] = 26137,
  [SMALL_STATE(2552)] = 26267,
  [SMALL_STATE(2553)] = 26397,
  [SMALL_STATE(2554)] = 26473,
  [SMALL_STATE(2555)] = 26603,
  [SMALL_STATE(2556)] = 26679,
  [SMALL_STATE(2557)] = 26753,
  [SMALL_STATE(2558)] = 26829,
  [SMALL_STATE(2559)] = 26905,
  [SMALL_STATE(2560)] = 26981,
  [SMALL_STATE(2561)] = 27057,
  [SMALL_STATE(2562)] = 27134,
  [SMALL_STATE(2563)] = 27225,
  [SMALL_STATE(2564)] = 27320,
  [SMALL_STATE(2565)] = 27413,
  [SMALL_STATE(2566)] = 27526,
  [SMALL_STATE(2567)] = 27631,
  [SMALL_STATE(2568)] = 27730,
  [SMALL_STATE(2569)] = 27801,
  [SMALL_STATE(2570)] = 27882,
  [SMALL_STATE(2571)] = 27959,
  [SMALL_STATE(2572)] = 28036,
  [SMALL_STATE(2573)] = 28151,
  [SMALL_STATE(2574)] = 28236,
  [SMALL_STATE(2575)] = 28305,
  [SMALL_STATE(2576)] = 28382,
  [SMALL_STATE(2577)] = 28459,
  [SMALL_STATE(2578)] = 28536,
  [SMALL_STATE(2579)] = 28619,
  [SMALL_STATE(2580)] = 28696,
  [SMALL_STATE(2581)] = 28773,
  [SMALL_STATE(2582)] = 28846,
  [SMALL_STATE(2583)] = 28923,
  [SMALL_STATE(2584)] = 29012,
  [SMALL_STATE(2585)] = 29083,
  [SMALL_STATE(2586)] = 29154,
  [SMALL_STATE(2587)] = 29227,
  [SMALL_STATE(2588)] = 29304,
  [SMALL_STATE(2589)] = 29391,
  [SMALL_STATE(2590)] = 29468,
  [SMALL_STATE(2591)] = 29539,
  [SMALL_STATE(2592)] = 29640,
  [SMALL_STATE(2593)] = 29709,
  [SMALL_STATE(2594)] = 29778,
  [SMALL_STATE(2595)] = 29847,
  [SMALL_STATE(2596)] = 29916,
  [SMALL_STATE(2597)] = 30029,
  [SMALL_STATE(2598)] = 30098,
  [SMALL_STATE(2599)] = 30167,
  [SMALL_STATE(2600)] = 30236,
  [SMALL_STATE(2601)] = 30313,
  [SMALL_STATE(2602)] = 30381,
  [SMALL_STATE(2603)] = 30455,
  [SMALL_STATE(2604)] = 30523,
  [SMALL_STATE(2605)] = 30591,
  [SMALL_STATE(2606)] = 30659,
  [SMALL_STATE(2607)] = 30733,
  [SMALL_STATE(2608)] = 30801,
  [SMALL_STATE(2609)] = 30869,
  [SMALL_STATE(2610)] = 30937,
  [SMALL_STATE(2611)] = 31005,
  [SMALL_STATE(2612)] = 31079,
  [SMALL_STATE(2613)] = 31147,
  [SMALL_STATE(2614)] = 31219,
  [SMALL_STATE(2615)] = 31287,
  [SMALL_STATE(2616)] = 31361,
  [SMALL_STATE(2617)] = 31429,
  [SMALL_STATE(2618)] = 31503,
  [SMALL_STATE(2619)] = 31571,
  [SMALL_STATE(2620)] = 31639,
  [SMALL_STATE(2621)] = 31707,
  [SMALL_STATE(2622)] = 31775,
  [SMALL_STATE(2623)] = 31843,
  [SMALL_STATE(2624)] = 31913,
  [SMALL_STATE(2625)] = 31981,
  [SMALL_STATE(2626)] = 32049,
  [SMALL_STATE(2627)] = 32123,
  [SMALL_STATE(2628)] = 32191,
  [SMALL_STATE(2629)] = 32259,
  [SMALL_STATE(2630)] = 32327,
  [SMALL_STATE(2631)] = 32395,
  [SMALL_STATE(2632)] = 32463,
  [SMALL_STATE(2633)] = 32535,
  [SMALL_STATE(2634)] = 32607,
  [SMALL_STATE(2635)] = 32675,
  [SMALL_STATE(2636)] = 32743,
  [SMALL_STATE(2637)] = 32815,
  [SMALL_STATE(2638)] = 32883,
  [SMALL_STATE(2639)] = 32951,
  [SMALL_STATE(2640)] = 33019,
  [SMALL_STATE(2641)] = 33087,
  [SMALL_STATE(2642)] = 33155,
  [SMALL_STATE(2643)] = 33223,
  [SMALL_STATE(2644)] = 33291,
  [SMALL_STATE(2645)] = 33359,
  [SMALL_STATE(2646)] = 33431,
  [SMALL_STATE(2647)] = 33499,
  [SMALL_STATE(2648)] = 33567,
  [SMALL_STATE(2649)] = 33635,
  [SMALL_STATE(2650)] = 33703,
  [SMALL_STATE(2651)] = 33771,
  [SMALL_STATE(2652)] = 33839,
  [SMALL_STATE(2653)] = 33907,
  [SMALL_STATE(2654)] = 33975,
  [SMALL_STATE(2655)] = 34043,
  [SMALL_STATE(2656)] = 34111,
  [SMALL_STATE(2657)] = 34185,
  [SMALL_STATE(2658)] = 34253,
  [SMALL_STATE(2659)] = 34321,
  [SMALL_STATE(2660)] = 34389,
  [SMALL_STATE(2661)] = 34457,
  [SMALL_STATE(2662)] = 34525,
  [SMALL_STATE(2663)] = 34593,
  [SMALL_STATE(2664)] = 34667,
  [SMALL_STATE(2665)] = 34735,
  [SMALL_STATE(2666)] = 34803,
  [SMALL_STATE(2667)] = 34875,
  [SMALL_STATE(2668)] = 34943,
  [SMALL_STATE(2669)] = 35010,
  [SMALL_STATE(2670)] = 35077,
  [SMALL_STATE(2671)] = 35144,
  [SMALL_STATE(2672)] = 35211,
  [SMALL_STATE(2673)] = 35278,
  [SMALL_STATE(2674)] = 35345,
  [SMALL_STATE(2675)] = 35412,
  [SMALL_STATE(2676)] = 35479,
  [SMALL_STATE(2677)] = 35546,
  [SMALL_STATE(2678)] = 35613,
  [SMALL_STATE(2679)] = 35684,
  [SMALL_STATE(2680)] = 35755,
  [SMALL_STATE(2681)] = 35822,
  [SMALL_STATE(2682)] = 35893,
  [SMALL_STATE(2683)] = 35960,
  [SMALL_STATE(2684)] = 36027,
  [SMALL_STATE(2685)] = 36098,
  [SMALL_STATE(2686)] = 36165,
  [SMALL_STATE(2687)] = 36232,
  [SMALL_STATE(2688)] = 36299,
  [SMALL_STATE(2689)] = 36370,
  [SMALL_STATE(2690)] = 36437,
  [SMALL_STATE(2691)] = 36504,
  [SMALL_STATE(2692)] = 36571,
  [SMALL_STATE(2693)] = 36638,
  [SMALL_STATE(2694)] = 36705,
  [SMALL_STATE(2695)] = 36772,
  [SMALL_STATE(2696)] = 36839,
  [SMALL_STATE(2697)] = 36906,
  [SMALL_STATE(2698)] = 36973,
  [SMALL_STATE(2699)] = 37040,
  [SMALL_STATE(2700)] = 37107,
  [SMALL_STATE(2701)] = 37174,
  [SMALL_STATE(2702)] = 37241,
  [SMALL_STATE(2703)] = 37312,
  [SMALL_STATE(2704)] = 37379,
  [SMALL_STATE(2705)] = 37446,
  [SMALL_STATE(2706)] = 37513,
  [SMALL_STATE(2707)] = 37580,
  [SMALL_STATE(2708)] = 37647,
  [SMALL_STATE(2709)] = 37714,
  [SMALL_STATE(2710)] = 37781,
  [SMALL_STATE(2711)] = 37848,
  [SMALL_STATE(2712)] = 37963,
  [SMALL_STATE(2713)] = 38030,
  [SMALL_STATE(2714)] = 38103,
  [SMALL_STATE(2715)] = 38170,
  [SMALL_STATE(2716)] = 38237,
  [SMALL_STATE(2717)] = 38304,
  [SMALL_STATE(2718)] = 38371,
  [SMALL_STATE(2719)] = 38438,
  [SMALL_STATE(2720)] = 38505,
  [SMALL_STATE(2721)] = 38572,
  [SMALL_STATE(2722)] = 38639,
  [SMALL_STATE(2723)] = 38706,
  [SMALL_STATE(2724)] = 38773,
  [SMALL_STATE(2725)] = 38840,
  [SMALL_STATE(2726)] = 38907,
  [SMALL_STATE(2727)] = 38974,
  [SMALL_STATE(2728)] = 39041,
  [SMALL_STATE(2729)] = 39108,
  [SMALL_STATE(2730)] = 39175,
  [SMALL_STATE(2731)] = 39248,
  [SMALL_STATE(2732)] = 39315,
  [SMALL_STATE(2733)] = 39382,
  [SMALL_STATE(2734)] = 39449,
  [SMALL_STATE(2735)] = 39516,
  [SMALL_STATE(2736)] = 39583,
  [SMALL_STATE(2737)] = 39650,
  [SMALL_STATE(2738)] = 39717,
  [SMALL_STATE(2739)] = 39788,
  [SMALL_STATE(2740)] = 39877,
  [SMALL_STATE(2741)] = 39990,
  [SMALL_STATE(2742)] = 40069,
  [SMALL_STATE(2743)] = 40156,
  [SMALL_STATE(2744)] = 40241,
  [SMALL_STATE(2745)] = 40340,
  [SMALL_STATE(2746)] = 40437,
  [SMALL_STATE(2747)] = 40530,
  [SMALL_STATE(2748)] = 40621,
  [SMALL_STATE(2749)] = 40704,
  [SMALL_STATE(2750)] = 40785,
  [SMALL_STATE(2751)] = 40860,
  [SMALL_STATE(2752)] = 40971,
  [SMALL_STATE(2753)] = 41046,
  [SMALL_STATE(2754)] = 41121,
  [SMALL_STATE(2755)] = 41232,
  [SMALL_STATE(2756)] = 41335,
  [SMALL_STATE(2757)] = 41408,
  [SMALL_STATE(2758)] = 41477,
  [SMALL_STATE(2759)] = 41544,
  [SMALL_STATE(2760)] = 41611,
  [SMALL_STATE(2761)] = 41678,
  [SMALL_STATE(2762)] = 41745,
  [SMALL_STATE(2763)] = 41816,
  [SMALL_STATE(2764)] = 41891,
  [SMALL_STATE(2765)] = 41966,
  [SMALL_STATE(2766)] = 42033,
  [SMALL_STATE(2767)] = 42100,
  [SMALL_STATE(2768)] = 42167,
  [SMALL_STATE(2769)] = 42234,
  [SMALL_STATE(2770)] = 42320,
  [SMALL_STATE(2771)] = 42388,
  [SMALL_STATE(2772)] = 42454,
  [SMALL_STATE(2773)] = 42528,
  [SMALL_STATE(2774)] = 42594,
  [SMALL_STATE(2775)] = 42668,
  [SMALL_STATE(2776)] = 42734,
  [SMALL_STATE(2777)] = 42800,
  [SMALL_STATE(2778)] = 42872,
  [SMALL_STATE(2779)] = 42942,
  [SMALL_STATE(2780)] = 43008,
  [SMALL_STATE(2781)] = 43082,
  [SMALL_STATE(2782)] = 43170,
  [SMALL_STATE(2783)] = 43282,
  [SMALL_STATE(2784)] = 43360,
  [SMALL_STATE(2785)] = 43426,
  [SMALL_STATE(2786)] = 43492,
  [SMALL_STATE(2787)] = 43562,
  [SMALL_STATE(2788)] = 43672,
  [SMALL_STATE(2789)] = 43744,
  [SMALL_STATE(2790)] = 43842,
  [SMALL_STATE(2791)] = 43938,
  [SMALL_STATE(2792)] = 44030,
  [SMALL_STATE(2793)] = 44132,
  [SMALL_STATE(2794)] = 44222,
  [SMALL_STATE(2795)] = 44304,
  [SMALL_STATE(2796)] = 44372,
  [SMALL_STATE(2797)] = 44452,
  [SMALL_STATE(2798)] = 44520,
  [SMALL_STATE(2799)] = 44594,
  [SMALL_STATE(2800)] = 44660,
  [SMALL_STATE(2801)] = 44726,
  [SMALL_STATE(2802)] = 44800,
  [SMALL_STATE(2803)] = 44910,
  [SMALL_STATE(2804)] = 44994,
  [SMALL_STATE(2805)] = 45059,
  [SMALL_STATE(2806)] = 45124,
  [SMALL_STATE(2807)] = 45189,
  [SMALL_STATE(2808)] = 45260,
  [SMALL_STATE(2809)] = 45325,
  [SMALL_STATE(2810)] = 45390,
  [SMALL_STATE(2811)] = 45455,
  [SMALL_STATE(2812)] = 45520,
  [SMALL_STATE(2813)] = 45585,
  [SMALL_STATE(2814)] = 45650,
  [SMALL_STATE(2815)] = 45715,
  [SMALL_STATE(2816)] = 45780,
  [SMALL_STATE(2817)] = 45849,
  [SMALL_STATE(2818)] = 45914,
  [SMALL_STATE(2819)] = 45979,
  [SMALL_STATE(2820)] = 46044,
  [SMALL_STATE(2821)] = 46173,
  [SMALL_STATE(2822)] = 46238,
  [SMALL_STATE(2823)] = 46303,
  [SMALL_STATE(2824)] = 46368,
  [SMALL_STATE(2825)] = 46433,
  [SMALL_STATE(2826)] = 46498,
  [SMALL_STATE(2827)] = 46563,
  [SMALL_STATE(2828)] = 46628,
  [SMALL_STATE(2829)] = 46693,
  [SMALL_STATE(2830)] = 46758,
  [SMALL_STATE(2831)] = 46823,
  [SMALL_STATE(2832)] = 46888,
  [SMALL_STATE(2833)] = 46953,
  [SMALL_STATE(2834)] = 47018,
  [SMALL_STATE(2835)] = 47087,
  [SMALL_STATE(2836)] = 47152,
  [SMALL_STATE(2837)] = 47217,
  [SMALL_STATE(2838)] = 47282,
  [SMALL_STATE(2839)] = 47347,
  [SMALL_STATE(2840)] = 47412,
  [SMALL_STATE(2841)] = 47477,
  [SMALL_STATE(2842)] = 47542,
  [SMALL_STATE(2843)] = 47607,
  [SMALL_STATE(2844)] = 47672,
  [SMALL_STATE(2845)] = 47741,
  [SMALL_STATE(2846)] = 47806,
  [SMALL_STATE(2847)] = 47871,
  [SMALL_STATE(2848)] = 47936,
  [SMALL_STATE(2849)] = 48009,
  [SMALL_STATE(2850)] = 48074,
  [SMALL_STATE(2851)] = 48147,
  [SMALL_STATE(2852)] = 48212,
  [SMALL_STATE(2853)] = 48281,
  [SMALL_STATE(2854)] = 48346,
  [SMALL_STATE(2855)] = 48411,
  [SMALL_STATE(2856)] = 48484,
  [SMALL_STATE(2857)] = 48549,
  [SMALL_STATE(2858)] = 48614,
  [SMALL_STATE(2859)] = 48679,
  [SMALL_STATE(2860)] = 48744,
  [SMALL_STATE(2861)] = 48809,
  [SMALL_STATE(2862)] = 48874,
  [SMALL_STATE(2863)] = 48939,
  [SMALL_STATE(2864)] = 49004,
  [SMALL_STATE(2865)] = 49069,
  [SMALL_STATE(2866)] = 49134,
  [SMALL_STATE(2867)] = 49199,
  [SMALL_STATE(2868)] = 49264,
  [SMALL_STATE(2869)] = 49333,
  [SMALL_STATE(2870)] = 49398,
  [SMALL_STATE(2871)] = 49463,
  [SMALL_STATE(2872)] = 49532,
  [SMALL_STATE(2873)] = 49601,
  [SMALL_STATE(2874)] = 49666,
  [SMALL_STATE(2875)] = 49731,
  [SMALL_STATE(2876)] = 49796,
  [SMALL_STATE(2877)] = 49861,
  [SMALL_STATE(2878)] = 49926,
  [SMALL_STATE(2879)] = 49991,
  [SMALL_STATE(2880)] = 50056,
  [SMALL_STATE(2881)] = 50121,
  [SMALL_STATE(2882)] = 50186,
  [SMALL_STATE(2883)] = 50255,
  [SMALL_STATE(2884)] = 50320,
  [SMALL_STATE(2885)] = 50385,
  [SMALL_STATE(2886)] = 50450,
  [SMALL_STATE(2887)] = 50561,
  [SMALL_STATE(2888)] = 50626,
  [SMALL_STATE(2889)] = 50703,
  [SMALL_STATE(2890)] = 50788,
  [SMALL_STATE(2891)] = 50871,
  [SMALL_STATE(2892)] = 50968,
  [SMALL_STATE(2893)] = 51063,
  [SMALL_STATE(2894)] = 51154,
  [SMALL_STATE(2895)] = 51243,
  [SMALL_STATE(2896)] = 51324,
  [SMALL_STATE(2897)] = 51403,
  [SMALL_STATE(2898)] = 51476,
  [SMALL_STATE(2899)] = 51541,
  [SMALL_STATE(2900)] = 51606,
  [SMALL_STATE(2901)] = 51671,
  [SMALL_STATE(2902)] = 51780,
  [SMALL_STATE(2903)] = 51845,
  [SMALL_STATE(2904)] = 51918,
  [SMALL_STATE(2905)] = 51987,
  [SMALL_STATE(2906)] = 52052,
  [SMALL_STATE(2907)] = 52117,
  [SMALL_STATE(2908)] = 52182,
  [SMALL_STATE(2909)] = 52247,
  [SMALL_STATE(2910)] = 52312,
  [SMALL_STATE(2911)] = 52385,
  [SMALL_STATE(2912)] = 52450,
  [SMALL_STATE(2913)] = 52515,
  [SMALL_STATE(2914)] = 52580,
  [SMALL_STATE(2915)] = 52645,
  [SMALL_STATE(2916)] = 52710,
  [SMALL_STATE(2917)] = 52775,
  [SMALL_STATE(2918)] = 52884,
  [SMALL_STATE(2919)] = 52985,
  [SMALL_STATE(2920)] = 53114,
  [SMALL_STATE(2921)] = 53179,
  [SMALL_STATE(2922)] = 53244,
  [SMALL_STATE(2923)] = 53309,
  [SMALL_STATE(2924)] = 53374,
  [SMALL_STATE(2925)] = 53439,
  [SMALL_STATE(2926)] = 53504,
  [SMALL_STATE(2927)] = 53569,
  [SMALL_STATE(2928)] = 53634,
  [SMALL_STATE(2929)] = 53699,
  [SMALL_STATE(2930)] = 53764,
  [SMALL_STATE(2931)] = 53837,
  [SMALL_STATE(2932)] = 53902,
  [SMALL_STATE(2933)] = 53967,
  [SMALL_STATE(2934)] = 54032,
  [SMALL_STATE(2935)] = 54097,
  [SMALL_STATE(2936)] = 54162,
  [SMALL_STATE(2937)] = 54227,
  [SMALL_STATE(2938)] = 54292,
  [SMALL_STATE(2939)] = 54357,
  [SMALL_STATE(2940)] = 54422,
  [SMALL_STATE(2941)] = 54487,
  [SMALL_STATE(2942)] = 54552,
  [SMALL_STATE(2943)] = 54617,
  [SMALL_STATE(2944)] = 54682,
  [SMALL_STATE(2945)] = 54747,
  [SMALL_STATE(2946)] = 54812,
  [SMALL_STATE(2947)] = 54877,
  [SMALL_STATE(2948)] = 54942,
  [SMALL_STATE(2949)] = 55007,
  [SMALL_STATE(2950)] = 55072,
  [SMALL_STATE(2951)] = 55137,
  [SMALL_STATE(2952)] = 55202,
  [SMALL_STATE(2953)] = 55267,
  [SMALL_STATE(2954)] = 55332,
  [SMALL_STATE(2955)] = 55399,
  [SMALL_STATE(2956)] = 55486,
  [SMALL_STATE(2957)] = 55610,
  [SMALL_STATE(2958)] = 55686,
  [SMALL_STATE(2959)] = 55758,
  [SMALL_STATE(2960)] = 55828,
  [SMALL_STATE(2961)] = 55908,
  [SMALL_STATE(2962)] = 55984,
  [SMALL_STATE(2963)] = 56052,
  [SMALL_STATE(2964)] = 56124,
  [SMALL_STATE(2965)] = 56204,
  [SMALL_STATE(2966)] = 56328,
  [SMALL_STATE(2967)] = 56404,
  [SMALL_STATE(2968)] = 56528,
  [SMALL_STATE(2969)] = 56604,
  [SMALL_STATE(2970)] = 56674,
  [SMALL_STATE(2971)] = 56750,
  [SMALL_STATE(2972)] = 56826,
  [SMALL_STATE(2973)] = 56904,
  [SMALL_STATE(2974)] = 56980,
  [SMALL_STATE(2975)] = 57052,
  [SMALL_STATE(2976)] = 57122,
  [SMALL_STATE(2977)] = 57192,
  [SMALL_STATE(2978)] = 57268,
  [SMALL_STATE(2979)] = 57348,
  [SMALL_STATE(2980)] = 57418,
  [SMALL_STATE(2981)] = 57496,
  [SMALL_STATE(2982)] = 57574,
  [SMALL_STATE(2983)] = 57654,
  [SMALL_STATE(2984)] = 57730,
  [SMALL_STATE(2985)] = 57806,
  [SMALL_STATE(2986)] = 57878,
  [SMALL_STATE(2987)] = 57944,
  [SMALL_STATE(2988)] = 58022,
  [SMALL_STATE(2989)] = 58092,
  [SMALL_STATE(2990)] = 58170,
  [SMALL_STATE(2991)] = 58248,
  [SMALL_STATE(2992)] = 58318,
  [SMALL_STATE(2993)] = 58394,
  [SMALL_STATE(2994)] = 58474,
  [SMALL_STATE(2995)] = 58542,
  [SMALL_STATE(2996)] = 58612,
  [SMALL_STATE(2997)] = 58692,
  [SMALL_STATE(2998)] = 58768,
  [SMALL_STATE(2999)] = 58836,
  [SMALL_STATE(3000)] = 58912,
  [SMALL_STATE(3001)] = 58988,
  [SMALL_STATE(3002)] = 59054,
  [SMALL_STATE(3003)] = 59118,
  [SMALL_STATE(3004)] = 59198,
  [SMALL_STATE(3005)] = 59270,
  [SMALL_STATE(3006)] = 59394,
  [SMALL_STATE(3007)] = 59470,
  [SMALL_STATE(3008)] = 59540,
  [SMALL_STATE(3009)] = 59616,
  [SMALL_STATE(3010)] = 59688,
  [SMALL_STATE(3011)] = 59756,
  [SMALL_STATE(3012)] = 59836,
  [SMALL_STATE(3013)] = 59916,
  [SMALL_STATE(3014)] = 59992,
  [SMALL_STATE(3015)] = 60062,
  [SMALL_STATE(3016)] = 60128,
  [SMALL_STATE(3017)] = 60204,
  [SMALL_STATE(3018)] = 60267,
  [SMALL_STATE(3019)] = 60330,
  [SMALL_STATE(3020)] = 60393,
  [SMALL_STATE(3021)] = 60456,
  [SMALL_STATE(3022)] = 60519,
  [SMALL_STATE(3023)] = 60582,
  [SMALL_STATE(3024)] = 60645,
  [SMALL_STATE(3025)] = 60708,
  [SMALL_STATE(3026)] = 60775,
  [SMALL_STATE(3027)] = 60844,
  [SMALL_STATE(3028)] = 60907,
  [SMALL_STATE(3029)] = 60970,
  [SMALL_STATE(3030)] = 61049,
  [SMALL_STATE(3031)] = 61124,
  [SMALL_STATE(3032)] = 61235,
  [SMALL_STATE(3033)] = 61298,
  [SMALL_STATE(3034)] = 61363,
  [SMALL_STATE(3035)] = 61426,
  [SMALL_STATE(3036)] = 61491,
  [SMALL_STATE(3037)] = 61570,
  [SMALL_STATE(3038)] = 61645,
  [SMALL_STATE(3039)] = 61720,
  [SMALL_STATE(3040)] = 61783,
  [SMALL_STATE(3041)] = 61850,
  [SMALL_STATE(3042)] = 61915,
  [SMALL_STATE(3043)] = 61978,
  [SMALL_STATE(3044)] = 62041,
  [SMALL_STATE(3045)] = 62106,
  [SMALL_STATE(3046)] = 62185,
  [SMALL_STATE(3047)] = 62248,
  [SMALL_STATE(3048)] = 62323,
  [SMALL_STATE(3049)] = 62398,
  [SMALL_STATE(3050)] = 62465,
  [SMALL_STATE(3051)] = 62528,
  [SMALL_STATE(3052)] = 62591,
  [SMALL_STATE(3053)] = 62666,
  [SMALL_STATE(3054)] = 62787,
  [SMALL_STATE(3055)] = 62850,
  [SMALL_STATE(3056)] = 62913,
  [SMALL_STATE(3057)] = 62976,
  [SMALL_STATE(3058)] = 63039,
  [SMALL_STATE(3059)] = 63102,
  [SMALL_STATE(3060)] = 63179,
  [SMALL_STATE(3061)] = 63256,
  [SMALL_STATE(3062)] = 63319,
  [SMALL_STATE(3063)] = 63386,
  [SMALL_STATE(3064)] = 63453,
  [SMALL_STATE(3065)] = 63516,
  [SMALL_STATE(3066)] = 63595,
  [SMALL_STATE(3067)] = 63670,
  [SMALL_STATE(3068)] = 63733,
  [SMALL_STATE(3069)] = 63796,
  [SMALL_STATE(3070)] = 63859,
  [SMALL_STATE(3071)] = 63926,
  [SMALL_STATE(3072)] = 63989,
  [SMALL_STATE(3073)] = 64068,
  [SMALL_STATE(3074)] = 64143,
  [SMALL_STATE(3075)] = 64218,
  [SMALL_STATE(3076)] = 64297,
  [SMALL_STATE(3077)] = 64372,
  [SMALL_STATE(3078)] = 64447,
  [SMALL_STATE(3079)] = 64510,
  [SMALL_STATE(3080)] = 64573,
  [SMALL_STATE(3081)] = 64648,
  [SMALL_STATE(3082)] = 64711,
  [SMALL_STATE(3083)] = 64774,
  [SMALL_STATE(3084)] = 64837,
  [SMALL_STATE(3085)] = 64900,
  [SMALL_STATE(3086)] = 64963,
  [SMALL_STATE(3087)] = 65040,
  [SMALL_STATE(3088)] = 65117,
  [SMALL_STATE(3089)] = 65196,
  [SMALL_STATE(3090)] = 65271,
  [SMALL_STATE(3091)] = 65350,
  [SMALL_STATE(3092)] = 65425,
  [SMALL_STATE(3093)] = 65500,
  [SMALL_STATE(3094)] = 65579,
  [SMALL_STATE(3095)] = 65654,
  [SMALL_STATE(3096)] = 65729,
  [SMALL_STATE(3097)] = 65792,
  [SMALL_STATE(3098)] = 65867,
  [SMALL_STATE(3099)] = 65930,
  [SMALL_STATE(3100)] = 65993,
  [SMALL_STATE(3101)] = 66056,
  [SMALL_STATE(3102)] = 66167,
  [SMALL_STATE(3103)] = 66230,
  [SMALL_STATE(3104)] = 66293,
  [SMALL_STATE(3105)] = 66356,
  [SMALL_STATE(3106)] = 66419,
  [SMALL_STATE(3107)] = 66482,
  [SMALL_STATE(3108)] = 66559,
  [SMALL_STATE(3109)] = 66622,
  [SMALL_STATE(3110)] = 66685,
  [SMALL_STATE(3111)] = 66748,
  [SMALL_STATE(3112)] = 66811,
  [SMALL_STATE(3113)] = 66874,
  [SMALL_STATE(3114)] = 66937,
  [SMALL_STATE(3115)] = 67000,
  [SMALL_STATE(3116)] = 67063,
  [SMALL_STATE(3117)] = 67126,
  [SMALL_STATE(3118)] = 67189,
  [SMALL_STATE(3119)] = 67252,
  [SMALL_STATE(3120)] = 67315,
  [SMALL_STATE(3121)] = 67378,
  [SMALL_STATE(3122)] = 67441,
  [SMALL_STATE(3123)] = 67504,
  [SMALL_STATE(3124)] = 67567,
  [SMALL_STATE(3125)] = 67630,
  [SMALL_STATE(3126)] = 67693,
  [SMALL_STATE(3127)] = 67756,
  [SMALL_STATE(3128)] = 67819,
  [SMALL_STATE(3129)] = 67882,
  [SMALL_STATE(3130)] = 67945,
  [SMALL_STATE(3131)] = 68008,
  [SMALL_STATE(3132)] = 68071,
  [SMALL_STATE(3133)] = 68140,
  [SMALL_STATE(3134)] = 68203,
  [SMALL_STATE(3135)] = 68266,
  [SMALL_STATE(3136)] = 68329,
  [SMALL_STATE(3137)] = 68392,
  [SMALL_STATE(3138)] = 68455,
  [SMALL_STATE(3139)] = 68518,
  [SMALL_STATE(3140)] = 68581,
  [SMALL_STATE(3141)] = 68644,
  [SMALL_STATE(3142)] = 68707,
  [SMALL_STATE(3143)] = 68770,
  [SMALL_STATE(3144)] = 68833,
  [SMALL_STATE(3145)] = 68896,
  [SMALL_STATE(3146)] = 68961,
  [SMALL_STATE(3147)] = 69024,
  [SMALL_STATE(3148)] = 69087,
  [SMALL_STATE(3149)] = 69150,
  [SMALL_STATE(3150)] = 69213,
  [SMALL_STATE(3151)] = 69276,
  [SMALL_STATE(3152)] = 69339,
  [SMALL_STATE(3153)] = 69402,
  [SMALL_STATE(3154)] = 69465,
  [SMALL_STATE(3155)] = 69528,
  [SMALL_STATE(3156)] = 69591,
  [SMALL_STATE(3157)] = 69660,
  [SMALL_STATE(3158)] = 69731,
  [SMALL_STATE(3159)] = 69798,
  [SMALL_STATE(3160)] = 69861,
  [SMALL_STATE(3161)] = 69930,
  [SMALL_STATE(3162)] = 70001,
  [SMALL_STATE(3163)] = 70070,
  [SMALL_STATE(3164)] = 70133,
  [SMALL_STATE(3165)] = 70204,
  [SMALL_STATE(3166)] = 70267,
  [SMALL_STATE(3167)] = 70330,
  [SMALL_STATE(3168)] = 70393,
  [SMALL_STATE(3169)] = 70464,
  [SMALL_STATE(3170)] = 70527,
  [SMALL_STATE(3171)] = 70590,
  [SMALL_STATE(3172)] = 70653,
  [SMALL_STATE(3173)] = 70722,
  [SMALL_STATE(3174)] = 70785,
  [SMALL_STATE(3175)] = 70856,
  [SMALL_STATE(3176)] = 70925,
  [SMALL_STATE(3177)] = 70994,
  [SMALL_STATE(3178)] = 71065,
  [SMALL_STATE(3179)] = 71134,
  [SMALL_STATE(3180)] = 71197,
  [SMALL_STATE(3181)] = 71260,
  [SMALL_STATE(3182)] = 71323,
  [SMALL_STATE(3183)] = 71386,
  [SMALL_STATE(3184)] = 71449,
  [SMALL_STATE(3185)] = 71512,
  [SMALL_STATE(3186)] = 71575,
  [SMALL_STATE(3187)] = 71638,
  [SMALL_STATE(3188)] = 71701,
  [SMALL_STATE(3189)] = 71764,
  [SMALL_STATE(3190)] = 71827,
  [SMALL_STATE(3191)] = 71890,
  [SMALL_STATE(3192)] = 71953,
  [SMALL_STATE(3193)] = 72016,
  [SMALL_STATE(3194)] = 72093,
  [SMALL_STATE(3195)] = 72156,
  [SMALL_STATE(3196)] = 72219,
  [SMALL_STATE(3197)] = 72284,
  [SMALL_STATE(3198)] = 72347,
  [SMALL_STATE(3199)] = 72410,
  [SMALL_STATE(3200)] = 72473,
  [SMALL_STATE(3201)] = 72536,
  [SMALL_STATE(3202)] = 72599,
  [SMALL_STATE(3203)] = 72662,
  [SMALL_STATE(3204)] = 72725,
  [SMALL_STATE(3205)] = 72788,
  [SMALL_STATE(3206)] = 72851,
  [SMALL_STATE(3207)] = 72914,
  [SMALL_STATE(3208)] = 72977,
  [SMALL_STATE(3209)] = 73061,
  [SMALL_STATE(3210)] = 73123,
  [SMALL_STATE(3211)] = 73185,
  [SMALL_STATE(3212)] = 73247,
  [SMALL_STATE(3213)] = 73309,
  [SMALL_STATE(3214)] = 73371,
  [SMALL_STATE(3215)] = 73441,
  [SMALL_STATE(3216)] = 73503,
  [SMALL_STATE(3217)] = 73565,
  [SMALL_STATE(3218)] = 73659,
  [SMALL_STATE(3219)] = 73763,
  [SMALL_STATE(3220)] = 73853,
  [SMALL_STATE(3221)] = 73941,
  [SMALL_STATE(3222)] = 74007,
  [SMALL_STATE(3223)] = 74087,
  [SMALL_STATE(3224)] = 74165,
  [SMALL_STATE(3225)] = 74235,
  [SMALL_STATE(3226)] = 74339,
  [SMALL_STATE(3227)] = 74443,
  [SMALL_STATE(3228)] = 74547,
  [SMALL_STATE(3229)] = 74609,
  [SMALL_STATE(3230)] = 74675,
  [SMALL_STATE(3231)] = 74781,
  [SMALL_STATE(3232)] = 74843,
  [SMALL_STATE(3233)] = 74905,
  [SMALL_STATE(3234)] = 74967,
  [SMALL_STATE(3235)] = 75073,
  [SMALL_STATE(3236)] = 75141,
  [SMALL_STATE(3237)] = 75211,
  [SMALL_STATE(3238)] = 75273,
  [SMALL_STATE(3239)] = 75377,
  [SMALL_STATE(3240)] = 75439,
  [SMALL_STATE(3241)] = 75509,
  [SMALL_STATE(3242)] = 75571,
  [SMALL_STATE(3243)] = 75637,
  [SMALL_STATE(3244)] = 75703,
  [SMALL_STATE(3245)] = 75769,
  [SMALL_STATE(3246)] = 75835,
  [SMALL_STATE(3247)] = 75905,
  [SMALL_STATE(3248)] = 75967,
  [SMALL_STATE(3249)] = 76043,
  [SMALL_STATE(3250)] = 76119,
  [SMALL_STATE(3251)] = 76197,
  [SMALL_STATE(3252)] = 76271,
  [SMALL_STATE(3253)] = 76349,
  [SMALL_STATE(3254)] = 76423,
  [SMALL_STATE(3255)] = 76497,
  [SMALL_STATE(3256)] = 76575,
  [SMALL_STATE(3257)] = 76649,
  [SMALL_STATE(3258)] = 76723,
  [SMALL_STATE(3259)] = 76797,
  [SMALL_STATE(3260)] = 76901,
  [SMALL_STATE(3261)] = 76971,
  [SMALL_STATE(3262)] = 77033,
  [SMALL_STATE(3263)] = 77137,
  [SMALL_STATE(3264)] = 77199,
  [SMALL_STATE(3265)] = 77261,
  [SMALL_STATE(3266)] = 77327,
  [SMALL_STATE(3267)] = 77389,
  [SMALL_STATE(3268)] = 77451,
  [SMALL_STATE(3269)] = 77513,
  [SMALL_STATE(3270)] = 77575,
  [SMALL_STATE(3271)] = 77637,
  [SMALL_STATE(3272)] = 77699,
  [SMALL_STATE(3273)] = 77785,
  [SMALL_STATE(3274)] = 77855,
  [SMALL_STATE(3275)] = 77917,
  [SMALL_STATE(3276)] = 77983,
  [SMALL_STATE(3277)] = 78053,
  [SMALL_STATE(3278)] = 78123,
  [SMALL_STATE(3279)] = 78231,
  [SMALL_STATE(3280)] = 78305,
  [SMALL_STATE(3281)] = 78389,
  [SMALL_STATE(3282)] = 78459,
  [SMALL_STATE(3283)] = 78541,
  [SMALL_STATE(3284)] = 78637,
  [SMALL_STATE(3285)] = 78731,
  [SMALL_STATE(3286)] = 78801,
  [SMALL_STATE(3287)] = 78891,
  [SMALL_STATE(3288)] = 78953,
  [SMALL_STATE(3289)] = 79015,
  [SMALL_STATE(3290)] = 79103,
  [SMALL_STATE(3291)] = 79173,
  [SMALL_STATE(3292)] = 79253,
  [SMALL_STATE(3293)] = 79331,
  [SMALL_STATE(3294)] = 79393,
  [SMALL_STATE(3295)] = 79499,
  [SMALL_STATE(3296)] = 79597,
  [SMALL_STATE(3297)] = 79659,
  [SMALL_STATE(3298)] = 79729,
  [SMALL_STATE(3299)] = 79799,
  [SMALL_STATE(3300)] = 79861,
  [SMALL_STATE(3301)] = 79923,
  [SMALL_STATE(3302)] = 79985,
  [SMALL_STATE(3303)] = 80103,
  [SMALL_STATE(3304)] = 80165,
  [SMALL_STATE(3305)] = 80271,
  [SMALL_STATE(3306)] = 80333,
  [SMALL_STATE(3307)] = 80395,
  [SMALL_STATE(3308)] = 80457,
  [SMALL_STATE(3309)] = 80519,
  [SMALL_STATE(3310)] = 80589,
  [SMALL_STATE(3311)] = 80651,
  [SMALL_STATE(3312)] = 80721,
  [SMALL_STATE(3313)] = 80783,
  [SMALL_STATE(3314)] = 80853,
  [SMALL_STATE(3315)] = 80939,
  [SMALL_STATE(3316)] = 81001,
  [SMALL_STATE(3317)] = 81063,
  [SMALL_STATE(3318)] = 81171,
  [SMALL_STATE(3319)] = 81239,
  [SMALL_STATE(3320)] = 81343,
  [SMALL_STATE(3321)] = 81417,
  [SMALL_STATE(3322)] = 81479,
  [SMALL_STATE(3323)] = 81545,
  [SMALL_STATE(3324)] = 81607,
  [SMALL_STATE(3325)] = 81669,
  [SMALL_STATE(3326)] = 81739,
  [SMALL_STATE(3327)] = 81805,
  [SMALL_STATE(3328)] = 81867,
  [SMALL_STATE(3329)] = 81929,
  [SMALL_STATE(3330)] = 81991,
  [SMALL_STATE(3331)] = 82053,
  [SMALL_STATE(3332)] = 82135,
  [SMALL_STATE(3333)] = 82197,
  [SMALL_STATE(3334)] = 82267,
  [SMALL_STATE(3335)] = 82329,
  [SMALL_STATE(3336)] = 82395,
  [SMALL_STATE(3337)] = 82491,
  [SMALL_STATE(3338)] = 82553,
  [SMALL_STATE(3339)] = 82623,
  [SMALL_STATE(3340)] = 82685,
  [SMALL_STATE(3341)] = 82747,
  [SMALL_STATE(3342)] = 82809,
  [SMALL_STATE(3343)] = 82871,
  [SMALL_STATE(3344)] = 82933,
  [SMALL_STATE(3345)] = 82995,
  [SMALL_STATE(3346)] = 83057,
  [SMALL_STATE(3347)] = 83119,
  [SMALL_STATE(3348)] = 83187,
  [SMALL_STATE(3349)] = 83249,
  [SMALL_STATE(3350)] = 83311,
  [SMALL_STATE(3351)] = 83373,
  [SMALL_STATE(3352)] = 83435,
  [SMALL_STATE(3353)] = 83497,
  [SMALL_STATE(3354)] = 83603,
  [SMALL_STATE(3355)] = 83665,
  [SMALL_STATE(3356)] = 83763,
  [SMALL_STATE(3357)] = 83825,
  [SMALL_STATE(3358)] = 83895,
  [SMALL_STATE(3359)] = 83965,
  [SMALL_STATE(3360)] = 84027,
  [SMALL_STATE(3361)] = 84089,
  [SMALL_STATE(3362)] = 84155,
  [SMALL_STATE(3363)] = 84221,
  [SMALL_STATE(3364)] = 84325,
  [SMALL_STATE(3365)] = 84387,
  [SMALL_STATE(3366)] = 84449,
  [SMALL_STATE(3367)] = 84511,
  [SMALL_STATE(3368)] = 84581,
  [SMALL_STATE(3369)] = 84643,
  [SMALL_STATE(3370)] = 84749,
  [SMALL_STATE(3371)] = 84811,
  [SMALL_STATE(3372)] = 84877,
  [SMALL_STATE(3373)] = 84939,
  [SMALL_STATE(3374)] = 85001,
  [SMALL_STATE(3375)] = 85063,
  [SMALL_STATE(3376)] = 85125,
  [SMALL_STATE(3377)] = 85187,
  [SMALL_STATE(3378)] = 85249,
  [SMALL_STATE(3379)] = 85311,
  [SMALL_STATE(3380)] = 85377,
  [SMALL_STATE(3381)] = 85439,
  [SMALL_STATE(3382)] = 85501,
  [SMALL_STATE(3383)] = 85605,
  [SMALL_STATE(3384)] = 85709,
  [SMALL_STATE(3385)] = 85771,
  [SMALL_STATE(3386)] = 85841,
  [SMALL_STATE(3387)] = 85903,
  [SMALL_STATE(3388)] = 85965,
  [SMALL_STATE(3389)] = 86027,
  [SMALL_STATE(3390)] = 86095,
  [SMALL_STATE(3391)] = 86157,
  [SMALL_STATE(3392)] = 86219,
  [SMALL_STATE(3393)] = 86281,
  [SMALL_STATE(3394)] = 86343,
  [SMALL_STATE(3395)] = 86405,
  [SMALL_STATE(3396)] = 86467,
  [SMALL_STATE(3397)] = 86529,
  [SMALL_STATE(3398)] = 86591,
  [SMALL_STATE(3399)] = 86653,
  [SMALL_STATE(3400)] = 86715,
  [SMALL_STATE(3401)] = 86777,
  [SMALL_STATE(3402)] = 86881,
  [SMALL_STATE(3403)] = 86943,
  [SMALL_STATE(3404)] = 87005,
  [SMALL_STATE(3405)] = 87123,
  [SMALL_STATE(3406)] = 87185,
  [SMALL_STATE(3407)] = 87247,
  [SMALL_STATE(3408)] = 87309,
  [SMALL_STATE(3409)] = 87371,
  [SMALL_STATE(3410)] = 87433,
  [SMALL_STATE(3411)] = 87495,
  [SMALL_STATE(3412)] = 87557,
  [SMALL_STATE(3413)] = 87619,
  [SMALL_STATE(3414)] = 87681,
  [SMALL_STATE(3415)] = 87745,
  [SMALL_STATE(3416)] = 87815,
  [SMALL_STATE(3417)] = 87877,
  [SMALL_STATE(3418)] = 87939,
  [SMALL_STATE(3419)] = 88043,
  [SMALL_STATE(3420)] = 88147,
  [SMALL_STATE(3421)] = 88217,
  [SMALL_STATE(3422)] = 88279,
  [SMALL_STATE(3423)] = 88341,
  [SMALL_STATE(3424)] = 88403,
  [SMALL_STATE(3425)] = 88473,
  [SMALL_STATE(3426)] = 88535,
  [SMALL_STATE(3427)] = 88605,
  [SMALL_STATE(3428)] = 88667,
  [SMALL_STATE(3429)] = 88729,
  [SMALL_STATE(3430)] = 88791,
  [SMALL_STATE(3431)] = 88853,
  [SMALL_STATE(3432)] = 88915,
  [SMALL_STATE(3433)] = 88977,
  [SMALL_STATE(3434)] = 89039,
  [SMALL_STATE(3435)] = 89101,
  [SMALL_STATE(3436)] = 89163,
  [SMALL_STATE(3437)] = 89225,
  [SMALL_STATE(3438)] = 89287,
  [SMALL_STATE(3439)] = 89349,
  [SMALL_STATE(3440)] = 89426,
  [SMALL_STATE(3441)] = 89493,
  [SMALL_STATE(3442)] = 89558,
  [SMALL_STATE(3443)] = 89625,
  [SMALL_STATE(3444)] = 89688,
  [SMALL_STATE(3445)] = 89753,
  [SMALL_STATE(3446)] = 89820,
  [SMALL_STATE(3447)] = 89887,
  [SMALL_STATE(3448)] = 89954,
  [SMALL_STATE(3449)] = 90021,
  [SMALL_STATE(3450)] = 90086,
  [SMALL_STATE(3451)] = 90161,
  [SMALL_STATE(3452)] = 90236,
  [SMALL_STATE(3453)] = 90305,
  [SMALL_STATE(3454)] = 90374,
  [SMALL_STATE(3455)] = 90441,
  [SMALL_STATE(3456)] = 90518,
  [SMALL_STATE(3457)] = 90591,
  [SMALL_STATE(3458)] = 90694,
  [SMALL_STATE(3459)] = 90761,
  [SMALL_STATE(3460)] = 90870,
  [SMALL_STATE(3461)] = 90933,
  [SMALL_STATE(3462)] = 90994,
  [SMALL_STATE(3463)] = 91097,
  [SMALL_STATE(3464)] = 91174,
  [SMALL_STATE(3465)] = 91247,
  [SMALL_STATE(3466)] = 91316,
  [SMALL_STATE(3467)] = 91383,
  [SMALL_STATE(3468)] = 91486,
  [SMALL_STATE(3469)] = 91559,
  [SMALL_STATE(3470)] = 91624,
  [SMALL_STATE(3471)] = 91687,
  [SMALL_STATE(3472)] = 91762,
  [SMALL_STATE(3473)] = 91837,
  [SMALL_STATE(3474)] = 91914,
  [SMALL_STATE(3475)] = 92021,
  [SMALL_STATE(3476)] = 92098,
  [SMALL_STATE(3477)] = 92171,
  [SMALL_STATE(3478)] = 92238,
  [SMALL_STATE(3479)] = 92305,
  [SMALL_STATE(3480)] = 92374,
  [SMALL_STATE(3481)] = 92477,
  [SMALL_STATE(3482)] = 92550,
  [SMALL_STATE(3483)] = 92617,
  [SMALL_STATE(3484)] = 92684,
  [SMALL_STATE(3485)] = 92757,
  [SMALL_STATE(3486)] = 92834,
  [SMALL_STATE(3487)] = 92907,
  [SMALL_STATE(3488)] = 92980,
  [SMALL_STATE(3489)] = 93083,
  [SMALL_STATE(3490)] = 93156,
  [SMALL_STATE(3491)] = 93223,
  [SMALL_STATE(3492)] = 93292,
  [SMALL_STATE(3493)] = 93365,
  [SMALL_STATE(3494)] = 93430,
  [SMALL_STATE(3495)] = 93497,
  [SMALL_STATE(3496)] = 93564,
  [SMALL_STATE(3497)] = 93631,
  [SMALL_STATE(3498)] = 93704,
  [SMALL_STATE(3499)] = 93773,
  [SMALL_STATE(3500)] = 93840,
  [SMALL_STATE(3501)] = 93909,
  [SMALL_STATE(3502)] = 94012,
  [SMALL_STATE(3503)] = 94079,
  [SMALL_STATE(3504)] = 94148,
  [SMALL_STATE(3505)] = 94215,
  [SMALL_STATE(3506)] = 94282,
  [SMALL_STATE(3507)] = 94349,
  [SMALL_STATE(3508)] = 94414,
  [SMALL_STATE(3509)] = 94481,
  [SMALL_STATE(3510)] = 94550,
  [SMALL_STATE(3511)] = 94617,
  [SMALL_STATE(3512)] = 94686,
  [SMALL_STATE(3513)] = 94751,
  [SMALL_STATE(3514)] = 94818,
  [SMALL_STATE(3515)] = 94881,
  [SMALL_STATE(3516)] = 94946,
  [SMALL_STATE(3517)] = 95015,
  [SMALL_STATE(3518)] = 95082,
  [SMALL_STATE(3519)] = 95149,
  [SMALL_STATE(3520)] = 95218,
  [SMALL_STATE(3521)] = 95285,
  [SMALL_STATE(3522)] = 95352,
  [SMALL_STATE(3523)] = 95455,
  [SMALL_STATE(3524)] = 95528,
  [SMALL_STATE(3525)] = 95588,
  [SMALL_STATE(3526)] = 95648,
  [SMALL_STATE(3527)] = 95708,
  [SMALL_STATE(3528)] = 95768,
  [SMALL_STATE(3529)] = 95828,
  [SMALL_STATE(3530)] = 95888,
  [SMALL_STATE(3531)] = 95948,
  [SMALL_STATE(3532)] = 96008,
  [SMALL_STATE(3533)] = 96112,
  [SMALL_STATE(3534)] = 96176,
  [SMALL_STATE(3535)] = 96240,
  [SMALL_STATE(3536)] = 96304,
  [SMALL_STATE(3537)] = 96364,
  [SMALL_STATE(3538)] = 96424,
  [SMALL_STATE(3539)] = 96484,
  [SMALL_STATE(3540)] = 96544,
  [SMALL_STATE(3541)] = 96604,
  [SMALL_STATE(3542)] = 96664,
  [SMALL_STATE(3543)] = 96728,
  [SMALL_STATE(3544)] = 96788,
  [SMALL_STATE(3545)] = 96848,
  [SMALL_STATE(3546)] = 96908,
  [SMALL_STATE(3547)] = 96968,
  [SMALL_STATE(3548)] = 97028,
  [SMALL_STATE(3549)] = 97088,
  [SMALL_STATE(3550)] = 97148,
  [SMALL_STATE(3551)] = 97208,
  [SMALL_STATE(3552)] = 97268,
  [SMALL_STATE(3553)] = 97328,
  [SMALL_STATE(3554)] = 97388,
  [SMALL_STATE(3555)] = 97448,
  [SMALL_STATE(3556)] = 97508,
  [SMALL_STATE(3557)] = 97568,
  [SMALL_STATE(3558)] = 97628,
  [SMALL_STATE(3559)] = 97688,
  [SMALL_STATE(3560)] = 97748,
  [SMALL_STATE(3561)] = 97808,
  [SMALL_STATE(3562)] = 97868,
  [SMALL_STATE(3563)] = 97928,
  [SMALL_STATE(3564)] = 97988,
  [SMALL_STATE(3565)] = 98048,
  [SMALL_STATE(3566)] = 98108,
  [SMALL_STATE(3567)] = 98168,
  [SMALL_STATE(3568)] = 98228,
  [SMALL_STATE(3569)] = 98294,
  [SMALL_STATE(3570)] = 98358,
  [SMALL_STATE(3571)] = 98418,
  [SMALL_STATE(3572)] = 98482,
  [SMALL_STATE(3573)] = 98542,
  [SMALL_STATE(3574)] = 98602,
  [SMALL_STATE(3575)] = 98666,
  [SMALL_STATE(3576)] = 98778,
  [SMALL_STATE(3577)] = 98838,
  [SMALL_STATE(3578)] = 98898,
  [SMALL_STATE(3579)] = 98964,
  [SMALL_STATE(3580)] = 99030,
  [SMALL_STATE(3581)] = 99096,
  [SMALL_STATE(3582)] = 99156,
  [SMALL_STATE(3583)] = 99216,
  [SMALL_STATE(3584)] = 99280,
  [SMALL_STATE(3585)] = 99340,
  [SMALL_STATE(3586)] = 99400,
  [SMALL_STATE(3587)] = 99466,
  [SMALL_STATE(3588)] = 99534,
  [SMALL_STATE(3589)] = 99594,
  [SMALL_STATE(3590)] = 99660,
  [SMALL_STATE(3591)] = 99726,
  [SMALL_STATE(3592)] = 99786,
  [SMALL_STATE(3593)] = 99854,
  [SMALL_STATE(3594)] = 99914,
  [SMALL_STATE(3595)] = 99974,
  [SMALL_STATE(3596)] = 100040,
  [SMALL_STATE(3597)] = 100104,
  [SMALL_STATE(3598)] = 100164,
  [SMALL_STATE(3599)] = 100224,
  [SMALL_STATE(3600)] = 100284,
  [SMALL_STATE(3601)] = 100344,
  [SMALL_STATE(3602)] = 100404,
  [SMALL_STATE(3603)] = 100464,
  [SMALL_STATE(3604)] = 100524,
  [SMALL_STATE(3605)] = 100584,
  [SMALL_STATE(3606)] = 100648,
  [SMALL_STATE(3607)] = 100712,
  [SMALL_STATE(3608)] = 100772,
  [SMALL_STATE(3609)] = 100832,
  [SMALL_STATE(3610)] = 100892,
  [SMALL_STATE(3611)] = 100952,
  [SMALL_STATE(3612)] = 101012,
  [SMALL_STATE(3613)] = 101072,
  [SMALL_STATE(3614)] = 101132,
  [SMALL_STATE(3615)] = 101192,
  [SMALL_STATE(3616)] = 101256,
  [SMALL_STATE(3617)] = 101320,
  [SMALL_STATE(3618)] = 101380,
  [SMALL_STATE(3619)] = 101440,
  [SMALL_STATE(3620)] = 101500,
  [SMALL_STATE(3621)] = 101560,
  [SMALL_STATE(3622)] = 101620,
  [SMALL_STATE(3623)] = 101682,
  [SMALL_STATE(3624)] = 101742,
  [SMALL_STATE(3625)] = 101802,
  [SMALL_STATE(3626)] = 101862,
  [SMALL_STATE(3627)] = 101922,
  [SMALL_STATE(3628)] = 101982,
  [SMALL_STATE(3629)] = 102042,
  [SMALL_STATE(3630)] = 102102,
  [SMALL_STATE(3631)] = 102162,
  [SMALL_STATE(3632)] = 102222,
  [SMALL_STATE(3633)] = 102282,
  [SMALL_STATE(3634)] = 102366,
  [SMALL_STATE(3635)] = 102472,
  [SMALL_STATE(3636)] = 102538,
  [SMALL_STATE(3637)] = 102602,
  [SMALL_STATE(3638)] = 102674,
  [SMALL_STATE(3639)] = 102734,
  [SMALL_STATE(3640)] = 102816,
  [SMALL_STATE(3641)] = 102896,
  [SMALL_STATE(3642)] = 102956,
  [SMALL_STATE(3643)] = 103016,
  [SMALL_STATE(3644)] = 103076,
  [SMALL_STATE(3645)] = 103136,
  [SMALL_STATE(3646)] = 103196,
  [SMALL_STATE(3647)] = 103290,
  [SMALL_STATE(3648)] = 103354,
  [SMALL_STATE(3649)] = 103446,
  [SMALL_STATE(3650)] = 103534,
  [SMALL_STATE(3651)] = 103620,
  [SMALL_STATE(3652)] = 103698,
  [SMALL_STATE(3653)] = 103774,
  [SMALL_STATE(3654)] = 103842,
  [SMALL_STATE(3655)] = 103902,
  [SMALL_STATE(3656)] = 103962,
  [SMALL_STATE(3657)] = 104022,
  [SMALL_STATE(3658)] = 104126,
  [SMALL_STATE(3659)] = 104186,
  [SMALL_STATE(3660)] = 104246,
  [SMALL_STATE(3661)] = 104306,
  [SMALL_STATE(3662)] = 104366,
  [SMALL_STATE(3663)] = 104426,
  [SMALL_STATE(3664)] = 104494,
  [SMALL_STATE(3665)] = 104554,
  [SMALL_STATE(3666)] = 104614,
  [SMALL_STATE(3667)] = 104674,
  [SMALL_STATE(3668)] = 104734,
  [SMALL_STATE(3669)] = 104800,
  [SMALL_STATE(3670)] = 104864,
  [SMALL_STATE(3671)] = 104928,
  [SMALL_STATE(3672)] = 104992,
  [SMALL_STATE(3673)] = 105052,
  [SMALL_STATE(3674)] = 105112,
  [SMALL_STATE(3675)] = 105172,
  [SMALL_STATE(3676)] = 105232,
  [SMALL_STATE(3677)] = 105292,
  [SMALL_STATE(3678)] = 105352,
  [SMALL_STATE(3679)] = 105412,
  [SMALL_STATE(3680)] = 105472,
  [SMALL_STATE(3681)] = 105540,
  [SMALL_STATE(3682)] = 105602,
  [SMALL_STATE(3683)] = 105668,
  [SMALL_STATE(3684)] = 105728,
  [SMALL_STATE(3685)] = 105792,
  [SMALL_STATE(3686)] = 105898,
  [SMALL_STATE(3687)] = 105962,
  [SMALL_STATE(3688)] = 106022,
  [SMALL_STATE(3689)] = 106082,
  [SMALL_STATE(3690)] = 106142,
  [SMALL_STATE(3691)] = 106204,
  [SMALL_STATE(3692)] = 106264,
  [SMALL_STATE(3693)] = 106324,
  [SMALL_STATE(3694)] = 106384,
  [SMALL_STATE(3695)] = 106444,
  [SMALL_STATE(3696)] = 106504,
  [SMALL_STATE(3697)] = 106564,
  [SMALL_STATE(3698)] = 106624,
  [SMALL_STATE(3699)] = 106684,
  [SMALL_STATE(3700)] = 106744,
  [SMALL_STATE(3701)] = 106804,
  [SMALL_STATE(3702)] = 106908,
  [SMALL_STATE(3703)] = 107004,
  [SMALL_STATE(3704)] = 107064,
  [SMALL_STATE(3705)] = 107126,
  [SMALL_STATE(3706)] = 107186,
  [SMALL_STATE(3707)] = 107246,
  [SMALL_STATE(3708)] = 107310,
  [SMALL_STATE(3709)] = 107370,
  [SMALL_STATE(3710)] = 107430,
  [SMALL_STATE(3711)] = 107494,
  [SMALL_STATE(3712)] = 107554,
  [SMALL_STATE(3713)] = 107613,
  [SMALL_STATE(3714)] = 107678,
  [SMALL_STATE(3715)] = 107737,
  [SMALL_STATE(3716)] = 107796,
  [SMALL_STATE(3717)] = 107855,
  [SMALL_STATE(3718)] = 107956,
  [SMALL_STATE(3719)] = 108017,
  [SMALL_STATE(3720)] = 108076,
  [SMALL_STATE(3721)] = 108135,
  [SMALL_STATE(3722)] = 108236,
  [SMALL_STATE(3723)] = 108295,
  [SMALL_STATE(3724)] = 108396,
  [SMALL_STATE(3725)] = 108455,
  [SMALL_STATE(3726)] = 108522,
  [SMALL_STATE(3727)] = 108581,
  [SMALL_STATE(3728)] = 108640,
  [SMALL_STATE(3729)] = 108701,
  [SMALL_STATE(3730)] = 108760,
  [SMALL_STATE(3731)] = 108819,
  [SMALL_STATE(3732)] = 108878,
  [SMALL_STATE(3733)] = 108937,
  [SMALL_STATE(3734)] = 109038,
  [SMALL_STATE(3735)] = 109097,
  [SMALL_STATE(3736)] = 109156,
  [SMALL_STATE(3737)] = 109215,
  [SMALL_STATE(3738)] = 109278,
  [SMALL_STATE(3739)] = 109379,
  [SMALL_STATE(3740)] = 109438,
  [SMALL_STATE(3741)] = 109501,
  [SMALL_STATE(3742)] = 109568,
  [SMALL_STATE(3743)] = 109627,
  [SMALL_STATE(3744)] = 109688,
  [SMALL_STATE(3745)] = 109747,
  [SMALL_STATE(3746)] = 109814,
  [SMALL_STATE(3747)] = 109881,
  [SMALL_STATE(3748)] = 109948,
  [SMALL_STATE(3749)] = 110049,
  [SMALL_STATE(3750)] = 110108,
  [SMALL_STATE(3751)] = 110175,
  [SMALL_STATE(3752)] = 110234,
  [SMALL_STATE(3753)] = 110293,
  [SMALL_STATE(3754)] = 110352,
  [SMALL_STATE(3755)] = 110411,
  [SMALL_STATE(3756)] = 110470,
  [SMALL_STATE(3757)] = 110533,
  [SMALL_STATE(3758)] = 110592,
  [SMALL_STATE(3759)] = 110651,
  [SMALL_STATE(3760)] = 110718,
  [SMALL_STATE(3761)] = 110781,
  [SMALL_STATE(3762)] = 110840,
  [SMALL_STATE(3763)] = 110907,
  [SMALL_STATE(3764)] = 110966,
  [SMALL_STATE(3765)] = 111025,
  [SMALL_STATE(3766)] = 111090,
  [SMALL_STATE(3767)] = 111157,
  [SMALL_STATE(3768)] = 111216,
  [SMALL_STATE(3769)] = 111275,
  [SMALL_STATE(3770)] = 111334,
  [SMALL_STATE(3771)] = 111401,
  [SMALL_STATE(3772)] = 111466,
  [SMALL_STATE(3773)] = 111525,
  [SMALL_STATE(3774)] = 111584,
  [SMALL_STATE(3775)] = 111643,
  [SMALL_STATE(3776)] = 111702,
  [SMALL_STATE(3777)] = 111761,
  [SMALL_STATE(3778)] = 111820,
  [SMALL_STATE(3779)] = 111879,
  [SMALL_STATE(3780)] = 111938,
  [SMALL_STATE(3781)] = 111997,
  [SMALL_STATE(3782)] = 112056,
  [SMALL_STATE(3783)] = 112115,
  [SMALL_STATE(3784)] = 112174,
  [SMALL_STATE(3785)] = 112233,
  [SMALL_STATE(3786)] = 112334,
  [SMALL_STATE(3787)] = 112393,
  [SMALL_STATE(3788)] = 112452,
  [SMALL_STATE(3789)] = 112511,
  [SMALL_STATE(3790)] = 112570,
  [SMALL_STATE(3791)] = 112629,
  [SMALL_STATE(3792)] = 112688,
  [SMALL_STATE(3793)] = 112751,
  [SMALL_STATE(3794)] = 112818,
  [SMALL_STATE(3795)] = 112877,
  [SMALL_STATE(3796)] = 112936,
  [SMALL_STATE(3797)] = 113003,
  [SMALL_STATE(3798)] = 113061,
  [SMALL_STATE(3799)] = 113119,
  [SMALL_STATE(3800)] = 113177,
  [SMALL_STATE(3801)] = 113235,
  [SMALL_STATE(3802)] = 113293,
  [SMALL_STATE(3803)] = 113351,
  [SMALL_STATE(3804)] = 113409,
  [SMALL_STATE(3805)] = 113473,
  [SMALL_STATE(3806)] = 113531,
  [SMALL_STATE(3807)] = 113589,
  [SMALL_STATE(3808)] = 113647,
  [SMALL_STATE(3809)] = 113705,
  [SMALL_STATE(3810)] = 113805,
  [SMALL_STATE(3811)] = 113863,
  [SMALL_STATE(3812)] = 113963,
  [SMALL_STATE(3813)] = 114021,
  [SMALL_STATE(3814)] = 114079,
  [SMALL_STATE(3815)] = 114139,
  [SMALL_STATE(3816)] = 114197,
  [SMALL_STATE(3817)] = 114257,
  [SMALL_STATE(3818)] = 114315,
  [SMALL_STATE(3819)] = 114423,
  [SMALL_STATE(3820)] = 114481,
  [SMALL_STATE(3821)] = 114539,
  [SMALL_STATE(3822)] = 114597,
  [SMALL_STATE(3823)] = 114655,
  [SMALL_STATE(3824)] = 114713,
  [SMALL_STATE(3825)] = 114771,
  [SMALL_STATE(3826)] = 114835,
  [SMALL_STATE(3827)] = 114893,
  [SMALL_STATE(3828)] = 114951,
  [SMALL_STATE(3829)] = 115009,
  [SMALL_STATE(3830)] = 115067,
  [SMALL_STATE(3831)] = 115167,
  [SMALL_STATE(3832)] = 115225,
  [SMALL_STATE(3833)] = 115287,
  [SMALL_STATE(3834)] = 115387,
  [SMALL_STATE(3835)] = 115487,
  [SMALL_STATE(3836)] = 115545,
  [SMALL_STATE(3837)] = 115603,
  [SMALL_STATE(3838)] = 115703,
  [SMALL_STATE(3839)] = 115803,
  [SMALL_STATE(3840)] = 115861,
  [SMALL_STATE(3841)] = 115961,
  [SMALL_STATE(3842)] = 116019,
  [SMALL_STATE(3843)] = 116119,
  [SMALL_STATE(3844)] = 116177,
  [SMALL_STATE(3845)] = 116241,
  [SMALL_STATE(3846)] = 116301,
  [SMALL_STATE(3847)] = 116363,
  [SMALL_STATE(3848)] = 116425,
  [SMALL_STATE(3849)] = 116483,
  [SMALL_STATE(3850)] = 116583,
  [SMALL_STATE(3851)] = 116683,
  [SMALL_STATE(3852)] = 116741,
  [SMALL_STATE(3853)] = 116799,
  [SMALL_STATE(3854)] = 116899,
  [SMALL_STATE(3855)] = 116957,
  [SMALL_STATE(3856)] = 117015,
  [SMALL_STATE(3857)] = 117079,
  [SMALL_STATE(3858)] = 117137,
  [SMALL_STATE(3859)] = 117199,
  [SMALL_STATE(3860)] = 117257,
  [SMALL_STATE(3861)] = 117357,
  [SMALL_STATE(3862)] = 117415,
  [SMALL_STATE(3863)] = 117487,
  [SMALL_STATE(3864)] = 117545,
  [SMALL_STATE(3865)] = 117603,
  [SMALL_STATE(3866)] = 117667,
  [SMALL_STATE(3867)] = 117739,
  [SMALL_STATE(3868)] = 117797,
  [SMALL_STATE(3869)] = 117871,
  [SMALL_STATE(3870)] = 117941,
  [SMALL_STATE(3871)] = 117999,
  [SMALL_STATE(3872)] = 118057,
  [SMALL_STATE(3873)] = 118115,
  [SMALL_STATE(3874)] = 118189,
  [SMALL_STATE(3875)] = 118259,
  [SMALL_STATE(3876)] = 118317,
  [SMALL_STATE(3877)] = 118375,
  [SMALL_STATE(3878)] = 118445,
  [SMALL_STATE(3879)] = 118503,
  [SMALL_STATE(3880)] = 118561,
  [SMALL_STATE(3881)] = 118619,
  [SMALL_STATE(3882)] = 118677,
  [SMALL_STATE(3883)] = 118735,
  [SMALL_STATE(3884)] = 118793,
  [SMALL_STATE(3885)] = 118851,
  [SMALL_STATE(3886)] = 118909,
  [SMALL_STATE(3887)] = 118967,
  [SMALL_STATE(3888)] = 119041,
  [SMALL_STATE(3889)] = 119099,
  [SMALL_STATE(3890)] = 119199,
  [SMALL_STATE(3891)] = 119257,
  [SMALL_STATE(3892)] = 119315,
  [SMALL_STATE(3893)] = 119385,
  [SMALL_STATE(3894)] = 119443,
  [SMALL_STATE(3895)] = 119501,
  [SMALL_STATE(3896)] = 119609,
  [SMALL_STATE(3897)] = 119667,
  [SMALL_STATE(3898)] = 119725,
  [SMALL_STATE(3899)] = 119795,
  [SMALL_STATE(3900)] = 119865,
  [SMALL_STATE(3901)] = 119923,
  [SMALL_STATE(3902)] = 119981,
  [SMALL_STATE(3903)] = 120039,
  [SMALL_STATE(3904)] = 120097,
  [SMALL_STATE(3905)] = 120155,
  [SMALL_STATE(3906)] = 120213,
  [SMALL_STATE(3907)] = 120271,
  [SMALL_STATE(3908)] = 120329,
  [SMALL_STATE(3909)] = 120387,
  [SMALL_STATE(3910)] = 120445,
  [SMALL_STATE(3911)] = 120503,
  [SMALL_STATE(3912)] = 120565,
  [SMALL_STATE(3913)] = 120623,
  [SMALL_STATE(3914)] = 120687,
  [SMALL_STATE(3915)] = 120745,
  [SMALL_STATE(3916)] = 120845,
  [SMALL_STATE(3917)] = 120903,
  [SMALL_STATE(3918)] = 120961,
  [SMALL_STATE(3919)] = 121019,
  [SMALL_STATE(3920)] = 121077,
  [SMALL_STATE(3921)] = 121135,
  [SMALL_STATE(3922)] = 121197,
  [SMALL_STATE(3923)] = 121261,
  [SMALL_STATE(3924)] = 121319,
  [SMALL_STATE(3925)] = 121377,
  [SMALL_STATE(3926)] = 121435,
  [SMALL_STATE(3927)] = 121493,
  [SMALL_STATE(3928)] = 121551,
  [SMALL_STATE(3929)] = 121609,
  [SMALL_STATE(3930)] = 121667,
  [SMALL_STATE(3931)] = 121725,
  [SMALL_STATE(3932)] = 121783,
  [SMALL_STATE(3933)] = 121883,
  [SMALL_STATE(3934)] = 121941,
  [SMALL_STATE(3935)] = 122003,
  [SMALL_STATE(3936)] = 122061,
  [SMALL_STATE(3937)] = 122161,
  [SMALL_STATE(3938)] = 122219,
  [SMALL_STATE(3939)] = 122277,
  [SMALL_STATE(3940)] = 122335,
  [SMALL_STATE(3941)] = 122393,
  [SMALL_STATE(3942)] = 122451,
  [SMALL_STATE(3943)] = 122509,
  [SMALL_STATE(3944)] = 122567,
  [SMALL_STATE(3945)] = 122631,
  [SMALL_STATE(3946)] = 122689,
  [SMALL_STATE(3947)] = 122753,
  [SMALL_STATE(3948)] = 122811,
  [SMALL_STATE(3949)] = 122875,
  [SMALL_STATE(3950)] = 122933,
  [SMALL_STATE(3951)] = 122991,
  [SMALL_STATE(3952)] = 123049,
  [SMALL_STATE(3953)] = 123107,
  [SMALL_STATE(3954)] = 123171,
  [SMALL_STATE(3955)] = 123229,
  [SMALL_STATE(3956)] = 123287,
  [SMALL_STATE(3957)] = 123351,
  [SMALL_STATE(3958)] = 123409,
  [SMALL_STATE(3959)] = 123467,
  [SMALL_STATE(3960)] = 123525,
  [SMALL_STATE(3961)] = 123589,
  [SMALL_STATE(3962)] = 123653,
  [SMALL_STATE(3963)] = 123711,
  [SMALL_STATE(3964)] = 123769,
  [SMALL_STATE(3965)] = 123831,
  [SMALL_STATE(3966)] = 123889,
  [SMALL_STATE(3967)] = 123989,
  [SMALL_STATE(3968)] = 124053,
  [SMALL_STATE(3969)] = 124153,
  [SMALL_STATE(3970)] = 124217,
  [SMALL_STATE(3971)] = 124277,
  [SMALL_STATE(3972)] = 124335,
  [SMALL_STATE(3973)] = 124393,
  [SMALL_STATE(3974)] = 124457,
  [SMALL_STATE(3975)] = 124515,
  [SMALL_STATE(3976)] = 124573,
  [SMALL_STATE(3977)] = 124631,
  [SMALL_STATE(3978)] = 124689,
  [SMALL_STATE(3979)] = 124747,
  [SMALL_STATE(3980)] = 124805,
  [SMALL_STATE(3981)] = 124863,
  [SMALL_STATE(3982)] = 124925,
  [SMALL_STATE(3983)] = 124983,
  [SMALL_STATE(3984)] = 125041,
  [SMALL_STATE(3985)] = 125099,
  [SMALL_STATE(3986)] = 125157,
  [SMALL_STATE(3987)] = 125215,
  [SMALL_STATE(3988)] = 125273,
  [SMALL_STATE(3989)] = 125331,
  [SMALL_STATE(3990)] = 125389,
  [SMALL_STATE(3991)] = 125447,
  [SMALL_STATE(3992)] = 125505,
  [SMALL_STATE(3993)] = 125563,
  [SMALL_STATE(3994)] = 125621,
  [SMALL_STATE(3995)] = 125679,
  [SMALL_STATE(3996)] = 125737,
  [SMALL_STATE(3997)] = 125795,
  [SMALL_STATE(3998)] = 125857,
  [SMALL_STATE(3999)] = 125915,
  [SMALL_STATE(4000)] = 126015,
  [SMALL_STATE(4001)] = 126073,
  [SMALL_STATE(4002)] = 126135,
  [SMALL_STATE(4003)] = 126199,
  [SMALL_STATE(4004)] = 126299,
  [SMALL_STATE(4005)] = 126357,
  [SMALL_STATE(4006)] = 126415,
  [SMALL_STATE(4007)] = 126473,
  [SMALL_STATE(4008)] = 126531,
  [SMALL_STATE(4009)] = 126589,
  [SMALL_STATE(4010)] = 126647,
  [SMALL_STATE(4011)] = 126705,
  [SMALL_STATE(4012)] = 126763,
  [SMALL_STATE(4013)] = 126825,
  [SMALL_STATE(4014)] = 126883,
  [SMALL_STATE(4015)] = 126945,
  [SMALL_STATE(4016)] = 127003,
  [SMALL_STATE(4017)] = 127066,
  [SMALL_STATE(4018)] = 127123,
  [SMALL_STATE(4019)] = 127180,
  [SMALL_STATE(4020)] = 127237,
  [SMALL_STATE(4021)] = 127294,
  [SMALL_STATE(4022)] = 127351,
  [SMALL_STATE(4023)] = 127412,
  [SMALL_STATE(4024)] = 127469,
  [SMALL_STATE(4025)] = 127526,
  [SMALL_STATE(4026)] = 127587,
  [SMALL_STATE(4027)] = 127644,
  [SMALL_STATE(4028)] = 127701,
  [SMALL_STATE(4029)] = 127758,
  [SMALL_STATE(4030)] = 127815,
  [SMALL_STATE(4031)] = 127872,
  [SMALL_STATE(4032)] = 127933,
  [SMALL_STATE(4033)] = 127994,
  [SMALL_STATE(4034)] = 128051,
  [SMALL_STATE(4035)] = 128112,
  [SMALL_STATE(4036)] = 128169,
  [SMALL_STATE(4037)] = 128226,
  [SMALL_STATE(4038)] = 128283,
  [SMALL_STATE(4039)] = 128340,
  [SMALL_STATE(4040)] = 128399,
  [SMALL_STATE(4041)] = 128456,
  [SMALL_STATE(4042)] = 128513,
  [SMALL_STATE(4043)] = 128612,
  [SMALL_STATE(4044)] = 128711,
  [SMALL_STATE(4045)] = 128810,
  [SMALL_STATE(4046)] = 128867,
  [SMALL_STATE(4047)] = 128924,
  [SMALL_STATE(4048)] = 129025,
  [SMALL_STATE(4049)] = 129124,
  [SMALL_STATE(4050)] = 129223,
  [SMALL_STATE(4051)] = 129322,
  [SMALL_STATE(4052)] = 129421,
  [SMALL_STATE(4053)] = 129480,
  [SMALL_STATE(4054)] = 129573,
  [SMALL_STATE(4055)] = 129634,
  [SMALL_STATE(4056)] = 129699,
  [SMALL_STATE(4057)] = 129756,
  [SMALL_STATE(4058)] = 129813,
  [SMALL_STATE(4059)] = 129870,
  [SMALL_STATE(4060)] = 129941,
  [SMALL_STATE(4061)] = 130012,
  [SMALL_STATE(4062)] = 130085,
  [SMALL_STATE(4063)] = 130154,
  [SMALL_STATE(4064)] = 130227,
  [SMALL_STATE(4065)] = 130296,
  [SMALL_STATE(4066)] = 130365,
  [SMALL_STATE(4067)] = 130438,
  [SMALL_STATE(4068)] = 130507,
  [SMALL_STATE(4069)] = 130576,
  [SMALL_STATE(4070)] = 130645,
  [SMALL_STATE(4071)] = 130702,
  [SMALL_STATE(4072)] = 130763,
  [SMALL_STATE(4073)] = 130824,
  [SMALL_STATE(4074)] = 130887,
  [SMALL_STATE(4075)] = 130944,
  [SMALL_STATE(4076)] = 131001,
  [SMALL_STATE(4077)] = 131058,
  [SMALL_STATE(4078)] = 131115,
  [SMALL_STATE(4079)] = 131172,
  [SMALL_STATE(4080)] = 131237,
  [SMALL_STATE(4081)] = 131294,
  [SMALL_STATE(4082)] = 131351,
  [SMALL_STATE(4083)] = 131412,
  [SMALL_STATE(4084)] = 131515,
  [SMALL_STATE(4085)] = 131572,
  [SMALL_STATE(4086)] = 131629,
  [SMALL_STATE(4087)] = 131690,
  [SMALL_STATE(4088)] = 131751,
  [SMALL_STATE(4089)] = 131812,
  [SMALL_STATE(4090)] = 131869,
  [SMALL_STATE(4091)] = 131926,
  [SMALL_STATE(4092)] = 131983,
  [SMALL_STATE(4093)] = 132044,
  [SMALL_STATE(4094)] = 132145,
  [SMALL_STATE(4095)] = 132202,
  [SMALL_STATE(4096)] = 132261,
  [SMALL_STATE(4097)] = 132318,
  [SMALL_STATE(4098)] = 132375,
  [SMALL_STATE(4099)] = 132432,
  [SMALL_STATE(4100)] = 132489,
  [SMALL_STATE(4101)] = 132546,
  [SMALL_STATE(4102)] = 132603,
  [SMALL_STATE(4103)] = 132660,
  [SMALL_STATE(4104)] = 132717,
  [SMALL_STATE(4105)] = 132774,
  [SMALL_STATE(4106)] = 132831,
  [SMALL_STATE(4107)] = 132924,
  [SMALL_STATE(4108)] = 132985,
  [SMALL_STATE(4109)] = 133042,
  [SMALL_STATE(4110)] = 133099,
  [SMALL_STATE(4111)] = 133156,
  [SMALL_STATE(4112)] = 133213,
  [SMALL_STATE(4113)] = 133278,
  [SMALL_STATE(4114)] = 133335,
  [SMALL_STATE(4115)] = 133396,
  [SMALL_STATE(4116)] = 133453,
  [SMALL_STATE(4117)] = 133518,
  [SMALL_STATE(4118)] = 133599,
  [SMALL_STATE(4119)] = 133656,
  [SMALL_STATE(4120)] = 133713,
  [SMALL_STATE(4121)] = 133770,
  [SMALL_STATE(4122)] = 133827,
  [SMALL_STATE(4123)] = 133884,
  [SMALL_STATE(4124)] = 133941,
  [SMALL_STATE(4125)] = 134044,
  [SMALL_STATE(4126)] = 134101,
  [SMALL_STATE(4127)] = 134206,
  [SMALL_STATE(4128)] = 134309,
  [SMALL_STATE(4129)] = 134366,
  [SMALL_STATE(4130)] = 134425,
  [SMALL_STATE(4131)] = 134482,
  [SMALL_STATE(4132)] = 134539,
  [SMALL_STATE(4133)] = 134608,
  [SMALL_STATE(4134)] = 134713,
  [SMALL_STATE(4135)] = 134794,
  [SMALL_STATE(4136)] = 134897,
  [SMALL_STATE(4137)] = 134954,
  [SMALL_STATE(4138)] = 135023,
  [SMALL_STATE(4139)] = 135080,
  [SMALL_STATE(4140)] = 135137,
  [SMALL_STATE(4141)] = 135194,
  [SMALL_STATE(4142)] = 135273,
  [SMALL_STATE(4143)] = 135330,
  [SMALL_STATE(4144)] = 135393,
  [SMALL_STATE(4145)] = 135458,
  [SMALL_STATE(4146)] = 135537,
  [SMALL_STATE(4147)] = 135594,
  [SMALL_STATE(4148)] = 135651,
  [SMALL_STATE(4149)] = 135708,
  [SMALL_STATE(4150)] = 135765,
  [SMALL_STATE(4151)] = 135822,
  [SMALL_STATE(4152)] = 135879,
  [SMALL_STATE(4153)] = 135936,
  [SMALL_STATE(4154)] = 135999,
  [SMALL_STATE(4155)] = 136056,
  [SMALL_STATE(4156)] = 136121,
  [SMALL_STATE(4157)] = 136182,
  [SMALL_STATE(4158)] = 136239,
  [SMALL_STATE(4159)] = 136304,
  [SMALL_STATE(4160)] = 136365,
  [SMALL_STATE(4161)] = 136422,
  [SMALL_STATE(4162)] = 136479,
  [SMALL_STATE(4163)] = 136542,
  [SMALL_STATE(4164)] = 136607,
  [SMALL_STATE(4165)] = 136672,
  [SMALL_STATE(4166)] = 136735,
  [SMALL_STATE(4167)] = 136792,
  [SMALL_STATE(4168)] = 136849,
  [SMALL_STATE(4169)] = 136906,
  [SMALL_STATE(4170)] = 136983,
  [SMALL_STATE(4171)] = 137040,
  [SMALL_STATE(4172)] = 137105,
  [SMALL_STATE(4173)] = 137164,
  [SMALL_STATE(4174)] = 137221,
  [SMALL_STATE(4175)] = 137278,
  [SMALL_STATE(4176)] = 137335,
  [SMALL_STATE(4177)] = 137426,
  [SMALL_STATE(4178)] = 137489,
  [SMALL_STATE(4179)] = 137552,
  [SMALL_STATE(4180)] = 137617,
  [SMALL_STATE(4181)] = 137674,
  [SMALL_STATE(4182)] = 137739,
  [SMALL_STATE(4183)] = 137802,
  [SMALL_STATE(4184)] = 137903,
  [SMALL_STATE(4185)] = 137960,
  [SMALL_STATE(4186)] = 138017,
  [SMALL_STATE(4187)] = 138074,
  [SMALL_STATE(4188)] = 138131,
  [SMALL_STATE(4189)] = 138208,
  [SMALL_STATE(4190)] = 138265,
  [SMALL_STATE(4191)] = 138356,
  [SMALL_STATE(4192)] = 138413,
  [SMALL_STATE(4193)] = 138470,
  [SMALL_STATE(4194)] = 138527,
  [SMALL_STATE(4195)] = 138584,
  [SMALL_STATE(4196)] = 138645,
  [SMALL_STATE(4197)] = 138706,
  [SMALL_STATE(4198)] = 138763,
  [SMALL_STATE(4199)] = 138820,
  [SMALL_STATE(4200)] = 138909,
  [SMALL_STATE(4201)] = 138970,
  [SMALL_STATE(4202)] = 139055,
  [SMALL_STATE(4203)] = 139112,
  [SMALL_STATE(4204)] = 139169,
  [SMALL_STATE(4205)] = 139226,
  [SMALL_STATE(4206)] = 139309,
  [SMALL_STATE(4207)] = 139384,
  [SMALL_STATE(4208)] = 139457,
  [SMALL_STATE(4209)] = 139522,
  [SMALL_STATE(4210)] = 139579,
  [SMALL_STATE(4211)] = 139636,
  [SMALL_STATE(4212)] = 139725,
  [SMALL_STATE(4213)] = 139782,
  [SMALL_STATE(4214)] = 139839,
  [SMALL_STATE(4215)] = 139896,
  [SMALL_STATE(4216)] = 139961,
  [SMALL_STATE(4217)] = 140018,
  [SMALL_STATE(4218)] = 140123,
  [SMALL_STATE(4219)] = 140180,
  [SMALL_STATE(4220)] = 140265,
  [SMALL_STATE(4221)] = 140348,
  [SMALL_STATE(4222)] = 140405,
  [SMALL_STATE(4223)] = 140462,
  [SMALL_STATE(4224)] = 140519,
  [SMALL_STATE(4225)] = 140580,
  [SMALL_STATE(4226)] = 140637,
  [SMALL_STATE(4227)] = 140694,
  [SMALL_STATE(4228)] = 140751,
  [SMALL_STATE(4229)] = 140814,
  [SMALL_STATE(4230)] = 140871,
  [SMALL_STATE(4231)] = 140930,
  [SMALL_STATE(4232)] = 140987,
  [SMALL_STATE(4233)] = 141050,
  [SMALL_STATE(4234)] = 141107,
  [SMALL_STATE(4235)] = 141164,
  [SMALL_STATE(4236)] = 141221,
  [SMALL_STATE(4237)] = 141278,
  [SMALL_STATE(4238)] = 141337,
  [SMALL_STATE(4239)] = 141412,
  [SMALL_STATE(4240)] = 141469,
  [SMALL_STATE(4241)] = 141542,
  [SMALL_STATE(4242)] = 141599,
  [SMALL_STATE(4243)] = 141656,
  [SMALL_STATE(4244)] = 141721,
  [SMALL_STATE(4245)] = 141778,
  [SMALL_STATE(4246)] = 141835,
  [SMALL_STATE(4247)] = 141894,
  [SMALL_STATE(4248)] = 141955,
  [SMALL_STATE(4249)] = 142012,
  [SMALL_STATE(4250)] = 142069,
  [SMALL_STATE(4251)] = 142126,
  [SMALL_STATE(4252)] = 142185,
  [SMALL_STATE(4253)] = 142242,
  [SMALL_STATE(4254)] = 142299,
  [SMALL_STATE(4255)] = 142356,
  [SMALL_STATE(4256)] = 142413,
  [SMALL_STATE(4257)] = 142470,
  [SMALL_STATE(4258)] = 142527,
  [SMALL_STATE(4259)] = 142584,
  [SMALL_STATE(4260)] = 142641,
  [SMALL_STATE(4261)] = 142702,
  [SMALL_STATE(4262)] = 142803,
  [SMALL_STATE(4263)] = 142862,
  [SMALL_STATE(4264)] = 142919,
  [SMALL_STATE(4265)] = 142984,
  [SMALL_STATE(4266)] = 143040,
  [SMALL_STATE(4267)] = 143096,
  [SMALL_STATE(4268)] = 143152,
  [SMALL_STATE(4269)] = 143208,
  [SMALL_STATE(4270)] = 143264,
  [SMALL_STATE(4271)] = 143320,
  [SMALL_STATE(4272)] = 143376,
  [SMALL_STATE(4273)] = 143432,
  [SMALL_STATE(4274)] = 143488,
  [SMALL_STATE(4275)] = 143544,
  [SMALL_STATE(4276)] = 143600,
  [SMALL_STATE(4277)] = 143656,
  [SMALL_STATE(4278)] = 143712,
  [SMALL_STATE(4279)] = 143768,
  [SMALL_STATE(4280)] = 143824,
  [SMALL_STATE(4281)] = 143880,
  [SMALL_STATE(4282)] = 143936,
  [SMALL_STATE(4283)] = 143992,
  [SMALL_STATE(4284)] = 144048,
  [SMALL_STATE(4285)] = 144104,
  [SMALL_STATE(4286)] = 144160,
  [SMALL_STATE(4287)] = 144216,
  [SMALL_STATE(4288)] = 144272,
  [SMALL_STATE(4289)] = 144330,
  [SMALL_STATE(4290)] = 144386,
  [SMALL_STATE(4291)] = 144442,
  [SMALL_STATE(4292)] = 144498,
  [SMALL_STATE(4293)] = 144554,
  [SMALL_STATE(4294)] = 144610,
  [SMALL_STATE(4295)] = 144666,
  [SMALL_STATE(4296)] = 144722,
  [SMALL_STATE(4297)] = 144778,
  [SMALL_STATE(4298)] = 144834,
  [SMALL_STATE(4299)] = 144890,
  [SMALL_STATE(4300)] = 144946,
  [SMALL_STATE(4301)] = 145002,
  [SMALL_STATE(4302)] = 145062,
  [SMALL_STATE(4303)] = 145118,
  [SMALL_STATE(4304)] = 145174,
  [SMALL_STATE(4305)] = 145230,
  [SMALL_STATE(4306)] = 145286,
  [SMALL_STATE(4307)] = 145342,
  [SMALL_STATE(4308)] = 145398,
  [SMALL_STATE(4309)] = 145454,
  [SMALL_STATE(4310)] = 145510,
  [SMALL_STATE(4311)] = 145566,
  [SMALL_STATE(4312)] = 145622,
  [SMALL_STATE(4313)] = 145678,
  [SMALL_STATE(4314)] = 145734,
  [SMALL_STATE(4315)] = 145790,
  [SMALL_STATE(4316)] = 145846,
  [SMALL_STATE(4317)] = 145902,
  [SMALL_STATE(4318)] = 145958,
  [SMALL_STATE(4319)] = 146014,
  [SMALL_STATE(4320)] = 146070,
  [SMALL_STATE(4321)] = 146126,
  [SMALL_STATE(4322)] = 146182,
  [SMALL_STATE(4323)] = 146238,
  [SMALL_STATE(4324)] = 146294,
  [SMALL_STATE(4325)] = 146350,
  [SMALL_STATE(4326)] = 146406,
  [SMALL_STATE(4327)] = 146462,
  [SMALL_STATE(4328)] = 146518,
  [SMALL_STATE(4329)] = 146574,
  [SMALL_STATE(4330)] = 146630,
  [SMALL_STATE(4331)] = 146686,
  [SMALL_STATE(4332)] = 146742,
  [SMALL_STATE(4333)] = 146798,
  [SMALL_STATE(4334)] = 146854,
  [SMALL_STATE(4335)] = 146910,
  [SMALL_STATE(4336)] = 146966,
  [SMALL_STATE(4337)] = 147022,
  [SMALL_STATE(4338)] = 147078,
  [SMALL_STATE(4339)] = 147138,
  [SMALL_STATE(4340)] = 147194,
  [SMALL_STATE(4341)] = 147250,
  [SMALL_STATE(4342)] = 147310,
  [SMALL_STATE(4343)] = 147366,
  [SMALL_STATE(4344)] = 147422,
  [SMALL_STATE(4345)] = 147482,
  [SMALL_STATE(4346)] = 147538,
  [SMALL_STATE(4347)] = 147594,
  [SMALL_STATE(4348)] = 147650,
  [SMALL_STATE(4349)] = 147706,
  [SMALL_STATE(4350)] = 147762,
  [SMALL_STATE(4351)] = 147818,
  [SMALL_STATE(4352)] = 147874,
  [SMALL_STATE(4353)] = 147930,
  [SMALL_STATE(4354)] = 147986,
  [SMALL_STATE(4355)] = 148042,
  [SMALL_STATE(4356)] = 148102,
  [SMALL_STATE(4357)] = 148158,
  [SMALL_STATE(4358)] = 148214,
  [SMALL_STATE(4359)] = 148270,
  [SMALL_STATE(4360)] = 148326,
  [SMALL_STATE(4361)] = 148382,
  [SMALL_STATE(4362)] = 148438,
  [SMALL_STATE(4363)] = 148494,
  [SMALL_STATE(4364)] = 148550,
  [SMALL_STATE(4365)] = 148606,
  [SMALL_STATE(4366)] = 148662,
  [SMALL_STATE(4367)] = 148718,
  [SMALL_STATE(4368)] = 148774,
  [SMALL_STATE(4369)] = 148830,
  [SMALL_STATE(4370)] = 148886,
  [SMALL_STATE(4371)] = 148942,
  [SMALL_STATE(4372)] = 148998,
  [SMALL_STATE(4373)] = 149054,
  [SMALL_STATE(4374)] = 149110,
  [SMALL_STATE(4375)] = 149168,
  [SMALL_STATE(4376)] = 149224,
  [SMALL_STATE(4377)] = 149280,
  [SMALL_STATE(4378)] = 149336,
  [SMALL_STATE(4379)] = 149392,
  [SMALL_STATE(4380)] = 149490,
  [SMALL_STATE(4381)] = 149546,
  [SMALL_STATE(4382)] = 149602,
  [SMALL_STATE(4383)] = 149658,
  [SMALL_STATE(4384)] = 149714,
  [SMALL_STATE(4385)] = 149770,
  [SMALL_STATE(4386)] = 149868,
  [SMALL_STATE(4387)] = 149930,
  [SMALL_STATE(4388)] = 149988,
  [SMALL_STATE(4389)] = 150086,
  [SMALL_STATE(4390)] = 150184,
  [SMALL_STATE(4391)] = 150282,
  [SMALL_STATE(4392)] = 150380,
  [SMALL_STATE(4393)] = 150478,
  [SMALL_STATE(4394)] = 150576,
  [SMALL_STATE(4395)] = 150674,
  [SMALL_STATE(4396)] = 150736,
  [SMALL_STATE(4397)] = 150834,
  [SMALL_STATE(4398)] = 150932,
  [SMALL_STATE(4399)] = 150988,
  [SMALL_STATE(4400)] = 151088,
  [SMALL_STATE(4401)] = 151144,
  [SMALL_STATE(4402)] = 151250,
  [SMALL_STATE(4403)] = 151306,
  [SMALL_STATE(4404)] = 151368,
  [SMALL_STATE(4405)] = 151424,
  [SMALL_STATE(4406)] = 151480,
  [SMALL_STATE(4407)] = 151536,
  [SMALL_STATE(4408)] = 151592,
  [SMALL_STATE(4409)] = 151654,
  [SMALL_STATE(4410)] = 151752,
  [SMALL_STATE(4411)] = 151808,
  [SMALL_STATE(4412)] = 151906,
  [SMALL_STATE(4413)] = 152008,
  [SMALL_STATE(4414)] = 152068,
  [SMALL_STATE(4415)] = 152126,
  [SMALL_STATE(4416)] = 152182,
  [SMALL_STATE(4417)] = 152238,
  [SMALL_STATE(4418)] = 152298,
  [SMALL_STATE(4419)] = 152354,
  [SMALL_STATE(4420)] = 152410,
  [SMALL_STATE(4421)] = 152508,
  [SMALL_STATE(4422)] = 152572,
  [SMALL_STATE(4423)] = 152628,
  [SMALL_STATE(4424)] = 152692,
  [SMALL_STATE(4425)] = 152748,
  [SMALL_STATE(4426)] = 152804,
  [SMALL_STATE(4427)] = 152860,
  [SMALL_STATE(4428)] = 152916,
  [SMALL_STATE(4429)] = 152972,
  [SMALL_STATE(4430)] = 153034,
  [SMALL_STATE(4431)] = 153090,
  [SMALL_STATE(4432)] = 153146,
  [SMALL_STATE(4433)] = 153202,
  [SMALL_STATE(4434)] = 153258,
  [SMALL_STATE(4435)] = 153314,
  [SMALL_STATE(4436)] = 153370,
  [SMALL_STATE(4437)] = 153426,
  [SMALL_STATE(4438)] = 153482,
  [SMALL_STATE(4439)] = 153538,
  [SMALL_STATE(4440)] = 153618,
  [SMALL_STATE(4441)] = 153720,
  [SMALL_STATE(4442)] = 153780,
  [SMALL_STATE(4443)] = 153840,
  [SMALL_STATE(4444)] = 153900,
  [SMALL_STATE(4445)] = 153960,
  [SMALL_STATE(4446)] = 154020,
  [SMALL_STATE(4447)] = 154088,
  [SMALL_STATE(4448)] = 154166,
  [SMALL_STATE(4449)] = 154242,
  [SMALL_STATE(4450)] = 154332,
  [SMALL_STATE(4451)] = 154420,
  [SMALL_STATE(4452)] = 154504,
  [SMALL_STATE(4453)] = 154586,
  [SMALL_STATE(4454)] = 154646,
  [SMALL_STATE(4455)] = 154706,
  [SMALL_STATE(4456)] = 154780,
  [SMALL_STATE(4457)] = 154852,
  [SMALL_STATE(4458)] = 154916,
  [SMALL_STATE(4459)] = 154972,
  [SMALL_STATE(4460)] = 155028,
  [SMALL_STATE(4461)] = 155084,
  [SMALL_STATE(4462)] = 155184,
  [SMALL_STATE(4463)] = 155240,
  [SMALL_STATE(4464)] = 155296,
  [SMALL_STATE(4465)] = 155360,
  [SMALL_STATE(4466)] = 155458,
  [SMALL_STATE(4467)] = 155514,
  [SMALL_STATE(4468)] = 155570,
  [SMALL_STATE(4469)] = 155626,
  [SMALL_STATE(4470)] = 155682,
  [SMALL_STATE(4471)] = 155738,
  [SMALL_STATE(4472)] = 155794,
  [SMALL_STATE(4473)] = 155858,
  [SMALL_STATE(4474)] = 155914,
  [SMALL_STATE(4475)] = 155970,
  [SMALL_STATE(4476)] = 156026,
  [SMALL_STATE(4477)] = 156082,
  [SMALL_STATE(4478)] = 156138,
  [SMALL_STATE(4479)] = 156194,
  [SMALL_STATE(4480)] = 156294,
  [SMALL_STATE(4481)] = 156386,
  [SMALL_STATE(4482)] = 156492,
  [SMALL_STATE(4483)] = 156548,
  [SMALL_STATE(4484)] = 156604,
  [SMALL_STATE(4485)] = 156660,
  [SMALL_STATE(4486)] = 156716,
  [SMALL_STATE(4487)] = 156772,
  [SMALL_STATE(4488)] = 156828,
  [SMALL_STATE(4489)] = 156884,
  [SMALL_STATE(4490)] = 156940,
  [SMALL_STATE(4491)] = 156996,
  [SMALL_STATE(4492)] = 157052,
  [SMALL_STATE(4493)] = 157108,
  [SMALL_STATE(4494)] = 157164,
  [SMALL_STATE(4495)] = 157220,
  [SMALL_STATE(4496)] = 157276,
  [SMALL_STATE(4497)] = 157332,
  [SMALL_STATE(4498)] = 157388,
  [SMALL_STATE(4499)] = 157444,
  [SMALL_STATE(4500)] = 157500,
  [SMALL_STATE(4501)] = 157556,
  [SMALL_STATE(4502)] = 157612,
  [SMALL_STATE(4503)] = 157668,
  [SMALL_STATE(4504)] = 157724,
  [SMALL_STATE(4505)] = 157780,
  [SMALL_STATE(4506)] = 157853,
  [SMALL_STATE(4507)] = 157908,
  [SMALL_STATE(4508)] = 157963,
  [SMALL_STATE(4509)] = 158018,
  [SMALL_STATE(4510)] = 158073,
  [SMALL_STATE(4511)] = 158128,
  [SMALL_STATE(4512)] = 158183,
  [SMALL_STATE(4513)] = 158238,
  [SMALL_STATE(4514)] = 158293,
  [SMALL_STATE(4515)] = 158348,
  [SMALL_STATE(4516)] = 158403,
  [SMALL_STATE(4517)] = 158458,
  [SMALL_STATE(4518)] = 158513,
  [SMALL_STATE(4519)] = 158568,
  [SMALL_STATE(4520)] = 158623,
  [SMALL_STATE(4521)] = 158678,
  [SMALL_STATE(4522)] = 158733,
  [SMALL_STATE(4523)] = 158788,
  [SMALL_STATE(4524)] = 158843,
  [SMALL_STATE(4525)] = 158898,
  [SMALL_STATE(4526)] = 158953,
  [SMALL_STATE(4527)] = 159008,
  [SMALL_STATE(4528)] = 159063,
  [SMALL_STATE(4529)] = 159118,
  [SMALL_STATE(4530)] = 159173,
  [SMALL_STATE(4531)] = 159228,
  [SMALL_STATE(4532)] = 159283,
  [SMALL_STATE(4533)] = 159338,
  [SMALL_STATE(4534)] = 159395,
  [SMALL_STATE(4535)] = 159450,
  [SMALL_STATE(4536)] = 159505,
  [SMALL_STATE(4537)] = 159560,
  [SMALL_STATE(4538)] = 159615,
  [SMALL_STATE(4539)] = 159670,
  [SMALL_STATE(4540)] = 159729,
  [SMALL_STATE(4541)] = 159784,
  [SMALL_STATE(4542)] = 159839,
  [SMALL_STATE(4543)] = 159896,
  [SMALL_STATE(4544)] = 159957,
  [SMALL_STATE(4545)] = 160016,
  [SMALL_STATE(4546)] = 160075,
  [SMALL_STATE(4547)] = 160134,
  [SMALL_STATE(4548)] = 160193,
  [SMALL_STATE(4549)] = 160290,
  [SMALL_STATE(4550)] = 160345,
  [SMALL_STATE(4551)] = 160400,
  [SMALL_STATE(4552)] = 160497,
  [SMALL_STATE(4553)] = 160594,
  [SMALL_STATE(4554)] = 160649,
  [SMALL_STATE(4555)] = 160746,
  [SMALL_STATE(4556)] = 160801,
  [SMALL_STATE(4557)] = 160856,
  [SMALL_STATE(4558)] = 160911,
  [SMALL_STATE(4559)] = 160966,
  [SMALL_STATE(4560)] = 161021,
  [SMALL_STATE(4561)] = 161076,
  [SMALL_STATE(4562)] = 161135,
  [SMALL_STATE(4563)] = 161190,
  [SMALL_STATE(4564)] = 161253,
  [SMALL_STATE(4565)] = 161308,
  [SMALL_STATE(4566)] = 161371,
  [SMALL_STATE(4567)] = 161426,
  [SMALL_STATE(4568)] = 161481,
  [SMALL_STATE(4569)] = 161536,
  [SMALL_STATE(4570)] = 161595,
  [SMALL_STATE(4571)] = 161650,
  [SMALL_STATE(4572)] = 161705,
  [SMALL_STATE(4573)] = 161760,
  [SMALL_STATE(4574)] = 161815,
  [SMALL_STATE(4575)] = 161870,
  [SMALL_STATE(4576)] = 161925,
  [SMALL_STATE(4577)] = 161980,
  [SMALL_STATE(4578)] = 162035,
  [SMALL_STATE(4579)] = 162090,
  [SMALL_STATE(4580)] = 162149,
  [SMALL_STATE(4581)] = 162208,
  [SMALL_STATE(4582)] = 162263,
  [SMALL_STATE(4583)] = 162318,
  [SMALL_STATE(4584)] = 162373,
  [SMALL_STATE(4585)] = 162428,
  [SMALL_STATE(4586)] = 162483,
  [SMALL_STATE(4587)] = 162562,
  [SMALL_STATE(4588)] = 162661,
  [SMALL_STATE(4589)] = 162728,
  [SMALL_STATE(4590)] = 162805,
  [SMALL_STATE(4591)] = 162880,
  [SMALL_STATE(4592)] = 162967,
  [SMALL_STATE(4593)] = 163052,
  [SMALL_STATE(4594)] = 163135,
  [SMALL_STATE(4595)] = 163216,
  [SMALL_STATE(4596)] = 163271,
  [SMALL_STATE(4597)] = 163334,
  [SMALL_STATE(4598)] = 163389,
  [SMALL_STATE(4599)] = 163444,
  [SMALL_STATE(4600)] = 163499,
  [SMALL_STATE(4601)] = 163554,
  [SMALL_STATE(4602)] = 163609,
  [SMALL_STATE(4603)] = 163664,
  [SMALL_STATE(4604)] = 163719,
  [SMALL_STATE(4605)] = 163816,
  [SMALL_STATE(4606)] = 163871,
  [SMALL_STATE(4607)] = 163926,
  [SMALL_STATE(4608)] = 163981,
  [SMALL_STATE(4609)] = 164036,
  [SMALL_STATE(4610)] = 164091,
  [SMALL_STATE(4611)] = 164188,
  [SMALL_STATE(4612)] = 164251,
  [SMALL_STATE(4613)] = 164306,
  [SMALL_STATE(4614)] = 164361,
  [SMALL_STATE(4615)] = 164416,
  [SMALL_STATE(4616)] = 164475,
  [SMALL_STATE(4617)] = 164536,
  [SMALL_STATE(4618)] = 164591,
  [SMALL_STATE(4619)] = 164646,
  [SMALL_STATE(4620)] = 164701,
  [SMALL_STATE(4621)] = 164756,
  [SMALL_STATE(4622)] = 164811,
  [SMALL_STATE(4623)] = 164866,
  [SMALL_STATE(4624)] = 164921,
  [SMALL_STATE(4625)] = 164976,
  [SMALL_STATE(4626)] = 165055,
  [SMALL_STATE(4627)] = 165158,
  [SMALL_STATE(4628)] = 165225,
  [SMALL_STATE(4629)] = 165302,
  [SMALL_STATE(4630)] = 165377,
  [SMALL_STATE(4631)] = 165466,
  [SMALL_STATE(4632)] = 165553,
  [SMALL_STATE(4633)] = 165636,
  [SMALL_STATE(4634)] = 165717,
  [SMALL_STATE(4635)] = 165790,
  [SMALL_STATE(4636)] = 165861,
  [SMALL_STATE(4637)] = 165924,
  [SMALL_STATE(4638)] = 166025,
  [SMALL_STATE(4639)] = 166088,
  [SMALL_STATE(4640)] = 166151,
  [SMALL_STATE(4641)] = 166252,
  [SMALL_STATE(4642)] = 166345,
  [SMALL_STATE(4643)] = 166400,
  [SMALL_STATE(4644)] = 166455,
  [SMALL_STATE(4645)] = 166510,
  [SMALL_STATE(4646)] = 166565,
  [SMALL_STATE(4647)] = 166620,
  [SMALL_STATE(4648)] = 166675,
  [SMALL_STATE(4649)] = 166730,
  [SMALL_STATE(4650)] = 166785,
  [SMALL_STATE(4651)] = 166840,
  [SMALL_STATE(4652)] = 166895,
  [SMALL_STATE(4653)] = 166950,
  [SMALL_STATE(4654)] = 167005,
  [SMALL_STATE(4655)] = 167066,
  [SMALL_STATE(4656)] = 167125,
  [SMALL_STATE(4657)] = 167180,
  [SMALL_STATE(4658)] = 167237,
  [SMALL_STATE(4659)] = 167292,
  [SMALL_STATE(4660)] = 167389,
  [SMALL_STATE(4661)] = 167452,
  [SMALL_STATE(4662)] = 167511,
  [SMALL_STATE(4663)] = 167566,
  [SMALL_STATE(4664)] = 167621,
  [SMALL_STATE(4665)] = 167676,
  [SMALL_STATE(4666)] = 167731,
  [SMALL_STATE(4667)] = 167786,
  [SMALL_STATE(4668)] = 167841,
  [SMALL_STATE(4669)] = 167896,
  [SMALL_STATE(4670)] = 167951,
  [SMALL_STATE(4671)] = 168006,
  [SMALL_STATE(4672)] = 168061,
  [SMALL_STATE(4673)] = 168116,
  [SMALL_STATE(4674)] = 168171,
  [SMALL_STATE(4675)] = 168272,
  [SMALL_STATE(4676)] = 168327,
  [SMALL_STATE(4677)] = 168382,
  [SMALL_STATE(4678)] = 168437,
  [SMALL_STATE(4679)] = 168496,
  [SMALL_STATE(4680)] = 168559,
  [SMALL_STATE(4681)] = 168622,
  [SMALL_STATE(4682)] = 168683,
  [SMALL_STATE(4683)] = 168738,
  [SMALL_STATE(4684)] = 168793,
  [SMALL_STATE(4685)] = 168890,
  [SMALL_STATE(4686)] = 168945,
  [SMALL_STATE(4687)] = 169000,
  [SMALL_STATE(4688)] = 169055,
  [SMALL_STATE(4689)] = 169152,
  [SMALL_STATE(4690)] = 169241,
  [SMALL_STATE(4691)] = 169296,
  [SMALL_STATE(4692)] = 169351,
  [SMALL_STATE(4693)] = 169406,
  [SMALL_STATE(4694)] = 169461,
  [SMALL_STATE(4695)] = 169516,
  [SMALL_STATE(4696)] = 169587,
  [SMALL_STATE(4697)] = 169669,
  [SMALL_STATE(4698)] = 169729,
  [SMALL_STATE(4699)] = 169785,
  [SMALL_STATE(4700)] = 169839,
  [SMALL_STATE(4701)] = 169893,
  [SMALL_STATE(4702)] = 169989,
  [SMALL_STATE(4703)] = 170051,
  [SMALL_STATE(4704)] = 170113,
  [SMALL_STATE(4705)] = 170169,
  [SMALL_STATE(4706)] = 170225,
  [SMALL_STATE(4707)] = 170279,
  [SMALL_STATE(4708)] = 170357,
  [SMALL_STATE(4709)] = 170455,
  [SMALL_STATE(4710)] = 170521,
  [SMALL_STATE(4711)] = 170597,
  [SMALL_STATE(4712)] = 170671,
  [SMALL_STATE(4713)] = 170757,
  [SMALL_STATE(4714)] = 170841,
  [SMALL_STATE(4715)] = 170945,
  [SMALL_STATE(4716)] = 171005,
  [SMALL_STATE(4717)] = 171063,
  [SMALL_STATE(4718)] = 171135,
  [SMALL_STATE(4719)] = 171205,
  [SMALL_STATE(4720)] = 171267,
  [SMALL_STATE(4721)] = 171363,
  [SMALL_STATE(4722)] = 171459,
  [SMALL_STATE(4723)] = 171521,
  [SMALL_STATE(4724)] = 171581,
  [SMALL_STATE(4725)] = 171637,
  [SMALL_STATE(4726)] = 171733,
  [SMALL_STATE(4727)] = 171795,
  [SMALL_STATE(4728)] = 171891,
  [SMALL_STATE(4729)] = 171979,
  [SMALL_STATE(4730)] = 172037,
  [SMALL_STATE(4731)] = 172091,
  [SMALL_STATE(4732)] = 172187,
  [SMALL_STATE(4733)] = 172243,
  [SMALL_STATE(4734)] = 172305,
  [SMALL_STATE(4735)] = 172359,
  [SMALL_STATE(4736)] = 172455,
  [SMALL_STATE(4737)] = 172551,
  [SMALL_STATE(4738)] = 172611,
  [SMALL_STATE(4739)] = 172665,
  [SMALL_STATE(4740)] = 172719,
  [SMALL_STATE(4741)] = 172815,
  [SMALL_STATE(4742)] = 172873,
  [SMALL_STATE(4743)] = 172953,
  [SMALL_STATE(4744)] = 173006,
  [SMALL_STATE(4745)] = 173059,
  [SMALL_STATE(4746)] = 173152,
  [SMALL_STATE(4747)] = 173213,
  [SMALL_STATE(4748)] = 173272,
  [SMALL_STATE(4749)] = 173365,
  [SMALL_STATE(4750)] = 173460,
  [SMALL_STATE(4751)] = 173553,
  [SMALL_STATE(4752)] = 173606,
  [SMALL_STATE(4753)] = 173659,
  [SMALL_STATE(4754)] = 173712,
  [SMALL_STATE(4755)] = 173765,
  [SMALL_STATE(4756)] = 173818,
  [SMALL_STATE(4757)] = 173871,
  [SMALL_STATE(4758)] = 173968,
  [SMALL_STATE(4759)] = 174057,
  [SMALL_STATE(4760)] = 174110,
  [SMALL_STATE(4761)] = 174163,
  [SMALL_STATE(4762)] = 174256,
  [SMALL_STATE(4763)] = 174309,
  [SMALL_STATE(4764)] = 174362,
  [SMALL_STATE(4765)] = 174415,
  [SMALL_STATE(4766)] = 174468,
  [SMALL_STATE(4767)] = 174521,
  [SMALL_STATE(4768)] = 174574,
  [SMALL_STATE(4769)] = 174627,
  [SMALL_STATE(4770)] = 174680,
  [SMALL_STATE(4771)] = 174733,
  [SMALL_STATE(4772)] = 174786,
  [SMALL_STATE(4773)] = 174839,
  [SMALL_STATE(4774)] = 174892,
  [SMALL_STATE(4775)] = 174945,
  [SMALL_STATE(4776)] = 174998,
  [SMALL_STATE(4777)] = 175051,
  [SMALL_STATE(4778)] = 175104,
  [SMALL_STATE(4779)] = 175157,
  [SMALL_STATE(4780)] = 175210,
  [SMALL_STATE(4781)] = 175263,
  [SMALL_STATE(4782)] = 175316,
  [SMALL_STATE(4783)] = 175369,
  [SMALL_STATE(4784)] = 175422,
  [SMALL_STATE(4785)] = 175475,
  [SMALL_STATE(4786)] = 175528,
  [SMALL_STATE(4787)] = 175581,
  [SMALL_STATE(4788)] = 175634,
  [SMALL_STATE(4789)] = 175687,
  [SMALL_STATE(4790)] = 175740,
  [SMALL_STATE(4791)] = 175793,
  [SMALL_STATE(4792)] = 175846,
  [SMALL_STATE(4793)] = 175899,
  [SMALL_STATE(4794)] = 175952,
  [SMALL_STATE(4795)] = 176005,
  [SMALL_STATE(4796)] = 176058,
  [SMALL_STATE(4797)] = 176111,
  [SMALL_STATE(4798)] = 176164,
  [SMALL_STATE(4799)] = 176217,
  [SMALL_STATE(4800)] = 176270,
  [SMALL_STATE(4801)] = 176323,
  [SMALL_STATE(4802)] = 176376,
  [SMALL_STATE(4803)] = 176429,
  [SMALL_STATE(4804)] = 176482,
  [SMALL_STATE(4805)] = 176541,
  [SMALL_STATE(4806)] = 176598,
  [SMALL_STATE(4807)] = 176693,
  [SMALL_STATE(4808)] = 176746,
  [SMALL_STATE(4809)] = 176799,
  [SMALL_STATE(4810)] = 176860,
  [SMALL_STATE(4811)] = 176913,
  [SMALL_STATE(4812)] = 176974,
  [SMALL_STATE(4813)] = 177027,
  [SMALL_STATE(4814)] = 177080,
  [SMALL_STATE(4815)] = 177133,
  [SMALL_STATE(4816)] = 177226,
  [SMALL_STATE(4817)] = 177291,
  [SMALL_STATE(4818)] = 177386,
  [SMALL_STATE(4819)] = 177445,
  [SMALL_STATE(4820)] = 177544,
  [SMALL_STATE(4821)] = 177597,
  [SMALL_STATE(4822)] = 177692,
  [SMALL_STATE(4823)] = 177745,
  [SMALL_STATE(4824)] = 177822,
  [SMALL_STATE(4825)] = 177921,
  [SMALL_STATE(4826)] = 177986,
  [SMALL_STATE(4827)] = 178061,
  [SMALL_STATE(4828)] = 178134,
  [SMALL_STATE(4829)] = 178221,
  [SMALL_STATE(4830)] = 178306,
  [SMALL_STATE(4831)] = 178387,
  [SMALL_STATE(4832)] = 178466,
  [SMALL_STATE(4833)] = 178537,
  [SMALL_STATE(4834)] = 178606,
  [SMALL_STATE(4835)] = 178667,
  [SMALL_STATE(4836)] = 178764,
  [SMALL_STATE(4837)] = 178825,
  [SMALL_STATE(4838)] = 178878,
  [SMALL_STATE(4839)] = 178973,
  [SMALL_STATE(4840)] = 179034,
  [SMALL_STATE(4841)] = 179131,
  [SMALL_STATE(4842)] = 179220,
  [SMALL_STATE(4843)] = 179315,
  [SMALL_STATE(4844)] = 179410,
  [SMALL_STATE(4845)] = 179465,
  [SMALL_STATE(4846)] = 179560,
  [SMALL_STATE(4847)] = 179655,
  [SMALL_STATE(4848)] = 179758,
  [SMALL_STATE(4849)] = 179823,
  [SMALL_STATE(4850)] = 179876,
  [SMALL_STATE(4851)] = 179935,
  [SMALL_STATE(4852)] = 179988,
  [SMALL_STATE(4853)] = 180041,
  [SMALL_STATE(4854)] = 180094,
  [SMALL_STATE(4855)] = 180147,
  [SMALL_STATE(4856)] = 180200,
  [SMALL_STATE(4857)] = 180255,
  [SMALL_STATE(4858)] = 180308,
  [SMALL_STATE(4859)] = 180385,
  [SMALL_STATE(4860)] = 180484,
  [SMALL_STATE(4861)] = 180579,
  [SMALL_STATE(4862)] = 180674,
  [SMALL_STATE(4863)] = 180739,
  [SMALL_STATE(4864)] = 180814,
  [SMALL_STATE(4865)] = 180887,
  [SMALL_STATE(4866)] = 180974,
  [SMALL_STATE(4867)] = 181059,
  [SMALL_STATE(4868)] = 181140,
  [SMALL_STATE(4869)] = 181219,
  [SMALL_STATE(4870)] = 181290,
  [SMALL_STATE(4871)] = 181359,
  [SMALL_STATE(4872)] = 181420,
  [SMALL_STATE(4873)] = 181515,
  [SMALL_STATE(4874)] = 181568,
  [SMALL_STATE(4875)] = 181621,
  [SMALL_STATE(4876)] = 181674,
  [SMALL_STATE(4877)] = 181771,
  [SMALL_STATE(4878)] = 181824,
  [SMALL_STATE(4879)] = 181889,
  [SMALL_STATE(4880)] = 181954,
  [SMALL_STATE(4881)] = 182049,
  [SMALL_STATE(4882)] = 182154,
  [SMALL_STATE(4883)] = 182211,
  [SMALL_STATE(4884)] = 182272,
  [SMALL_STATE(4885)] = 182333,
  [SMALL_STATE(4886)] = 182394,
  [SMALL_STATE(4887)] = 182447,
  [SMALL_STATE(4888)] = 182500,
  [SMALL_STATE(4889)] = 182553,
  [SMALL_STATE(4890)] = 182648,
  [SMALL_STATE(4891)] = 182713,
  [SMALL_STATE(4892)] = 182766,
  [SMALL_STATE(4893)] = 182860,
  [SMALL_STATE(4894)] = 182954,
  [SMALL_STATE(4895)] = 183046,
  [SMALL_STATE(4896)] = 183140,
  [SMALL_STATE(4897)] = 183234,
  [SMALL_STATE(4898)] = 183328,
  [SMALL_STATE(4899)] = 183386,
  [SMALL_STATE(4900)] = 183488,
  [SMALL_STATE(4901)] = 183580,
  [SMALL_STATE(4902)] = 183674,
  [SMALL_STATE(4903)] = 183768,
  [SMALL_STATE(4904)] = 183862,
  [SMALL_STATE(4905)] = 183956,
  [SMALL_STATE(4906)] = 184050,
  [SMALL_STATE(4907)] = 184144,
  [SMALL_STATE(4908)] = 184238,
  [SMALL_STATE(4909)] = 184332,
  [SMALL_STATE(4910)] = 184424,
  [SMALL_STATE(4911)] = 184518,
  [SMALL_STATE(4912)] = 184612,
  [SMALL_STATE(4913)] = 184706,
  [SMALL_STATE(4914)] = 184800,
  [SMALL_STATE(4915)] = 184902,
  [SMALL_STATE(4916)] = 184994,
  [SMALL_STATE(4917)] = 185088,
  [SMALL_STATE(4918)] = 185182,
  [SMALL_STATE(4919)] = 185276,
  [SMALL_STATE(4920)] = 185370,
  [SMALL_STATE(4921)] = 185464,
  [SMALL_STATE(4922)] = 185558,
  [SMALL_STATE(4923)] = 185652,
  [SMALL_STATE(4924)] = 185746,
  [SMALL_STATE(4925)] = 185840,
  [SMALL_STATE(4926)] = 185934,
  [SMALL_STATE(4927)] = 186028,
  [SMALL_STATE(4928)] = 186122,
  [SMALL_STATE(4929)] = 186216,
  [SMALL_STATE(4930)] = 186310,
  [SMALL_STATE(4931)] = 186404,
  [SMALL_STATE(4932)] = 186498,
  [SMALL_STATE(4933)] = 186592,
  [SMALL_STATE(4934)] = 186686,
  [SMALL_STATE(4935)] = 186780,
  [SMALL_STATE(4936)] = 186874,
  [SMALL_STATE(4937)] = 186966,
  [SMALL_STATE(4938)] = 187066,
  [SMALL_STATE(4939)] = 187160,
  [SMALL_STATE(4940)] = 187252,
  [SMALL_STATE(4941)] = 187346,
  [SMALL_STATE(4942)] = 187440,
  [SMALL_STATE(4943)] = 187534,
  [SMALL_STATE(4944)] = 187628,
  [SMALL_STATE(4945)] = 187722,
  [SMALL_STATE(4946)] = 187816,
  [SMALL_STATE(4947)] = 187910,
  [SMALL_STATE(4948)] = 188004,
  [SMALL_STATE(4949)] = 188098,
  [SMALL_STATE(4950)] = 188192,
  [SMALL_STATE(4951)] = 188286,
  [SMALL_STATE(4952)] = 188380,
  [SMALL_STATE(4953)] = 188474,
  [SMALL_STATE(4954)] = 188573,
  [SMALL_STATE(4955)] = 188672,
  [SMALL_STATE(4956)] = 188771,
  [SMALL_STATE(4957)] = 188870,
  [SMALL_STATE(4958)] = 188969,
  [SMALL_STATE(4959)] = 189068,
  [SMALL_STATE(4960)] = 189167,
  [SMALL_STATE(4961)] = 189266,
  [SMALL_STATE(4962)] = 189365,
  [SMALL_STATE(4963)] = 189464,
  [SMALL_STATE(4964)] = 189563,
  [SMALL_STATE(4965)] = 189654,
  [SMALL_STATE(4966)] = 189749,
  [SMALL_STATE(4967)] = 189848,
  [SMALL_STATE(4968)] = 189947,
  [SMALL_STATE(4969)] = 190046,
  [SMALL_STATE(4970)] = 190145,
  [SMALL_STATE(4971)] = 190235,
  [SMALL_STATE(4972)] = 190325,
  [SMALL_STATE(4973)] = 190415,
  [SMALL_STATE(4974)] = 190505,
  [SMALL_STATE(4975)] = 190595,
  [SMALL_STATE(4976)] = 190685,
  [SMALL_STATE(4977)] = 190775,
  [SMALL_STATE(4978)] = 190865,
  [SMALL_STATE(4979)] = 190955,
  [SMALL_STATE(4980)] = 191045,
  [SMALL_STATE(4981)] = 191135,
  [SMALL_STATE(4982)] = 191225,
  [SMALL_STATE(4983)] = 191315,
  [SMALL_STATE(4984)] = 191409,
  [SMALL_STATE(4985)] = 191499,
  [SMALL_STATE(4986)] = 191589,
  [SMALL_STATE(4987)] = 191679,
  [SMALL_STATE(4988)] = 191769,
  [SMALL_STATE(4989)] = 191859,
  [SMALL_STATE(4990)] = 191949,
  [SMALL_STATE(4991)] = 192039,
  [SMALL_STATE(4992)] = 192145,
  [SMALL_STATE(4993)] = 192235,
  [SMALL_STATE(4994)] = 192325,
  [SMALL_STATE(4995)] = 192415,
  [SMALL_STATE(4996)] = 192505,
  [SMALL_STATE(4997)] = 192595,
  [SMALL_STATE(4998)] = 192685,
  [SMALL_STATE(4999)] = 192775,
  [SMALL_STATE(5000)] = 192865,
  [SMALL_STATE(5001)] = 192955,
  [SMALL_STATE(5002)] = 193045,
  [SMALL_STATE(5003)] = 193135,
  [SMALL_STATE(5004)] = 193225,
  [SMALL_STATE(5005)] = 193315,
  [SMALL_STATE(5006)] = 193405,
  [SMALL_STATE(5007)] = 193495,
  [SMALL_STATE(5008)] = 193585,
  [SMALL_STATE(5009)] = 193675,
  [SMALL_STATE(5010)] = 193765,
  [SMALL_STATE(5011)] = 193855,
  [SMALL_STATE(5012)] = 193945,
  [SMALL_STATE(5013)] = 194035,
  [SMALL_STATE(5014)] = 194125,
  [SMALL_STATE(5015)] = 194215,
  [SMALL_STATE(5016)] = 194311,
  [SMALL_STATE(5017)] = 194401,
  [SMALL_STATE(5018)] = 194491,
  [SMALL_STATE(5019)] = 194581,
  [SMALL_STATE(5020)] = 194671,
  [SMALL_STATE(5021)] = 194761,
  [SMALL_STATE(5022)] = 194851,
  [SMALL_STATE(5023)] = 194941,
  [SMALL_STATE(5024)] = 195031,
  [SMALL_STATE(5025)] = 195121,
  [SMALL_STATE(5026)] = 195211,
  [SMALL_STATE(5027)] = 195301,
  [SMALL_STATE(5028)] = 195391,
  [SMALL_STATE(5029)] = 195481,
  [SMALL_STATE(5030)] = 195571,
  [SMALL_STATE(5031)] = 195661,
  [SMALL_STATE(5032)] = 195751,
  [SMALL_STATE(5033)] = 195841,
  [SMALL_STATE(5034)] = 195931,
  [SMALL_STATE(5035)] = 196021,
  [SMALL_STATE(5036)] = 196111,
  [SMALL_STATE(5037)] = 196201,
  [SMALL_STATE(5038)] = 196291,
  [SMALL_STATE(5039)] = 196381,
  [SMALL_STATE(5040)] = 196471,
  [SMALL_STATE(5041)] = 196527,
  [SMALL_STATE(5042)] = 196617,
  [SMALL_STATE(5043)] = 196707,
  [SMALL_STATE(5044)] = 196797,
  [SMALL_STATE(5045)] = 196887,
  [SMALL_STATE(5046)] = 196977,
  [SMALL_STATE(5047)] = 197067,
  [SMALL_STATE(5048)] = 197157,
  [SMALL_STATE(5049)] = 197247,
  [SMALL_STATE(5050)] = 197337,
  [SMALL_STATE(5051)] = 197427,
  [SMALL_STATE(5052)] = 197517,
  [SMALL_STATE(5053)] = 197607,
  [SMALL_STATE(5054)] = 197697,
  [SMALL_STATE(5055)] = 197787,
  [SMALL_STATE(5056)] = 197877,
  [SMALL_STATE(5057)] = 197967,
  [SMALL_STATE(5058)] = 198057,
  [SMALL_STATE(5059)] = 198147,
  [SMALL_STATE(5060)] = 198237,
  [SMALL_STATE(5061)] = 198327,
  [SMALL_STATE(5062)] = 198417,
  [SMALL_STATE(5063)] = 198507,
  [SMALL_STATE(5064)] = 198597,
  [SMALL_STATE(5065)] = 198687,
  [SMALL_STATE(5066)] = 198777,
  [SMALL_STATE(5067)] = 198867,
  [SMALL_STATE(5068)] = 198957,
  [SMALL_STATE(5069)] = 199047,
  [SMALL_STATE(5070)] = 199137,
  [SMALL_STATE(5071)] = 199227,
  [SMALL_STATE(5072)] = 199317,
  [SMALL_STATE(5073)] = 199407,
  [SMALL_STATE(5074)] = 199497,
  [SMALL_STATE(5075)] = 199587,
  [SMALL_STATE(5076)] = 199677,
  [SMALL_STATE(5077)] = 199767,
  [SMALL_STATE(5078)] = 199857,
  [SMALL_STATE(5079)] = 199947,
  [SMALL_STATE(5080)] = 200037,
  [SMALL_STATE(5081)] = 200127,
  [SMALL_STATE(5082)] = 200217,
  [SMALL_STATE(5083)] = 200307,
  [SMALL_STATE(5084)] = 200397,
  [SMALL_STATE(5085)] = 200487,
  [SMALL_STATE(5086)] = 200577,
  [SMALL_STATE(5087)] = 200667,
  [SMALL_STATE(5088)] = 200757,
  [SMALL_STATE(5089)] = 200847,
  [SMALL_STATE(5090)] = 200937,
  [SMALL_STATE(5091)] = 201027,
  [SMALL_STATE(5092)] = 201117,
  [SMALL_STATE(5093)] = 201207,
  [SMALL_STATE(5094)] = 201297,
  [SMALL_STATE(5095)] = 201387,
  [SMALL_STATE(5096)] = 201477,
  [SMALL_STATE(5097)] = 201567,
  [SMALL_STATE(5098)] = 201657,
  [SMALL_STATE(5099)] = 201747,
  [SMALL_STATE(5100)] = 201837,
  [SMALL_STATE(5101)] = 201927,
  [SMALL_STATE(5102)] = 202017,
  [SMALL_STATE(5103)] = 202107,
  [SMALL_STATE(5104)] = 202197,
  [SMALL_STATE(5105)] = 202287,
  [SMALL_STATE(5106)] = 202377,
  [SMALL_STATE(5107)] = 202467,
  [SMALL_STATE(5108)] = 202557,
  [SMALL_STATE(5109)] = 202647,
  [SMALL_STATE(5110)] = 202737,
  [SMALL_STATE(5111)] = 202831,
  [SMALL_STATE(5112)] = 202921,
  [SMALL_STATE(5113)] = 203011,
  [SMALL_STATE(5114)] = 203101,
  [SMALL_STATE(5115)] = 203191,
  [SMALL_STATE(5116)] = 203281,
  [SMALL_STATE(5117)] = 203337,
  [SMALL_STATE(5118)] = 203427,
  [SMALL_STATE(5119)] = 203517,
  [SMALL_STATE(5120)] = 203607,
  [SMALL_STATE(5121)] = 203697,
  [SMALL_STATE(5122)] = 203787,
  [SMALL_STATE(5123)] = 203877,
  [SMALL_STATE(5124)] = 203967,
  [SMALL_STATE(5125)] = 204057,
  [SMALL_STATE(5126)] = 204147,
  [SMALL_STATE(5127)] = 204237,
  [SMALL_STATE(5128)] = 204327,
  [SMALL_STATE(5129)] = 204417,
  [SMALL_STATE(5130)] = 204507,
  [SMALL_STATE(5131)] = 204597,
  [SMALL_STATE(5132)] = 204687,
  [SMALL_STATE(5133)] = 204777,
  [SMALL_STATE(5134)] = 204867,
  [SMALL_STATE(5135)] = 204957,
  [SMALL_STATE(5136)] = 205047,
  [SMALL_STATE(5137)] = 205137,
  [SMALL_STATE(5138)] = 205227,
  [SMALL_STATE(5139)] = 205317,
  [SMALL_STATE(5140)] = 205407,
  [SMALL_STATE(5141)] = 205497,
  [SMALL_STATE(5142)] = 205587,
  [SMALL_STATE(5143)] = 205677,
  [SMALL_STATE(5144)] = 205767,
  [SMALL_STATE(5145)] = 205857,
  [SMALL_STATE(5146)] = 205947,
  [SMALL_STATE(5147)] = 206037,
  [SMALL_STATE(5148)] = 206127,
  [SMALL_STATE(5149)] = 206217,
  [SMALL_STATE(5150)] = 206307,
  [SMALL_STATE(5151)] = 206401,
  [SMALL_STATE(5152)] = 206491,
  [SMALL_STATE(5153)] = 206581,
  [SMALL_STATE(5154)] = 206671,
  [SMALL_STATE(5155)] = 206761,
  [SMALL_STATE(5156)] = 206851,
  [SMALL_STATE(5157)] = 206941,
  [SMALL_STATE(5158)] = 207031,
  [SMALL_STATE(5159)] = 207121,
  [SMALL_STATE(5160)] = 207211,
  [SMALL_STATE(5161)] = 207301,
  [SMALL_STATE(5162)] = 207391,
  [SMALL_STATE(5163)] = 207481,
  [SMALL_STATE(5164)] = 207571,
  [SMALL_STATE(5165)] = 207658,
  [SMALL_STATE(5166)] = 207745,
  [SMALL_STATE(5167)] = 207832,
  [SMALL_STATE(5168)] = 207919,
  [SMALL_STATE(5169)] = 208006,
  [SMALL_STATE(5170)] = 208093,
  [SMALL_STATE(5171)] = 208180,
  [SMALL_STATE(5172)] = 208267,
  [SMALL_STATE(5173)] = 208354,
  [SMALL_STATE(5174)] = 208441,
  [SMALL_STATE(5175)] = 208528,
  [SMALL_STATE(5176)] = 208615,
  [SMALL_STATE(5177)] = 208702,
  [SMALL_STATE(5178)] = 208789,
  [SMALL_STATE(5179)] = 208876,
  [SMALL_STATE(5180)] = 208963,
  [SMALL_STATE(5181)] = 209050,
  [SMALL_STATE(5182)] = 209137,
  [SMALL_STATE(5183)] = 209186,
  [SMALL_STATE(5184)] = 209273,
  [SMALL_STATE(5185)] = 209360,
  [SMALL_STATE(5186)] = 209447,
  [SMALL_STATE(5187)] = 209534,
  [SMALL_STATE(5188)] = 209621,
  [SMALL_STATE(5189)] = 209708,
  [SMALL_STATE(5190)] = 209795,
  [SMALL_STATE(5191)] = 209882,
  [SMALL_STATE(5192)] = 209969,
  [SMALL_STATE(5193)] = 210056,
  [SMALL_STATE(5194)] = 210143,
  [SMALL_STATE(5195)] = 210230,
  [SMALL_STATE(5196)] = 210317,
  [SMALL_STATE(5197)] = 210404,
  [SMALL_STATE(5198)] = 210491,
  [SMALL_STATE(5199)] = 210578,
  [SMALL_STATE(5200)] = 210665,
  [SMALL_STATE(5201)] = 210752,
  [SMALL_STATE(5202)] = 210839,
  [SMALL_STATE(5203)] = 210926,
  [SMALL_STATE(5204)] = 211013,
  [SMALL_STATE(5205)] = 211100,
  [SMALL_STATE(5206)] = 211187,
  [SMALL_STATE(5207)] = 211274,
  [SMALL_STATE(5208)] = 211361,
  [SMALL_STATE(5209)] = 211448,
  [SMALL_STATE(5210)] = 211535,
  [SMALL_STATE(5211)] = 211622,
  [SMALL_STATE(5212)] = 211709,
  [SMALL_STATE(5213)] = 211796,
  [SMALL_STATE(5214)] = 211883,
  [SMALL_STATE(5215)] = 211970,
  [SMALL_STATE(5216)] = 212057,
  [SMALL_STATE(5217)] = 212144,
  [SMALL_STATE(5218)] = 212231,
  [SMALL_STATE(5219)] = 212318,
  [SMALL_STATE(5220)] = 212405,
  [SMALL_STATE(5221)] = 212492,
  [SMALL_STATE(5222)] = 212579,
  [SMALL_STATE(5223)] = 212666,
  [SMALL_STATE(5224)] = 212753,
  [SMALL_STATE(5225)] = 212840,
  [SMALL_STATE(5226)] = 212927,
  [SMALL_STATE(5227)] = 213014,
  [SMALL_STATE(5228)] = 213101,
  [SMALL_STATE(5229)] = 213188,
  [SMALL_STATE(5230)] = 213275,
  [SMALL_STATE(5231)] = 213362,
  [SMALL_STATE(5232)] = 213449,
  [SMALL_STATE(5233)] = 213536,
  [SMALL_STATE(5234)] = 213623,
  [SMALL_STATE(5235)] = 213710,
  [SMALL_STATE(5236)] = 213797,
  [SMALL_STATE(5237)] = 213884,
  [SMALL_STATE(5238)] = 213971,
  [SMALL_STATE(5239)] = 214058,
  [SMALL_STATE(5240)] = 214145,
  [SMALL_STATE(5241)] = 214232,
  [SMALL_STATE(5242)] = 214319,
  [SMALL_STATE(5243)] = 214406,
  [SMALL_STATE(5244)] = 214493,
  [SMALL_STATE(5245)] = 214580,
  [SMALL_STATE(5246)] = 214667,
  [SMALL_STATE(5247)] = 214754,
  [SMALL_STATE(5248)] = 214841,
  [SMALL_STATE(5249)] = 214928,
  [SMALL_STATE(5250)] = 215015,
  [SMALL_STATE(5251)] = 215102,
  [SMALL_STATE(5252)] = 215189,
  [SMALL_STATE(5253)] = 215276,
  [SMALL_STATE(5254)] = 215363,
  [SMALL_STATE(5255)] = 215450,
  [SMALL_STATE(5256)] = 215537,
  [SMALL_STATE(5257)] = 215624,
  [SMALL_STATE(5258)] = 215711,
  [SMALL_STATE(5259)] = 215798,
  [SMALL_STATE(5260)] = 215885,
  [SMALL_STATE(5261)] = 215972,
  [SMALL_STATE(5262)] = 216059,
  [SMALL_STATE(5263)] = 216146,
  [SMALL_STATE(5264)] = 216233,
  [SMALL_STATE(5265)] = 216320,
  [SMALL_STATE(5266)] = 216407,
  [SMALL_STATE(5267)] = 216494,
  [SMALL_STATE(5268)] = 216581,
  [SMALL_STATE(5269)] = 216668,
  [SMALL_STATE(5270)] = 216755,
  [SMALL_STATE(5271)] = 216842,
  [SMALL_STATE(5272)] = 216929,
  [SMALL_STATE(5273)] = 217016,
  [SMALL_STATE(5274)] = 217103,
  [SMALL_STATE(5275)] = 217190,
  [SMALL_STATE(5276)] = 217277,
  [SMALL_STATE(5277)] = 217364,
  [SMALL_STATE(5278)] = 217451,
  [SMALL_STATE(5279)] = 217538,
  [SMALL_STATE(5280)] = 217591,
  [SMALL_STATE(5281)] = 217678,
  [SMALL_STATE(5282)] = 217765,
  [SMALL_STATE(5283)] = 217852,
  [SMALL_STATE(5284)] = 217939,
  [SMALL_STATE(5285)] = 218026,
  [SMALL_STATE(5286)] = 218113,
  [SMALL_STATE(5287)] = 218200,
  [SMALL_STATE(5288)] = 218287,
  [SMALL_STATE(5289)] = 218374,
  [SMALL_STATE(5290)] = 218461,
  [SMALL_STATE(5291)] = 218548,
  [SMALL_STATE(5292)] = 218635,
  [SMALL_STATE(5293)] = 218722,
  [SMALL_STATE(5294)] = 218809,
  [SMALL_STATE(5295)] = 218896,
  [SMALL_STATE(5296)] = 218983,
  [SMALL_STATE(5297)] = 219070,
  [SMALL_STATE(5298)] = 219157,
  [SMALL_STATE(5299)] = 219244,
  [SMALL_STATE(5300)] = 219331,
  [SMALL_STATE(5301)] = 219418,
  [SMALL_STATE(5302)] = 219505,
  [SMALL_STATE(5303)] = 219592,
  [SMALL_STATE(5304)] = 219679,
  [SMALL_STATE(5305)] = 219766,
  [SMALL_STATE(5306)] = 219853,
  [SMALL_STATE(5307)] = 219940,
  [SMALL_STATE(5308)] = 220027,
  [SMALL_STATE(5309)] = 220114,
  [SMALL_STATE(5310)] = 220201,
  [SMALL_STATE(5311)] = 220288,
  [SMALL_STATE(5312)] = 220375,
  [SMALL_STATE(5313)] = 220462,
  [SMALL_STATE(5314)] = 220549,
  [SMALL_STATE(5315)] = 220636,
  [SMALL_STATE(5316)] = 220723,
  [SMALL_STATE(5317)] = 220810,
  [SMALL_STATE(5318)] = 220897,
  [SMALL_STATE(5319)] = 220984,
  [SMALL_STATE(5320)] = 221071,
  [SMALL_STATE(5321)] = 221158,
  [SMALL_STATE(5322)] = 221245,
  [SMALL_STATE(5323)] = 221332,
  [SMALL_STATE(5324)] = 221419,
  [SMALL_STATE(5325)] = 221506,
  [SMALL_STATE(5326)] = 221593,
  [SMALL_STATE(5327)] = 221680,
  [SMALL_STATE(5328)] = 221767,
  [SMALL_STATE(5329)] = 221854,
  [SMALL_STATE(5330)] = 221941,
  [SMALL_STATE(5331)] = 222028,
  [SMALL_STATE(5332)] = 222115,
  [SMALL_STATE(5333)] = 222202,
  [SMALL_STATE(5334)] = 222289,
  [SMALL_STATE(5335)] = 222376,
  [SMALL_STATE(5336)] = 222463,
  [SMALL_STATE(5337)] = 222550,
  [SMALL_STATE(5338)] = 222637,
  [SMALL_STATE(5339)] = 222724,
  [SMALL_STATE(5340)] = 222811,
  [SMALL_STATE(5341)] = 222898,
  [SMALL_STATE(5342)] = 222985,
  [SMALL_STATE(5343)] = 223072,
  [SMALL_STATE(5344)] = 223159,
  [SMALL_STATE(5345)] = 223246,
  [SMALL_STATE(5346)] = 223333,
  [SMALL_STATE(5347)] = 223420,
  [SMALL_STATE(5348)] = 223507,
  [SMALL_STATE(5349)] = 223594,
  [SMALL_STATE(5350)] = 223681,
  [SMALL_STATE(5351)] = 223768,
  [SMALL_STATE(5352)] = 223855,
  [SMALL_STATE(5353)] = 223942,
  [SMALL_STATE(5354)] = 224029,
  [SMALL_STATE(5355)] = 224116,
  [SMALL_STATE(5356)] = 224203,
  [SMALL_STATE(5357)] = 224290,
  [SMALL_STATE(5358)] = 224377,
  [SMALL_STATE(5359)] = 224464,
  [SMALL_STATE(5360)] = 224551,
  [SMALL_STATE(5361)] = 224638,
  [SMALL_STATE(5362)] = 224725,
  [SMALL_STATE(5363)] = 224812,
  [SMALL_STATE(5364)] = 224899,
  [SMALL_STATE(5365)] = 224986,
  [SMALL_STATE(5366)] = 225073,
  [SMALL_STATE(5367)] = 225160,
  [SMALL_STATE(5368)] = 225247,
  [SMALL_STATE(5369)] = 225334,
  [SMALL_STATE(5370)] = 225421,
  [SMALL_STATE(5371)] = 225476,
  [SMALL_STATE(5372)] = 225563,
  [SMALL_STATE(5373)] = 225650,
  [SMALL_STATE(5374)] = 225737,
  [SMALL_STATE(5375)] = 225824,
  [SMALL_STATE(5376)] = 225911,
  [SMALL_STATE(5377)] = 225998,
  [SMALL_STATE(5378)] = 226085,
  [SMALL_STATE(5379)] = 226172,
  [SMALL_STATE(5380)] = 226259,
  [SMALL_STATE(5381)] = 226346,
  [SMALL_STATE(5382)] = 226433,
  [SMALL_STATE(5383)] = 226520,
  [SMALL_STATE(5384)] = 226607,
  [SMALL_STATE(5385)] = 226694,
  [SMALL_STATE(5386)] = 226781,
  [SMALL_STATE(5387)] = 226868,
  [SMALL_STATE(5388)] = 226955,
  [SMALL_STATE(5389)] = 227042,
  [SMALL_STATE(5390)] = 227129,
  [SMALL_STATE(5391)] = 227216,
  [SMALL_STATE(5392)] = 227303,
  [SMALL_STATE(5393)] = 227390,
  [SMALL_STATE(5394)] = 227477,
  [SMALL_STATE(5395)] = 227564,
  [SMALL_STATE(5396)] = 227651,
  [SMALL_STATE(5397)] = 227738,
  [SMALL_STATE(5398)] = 227825,
  [SMALL_STATE(5399)] = 227912,
  [SMALL_STATE(5400)] = 227999,
  [SMALL_STATE(5401)] = 228086,
  [SMALL_STATE(5402)] = 228173,
  [SMALL_STATE(5403)] = 228260,
  [SMALL_STATE(5404)] = 228347,
  [SMALL_STATE(5405)] = 228434,
  [SMALL_STATE(5406)] = 228521,
  [SMALL_STATE(5407)] = 228608,
  [SMALL_STATE(5408)] = 228695,
  [SMALL_STATE(5409)] = 228782,
  [SMALL_STATE(5410)] = 228869,
  [SMALL_STATE(5411)] = 228956,
  [SMALL_STATE(5412)] = 229043,
  [SMALL_STATE(5413)] = 229130,
  [SMALL_STATE(5414)] = 229217,
  [SMALL_STATE(5415)] = 229304,
  [SMALL_STATE(5416)] = 229391,
  [SMALL_STATE(5417)] = 229478,
  [SMALL_STATE(5418)] = 229565,
  [SMALL_STATE(5419)] = 229652,
  [SMALL_STATE(5420)] = 229739,
  [SMALL_STATE(5421)] = 229826,
  [SMALL_STATE(5422)] = 229913,
  [SMALL_STATE(5423)] = 230000,
  [SMALL_STATE(5424)] = 230087,
  [SMALL_STATE(5425)] = 230174,
  [SMALL_STATE(5426)] = 230261,
  [SMALL_STATE(5427)] = 230348,
  [SMALL_STATE(5428)] = 230435,
  [SMALL_STATE(5429)] = 230522,
  [SMALL_STATE(5430)] = 230609,
  [SMALL_STATE(5431)] = 230696,
  [SMALL_STATE(5432)] = 230783,
  [SMALL_STATE(5433)] = 230870,
  [SMALL_STATE(5434)] = 230957,
  [SMALL_STATE(5435)] = 231044,
  [SMALL_STATE(5436)] = 231131,
  [SMALL_STATE(5437)] = 231218,
  [SMALL_STATE(5438)] = 231305,
  [SMALL_STATE(5439)] = 231392,
  [SMALL_STATE(5440)] = 231479,
  [SMALL_STATE(5441)] = 231566,
  [SMALL_STATE(5442)] = 231653,
  [SMALL_STATE(5443)] = 231740,
  [SMALL_STATE(5444)] = 231827,
  [SMALL_STATE(5445)] = 231914,
  [SMALL_STATE(5446)] = 232001,
  [SMALL_STATE(5447)] = 232088,
  [SMALL_STATE(5448)] = 232175,
  [SMALL_STATE(5449)] = 232262,
  [SMALL_STATE(5450)] = 232349,
  [SMALL_STATE(5451)] = 232436,
  [SMALL_STATE(5452)] = 232523,
  [SMALL_STATE(5453)] = 232610,
  [SMALL_STATE(5454)] = 232697,
  [SMALL_STATE(5455)] = 232784,
  [SMALL_STATE(5456)] = 232871,
  [SMALL_STATE(5457)] = 232958,
  [SMALL_STATE(5458)] = 233045,
  [SMALL_STATE(5459)] = 233132,
  [SMALL_STATE(5460)] = 233219,
  [SMALL_STATE(5461)] = 233306,
  [SMALL_STATE(5462)] = 233393,
  [SMALL_STATE(5463)] = 233480,
  [SMALL_STATE(5464)] = 233567,
  [SMALL_STATE(5465)] = 233654,
  [SMALL_STATE(5466)] = 233741,
  [SMALL_STATE(5467)] = 233828,
  [SMALL_STATE(5468)] = 233915,
  [SMALL_STATE(5469)] = 234002,
  [SMALL_STATE(5470)] = 234089,
  [SMALL_STATE(5471)] = 234176,
  [SMALL_STATE(5472)] = 234263,
  [SMALL_STATE(5473)] = 234350,
  [SMALL_STATE(5474)] = 234437,
  [SMALL_STATE(5475)] = 234524,
  [SMALL_STATE(5476)] = 234611,
  [SMALL_STATE(5477)] = 234698,
  [SMALL_STATE(5478)] = 234785,
  [SMALL_STATE(5479)] = 234872,
  [SMALL_STATE(5480)] = 234959,
  [SMALL_STATE(5481)] = 235046,
  [SMALL_STATE(5482)] = 235133,
  [SMALL_STATE(5483)] = 235220,
  [SMALL_STATE(5484)] = 235307,
  [SMALL_STATE(5485)] = 235394,
  [SMALL_STATE(5486)] = 235481,
  [SMALL_STATE(5487)] = 235568,
  [SMALL_STATE(5488)] = 235655,
  [SMALL_STATE(5489)] = 235742,
  [SMALL_STATE(5490)] = 235829,
  [SMALL_STATE(5491)] = 235916,
  [SMALL_STATE(5492)] = 236003,
  [SMALL_STATE(5493)] = 236090,
  [SMALL_STATE(5494)] = 236177,
  [SMALL_STATE(5495)] = 236264,
  [SMALL_STATE(5496)] = 236351,
  [SMALL_STATE(5497)] = 236438,
  [SMALL_STATE(5498)] = 236525,
  [SMALL_STATE(5499)] = 236612,
  [SMALL_STATE(5500)] = 236699,
  [SMALL_STATE(5501)] = 236786,
  [SMALL_STATE(5502)] = 236873,
  [SMALL_STATE(5503)] = 236960,
  [SMALL_STATE(5504)] = 237047,
  [SMALL_STATE(5505)] = 237134,
  [SMALL_STATE(5506)] = 237221,
  [SMALL_STATE(5507)] = 237308,
  [SMALL_STATE(5508)] = 237411,
  [SMALL_STATE(5509)] = 237498,
  [SMALL_STATE(5510)] = 237585,
  [SMALL_STATE(5511)] = 237672,
  [SMALL_STATE(5512)] = 237759,
  [SMALL_STATE(5513)] = 237846,
  [SMALL_STATE(5514)] = 237933,
  [SMALL_STATE(5515)] = 238020,
  [SMALL_STATE(5516)] = 238107,
  [SMALL_STATE(5517)] = 238194,
  [SMALL_STATE(5518)] = 238281,
  [SMALL_STATE(5519)] = 238368,
  [SMALL_STATE(5520)] = 238455,
  [SMALL_STATE(5521)] = 238542,
  [SMALL_STATE(5522)] = 238629,
  [SMALL_STATE(5523)] = 238716,
  [SMALL_STATE(5524)] = 238803,
  [SMALL_STATE(5525)] = 238890,
  [SMALL_STATE(5526)] = 238977,
  [SMALL_STATE(5527)] = 239064,
  [SMALL_STATE(5528)] = 239151,
  [SMALL_STATE(5529)] = 239238,
  [SMALL_STATE(5530)] = 239325,
  [SMALL_STATE(5531)] = 239412,
  [SMALL_STATE(5532)] = 239499,
  [SMALL_STATE(5533)] = 239586,
  [SMALL_STATE(5534)] = 239673,
  [SMALL_STATE(5535)] = 239760,
  [SMALL_STATE(5536)] = 239847,
  [SMALL_STATE(5537)] = 239934,
  [SMALL_STATE(5538)] = 240021,
  [SMALL_STATE(5539)] = 240070,
  [SMALL_STATE(5540)] = 240157,
  [SMALL_STATE(5541)] = 240244,
  [SMALL_STATE(5542)] = 240331,
  [SMALL_STATE(5543)] = 240418,
  [SMALL_STATE(5544)] = 240505,
  [SMALL_STATE(5545)] = 240592,
  [SMALL_STATE(5546)] = 240679,
  [SMALL_STATE(5547)] = 240766,
  [SMALL_STATE(5548)] = 240853,
  [SMALL_STATE(5549)] = 240940,
  [SMALL_STATE(5550)] = 241027,
  [SMALL_STATE(5551)] = 241114,
  [SMALL_STATE(5552)] = 241201,
  [SMALL_STATE(5553)] = 241288,
  [SMALL_STATE(5554)] = 241375,
  [SMALL_STATE(5555)] = 241462,
  [SMALL_STATE(5556)] = 241549,
  [SMALL_STATE(5557)] = 241636,
  [SMALL_STATE(5558)] = 241723,
  [SMALL_STATE(5559)] = 241810,
  [SMALL_STATE(5560)] = 241897,
  [SMALL_STATE(5561)] = 241984,
  [SMALL_STATE(5562)] = 242071,
  [SMALL_STATE(5563)] = 242158,
  [SMALL_STATE(5564)] = 242245,
  [SMALL_STATE(5565)] = 242332,
  [SMALL_STATE(5566)] = 242419,
  [SMALL_STATE(5567)] = 242506,
  [SMALL_STATE(5568)] = 242593,
  [SMALL_STATE(5569)] = 242680,
  [SMALL_STATE(5570)] = 242767,
  [SMALL_STATE(5571)] = 242854,
  [SMALL_STATE(5572)] = 242941,
  [SMALL_STATE(5573)] = 243028,
  [SMALL_STATE(5574)] = 243115,
  [SMALL_STATE(5575)] = 243202,
  [SMALL_STATE(5576)] = 243289,
  [SMALL_STATE(5577)] = 243376,
  [SMALL_STATE(5578)] = 243463,
  [SMALL_STATE(5579)] = 243550,
  [SMALL_STATE(5580)] = 243637,
  [SMALL_STATE(5581)] = 243724,
  [SMALL_STATE(5582)] = 243811,
  [SMALL_STATE(5583)] = 243898,
  [SMALL_STATE(5584)] = 243985,
  [SMALL_STATE(5585)] = 244072,
  [SMALL_STATE(5586)] = 244159,
  [SMALL_STATE(5587)] = 244246,
  [SMALL_STATE(5588)] = 244333,
  [SMALL_STATE(5589)] = 244420,
  [SMALL_STATE(5590)] = 244507,
  [SMALL_STATE(5591)] = 244594,
  [SMALL_STATE(5592)] = 244681,
  [SMALL_STATE(5593)] = 244768,
  [SMALL_STATE(5594)] = 244855,
  [SMALL_STATE(5595)] = 244942,
  [SMALL_STATE(5596)] = 245029,
  [SMALL_STATE(5597)] = 245116,
  [SMALL_STATE(5598)] = 245203,
  [SMALL_STATE(5599)] = 245290,
  [SMALL_STATE(5600)] = 245377,
  [SMALL_STATE(5601)] = 245464,
  [SMALL_STATE(5602)] = 245551,
  [SMALL_STATE(5603)] = 245638,
  [SMALL_STATE(5604)] = 245725,
  [SMALL_STATE(5605)] = 245812,
  [SMALL_STATE(5606)] = 245899,
  [SMALL_STATE(5607)] = 245986,
  [SMALL_STATE(5608)] = 246073,
  [SMALL_STATE(5609)] = 246160,
  [SMALL_STATE(5610)] = 246247,
  [SMALL_STATE(5611)] = 246334,
  [SMALL_STATE(5612)] = 246421,
  [SMALL_STATE(5613)] = 246508,
  [SMALL_STATE(5614)] = 246595,
  [SMALL_STATE(5615)] = 246682,
  [SMALL_STATE(5616)] = 246769,
  [SMALL_STATE(5617)] = 246856,
  [SMALL_STATE(5618)] = 246943,
  [SMALL_STATE(5619)] = 247030,
  [SMALL_STATE(5620)] = 247117,
  [SMALL_STATE(5621)] = 247204,
  [SMALL_STATE(5622)] = 247291,
  [SMALL_STATE(5623)] = 247378,
  [SMALL_STATE(5624)] = 247465,
  [SMALL_STATE(5625)] = 247552,
  [SMALL_STATE(5626)] = 247639,
  [SMALL_STATE(5627)] = 247726,
  [SMALL_STATE(5628)] = 247813,
  [SMALL_STATE(5629)] = 247900,
  [SMALL_STATE(5630)] = 247995,
  [SMALL_STATE(5631)] = 248082,
  [SMALL_STATE(5632)] = 248169,
  [SMALL_STATE(5633)] = 248256,
  [SMALL_STATE(5634)] = 248343,
  [SMALL_STATE(5635)] = 248430,
  [SMALL_STATE(5636)] = 248517,
  [SMALL_STATE(5637)] = 248604,
  [SMALL_STATE(5638)] = 248691,
  [SMALL_STATE(5639)] = 248778,
  [SMALL_STATE(5640)] = 248865,
  [SMALL_STATE(5641)] = 248952,
  [SMALL_STATE(5642)] = 249039,
  [SMALL_STATE(5643)] = 249126,
  [SMALL_STATE(5644)] = 249213,
  [SMALL_STATE(5645)] = 249300,
  [SMALL_STATE(5646)] = 249387,
  [SMALL_STATE(5647)] = 249474,
  [SMALL_STATE(5648)] = 249561,
  [SMALL_STATE(5649)] = 249648,
  [SMALL_STATE(5650)] = 249735,
  [SMALL_STATE(5651)] = 249822,
  [SMALL_STATE(5652)] = 249909,
  [SMALL_STATE(5653)] = 249996,
  [SMALL_STATE(5654)] = 250083,
  [SMALL_STATE(5655)] = 250170,
  [SMALL_STATE(5656)] = 250257,
  [SMALL_STATE(5657)] = 250306,
  [SMALL_STATE(5658)] = 250393,
  [SMALL_STATE(5659)] = 250480,
  [SMALL_STATE(5660)] = 250567,
  [SMALL_STATE(5661)] = 250654,
  [SMALL_STATE(5662)] = 250741,
  [SMALL_STATE(5663)] = 250828,
  [SMALL_STATE(5664)] = 250915,
  [SMALL_STATE(5665)] = 251002,
  [SMALL_STATE(5666)] = 251089,
  [SMALL_STATE(5667)] = 251176,
  [SMALL_STATE(5668)] = 251263,
  [SMALL_STATE(5669)] = 251350,
  [SMALL_STATE(5670)] = 251437,
  [SMALL_STATE(5671)] = 251524,
  [SMALL_STATE(5672)] = 251611,
  [SMALL_STATE(5673)] = 251698,
  [SMALL_STATE(5674)] = 251785,
  [SMALL_STATE(5675)] = 251872,
  [SMALL_STATE(5676)] = 251921,
  [SMALL_STATE(5677)] = 252008,
  [SMALL_STATE(5678)] = 252095,
  [SMALL_STATE(5679)] = 252182,
  [SMALL_STATE(5680)] = 252269,
  [SMALL_STATE(5681)] = 252356,
  [SMALL_STATE(5682)] = 252443,
  [SMALL_STATE(5683)] = 252530,
  [SMALL_STATE(5684)] = 252617,
  [SMALL_STATE(5685)] = 252704,
  [SMALL_STATE(5686)] = 252791,
  [SMALL_STATE(5687)] = 252878,
  [SMALL_STATE(5688)] = 252965,
  [SMALL_STATE(5689)] = 253052,
  [SMALL_STATE(5690)] = 253139,
  [SMALL_STATE(5691)] = 253226,
  [SMALL_STATE(5692)] = 253313,
  [SMALL_STATE(5693)] = 253400,
  [SMALL_STATE(5694)] = 253487,
  [SMALL_STATE(5695)] = 253574,
  [SMALL_STATE(5696)] = 253661,
  [SMALL_STATE(5697)] = 253748,
  [SMALL_STATE(5698)] = 253835,
  [SMALL_STATE(5699)] = 253922,
  [SMALL_STATE(5700)] = 254009,
  [SMALL_STATE(5701)] = 254096,
  [SMALL_STATE(5702)] = 254183,
  [SMALL_STATE(5703)] = 254270,
  [SMALL_STATE(5704)] = 254357,
  [SMALL_STATE(5705)] = 254444,
  [SMALL_STATE(5706)] = 254531,
  [SMALL_STATE(5707)] = 254618,
  [SMALL_STATE(5708)] = 254705,
  [SMALL_STATE(5709)] = 254792,
  [SMALL_STATE(5710)] = 254879,
  [SMALL_STATE(5711)] = 254966,
  [SMALL_STATE(5712)] = 255053,
  [SMALL_STATE(5713)] = 255140,
  [SMALL_STATE(5714)] = 255227,
  [SMALL_STATE(5715)] = 255314,
  [SMALL_STATE(5716)] = 255364,
  [SMALL_STATE(5717)] = 255414,
  [SMALL_STATE(5718)] = 255464,
  [SMALL_STATE(5719)] = 255514,
  [SMALL_STATE(5720)] = 255564,
  [SMALL_STATE(5721)] = 255614,
  [SMALL_STATE(5722)] = 255710,
  [SMALL_STATE(5723)] = 255760,
  [SMALL_STATE(5724)] = 255810,
  [SMALL_STATE(5725)] = 255860,
  [SMALL_STATE(5726)] = 255910,
  [SMALL_STATE(5727)] = 255960,
  [SMALL_STATE(5728)] = 256010,
  [SMALL_STATE(5729)] = 256060,
  [SMALL_STATE(5730)] = 256110,
  [SMALL_STATE(5731)] = 256160,
  [SMALL_STATE(5732)] = 256210,
  [SMALL_STATE(5733)] = 256260,
  [SMALL_STATE(5734)] = 256310,
  [SMALL_STATE(5735)] = 256360,
  [SMALL_STATE(5736)] = 256410,
  [SMALL_STATE(5737)] = 256460,
  [SMALL_STATE(5738)] = 256510,
  [SMALL_STATE(5739)] = 256560,
  [SMALL_STATE(5740)] = 256610,
  [SMALL_STATE(5741)] = 256660,
  [SMALL_STATE(5742)] = 256710,
  [SMALL_STATE(5743)] = 256760,
  [SMALL_STATE(5744)] = 256810,
  [SMALL_STATE(5745)] = 256860,
  [SMALL_STATE(5746)] = 256956,
  [SMALL_STATE(5747)] = 257006,
  [SMALL_STATE(5748)] = 257056,
  [SMALL_STATE(5749)] = 257106,
  [SMALL_STATE(5750)] = 257156,
  [SMALL_STATE(5751)] = 257206,
  [SMALL_STATE(5752)] = 257256,
  [SMALL_STATE(5753)] = 257306,
  [SMALL_STATE(5754)] = 257406,
  [SMALL_STATE(5755)] = 257456,
  [SMALL_STATE(5756)] = 257506,
  [SMALL_STATE(5757)] = 257556,
  [SMALL_STATE(5758)] = 257606,
  [SMALL_STATE(5759)] = 257656,
  [SMALL_STATE(5760)] = 257750,
  [SMALL_STATE(5761)] = 257800,
  [SMALL_STATE(5762)] = 257850,
  [SMALL_STATE(5763)] = 257900,
  [SMALL_STATE(5764)] = 257950,
  [SMALL_STATE(5765)] = 258000,
  [SMALL_STATE(5766)] = 258050,
  [SMALL_STATE(5767)] = 258100,
  [SMALL_STATE(5768)] = 258150,
  [SMALL_STATE(5769)] = 258200,
  [SMALL_STATE(5770)] = 258250,
  [SMALL_STATE(5771)] = 258350,
  [SMALL_STATE(5772)] = 258450,
  [SMALL_STATE(5773)] = 258500,
  [SMALL_STATE(5774)] = 258550,
  [SMALL_STATE(5775)] = 258600,
  [SMALL_STATE(5776)] = 258650,
  [SMALL_STATE(5777)] = 258700,
  [SMALL_STATE(5778)] = 258750,
  [SMALL_STATE(5779)] = 258800,
  [SMALL_STATE(5780)] = 258850,
  [SMALL_STATE(5781)] = 258900,
  [SMALL_STATE(5782)] = 258950,
  [SMALL_STATE(5783)] = 259000,
  [SMALL_STATE(5784)] = 259050,
  [SMALL_STATE(5785)] = 259100,
  [SMALL_STATE(5786)] = 259150,
  [SMALL_STATE(5787)] = 259200,
  [SMALL_STATE(5788)] = 259300,
  [SMALL_STATE(5789)] = 259350,
  [SMALL_STATE(5790)] = 259400,
  [SMALL_STATE(5791)] = 259450,
  [SMALL_STATE(5792)] = 259500,
  [SMALL_STATE(5793)] = 259550,
  [SMALL_STATE(5794)] = 259600,
  [SMALL_STATE(5795)] = 259650,
  [SMALL_STATE(5796)] = 259700,
  [SMALL_STATE(5797)] = 259750,
  [SMALL_STATE(5798)] = 259800,
  [SMALL_STATE(5799)] = 259850,
  [SMALL_STATE(5800)] = 259900,
  [SMALL_STATE(5801)] = 259950,
  [SMALL_STATE(5802)] = 260000,
  [SMALL_STATE(5803)] = 260050,
  [SMALL_STATE(5804)] = 260146,
  [SMALL_STATE(5805)] = 260196,
  [SMALL_STATE(5806)] = 260246,
  [SMALL_STATE(5807)] = 260296,
  [SMALL_STATE(5808)] = 260392,
  [SMALL_STATE(5809)] = 260488,
  [SMALL_STATE(5810)] = 260538,
  [SMALL_STATE(5811)] = 260588,
  [SMALL_STATE(5812)] = 260638,
  [SMALL_STATE(5813)] = 260688,
  [SMALL_STATE(5814)] = 260738,
  [SMALL_STATE(5815)] = 260788,
  [SMALL_STATE(5816)] = 260838,
  [SMALL_STATE(5817)] = 260888,
  [SMALL_STATE(5818)] = 260938,
  [SMALL_STATE(5819)] = 260988,
  [SMALL_STATE(5820)] = 261038,
  [SMALL_STATE(5821)] = 261088,
  [SMALL_STATE(5822)] = 261138,
  [SMALL_STATE(5823)] = 261188,
  [SMALL_STATE(5824)] = 261238,
  [SMALL_STATE(5825)] = 261288,
  [SMALL_STATE(5826)] = 261338,
  [SMALL_STATE(5827)] = 261388,
  [SMALL_STATE(5828)] = 261438,
  [SMALL_STATE(5829)] = 261488,
  [SMALL_STATE(5830)] = 261538,
  [SMALL_STATE(5831)] = 261588,
  [SMALL_STATE(5832)] = 261638,
  [SMALL_STATE(5833)] = 261688,
  [SMALL_STATE(5834)] = 261738,
  [SMALL_STATE(5835)] = 261788,
  [SMALL_STATE(5836)] = 261838,
  [SMALL_STATE(5837)] = 261888,
  [SMALL_STATE(5838)] = 261938,
  [SMALL_STATE(5839)] = 261988,
  [SMALL_STATE(5840)] = 262038,
  [SMALL_STATE(5841)] = 262088,
  [SMALL_STATE(5842)] = 262138,
  [SMALL_STATE(5843)] = 262188,
  [SMALL_STATE(5844)] = 262238,
  [SMALL_STATE(5845)] = 262288,
  [SMALL_STATE(5846)] = 262338,
  [SMALL_STATE(5847)] = 262388,
  [SMALL_STATE(5848)] = 262438,
  [SMALL_STATE(5849)] = 262488,
  [SMALL_STATE(5850)] = 262538,
  [SMALL_STATE(5851)] = 262588,
  [SMALL_STATE(5852)] = 262638,
  [SMALL_STATE(5853)] = 262688,
  [SMALL_STATE(5854)] = 262738,
  [SMALL_STATE(5855)] = 262788,
  [SMALL_STATE(5856)] = 262838,
  [SMALL_STATE(5857)] = 262888,
  [SMALL_STATE(5858)] = 262938,
  [SMALL_STATE(5859)] = 262988,
  [SMALL_STATE(5860)] = 263038,
  [SMALL_STATE(5861)] = 263088,
  [SMALL_STATE(5862)] = 263138,
  [SMALL_STATE(5863)] = 263188,
  [SMALL_STATE(5864)] = 263238,
  [SMALL_STATE(5865)] = 263288,
  [SMALL_STATE(5866)] = 263338,
  [SMALL_STATE(5867)] = 263388,
  [SMALL_STATE(5868)] = 263438,
  [SMALL_STATE(5869)] = 263488,
  [SMALL_STATE(5870)] = 263538,
  [SMALL_STATE(5871)] = 263588,
  [SMALL_STATE(5872)] = 263638,
  [SMALL_STATE(5873)] = 263688,
  [SMALL_STATE(5874)] = 263738,
  [SMALL_STATE(5875)] = 263788,
  [SMALL_STATE(5876)] = 263838,
  [SMALL_STATE(5877)] = 263888,
  [SMALL_STATE(5878)] = 263938,
  [SMALL_STATE(5879)] = 263988,
  [SMALL_STATE(5880)] = 264038,
  [SMALL_STATE(5881)] = 264088,
  [SMALL_STATE(5882)] = 264138,
  [SMALL_STATE(5883)] = 264188,
  [SMALL_STATE(5884)] = 264238,
  [SMALL_STATE(5885)] = 264288,
  [SMALL_STATE(5886)] = 264338,
  [SMALL_STATE(5887)] = 264388,
  [SMALL_STATE(5888)] = 264438,
  [SMALL_STATE(5889)] = 264488,
  [SMALL_STATE(5890)] = 264538,
  [SMALL_STATE(5891)] = 264588,
  [SMALL_STATE(5892)] = 264638,
  [SMALL_STATE(5893)] = 264688,
  [SMALL_STATE(5894)] = 264738,
  [SMALL_STATE(5895)] = 264788,
  [SMALL_STATE(5896)] = 264838,
  [SMALL_STATE(5897)] = 264888,
  [SMALL_STATE(5898)] = 264984,
  [SMALL_STATE(5899)] = 265034,
  [SMALL_STATE(5900)] = 265084,
  [SMALL_STATE(5901)] = 265134,
  [SMALL_STATE(5902)] = 265234,
  [SMALL_STATE(5903)] = 265329,
  [SMALL_STATE(5904)] = 265382,
  [SMALL_STATE(5905)] = 265435,
  [SMALL_STATE(5906)] = 265488,
  [SMALL_STATE(5907)] = 265585,
  [SMALL_STATE(5908)] = 265638,
  [SMALL_STATE(5909)] = 265735,
  [SMALL_STATE(5910)] = 265832,
  [SMALL_STATE(5911)] = 265929,
  [SMALL_STATE(5912)] = 265982,
  [SMALL_STATE(5913)] = 266079,
  [SMALL_STATE(5914)] = 266176,
  [SMALL_STATE(5915)] = 266229,
  [SMALL_STATE(5916)] = 266326,
  [SMALL_STATE(5917)] = 266379,
  [SMALL_STATE(5918)] = 266476,
  [SMALL_STATE(5919)] = 266529,
  [SMALL_STATE(5920)] = 266626,
  [SMALL_STATE(5921)] = 266679,
  [SMALL_STATE(5922)] = 266776,
  [SMALL_STATE(5923)] = 266871,
  [SMALL_STATE(5924)] = 266968,
  [SMALL_STATE(5925)] = 267065,
  [SMALL_STATE(5926)] = 267162,
  [SMALL_STATE(5927)] = 267259,
  [SMALL_STATE(5928)] = 267312,
  [SMALL_STATE(5929)] = 267409,
  [SMALL_STATE(5930)] = 267506,
  [SMALL_STATE(5931)] = 267559,
  [SMALL_STATE(5932)] = 267656,
  [SMALL_STATE(5933)] = 267753,
  [SMALL_STATE(5934)] = 267806,
  [SMALL_STATE(5935)] = 267903,
  [SMALL_STATE(5936)] = 268000,
  [SMALL_STATE(5937)] = 268097,
  [SMALL_STATE(5938)] = 268194,
  [SMALL_STATE(5939)] = 268291,
  [SMALL_STATE(5940)] = 268388,
  [SMALL_STATE(5941)] = 268485,
  [SMALL_STATE(5942)] = 268582,
  [SMALL_STATE(5943)] = 268629,
  [SMALL_STATE(5944)] = 268726,
  [SMALL_STATE(5945)] = 268821,
  [SMALL_STATE(5946)] = 268918,
  [SMALL_STATE(5947)] = 269015,
  [SMALL_STATE(5948)] = 269112,
  [SMALL_STATE(5949)] = 269209,
  [SMALL_STATE(5950)] = 269306,
  [SMALL_STATE(5951)] = 269403,
  [SMALL_STATE(5952)] = 269498,
  [SMALL_STATE(5953)] = 269551,
  [SMALL_STATE(5954)] = 269648,
  [SMALL_STATE(5955)] = 269745,
  [SMALL_STATE(5956)] = 269798,
  [SMALL_STATE(5957)] = 269895,
  [SMALL_STATE(5958)] = 269948,
  [SMALL_STATE(5959)] = 270045,
  [SMALL_STATE(5960)] = 270142,
  [SMALL_STATE(5961)] = 270239,
  [SMALL_STATE(5962)] = 270336,
  [SMALL_STATE(5963)] = 270431,
  [SMALL_STATE(5964)] = 270484,
  [SMALL_STATE(5965)] = 270581,
  [SMALL_STATE(5966)] = 270678,
  [SMALL_STATE(5967)] = 270775,
  [SMALL_STATE(5968)] = 270869,
  [SMALL_STATE(5969)] = 270963,
  [SMALL_STATE(5970)] = 271057,
  [SMALL_STATE(5971)] = 271151,
  [SMALL_STATE(5972)] = 271245,
  [SMALL_STATE(5973)] = 271339,
  [SMALL_STATE(5974)] = 271433,
  [SMALL_STATE(5975)] = 271527,
  [SMALL_STATE(5976)] = 271621,
  [SMALL_STATE(5977)] = 271715,
  [SMALL_STATE(5978)] = 271809,
  [SMALL_STATE(5979)] = 271903,
  [SMALL_STATE(5980)] = 271997,
  [SMALL_STATE(5981)] = 272091,
  [SMALL_STATE(5982)] = 272185,
  [SMALL_STATE(5983)] = 272279,
  [SMALL_STATE(5984)] = 272373,
  [SMALL_STATE(5985)] = 272467,
  [SMALL_STATE(5986)] = 272561,
  [SMALL_STATE(5987)] = 272655,
  [SMALL_STATE(5988)] = 272749,
  [SMALL_STATE(5989)] = 272843,
  [SMALL_STATE(5990)] = 272937,
  [SMALL_STATE(5991)] = 273031,
  [SMALL_STATE(5992)] = 273125,
  [SMALL_STATE(5993)] = 273219,
  [SMALL_STATE(5994)] = 273313,
  [SMALL_STATE(5995)] = 273407,
  [SMALL_STATE(5996)] = 273501,
  [SMALL_STATE(5997)] = 273595,
  [SMALL_STATE(5998)] = 273689,
  [SMALL_STATE(5999)] = 273783,
  [SMALL_STATE(6000)] = 273877,
  [SMALL_STATE(6001)] = 273971,
  [SMALL_STATE(6002)] = 274061,
  [SMALL_STATE(6003)] = 274155,
  [SMALL_STATE(6004)] = 274249,
  [SMALL_STATE(6005)] = 274343,
  [SMALL_STATE(6006)] = 274437,
  [SMALL_STATE(6007)] = 274529,
  [SMALL_STATE(6008)] = 274623,
  [SMALL_STATE(6009)] = 274717,
  [SMALL_STATE(6010)] = 274811,
  [SMALL_STATE(6011)] = 274905,
  [SMALL_STATE(6012)] = 274999,
  [SMALL_STATE(6013)] = 275093,
  [SMALL_STATE(6014)] = 275187,
  [SMALL_STATE(6015)] = 275281,
  [SMALL_STATE(6016)] = 275375,
  [SMALL_STATE(6017)] = 275469,
  [SMALL_STATE(6018)] = 275563,
  [SMALL_STATE(6019)] = 275657,
  [SMALL_STATE(6020)] = 275751,
  [SMALL_STATE(6021)] = 275845,
  [SMALL_STATE(6022)] = 275939,
  [SMALL_STATE(6023)] = 276033,
  [SMALL_STATE(6024)] = 276127,
  [SMALL_STATE(6025)] = 276221,
  [SMALL_STATE(6026)] = 276315,
  [SMALL_STATE(6027)] = 276409,
  [SMALL_STATE(6028)] = 276503,
  [SMALL_STATE(6029)] = 276597,
  [SMALL_STATE(6030)] = 276691,
  [SMALL_STATE(6031)] = 276785,
  [SMALL_STATE(6032)] = 276879,
  [SMALL_STATE(6033)] = 276973,
  [SMALL_STATE(6034)] = 277067,
  [SMALL_STATE(6035)] = 277161,
  [SMALL_STATE(6036)] = 277255,
  [SMALL_STATE(6037)] = 277349,
  [SMALL_STATE(6038)] = 277443,
  [SMALL_STATE(6039)] = 277537,
  [SMALL_STATE(6040)] = 277631,
  [SMALL_STATE(6041)] = 277725,
  [SMALL_STATE(6042)] = 277819,
  [SMALL_STATE(6043)] = 277913,
  [SMALL_STATE(6044)] = 278007,
  [SMALL_STATE(6045)] = 278101,
  [SMALL_STATE(6046)] = 278195,
  [SMALL_STATE(6047)] = 278289,
  [SMALL_STATE(6048)] = 278383,
  [SMALL_STATE(6049)] = 278477,
  [SMALL_STATE(6050)] = 278571,
  [SMALL_STATE(6051)] = 278665,
  [SMALL_STATE(6052)] = 278759,
  [SMALL_STATE(6053)] = 278853,
  [SMALL_STATE(6054)] = 278947,
  [SMALL_STATE(6055)] = 279041,
  [SMALL_STATE(6056)] = 279135,
  [SMALL_STATE(6057)] = 279229,
  [SMALL_STATE(6058)] = 279323,
  [SMALL_STATE(6059)] = 279417,
  [SMALL_STATE(6060)] = 279511,
  [SMALL_STATE(6061)] = 279605,
  [SMALL_STATE(6062)] = 279699,
  [SMALL_STATE(6063)] = 279793,
  [SMALL_STATE(6064)] = 279887,
  [SMALL_STATE(6065)] = 279981,
  [SMALL_STATE(6066)] = 280075,
  [SMALL_STATE(6067)] = 280169,
  [SMALL_STATE(6068)] = 280263,
  [SMALL_STATE(6069)] = 280357,
  [SMALL_STATE(6070)] = 280447,
  [SMALL_STATE(6071)] = 280541,
  [SMALL_STATE(6072)] = 280635,
  [SMALL_STATE(6073)] = 280729,
  [SMALL_STATE(6074)] = 280823,
  [SMALL_STATE(6075)] = 280917,
  [SMALL_STATE(6076)] = 281011,
  [SMALL_STATE(6077)] = 281105,
  [SMALL_STATE(6078)] = 281199,
  [SMALL_STATE(6079)] = 281293,
  [SMALL_STATE(6080)] = 281387,
  [SMALL_STATE(6081)] = 281481,
  [SMALL_STATE(6082)] = 281575,
  [SMALL_STATE(6083)] = 281669,
  [SMALL_STATE(6084)] = 281763,
  [SMALL_STATE(6085)] = 281857,
  [SMALL_STATE(6086)] = 281951,
  [SMALL_STATE(6087)] = 282045,
  [SMALL_STATE(6088)] = 282139,
  [SMALL_STATE(6089)] = 282233,
  [SMALL_STATE(6090)] = 282327,
  [SMALL_STATE(6091)] = 282421,
  [SMALL_STATE(6092)] = 282515,
  [SMALL_STATE(6093)] = 282609,
  [SMALL_STATE(6094)] = 282703,
  [SMALL_STATE(6095)] = 282797,
  [SMALL_STATE(6096)] = 282891,
  [SMALL_STATE(6097)] = 282985,
  [SMALL_STATE(6098)] = 283079,
  [SMALL_STATE(6099)] = 283173,
  [SMALL_STATE(6100)] = 283267,
  [SMALL_STATE(6101)] = 283361,
  [SMALL_STATE(6102)] = 283455,
  [SMALL_STATE(6103)] = 283549,
  [SMALL_STATE(6104)] = 283643,
  [SMALL_STATE(6105)] = 283737,
  [SMALL_STATE(6106)] = 283829,
  [SMALL_STATE(6107)] = 283923,
  [SMALL_STATE(6108)] = 284017,
  [SMALL_STATE(6109)] = 284111,
  [SMALL_STATE(6110)] = 284205,
  [SMALL_STATE(6111)] = 284299,
  [SMALL_STATE(6112)] = 284393,
  [SMALL_STATE(6113)] = 284487,
  [SMALL_STATE(6114)] = 284581,
  [SMALL_STATE(6115)] = 284675,
  [SMALL_STATE(6116)] = 284769,
  [SMALL_STATE(6117)] = 284863,
  [SMALL_STATE(6118)] = 284957,
  [SMALL_STATE(6119)] = 285051,
  [SMALL_STATE(6120)] = 285145,
  [SMALL_STATE(6121)] = 285239,
  [SMALL_STATE(6122)] = 285333,
  [SMALL_STATE(6123)] = 285427,
  [SMALL_STATE(6124)] = 285521,
  [SMALL_STATE(6125)] = 285615,
  [SMALL_STATE(6126)] = 285709,
  [SMALL_STATE(6127)] = 285803,
  [SMALL_STATE(6128)] = 285897,
  [SMALL_STATE(6129)] = 285991,
  [SMALL_STATE(6130)] = 286085,
  [SMALL_STATE(6131)] = 286175,
  [SMALL_STATE(6132)] = 286269,
  [SMALL_STATE(6133)] = 286363,
  [SMALL_STATE(6134)] = 286457,
  [SMALL_STATE(6135)] = 286551,
  [SMALL_STATE(6136)] = 286645,
  [SMALL_STATE(6137)] = 286739,
  [SMALL_STATE(6138)] = 286833,
  [SMALL_STATE(6139)] = 286927,
  [SMALL_STATE(6140)] = 287021,
  [SMALL_STATE(6141)] = 287115,
  [SMALL_STATE(6142)] = 287209,
  [SMALL_STATE(6143)] = 287303,
  [SMALL_STATE(6144)] = 287397,
  [SMALL_STATE(6145)] = 287491,
  [SMALL_STATE(6146)] = 287585,
  [SMALL_STATE(6147)] = 287679,
  [SMALL_STATE(6148)] = 287773,
  [SMALL_STATE(6149)] = 287864,
  [SMALL_STATE(6150)] = 287953,
  [SMALL_STATE(6151)] = 288042,
  [SMALL_STATE(6152)] = 288133,
  [SMALL_STATE(6153)] = 288182,
  [SMALL_STATE(6154)] = 288273,
  [SMALL_STATE(6155)] = 288364,
  [SMALL_STATE(6156)] = 288455,
  [SMALL_STATE(6157)] = 288546,
  [SMALL_STATE(6158)] = 288637,
  [SMALL_STATE(6159)] = 288728,
  [SMALL_STATE(6160)] = 288777,
  [SMALL_STATE(6161)] = 288868,
  [SMALL_STATE(6162)] = 288959,
  [SMALL_STATE(6163)] = 289048,
  [SMALL_STATE(6164)] = 289097,
  [SMALL_STATE(6165)] = 289188,
  [SMALL_STATE(6166)] = 289279,
  [SMALL_STATE(6167)] = 289328,
  [SMALL_STATE(6168)] = 289419,
  [SMALL_STATE(6169)] = 289510,
  [SMALL_STATE(6170)] = 289601,
  [SMALL_STATE(6171)] = 289692,
  [SMALL_STATE(6172)] = 289783,
  [SMALL_STATE(6173)] = 289874,
  [SMALL_STATE(6174)] = 289963,
  [SMALL_STATE(6175)] = 290054,
  [SMALL_STATE(6176)] = 290143,
  [SMALL_STATE(6177)] = 290234,
  [SMALL_STATE(6178)] = 290325,
  [SMALL_STATE(6179)] = 290416,
  [SMALL_STATE(6180)] = 290465,
  [SMALL_STATE(6181)] = 290514,
  [SMALL_STATE(6182)] = 290605,
  [SMALL_STATE(6183)] = 290654,
  [SMALL_STATE(6184)] = 290743,
  [SMALL_STATE(6185)] = 290834,
  [SMALL_STATE(6186)] = 290883,
  [SMALL_STATE(6187)] = 290974,
  [SMALL_STATE(6188)] = 291065,
  [SMALL_STATE(6189)] = 291154,
  [SMALL_STATE(6190)] = 291243,
  [SMALL_STATE(6191)] = 291334,
  [SMALL_STATE(6192)] = 291423,
  [SMALL_STATE(6193)] = 291472,
  [SMALL_STATE(6194)] = 291563,
  [SMALL_STATE(6195)] = 291612,
  [SMALL_STATE(6196)] = 291701,
  [SMALL_STATE(6197)] = 291790,
  [SMALL_STATE(6198)] = 291839,
  [SMALL_STATE(6199)] = 291928,
  [SMALL_STATE(6200)] = 292017,
  [SMALL_STATE(6201)] = 292106,
  [SMALL_STATE(6202)] = 292195,
  [SMALL_STATE(6203)] = 292244,
  [SMALL_STATE(6204)] = 292293,
  [SMALL_STATE(6205)] = 292384,
  [SMALL_STATE(6206)] = 292473,
  [SMALL_STATE(6207)] = 292564,
  [SMALL_STATE(6208)] = 292613,
  [SMALL_STATE(6209)] = 292704,
  [SMALL_STATE(6210)] = 292753,
  [SMALL_STATE(6211)] = 292844,
  [SMALL_STATE(6212)] = 292893,
  [SMALL_STATE(6213)] = 292984,
  [SMALL_STATE(6214)] = 293072,
  [SMALL_STATE(6215)] = 293160,
  [SMALL_STATE(6216)] = 293248,
  [SMALL_STATE(6217)] = 293336,
  [SMALL_STATE(6218)] = 293424,
  [SMALL_STATE(6219)] = 293512,
  [SMALL_STATE(6220)] = 293600,
  [SMALL_STATE(6221)] = 293688,
  [SMALL_STATE(6222)] = 293776,
  [SMALL_STATE(6223)] = 293864,
  [SMALL_STATE(6224)] = 293952,
  [SMALL_STATE(6225)] = 294040,
  [SMALL_STATE(6226)] = 294128,
  [SMALL_STATE(6227)] = 294216,
  [SMALL_STATE(6228)] = 294304,
  [SMALL_STATE(6229)] = 294392,
  [SMALL_STATE(6230)] = 294480,
  [SMALL_STATE(6231)] = 294568,
  [SMALL_STATE(6232)] = 294656,
  [SMALL_STATE(6233)] = 294744,
  [SMALL_STATE(6234)] = 294832,
  [SMALL_STATE(6235)] = 294920,
  [SMALL_STATE(6236)] = 295008,
  [SMALL_STATE(6237)] = 295096,
  [SMALL_STATE(6238)] = 295184,
  [SMALL_STATE(6239)] = 295272,
  [SMALL_STATE(6240)] = 295360,
  [SMALL_STATE(6241)] = 295448,
  [SMALL_STATE(6242)] = 295536,
  [SMALL_STATE(6243)] = 295624,
  [SMALL_STATE(6244)] = 295712,
  [SMALL_STATE(6245)] = 295800,
  [SMALL_STATE(6246)] = 295888,
  [SMALL_STATE(6247)] = 295976,
  [SMALL_STATE(6248)] = 296064,
  [SMALL_STATE(6249)] = 296152,
  [SMALL_STATE(6250)] = 296240,
  [SMALL_STATE(6251)] = 296328,
  [SMALL_STATE(6252)] = 296416,
  [SMALL_STATE(6253)] = 296504,
  [SMALL_STATE(6254)] = 296592,
  [SMALL_STATE(6255)] = 296680,
  [SMALL_STATE(6256)] = 296768,
  [SMALL_STATE(6257)] = 296856,
  [SMALL_STATE(6258)] = 296944,
  [SMALL_STATE(6259)] = 297032,
  [SMALL_STATE(6260)] = 297120,
  [SMALL_STATE(6261)] = 297208,
  [SMALL_STATE(6262)] = 297296,
  [SMALL_STATE(6263)] = 297384,
  [SMALL_STATE(6264)] = 297472,
  [SMALL_STATE(6265)] = 297560,
  [SMALL_STATE(6266)] = 297648,
  [SMALL_STATE(6267)] = 297736,
  [SMALL_STATE(6268)] = 297824,
  [SMALL_STATE(6269)] = 297912,
  [SMALL_STATE(6270)] = 298000,
  [SMALL_STATE(6271)] = 298088,
  [SMALL_STATE(6272)] = 298176,
  [SMALL_STATE(6273)] = 298264,
  [SMALL_STATE(6274)] = 298352,
  [SMALL_STATE(6275)] = 298440,
  [SMALL_STATE(6276)] = 298528,
  [SMALL_STATE(6277)] = 298616,
  [SMALL_STATE(6278)] = 298704,
  [SMALL_STATE(6279)] = 298792,
  [SMALL_STATE(6280)] = 298880,
  [SMALL_STATE(6281)] = 298968,
  [SMALL_STATE(6282)] = 299056,
  [SMALL_STATE(6283)] = 299144,
  [SMALL_STATE(6284)] = 299232,
  [SMALL_STATE(6285)] = 299320,
  [SMALL_STATE(6286)] = 299408,
  [SMALL_STATE(6287)] = 299496,
  [SMALL_STATE(6288)] = 299584,
  [SMALL_STATE(6289)] = 299672,
  [SMALL_STATE(6290)] = 299760,
  [SMALL_STATE(6291)] = 299848,
  [SMALL_STATE(6292)] = 299936,
  [SMALL_STATE(6293)] = 300024,
  [SMALL_STATE(6294)] = 300112,
  [SMALL_STATE(6295)] = 300200,
  [SMALL_STATE(6296)] = 300288,
  [SMALL_STATE(6297)] = 300376,
  [SMALL_STATE(6298)] = 300464,
  [SMALL_STATE(6299)] = 300552,
  [SMALL_STATE(6300)] = 300640,
  [SMALL_STATE(6301)] = 300728,
  [SMALL_STATE(6302)] = 300816,
  [SMALL_STATE(6303)] = 300904,
  [SMALL_STATE(6304)] = 300992,
  [SMALL_STATE(6305)] = 301080,
  [SMALL_STATE(6306)] = 301168,
  [SMALL_STATE(6307)] = 301256,
  [SMALL_STATE(6308)] = 301344,
  [SMALL_STATE(6309)] = 301432,
  [SMALL_STATE(6310)] = 301520,
  [SMALL_STATE(6311)] = 301608,
  [SMALL_STATE(6312)] = 301696,
  [SMALL_STATE(6313)] = 301784,
  [SMALL_STATE(6314)] = 301872,
  [SMALL_STATE(6315)] = 301960,
  [SMALL_STATE(6316)] = 302048,
  [SMALL_STATE(6317)] = 302136,
  [SMALL_STATE(6318)] = 302224,
  [SMALL_STATE(6319)] = 302312,
  [SMALL_STATE(6320)] = 302400,
  [SMALL_STATE(6321)] = 302488,
  [SMALL_STATE(6322)] = 302576,
  [SMALL_STATE(6323)] = 302664,
  [SMALL_STATE(6324)] = 302752,
  [SMALL_STATE(6325)] = 302840,
  [SMALL_STATE(6326)] = 302928,
  [SMALL_STATE(6327)] = 303016,
  [SMALL_STATE(6328)] = 303104,
  [SMALL_STATE(6329)] = 303192,
  [SMALL_STATE(6330)] = 303280,
  [SMALL_STATE(6331)] = 303368,
  [SMALL_STATE(6332)] = 303456,
  [SMALL_STATE(6333)] = 303544,
  [SMALL_STATE(6334)] = 303632,
  [SMALL_STATE(6335)] = 303720,
  [SMALL_STATE(6336)] = 303808,
  [SMALL_STATE(6337)] = 303896,
  [SMALL_STATE(6338)] = 303984,
  [SMALL_STATE(6339)] = 304072,
  [SMALL_STATE(6340)] = 304160,
  [SMALL_STATE(6341)] = 304248,
  [SMALL_STATE(6342)] = 304336,
  [SMALL_STATE(6343)] = 304424,
  [SMALL_STATE(6344)] = 304512,
  [SMALL_STATE(6345)] = 304600,
  [SMALL_STATE(6346)] = 304688,
  [SMALL_STATE(6347)] = 304776,
  [SMALL_STATE(6348)] = 304864,
  [SMALL_STATE(6349)] = 304952,
  [SMALL_STATE(6350)] = 305040,
  [SMALL_STATE(6351)] = 305128,
  [SMALL_STATE(6352)] = 305216,
  [SMALL_STATE(6353)] = 305304,
  [SMALL_STATE(6354)] = 305392,
  [SMALL_STATE(6355)] = 305480,
  [SMALL_STATE(6356)] = 305568,
  [SMALL_STATE(6357)] = 305656,
  [SMALL_STATE(6358)] = 305744,
  [SMALL_STATE(6359)] = 305832,
  [SMALL_STATE(6360)] = 305920,
  [SMALL_STATE(6361)] = 306008,
  [SMALL_STATE(6362)] = 306096,
  [SMALL_STATE(6363)] = 306184,
  [SMALL_STATE(6364)] = 306272,
  [SMALL_STATE(6365)] = 306360,
  [SMALL_STATE(6366)] = 306448,
  [SMALL_STATE(6367)] = 306536,
  [SMALL_STATE(6368)] = 306624,
  [SMALL_STATE(6369)] = 306712,
  [SMALL_STATE(6370)] = 306800,
  [SMALL_STATE(6371)] = 306888,
  [SMALL_STATE(6372)] = 306976,
  [SMALL_STATE(6373)] = 307064,
  [SMALL_STATE(6374)] = 307152,
  [SMALL_STATE(6375)] = 307240,
  [SMALL_STATE(6376)] = 307328,
  [SMALL_STATE(6377)] = 307416,
  [SMALL_STATE(6378)] = 307504,
  [SMALL_STATE(6379)] = 307592,
  [SMALL_STATE(6380)] = 307680,
  [SMALL_STATE(6381)] = 307768,
  [SMALL_STATE(6382)] = 307856,
  [SMALL_STATE(6383)] = 307944,
  [SMALL_STATE(6384)] = 308032,
  [SMALL_STATE(6385)] = 308120,
  [SMALL_STATE(6386)] = 308208,
  [SMALL_STATE(6387)] = 308296,
  [SMALL_STATE(6388)] = 308384,
  [SMALL_STATE(6389)] = 308472,
  [SMALL_STATE(6390)] = 308560,
  [SMALL_STATE(6391)] = 308648,
  [SMALL_STATE(6392)] = 308736,
  [SMALL_STATE(6393)] = 308824,
  [SMALL_STATE(6394)] = 308912,
  [SMALL_STATE(6395)] = 309000,
  [SMALL_STATE(6396)] = 309088,
  [SMALL_STATE(6397)] = 309176,
  [SMALL_STATE(6398)] = 309264,
  [SMALL_STATE(6399)] = 309352,
  [SMALL_STATE(6400)] = 309440,
  [SMALL_STATE(6401)] = 309528,
  [SMALL_STATE(6402)] = 309616,
  [SMALL_STATE(6403)] = 309704,
  [SMALL_STATE(6404)] = 309792,
  [SMALL_STATE(6405)] = 309880,
  [SMALL_STATE(6406)] = 309968,
  [SMALL_STATE(6407)] = 310056,
  [SMALL_STATE(6408)] = 310144,
  [SMALL_STATE(6409)] = 310232,
  [SMALL_STATE(6410)] = 310320,
  [SMALL_STATE(6411)] = 310408,
  [SMALL_STATE(6412)] = 310496,
  [SMALL_STATE(6413)] = 310584,
  [SMALL_STATE(6414)] = 310672,
  [SMALL_STATE(6415)] = 310760,
  [SMALL_STATE(6416)] = 310848,
  [SMALL_STATE(6417)] = 310936,
  [SMALL_STATE(6418)] = 311024,
  [SMALL_STATE(6419)] = 311112,
  [SMALL_STATE(6420)] = 311200,
  [SMALL_STATE(6421)] = 311288,
  [SMALL_STATE(6422)] = 311376,
  [SMALL_STATE(6423)] = 311464,
  [SMALL_STATE(6424)] = 311552,
  [SMALL_STATE(6425)] = 311640,
  [SMALL_STATE(6426)] = 311728,
  [SMALL_STATE(6427)] = 311816,
  [SMALL_STATE(6428)] = 311904,
  [SMALL_STATE(6429)] = 311992,
  [SMALL_STATE(6430)] = 312080,
  [SMALL_STATE(6431)] = 312168,
  [SMALL_STATE(6432)] = 312256,
  [SMALL_STATE(6433)] = 312344,
  [SMALL_STATE(6434)] = 312432,
  [SMALL_STATE(6435)] = 312520,
  [SMALL_STATE(6436)] = 312608,
  [SMALL_STATE(6437)] = 312696,
  [SMALL_STATE(6438)] = 312784,
  [SMALL_STATE(6439)] = 312872,
  [SMALL_STATE(6440)] = 312960,
  [SMALL_STATE(6441)] = 313048,
  [SMALL_STATE(6442)] = 313136,
  [SMALL_STATE(6443)] = 313224,
  [SMALL_STATE(6444)] = 313312,
  [SMALL_STATE(6445)] = 313400,
  [SMALL_STATE(6446)] = 313488,
  [SMALL_STATE(6447)] = 313576,
  [SMALL_STATE(6448)] = 313664,
  [SMALL_STATE(6449)] = 313752,
  [SMALL_STATE(6450)] = 313840,
  [SMALL_STATE(6451)] = 313928,
  [SMALL_STATE(6452)] = 314016,
  [SMALL_STATE(6453)] = 314104,
  [SMALL_STATE(6454)] = 314192,
  [SMALL_STATE(6455)] = 314280,
  [SMALL_STATE(6456)] = 314368,
  [SMALL_STATE(6457)] = 314456,
  [SMALL_STATE(6458)] = 314544,
  [SMALL_STATE(6459)] = 314632,
  [SMALL_STATE(6460)] = 314720,
  [SMALL_STATE(6461)] = 314808,
  [SMALL_STATE(6462)] = 314896,
  [SMALL_STATE(6463)] = 314984,
  [SMALL_STATE(6464)] = 315072,
  [SMALL_STATE(6465)] = 315160,
  [SMALL_STATE(6466)] = 315248,
  [SMALL_STATE(6467)] = 315336,
  [SMALL_STATE(6468)] = 315424,
  [SMALL_STATE(6469)] = 315512,
  [SMALL_STATE(6470)] = 315600,
  [SMALL_STATE(6471)] = 315688,
  [SMALL_STATE(6472)] = 315776,
  [SMALL_STATE(6473)] = 315864,
  [SMALL_STATE(6474)] = 315952,
  [SMALL_STATE(6475)] = 316040,
  [SMALL_STATE(6476)] = 316128,
  [SMALL_STATE(6477)] = 316216,
  [SMALL_STATE(6478)] = 316304,
  [SMALL_STATE(6479)] = 316392,
  [SMALL_STATE(6480)] = 316480,
  [SMALL_STATE(6481)] = 316568,
  [SMALL_STATE(6482)] = 316656,
  [SMALL_STATE(6483)] = 316744,
  [SMALL_STATE(6484)] = 316832,
  [SMALL_STATE(6485)] = 316920,
  [SMALL_STATE(6486)] = 317008,
  [SMALL_STATE(6487)] = 317096,
  [SMALL_STATE(6488)] = 317184,
  [SMALL_STATE(6489)] = 317272,
  [SMALL_STATE(6490)] = 317360,
  [SMALL_STATE(6491)] = 317448,
  [SMALL_STATE(6492)] = 317536,
  [SMALL_STATE(6493)] = 317624,
  [SMALL_STATE(6494)] = 317712,
  [SMALL_STATE(6495)] = 317800,
  [SMALL_STATE(6496)] = 317888,
  [SMALL_STATE(6497)] = 317976,
  [SMALL_STATE(6498)] = 318064,
  [SMALL_STATE(6499)] = 318152,
  [SMALL_STATE(6500)] = 318240,
  [SMALL_STATE(6501)] = 318328,
  [SMALL_STATE(6502)] = 318416,
  [SMALL_STATE(6503)] = 318504,
  [SMALL_STATE(6504)] = 318592,
  [SMALL_STATE(6505)] = 318680,
  [SMALL_STATE(6506)] = 318768,
  [SMALL_STATE(6507)] = 318856,
  [SMALL_STATE(6508)] = 318944,
  [SMALL_STATE(6509)] = 319032,
  [SMALL_STATE(6510)] = 319120,
  [SMALL_STATE(6511)] = 319208,
  [SMALL_STATE(6512)] = 319296,
  [SMALL_STATE(6513)] = 319384,
  [SMALL_STATE(6514)] = 319472,
  [SMALL_STATE(6515)] = 319560,
  [SMALL_STATE(6516)] = 319648,
  [SMALL_STATE(6517)] = 319736,
  [SMALL_STATE(6518)] = 319824,
  [SMALL_STATE(6519)] = 319912,
  [SMALL_STATE(6520)] = 320000,
  [SMALL_STATE(6521)] = 320088,
  [SMALL_STATE(6522)] = 320176,
  [SMALL_STATE(6523)] = 320264,
  [SMALL_STATE(6524)] = 320352,
  [SMALL_STATE(6525)] = 320440,
  [SMALL_STATE(6526)] = 320528,
  [SMALL_STATE(6527)] = 320616,
  [SMALL_STATE(6528)] = 320704,
  [SMALL_STATE(6529)] = 320792,
  [SMALL_STATE(6530)] = 320880,
  [SMALL_STATE(6531)] = 320968,
  [SMALL_STATE(6532)] = 321056,
  [SMALL_STATE(6533)] = 321144,
  [SMALL_STATE(6534)] = 321232,
  [SMALL_STATE(6535)] = 321320,
  [SMALL_STATE(6536)] = 321408,
  [SMALL_STATE(6537)] = 321496,
  [SMALL_STATE(6538)] = 321584,
  [SMALL_STATE(6539)] = 321672,
  [SMALL_STATE(6540)] = 321760,
  [SMALL_STATE(6541)] = 321848,
  [SMALL_STATE(6542)] = 321936,
  [SMALL_STATE(6543)] = 322024,
  [SMALL_STATE(6544)] = 322112,
  [SMALL_STATE(6545)] = 322200,
  [SMALL_STATE(6546)] = 322288,
  [SMALL_STATE(6547)] = 322376,
  [SMALL_STATE(6548)] = 322464,
  [SMALL_STATE(6549)] = 322552,
  [SMALL_STATE(6550)] = 322640,
  [SMALL_STATE(6551)] = 322728,
  [SMALL_STATE(6552)] = 322816,
  [SMALL_STATE(6553)] = 322904,
  [SMALL_STATE(6554)] = 322992,
  [SMALL_STATE(6555)] = 323080,
  [SMALL_STATE(6556)] = 323168,
  [SMALL_STATE(6557)] = 323256,
  [SMALL_STATE(6558)] = 323344,
  [SMALL_STATE(6559)] = 323432,
  [SMALL_STATE(6560)] = 323520,
  [SMALL_STATE(6561)] = 323608,
  [SMALL_STATE(6562)] = 323696,
  [SMALL_STATE(6563)] = 323784,
  [SMALL_STATE(6564)] = 323872,
  [SMALL_STATE(6565)] = 323960,
  [SMALL_STATE(6566)] = 324048,
  [SMALL_STATE(6567)] = 324136,
  [SMALL_STATE(6568)] = 324224,
  [SMALL_STATE(6569)] = 324312,
  [SMALL_STATE(6570)] = 324400,
  [SMALL_STATE(6571)] = 324488,
  [SMALL_STATE(6572)] = 324576,
  [SMALL_STATE(6573)] = 324664,
  [SMALL_STATE(6574)] = 324752,
  [SMALL_STATE(6575)] = 324840,
  [SMALL_STATE(6576)] = 324928,
  [SMALL_STATE(6577)] = 325016,
  [SMALL_STATE(6578)] = 325104,
  [SMALL_STATE(6579)] = 325192,
  [SMALL_STATE(6580)] = 325280,
  [SMALL_STATE(6581)] = 325368,
  [SMALL_STATE(6582)] = 325456,
  [SMALL_STATE(6583)] = 325544,
  [SMALL_STATE(6584)] = 325632,
  [SMALL_STATE(6585)] = 325720,
  [SMALL_STATE(6586)] = 325808,
  [SMALL_STATE(6587)] = 325896,
  [SMALL_STATE(6588)] = 325984,
  [SMALL_STATE(6589)] = 326072,
  [SMALL_STATE(6590)] = 326160,
  [SMALL_STATE(6591)] = 326248,
  [SMALL_STATE(6592)] = 326336,
  [SMALL_STATE(6593)] = 326424,
  [SMALL_STATE(6594)] = 326512,
  [SMALL_STATE(6595)] = 326600,
  [SMALL_STATE(6596)] = 326688,
  [SMALL_STATE(6597)] = 326776,
  [SMALL_STATE(6598)] = 326864,
  [SMALL_STATE(6599)] = 326952,
  [SMALL_STATE(6600)] = 327040,
  [SMALL_STATE(6601)] = 327128,
  [SMALL_STATE(6602)] = 327216,
  [SMALL_STATE(6603)] = 327304,
  [SMALL_STATE(6604)] = 327392,
  [SMALL_STATE(6605)] = 327480,
  [SMALL_STATE(6606)] = 327568,
  [SMALL_STATE(6607)] = 327656,
  [SMALL_STATE(6608)] = 327744,
  [SMALL_STATE(6609)] = 327832,
  [SMALL_STATE(6610)] = 327920,
  [SMALL_STATE(6611)] = 328008,
  [SMALL_STATE(6612)] = 328096,
  [SMALL_STATE(6613)] = 328184,
  [SMALL_STATE(6614)] = 328272,
  [SMALL_STATE(6615)] = 328360,
  [SMALL_STATE(6616)] = 328403,
  [SMALL_STATE(6617)] = 328488,
  [SMALL_STATE(6618)] = 328531,
  [SMALL_STATE(6619)] = 328574,
  [SMALL_STATE(6620)] = 328617,
  [SMALL_STATE(6621)] = 328660,
  [SMALL_STATE(6622)] = 328724,
  [SMALL_STATE(6623)] = 328788,
  [SMALL_STATE(6624)] = 328852,
  [SMALL_STATE(6625)] = 328916,
  [SMALL_STATE(6626)] = 328980,
  [SMALL_STATE(6627)] = 329044,
  [SMALL_STATE(6628)] = 329108,
  [SMALL_STATE(6629)] = 329141,
  [SMALL_STATE(6630)] = 329174,
  [SMALL_STATE(6631)] = 329211,
  [SMALL_STATE(6632)] = 329248,
  [SMALL_STATE(6633)] = 329290,
  [SMALL_STATE(6634)] = 329338,
  [SMALL_STATE(6635)] = 329386,
  [SMALL_STATE(6636)] = 329434,
  [SMALL_STATE(6637)] = 329476,
  [SMALL_STATE(6638)] = 329524,
  [SMALL_STATE(6639)] = 329572,
  [SMALL_STATE(6640)] = 329620,
  [SMALL_STATE(6641)] = 329668,
  [SMALL_STATE(6642)] = 329716,
  [SMALL_STATE(6643)] = 329764,
  [SMALL_STATE(6644)] = 329806,
  [SMALL_STATE(6645)] = 329854,
  [SMALL_STATE(6646)] = 329902,
  [SMALL_STATE(6647)] = 329950,
  [SMALL_STATE(6648)] = 329992,
  [SMALL_STATE(6649)] = 330034,
  [SMALL_STATE(6650)] = 330076,
  [SMALL_STATE(6651)] = 330124,
  [SMALL_STATE(6652)] = 330158,
  [SMALL_STATE(6653)] = 330192,
  [SMALL_STATE(6654)] = 330240,
  [SMALL_STATE(6655)] = 330288,
  [SMALL_STATE(6656)] = 330336,
  [SMALL_STATE(6657)] = 330384,
  [SMALL_STATE(6658)] = 330432,
  [SMALL_STATE(6659)] = 330473,
  [SMALL_STATE(6660)] = 330512,
  [SMALL_STATE(6661)] = 330543,
  [SMALL_STATE(6662)] = 330584,
  [SMALL_STATE(6663)] = 330625,
  [SMALL_STATE(6664)] = 330666,
  [SMALL_STATE(6665)] = 330705,
  [SMALL_STATE(6666)] = 330746,
  [SMALL_STATE(6667)] = 330785,
  [SMALL_STATE(6668)] = 330824,
  [SMALL_STATE(6669)] = 330865,
  [SMALL_STATE(6670)] = 330904,
  [SMALL_STATE(6671)] = 330943,
  [SMALL_STATE(6672)] = 330982,
  [SMALL_STATE(6673)] = 331023,
  [SMALL_STATE(6674)] = 331064,
  [SMALL_STATE(6675)] = 331103,
  [SMALL_STATE(6676)] = 331142,
  [SMALL_STATE(6677)] = 331181,
  [SMALL_STATE(6678)] = 331220,
  [SMALL_STATE(6679)] = 331259,
  [SMALL_STATE(6680)] = 331298,
  [SMALL_STATE(6681)] = 331343,
  [SMALL_STATE(6682)] = 331376,
  [SMALL_STATE(6683)] = 331417,
  [SMALL_STATE(6684)] = 331458,
  [SMALL_STATE(6685)] = 331497,
  [SMALL_STATE(6686)] = 331538,
  [SMALL_STATE(6687)] = 331577,
  [SMALL_STATE(6688)] = 331616,
  [SMALL_STATE(6689)] = 331657,
  [SMALL_STATE(6690)] = 331696,
  [SMALL_STATE(6691)] = 331735,
  [SMALL_STATE(6692)] = 331776,
  [SMALL_STATE(6693)] = 331816,
  [SMALL_STATE(6694)] = 331856,
  [SMALL_STATE(6695)] = 331894,
  [SMALL_STATE(6696)] = 331934,
  [SMALL_STATE(6697)] = 331972,
  [SMALL_STATE(6698)] = 332010,
  [SMALL_STATE(6699)] = 332050,
  [SMALL_STATE(6700)] = 332088,
  [SMALL_STATE(6701)] = 332126,
  [SMALL_STATE(6702)] = 332164,
  [SMALL_STATE(6703)] = 332194,
  [SMALL_STATE(6704)] = 332224,
  [SMALL_STATE(6705)] = 332264,
  [SMALL_STATE(6706)] = 332302,
  [SMALL_STATE(6707)] = 332340,
  [SMALL_STATE(6708)] = 332372,
  [SMALL_STATE(6709)] = 332412,
  [SMALL_STATE(6710)] = 332450,
  [SMALL_STATE(6711)] = 332490,
  [SMALL_STATE(6712)] = 332530,
  [SMALL_STATE(6713)] = 332560,
  [SMALL_STATE(6714)] = 332600,
  [SMALL_STATE(6715)] = 332630,
  [SMALL_STATE(6716)] = 332668,
  [SMALL_STATE(6717)] = 332708,
  [SMALL_STATE(6718)] = 332746,
  [SMALL_STATE(6719)] = 332784,
  [SMALL_STATE(6720)] = 332824,
  [SMALL_STATE(6721)] = 332853,
  [SMALL_STATE(6722)] = 332890,
  [SMALL_STATE(6723)] = 332927,
  [SMALL_STATE(6724)] = 332966,
  [SMALL_STATE(6725)] = 333003,
  [SMALL_STATE(6726)] = 333032,
  [SMALL_STATE(6727)] = 333073,
  [SMALL_STATE(6728)] = 333110,
  [SMALL_STATE(6729)] = 333147,
  [SMALL_STATE(6730)] = 333184,
  [SMALL_STATE(6731)] = 333221,
  [SMALL_STATE(6732)] = 333248,
  [SMALL_STATE(6733)] = 333275,
  [SMALL_STATE(6734)] = 333304,
  [SMALL_STATE(6735)] = 333341,
  [SMALL_STATE(6736)] = 333368,
  [SMALL_STATE(6737)] = 333395,
  [SMALL_STATE(6738)] = 333424,
  [SMALL_STATE(6739)] = 333451,
  [SMALL_STATE(6740)] = 333478,
  [SMALL_STATE(6741)] = 333505,
  [SMALL_STATE(6742)] = 333532,
  [SMALL_STATE(6743)] = 333571,
  [SMALL_STATE(6744)] = 333598,
  [SMALL_STATE(6745)] = 333625,
  [SMALL_STATE(6746)] = 333664,
  [SMALL_STATE(6747)] = 333698,
  [SMALL_STATE(6748)] = 333738,
  [SMALL_STATE(6749)] = 333764,
  [SMALL_STATE(6750)] = 333790,
  [SMALL_STATE(6751)] = 333820,
  [SMALL_STATE(6752)] = 333854,
  [SMALL_STATE(6753)] = 333882,
  [SMALL_STATE(6754)] = 333912,
  [SMALL_STATE(6755)] = 333946,
  [SMALL_STATE(6756)] = 333980,
  [SMALL_STATE(6757)] = 334010,
  [SMALL_STATE(6758)] = 334036,
  [SMALL_STATE(6759)] = 334062,
  [SMALL_STATE(6760)] = 334096,
  [SMALL_STATE(6761)] = 334136,
  [SMALL_STATE(6762)] = 334170,
  [SMALL_STATE(6763)] = 334208,
  [SMALL_STATE(6764)] = 334234,
  [SMALL_STATE(6765)] = 334272,
  [SMALL_STATE(6766)] = 334299,
  [SMALL_STATE(6767)] = 334326,
  [SMALL_STATE(6768)] = 334353,
  [SMALL_STATE(6769)] = 334380,
  [SMALL_STATE(6770)] = 334407,
  [SMALL_STATE(6771)] = 334434,
  [SMALL_STATE(6772)] = 334461,
  [SMALL_STATE(6773)] = 334498,
  [SMALL_STATE(6774)] = 334525,
  [SMALL_STATE(6775)] = 334562,
  [SMALL_STATE(6776)] = 334589,
  [SMALL_STATE(6777)] = 334616,
  [SMALL_STATE(6778)] = 334643,
  [SMALL_STATE(6779)] = 334670,
  [SMALL_STATE(6780)] = 334697,
  [SMALL_STATE(6781)] = 334724,
  [SMALL_STATE(6782)] = 334761,
  [SMALL_STATE(6783)] = 334798,
  [SMALL_STATE(6784)] = 334825,
  [SMALL_STATE(6785)] = 334862,
  [SMALL_STATE(6786)] = 334899,
  [SMALL_STATE(6787)] = 334936,
  [SMALL_STATE(6788)] = 334963,
  [SMALL_STATE(6789)] = 334990,
  [SMALL_STATE(6790)] = 335027,
  [SMALL_STATE(6791)] = 335064,
  [SMALL_STATE(6792)] = 335091,
  [SMALL_STATE(6793)] = 335118,
  [SMALL_STATE(6794)] = 335155,
  [SMALL_STATE(6795)] = 335192,
  [SMALL_STATE(6796)] = 335229,
  [SMALL_STATE(6797)] = 335256,
  [SMALL_STATE(6798)] = 335283,
  [SMALL_STATE(6799)] = 335310,
  [SMALL_STATE(6800)] = 335337,
  [SMALL_STATE(6801)] = 335364,
  [SMALL_STATE(6802)] = 335393,
  [SMALL_STATE(6803)] = 335420,
  [SMALL_STATE(6804)] = 335447,
  [SMALL_STATE(6805)] = 335484,
  [SMALL_STATE(6806)] = 335511,
  [SMALL_STATE(6807)] = 335538,
  [SMALL_STATE(6808)] = 335567,
  [SMALL_STATE(6809)] = 335594,
  [SMALL_STATE(6810)] = 335621,
  [SMALL_STATE(6811)] = 335658,
  [SMALL_STATE(6812)] = 335685,
  [SMALL_STATE(6813)] = 335722,
  [SMALL_STATE(6814)] = 335757,
  [SMALL_STATE(6815)] = 335794,
  [SMALL_STATE(6816)] = 335829,
  [SMALL_STATE(6817)] = 335864,
  [SMALL_STATE(6818)] = 335901,
  [SMALL_STATE(6819)] = 335936,
  [SMALL_STATE(6820)] = 335971,
  [SMALL_STATE(6821)] = 336006,
  [SMALL_STATE(6822)] = 336044,
  [SMALL_STATE(6823)] = 336078,
  [SMALL_STATE(6824)] = 336114,
  [SMALL_STATE(6825)] = 336148,
  [SMALL_STATE(6826)] = 336186,
  [SMALL_STATE(6827)] = 336220,
  [SMALL_STATE(6828)] = 336254,
  [SMALL_STATE(6829)] = 336288,
  [SMALL_STATE(6830)] = 336322,
  [SMALL_STATE(6831)] = 336358,
  [SMALL_STATE(6832)] = 336394,
  [SMALL_STATE(6833)] = 336428,
  [SMALL_STATE(6834)] = 336462,
  [SMALL_STATE(6835)] = 336500,
  [SMALL_STATE(6836)] = 336538,
  [SMALL_STATE(6837)] = 336572,
  [SMALL_STATE(6838)] = 336606,
  [SMALL_STATE(6839)] = 336640,
  [SMALL_STATE(6840)] = 336674,
  [SMALL_STATE(6841)] = 336708,
  [SMALL_STATE(6842)] = 336742,
  [SMALL_STATE(6843)] = 336778,
  [SMALL_STATE(6844)] = 336814,
  [SMALL_STATE(6845)] = 336852,
  [SMALL_STATE(6846)] = 336886,
  [SMALL_STATE(6847)] = 336920,
  [SMALL_STATE(6848)] = 336956,
  [SMALL_STATE(6849)] = 336992,
  [SMALL_STATE(6850)] = 337026,
  [SMALL_STATE(6851)] = 337060,
  [SMALL_STATE(6852)] = 337094,
  [SMALL_STATE(6853)] = 337130,
  [SMALL_STATE(6854)] = 337164,
  [SMALL_STATE(6855)] = 337198,
  [SMALL_STATE(6856)] = 337234,
  [SMALL_STATE(6857)] = 337268,
  [SMALL_STATE(6858)] = 337302,
  [SMALL_STATE(6859)] = 337336,
  [SMALL_STATE(6860)] = 337370,
  [SMALL_STATE(6861)] = 337406,
  [SMALL_STATE(6862)] = 337440,
  [SMALL_STATE(6863)] = 337474,
  [SMALL_STATE(6864)] = 337508,
  [SMALL_STATE(6865)] = 337542,
  [SMALL_STATE(6866)] = 337568,
  [SMALL_STATE(6867)] = 337602,
  [SMALL_STATE(6868)] = 337636,
  [SMALL_STATE(6869)] = 337670,
  [SMALL_STATE(6870)] = 337696,
  [SMALL_STATE(6871)] = 337734,
  [SMALL_STATE(6872)] = 337768,
  [SMALL_STATE(6873)] = 337804,
  [SMALL_STATE(6874)] = 337839,
  [SMALL_STATE(6875)] = 337862,
  [SMALL_STATE(6876)] = 337885,
  [SMALL_STATE(6877)] = 337908,
  [SMALL_STATE(6878)] = 337931,
  [SMALL_STATE(6879)] = 337956,
  [SMALL_STATE(6880)] = 337979,
  [SMALL_STATE(6881)] = 338002,
  [SMALL_STATE(6882)] = 338035,
  [SMALL_STATE(6883)] = 338070,
  [SMALL_STATE(6884)] = 338103,
  [SMALL_STATE(6885)] = 338136,
  [SMALL_STATE(6886)] = 338161,
  [SMALL_STATE(6887)] = 338186,
  [SMALL_STATE(6888)] = 338211,
  [SMALL_STATE(6889)] = 338236,
  [SMALL_STATE(6890)] = 338271,
  [SMALL_STATE(6891)] = 338304,
  [SMALL_STATE(6892)] = 338337,
  [SMALL_STATE(6893)] = 338360,
  [SMALL_STATE(6894)] = 338393,
  [SMALL_STATE(6895)] = 338416,
  [SMALL_STATE(6896)] = 338439,
  [SMALL_STATE(6897)] = 338462,
  [SMALL_STATE(6898)] = 338484,
  [SMALL_STATE(6899)] = 338508,
  [SMALL_STATE(6900)] = 338532,
  [SMALL_STATE(6901)] = 338554,
  [SMALL_STATE(6902)] = 338578,
  [SMALL_STATE(6903)] = 338600,
  [SMALL_STATE(6904)] = 338624,
  [SMALL_STATE(6905)] = 338646,
  [SMALL_STATE(6906)] = 338672,
  [SMALL_STATE(6907)] = 338694,
  [SMALL_STATE(6908)] = 338716,
  [SMALL_STATE(6909)] = 338738,
  [SMALL_STATE(6910)] = 338760,
  [SMALL_STATE(6911)] = 338782,
  [SMALL_STATE(6912)] = 338804,
  [SMALL_STATE(6913)] = 338828,
  [SMALL_STATE(6914)] = 338856,
  [SMALL_STATE(6915)] = 338884,
  [SMALL_STATE(6916)] = 338908,
  [SMALL_STATE(6917)] = 338934,
  [SMALL_STATE(6918)] = 338962,
  [SMALL_STATE(6919)] = 338986,
  [SMALL_STATE(6920)] = 339014,
  [SMALL_STATE(6921)] = 339040,
  [SMALL_STATE(6922)] = 339064,
  [SMALL_STATE(6923)] = 339086,
  [SMALL_STATE(6924)] = 339114,
  [SMALL_STATE(6925)] = 339138,
  [SMALL_STATE(6926)] = 339162,
  [SMALL_STATE(6927)] = 339184,
  [SMALL_STATE(6928)] = 339208,
  [SMALL_STATE(6929)] = 339234,
  [SMALL_STATE(6930)] = 339262,
  [SMALL_STATE(6931)] = 339286,
  [SMALL_STATE(6932)] = 339308,
  [SMALL_STATE(6933)] = 339334,
  [SMALL_STATE(6934)] = 339356,
  [SMALL_STATE(6935)] = 339378,
  [SMALL_STATE(6936)] = 339402,
  [SMALL_STATE(6937)] = 339426,
  [SMALL_STATE(6938)] = 339451,
  [SMALL_STATE(6939)] = 339472,
  [SMALL_STATE(6940)] = 339495,
  [SMALL_STATE(6941)] = 339518,
  [SMALL_STATE(6942)] = 339541,
  [SMALL_STATE(6943)] = 339564,
  [SMALL_STATE(6944)] = 339587,
  [SMALL_STATE(6945)] = 339610,
  [SMALL_STATE(6946)] = 339633,
  [SMALL_STATE(6947)] = 339656,
  [SMALL_STATE(6948)] = 339679,
  [SMALL_STATE(6949)] = 339702,
  [SMALL_STATE(6950)] = 339725,
  [SMALL_STATE(6951)] = 339748,
  [SMALL_STATE(6952)] = 339769,
  [SMALL_STATE(6953)] = 339794,
  [SMALL_STATE(6954)] = 339823,
  [SMALL_STATE(6955)] = 339852,
  [SMALL_STATE(6956)] = 339883,
  [SMALL_STATE(6957)] = 339906,
  [SMALL_STATE(6958)] = 339929,
  [SMALL_STATE(6959)] = 339952,
  [SMALL_STATE(6960)] = 339981,
  [SMALL_STATE(6961)] = 340004,
  [SMALL_STATE(6962)] = 340027,
  [SMALL_STATE(6963)] = 340056,
  [SMALL_STATE(6964)] = 340081,
  [SMALL_STATE(6965)] = 340102,
  [SMALL_STATE(6966)] = 340127,
  [SMALL_STATE(6967)] = 340150,
  [SMALL_STATE(6968)] = 340173,
  [SMALL_STATE(6969)] = 340196,
  [SMALL_STATE(6970)] = 340219,
  [SMALL_STATE(6971)] = 340242,
  [SMALL_STATE(6972)] = 340263,
  [SMALL_STATE(6973)] = 340288,
  [SMALL_STATE(6974)] = 340317,
  [SMALL_STATE(6975)] = 340340,
  [SMALL_STATE(6976)] = 340369,
  [SMALL_STATE(6977)] = 340394,
  [SMALL_STATE(6978)] = 340421,
  [SMALL_STATE(6979)] = 340444,
  [SMALL_STATE(6980)] = 340467,
  [SMALL_STATE(6981)] = 340496,
  [SMALL_STATE(6982)] = 340517,
  [SMALL_STATE(6983)] = 340540,
  [SMALL_STATE(6984)] = 340569,
  [SMALL_STATE(6985)] = 340592,
  [SMALL_STATE(6986)] = 340621,
  [SMALL_STATE(6987)] = 340644,
  [SMALL_STATE(6988)] = 340669,
  [SMALL_STATE(6989)] = 340690,
  [SMALL_STATE(6990)] = 340711,
  [SMALL_STATE(6991)] = 340731,
  [SMALL_STATE(6992)] = 340753,
  [SMALL_STATE(6993)] = 340775,
  [SMALL_STATE(6994)] = 340797,
  [SMALL_STATE(6995)] = 340813,
  [SMALL_STATE(6996)] = 340835,
  [SMALL_STATE(6997)] = 340857,
  [SMALL_STATE(6998)] = 340877,
  [SMALL_STATE(6999)] = 340897,
  [SMALL_STATE(7000)] = 340917,
  [SMALL_STATE(7001)] = 340937,
  [SMALL_STATE(7002)] = 340959,
  [SMALL_STATE(7003)] = 340979,
  [SMALL_STATE(7004)] = 340999,
  [SMALL_STATE(7005)] = 341021,
  [SMALL_STATE(7006)] = 341043,
  [SMALL_STATE(7007)] = 341063,
  [SMALL_STATE(7008)] = 341083,
  [SMALL_STATE(7009)] = 341103,
  [SMALL_STATE(7010)] = 341125,
  [SMALL_STATE(7011)] = 341145,
  [SMALL_STATE(7012)] = 341167,
  [SMALL_STATE(7013)] = 341187,
  [SMALL_STATE(7014)] = 341207,
  [SMALL_STATE(7015)] = 341227,
  [SMALL_STATE(7016)] = 341249,
  [SMALL_STATE(7017)] = 341269,
  [SMALL_STATE(7018)] = 341289,
  [SMALL_STATE(7019)] = 341311,
  [SMALL_STATE(7020)] = 341331,
  [SMALL_STATE(7021)] = 341353,
  [SMALL_STATE(7022)] = 341373,
  [SMALL_STATE(7023)] = 341393,
  [SMALL_STATE(7024)] = 341413,
  [SMALL_STATE(7025)] = 341433,
  [SMALL_STATE(7026)] = 341453,
  [SMALL_STATE(7027)] = 341473,
  [SMALL_STATE(7028)] = 341493,
  [SMALL_STATE(7029)] = 341515,
  [SMALL_STATE(7030)] = 341537,
  [SMALL_STATE(7031)] = 341557,
  [SMALL_STATE(7032)] = 341579,
  [SMALL_STATE(7033)] = 341601,
  [SMALL_STATE(7034)] = 341621,
  [SMALL_STATE(7035)] = 341641,
  [SMALL_STATE(7036)] = 341663,
  [SMALL_STATE(7037)] = 341685,
  [SMALL_STATE(7038)] = 341707,
  [SMALL_STATE(7039)] = 341727,
  [SMALL_STATE(7040)] = 341749,
  [SMALL_STATE(7041)] = 341767,
  [SMALL_STATE(7042)] = 341789,
  [SMALL_STATE(7043)] = 341811,
  [SMALL_STATE(7044)] = 341831,
  [SMALL_STATE(7045)] = 341853,
  [SMALL_STATE(7046)] = 341871,
  [SMALL_STATE(7047)] = 341893,
  [SMALL_STATE(7048)] = 341915,
  [SMALL_STATE(7049)] = 341937,
  [SMALL_STATE(7050)] = 341959,
  [SMALL_STATE(7051)] = 341981,
  [SMALL_STATE(7052)] = 342003,
  [SMALL_STATE(7053)] = 342023,
  [SMALL_STATE(7054)] = 342046,
  [SMALL_STATE(7055)] = 342071,
  [SMALL_STATE(7056)] = 342096,
  [SMALL_STATE(7057)] = 342123,
  [SMALL_STATE(7058)] = 342148,
  [SMALL_STATE(7059)] = 342173,
  [SMALL_STATE(7060)] = 342198,
  [SMALL_STATE(7061)] = 342219,
  [SMALL_STATE(7062)] = 342238,
  [SMALL_STATE(7063)] = 342261,
  [SMALL_STATE(7064)] = 342286,
  [SMALL_STATE(7065)] = 342305,
  [SMALL_STATE(7066)] = 342322,
  [SMALL_STATE(7067)] = 342347,
  [SMALL_STATE(7068)] = 342362,
  [SMALL_STATE(7069)] = 342389,
  [SMALL_STATE(7070)] = 342414,
  [SMALL_STATE(7071)] = 342433,
  [SMALL_STATE(7072)] = 342458,
  [SMALL_STATE(7073)] = 342483,
  [SMALL_STATE(7074)] = 342508,
  [SMALL_STATE(7075)] = 342533,
  [SMALL_STATE(7076)] = 342548,
  [SMALL_STATE(7077)] = 342567,
  [SMALL_STATE(7078)] = 342592,
  [SMALL_STATE(7079)] = 342613,
  [SMALL_STATE(7080)] = 342632,
  [SMALL_STATE(7081)] = 342651,
  [SMALL_STATE(7082)] = 342670,
  [SMALL_STATE(7083)] = 342691,
  [SMALL_STATE(7084)] = 342705,
  [SMALL_STATE(7085)] = 342719,
  [SMALL_STATE(7086)] = 342733,
  [SMALL_STATE(7087)] = 342747,
  [SMALL_STATE(7088)] = 342761,
  [SMALL_STATE(7089)] = 342775,
  [SMALL_STATE(7090)] = 342799,
  [SMALL_STATE(7091)] = 342817,
  [SMALL_STATE(7092)] = 342835,
  [SMALL_STATE(7093)] = 342859,
  [SMALL_STATE(7094)] = 342883,
  [SMALL_STATE(7095)] = 342897,
  [SMALL_STATE(7096)] = 342911,
  [SMALL_STATE(7097)] = 342925,
  [SMALL_STATE(7098)] = 342945,
  [SMALL_STATE(7099)] = 342965,
  [SMALL_STATE(7100)] = 342979,
  [SMALL_STATE(7101)] = 342993,
  [SMALL_STATE(7102)] = 343007,
  [SMALL_STATE(7103)] = 343023,
  [SMALL_STATE(7104)] = 343043,
  [SMALL_STATE(7105)] = 343061,
  [SMALL_STATE(7106)] = 343085,
  [SMALL_STATE(7107)] = 343099,
  [SMALL_STATE(7108)] = 343113,
  [SMALL_STATE(7109)] = 343127,
  [SMALL_STATE(7110)] = 343141,
  [SMALL_STATE(7111)] = 343155,
  [SMALL_STATE(7112)] = 343169,
  [SMALL_STATE(7113)] = 343183,
  [SMALL_STATE(7114)] = 343197,
  [SMALL_STATE(7115)] = 343221,
  [SMALL_STATE(7116)] = 343237,
  [SMALL_STATE(7117)] = 343251,
  [SMALL_STATE(7118)] = 343265,
  [SMALL_STATE(7119)] = 343279,
  [SMALL_STATE(7120)] = 343303,
  [SMALL_STATE(7121)] = 343317,
  [SMALL_STATE(7122)] = 343331,
  [SMALL_STATE(7123)] = 343345,
  [SMALL_STATE(7124)] = 343369,
  [SMALL_STATE(7125)] = 343383,
  [SMALL_STATE(7126)] = 343407,
  [SMALL_STATE(7127)] = 343421,
  [SMALL_STATE(7128)] = 343435,
  [SMALL_STATE(7129)] = 343449,
  [SMALL_STATE(7130)] = 343465,
  [SMALL_STATE(7131)] = 343479,
  [SMALL_STATE(7132)] = 343493,
  [SMALL_STATE(7133)] = 343507,
  [SMALL_STATE(7134)] = 343521,
  [SMALL_STATE(7135)] = 343535,
  [SMALL_STATE(7136)] = 343551,
  [SMALL_STATE(7137)] = 343565,
  [SMALL_STATE(7138)] = 343579,
  [SMALL_STATE(7139)] = 343593,
  [SMALL_STATE(7140)] = 343607,
  [SMALL_STATE(7141)] = 343621,
  [SMALL_STATE(7142)] = 343635,
  [SMALL_STATE(7143)] = 343649,
  [SMALL_STATE(7144)] = 343663,
  [SMALL_STATE(7145)] = 343679,
  [SMALL_STATE(7146)] = 343693,
  [SMALL_STATE(7147)] = 343707,
  [SMALL_STATE(7148)] = 343721,
  [SMALL_STATE(7149)] = 343735,
  [SMALL_STATE(7150)] = 343749,
  [SMALL_STATE(7151)] = 343769,
  [SMALL_STATE(7152)] = 343793,
  [SMALL_STATE(7153)] = 343807,
  [SMALL_STATE(7154)] = 343821,
  [SMALL_STATE(7155)] = 343835,
  [SMALL_STATE(7156)] = 343859,
  [SMALL_STATE(7157)] = 343873,
  [SMALL_STATE(7158)] = 343887,
  [SMALL_STATE(7159)] = 343909,
  [SMALL_STATE(7160)] = 343925,
  [SMALL_STATE(7161)] = 343945,
  [SMALL_STATE(7162)] = 343959,
  [SMALL_STATE(7163)] = 343975,
  [SMALL_STATE(7164)] = 343989,
  [SMALL_STATE(7165)] = 344003,
  [SMALL_STATE(7166)] = 344017,
  [SMALL_STATE(7167)] = 344031,
  [SMALL_STATE(7168)] = 344045,
  [SMALL_STATE(7169)] = 344059,
  [SMALL_STATE(7170)] = 344073,
  [SMALL_STATE(7171)] = 344087,
  [SMALL_STATE(7172)] = 344101,
  [SMALL_STATE(7173)] = 344115,
  [SMALL_STATE(7174)] = 344129,
  [SMALL_STATE(7175)] = 344143,
  [SMALL_STATE(7176)] = 344159,
  [SMALL_STATE(7177)] = 344173,
  [SMALL_STATE(7178)] = 344187,
  [SMALL_STATE(7179)] = 344209,
  [SMALL_STATE(7180)] = 344233,
  [SMALL_STATE(7181)] = 344247,
  [SMALL_STATE(7182)] = 344263,
  [SMALL_STATE(7183)] = 344277,
  [SMALL_STATE(7184)] = 344301,
  [SMALL_STATE(7185)] = 344319,
  [SMALL_STATE(7186)] = 344333,
  [SMALL_STATE(7187)] = 344349,
  [SMALL_STATE(7188)] = 344365,
  [SMALL_STATE(7189)] = 344387,
  [SMALL_STATE(7190)] = 344411,
  [SMALL_STATE(7191)] = 344427,
  [SMALL_STATE(7192)] = 344451,
  [SMALL_STATE(7193)] = 344467,
  [SMALL_STATE(7194)] = 344491,
  [SMALL_STATE(7195)] = 344513,
  [SMALL_STATE(7196)] = 344535,
  [SMALL_STATE(7197)] = 344559,
  [SMALL_STATE(7198)] = 344581,
  [SMALL_STATE(7199)] = 344597,
  [SMALL_STATE(7200)] = 344613,
  [SMALL_STATE(7201)] = 344635,
  [SMALL_STATE(7202)] = 344653,
  [SMALL_STATE(7203)] = 344667,
  [SMALL_STATE(7204)] = 344681,
  [SMALL_STATE(7205)] = 344701,
  [SMALL_STATE(7206)] = 344721,
  [SMALL_STATE(7207)] = 344737,
  [SMALL_STATE(7208)] = 344759,
  [SMALL_STATE(7209)] = 344773,
  [SMALL_STATE(7210)] = 344787,
  [SMALL_STATE(7211)] = 344807,
  [SMALL_STATE(7212)] = 344821,
  [SMALL_STATE(7213)] = 344837,
  [SMALL_STATE(7214)] = 344851,
  [SMALL_STATE(7215)] = 344873,
  [SMALL_STATE(7216)] = 344887,
  [SMALL_STATE(7217)] = 344901,
  [SMALL_STATE(7218)] = 344915,
  [SMALL_STATE(7219)] = 344929,
  [SMALL_STATE(7220)] = 344943,
  [SMALL_STATE(7221)] = 344959,
  [SMALL_STATE(7222)] = 344977,
  [SMALL_STATE(7223)] = 344991,
  [SMALL_STATE(7224)] = 345009,
  [SMALL_STATE(7225)] = 345023,
  [SMALL_STATE(7226)] = 345045,
  [SMALL_STATE(7227)] = 345065,
  [SMALL_STATE(7228)] = 345079,
  [SMALL_STATE(7229)] = 345093,
  [SMALL_STATE(7230)] = 345115,
  [SMALL_STATE(7231)] = 345129,
  [SMALL_STATE(7232)] = 345153,
  [SMALL_STATE(7233)] = 345167,
  [SMALL_STATE(7234)] = 345181,
  [SMALL_STATE(7235)] = 345195,
  [SMALL_STATE(7236)] = 345211,
  [SMALL_STATE(7237)] = 345235,
  [SMALL_STATE(7238)] = 345249,
  [SMALL_STATE(7239)] = 345269,
  [SMALL_STATE(7240)] = 345293,
  [SMALL_STATE(7241)] = 345317,
  [SMALL_STATE(7242)] = 345339,
  [SMALL_STATE(7243)] = 345363,
  [SMALL_STATE(7244)] = 345379,
  [SMALL_STATE(7245)] = 345403,
  [SMALL_STATE(7246)] = 345417,
  [SMALL_STATE(7247)] = 345435,
  [SMALL_STATE(7248)] = 345449,
  [SMALL_STATE(7249)] = 345465,
  [SMALL_STATE(7250)] = 345479,
  [SMALL_STATE(7251)] = 345493,
  [SMALL_STATE(7252)] = 345507,
  [SMALL_STATE(7253)] = 345521,
  [SMALL_STATE(7254)] = 345543,
  [SMALL_STATE(7255)] = 345565,
  [SMALL_STATE(7256)] = 345581,
  [SMALL_STATE(7257)] = 345595,
  [SMALL_STATE(7258)] = 345609,
  [SMALL_STATE(7259)] = 345623,
  [SMALL_STATE(7260)] = 345639,
  [SMALL_STATE(7261)] = 345655,
  [SMALL_STATE(7262)] = 345671,
  [SMALL_STATE(7263)] = 345685,
  [SMALL_STATE(7264)] = 345701,
  [SMALL_STATE(7265)] = 345715,
  [SMALL_STATE(7266)] = 345729,
  [SMALL_STATE(7267)] = 345745,
  [SMALL_STATE(7268)] = 345759,
  [SMALL_STATE(7269)] = 345773,
  [SMALL_STATE(7270)] = 345787,
  [SMALL_STATE(7271)] = 345801,
  [SMALL_STATE(7272)] = 345815,
  [SMALL_STATE(7273)] = 345829,
  [SMALL_STATE(7274)] = 345843,
  [SMALL_STATE(7275)] = 345867,
  [SMALL_STATE(7276)] = 345881,
  [SMALL_STATE(7277)] = 345895,
  [SMALL_STATE(7278)] = 345909,
  [SMALL_STATE(7279)] = 345923,
  [SMALL_STATE(7280)] = 345947,
  [SMALL_STATE(7281)] = 345965,
  [SMALL_STATE(7282)] = 345983,
  [SMALL_STATE(7283)] = 346001,
  [SMALL_STATE(7284)] = 346015,
  [SMALL_STATE(7285)] = 346031,
  [SMALL_STATE(7286)] = 346047,
  [SMALL_STATE(7287)] = 346063,
  [SMALL_STATE(7288)] = 346079,
  [SMALL_STATE(7289)] = 346097,
  [SMALL_STATE(7290)] = 346111,
  [SMALL_STATE(7291)] = 346127,
  [SMALL_STATE(7292)] = 346141,
  [SMALL_STATE(7293)] = 346155,
  [SMALL_STATE(7294)] = 346175,
  [SMALL_STATE(7295)] = 346195,
  [SMALL_STATE(7296)] = 346219,
  [SMALL_STATE(7297)] = 346235,
  [SMALL_STATE(7298)] = 346255,
  [SMALL_STATE(7299)] = 346271,
  [SMALL_STATE(7300)] = 346287,
  [SMALL_STATE(7301)] = 346303,
  [SMALL_STATE(7302)] = 346317,
  [SMALL_STATE(7303)] = 346333,
  [SMALL_STATE(7304)] = 346349,
  [SMALL_STATE(7305)] = 346363,
  [SMALL_STATE(7306)] = 346377,
  [SMALL_STATE(7307)] = 346391,
  [SMALL_STATE(7308)] = 346407,
  [SMALL_STATE(7309)] = 346423,
  [SMALL_STATE(7310)] = 346439,
  [SMALL_STATE(7311)] = 346459,
  [SMALL_STATE(7312)] = 346477,
  [SMALL_STATE(7313)] = 346501,
  [SMALL_STATE(7314)] = 346525,
  [SMALL_STATE(7315)] = 346541,
  [SMALL_STATE(7316)] = 346557,
  [SMALL_STATE(7317)] = 346571,
  [SMALL_STATE(7318)] = 346591,
  [SMALL_STATE(7319)] = 346615,
  [SMALL_STATE(7320)] = 346629,
  [SMALL_STATE(7321)] = 346645,
  [SMALL_STATE(7322)] = 346661,
  [SMALL_STATE(7323)] = 346681,
  [SMALL_STATE(7324)] = 346701,
  [SMALL_STATE(7325)] = 346717,
  [SMALL_STATE(7326)] = 346733,
  [SMALL_STATE(7327)] = 346755,
  [SMALL_STATE(7328)] = 346775,
  [SMALL_STATE(7329)] = 346789,
  [SMALL_STATE(7330)] = 346805,
  [SMALL_STATE(7331)] = 346819,
  [SMALL_STATE(7332)] = 346833,
  [SMALL_STATE(7333)] = 346847,
  [SMALL_STATE(7334)] = 346861,
  [SMALL_STATE(7335)] = 346875,
  [SMALL_STATE(7336)] = 346899,
  [SMALL_STATE(7337)] = 346915,
  [SMALL_STATE(7338)] = 346929,
  [SMALL_STATE(7339)] = 346943,
  [SMALL_STATE(7340)] = 346957,
  [SMALL_STATE(7341)] = 346971,
  [SMALL_STATE(7342)] = 346985,
  [SMALL_STATE(7343)] = 347009,
  [SMALL_STATE(7344)] = 347023,
  [SMALL_STATE(7345)] = 347039,
  [SMALL_STATE(7346)] = 347063,
  [SMALL_STATE(7347)] = 347087,
  [SMALL_STATE(7348)] = 347109,
  [SMALL_STATE(7349)] = 347133,
  [SMALL_STATE(7350)] = 347157,
  [SMALL_STATE(7351)] = 347171,
  [SMALL_STATE(7352)] = 347185,
  [SMALL_STATE(7353)] = 347199,
  [SMALL_STATE(7354)] = 347213,
  [SMALL_STATE(7355)] = 347227,
  [SMALL_STATE(7356)] = 347241,
  [SMALL_STATE(7357)] = 347255,
  [SMALL_STATE(7358)] = 347273,
  [SMALL_STATE(7359)] = 347294,
  [SMALL_STATE(7360)] = 347315,
  [SMALL_STATE(7361)] = 347336,
  [SMALL_STATE(7362)] = 347355,
  [SMALL_STATE(7363)] = 347374,
  [SMALL_STATE(7364)] = 347391,
  [SMALL_STATE(7365)] = 347412,
  [SMALL_STATE(7366)] = 347429,
  [SMALL_STATE(7367)] = 347450,
  [SMALL_STATE(7368)] = 347471,
  [SMALL_STATE(7369)] = 347488,
  [SMALL_STATE(7370)] = 347507,
  [SMALL_STATE(7371)] = 347528,
  [SMALL_STATE(7372)] = 347547,
  [SMALL_STATE(7373)] = 347566,
  [SMALL_STATE(7374)] = 347583,
  [SMALL_STATE(7375)] = 347604,
  [SMALL_STATE(7376)] = 347625,
  [SMALL_STATE(7377)] = 347646,
  [SMALL_STATE(7378)] = 347665,
  [SMALL_STATE(7379)] = 347686,
  [SMALL_STATE(7380)] = 347705,
  [SMALL_STATE(7381)] = 347724,
  [SMALL_STATE(7382)] = 347743,
  [SMALL_STATE(7383)] = 347762,
  [SMALL_STATE(7384)] = 347783,
  [SMALL_STATE(7385)] = 347804,
  [SMALL_STATE(7386)] = 347821,
  [SMALL_STATE(7387)] = 347838,
  [SMALL_STATE(7388)] = 347857,
  [SMALL_STATE(7389)] = 347878,
  [SMALL_STATE(7390)] = 347899,
  [SMALL_STATE(7391)] = 347920,
  [SMALL_STATE(7392)] = 347939,
  [SMALL_STATE(7393)] = 347960,
  [SMALL_STATE(7394)] = 347979,
  [SMALL_STATE(7395)] = 348000,
  [SMALL_STATE(7396)] = 348021,
  [SMALL_STATE(7397)] = 348040,
  [SMALL_STATE(7398)] = 348061,
  [SMALL_STATE(7399)] = 348082,
  [SMALL_STATE(7400)] = 348099,
  [SMALL_STATE(7401)] = 348120,
  [SMALL_STATE(7402)] = 348139,
  [SMALL_STATE(7403)] = 348156,
  [SMALL_STATE(7404)] = 348177,
  [SMALL_STATE(7405)] = 348194,
  [SMALL_STATE(7406)] = 348215,
  [SMALL_STATE(7407)] = 348236,
  [SMALL_STATE(7408)] = 348253,
  [SMALL_STATE(7409)] = 348270,
  [SMALL_STATE(7410)] = 348287,
  [SMALL_STATE(7411)] = 348306,
  [SMALL_STATE(7412)] = 348325,
  [SMALL_STATE(7413)] = 348342,
  [SMALL_STATE(7414)] = 348363,
  [SMALL_STATE(7415)] = 348382,
  [SMALL_STATE(7416)] = 348403,
  [SMALL_STATE(7417)] = 348422,
  [SMALL_STATE(7418)] = 348441,
  [SMALL_STATE(7419)] = 348460,
  [SMALL_STATE(7420)] = 348479,
  [SMALL_STATE(7421)] = 348498,
  [SMALL_STATE(7422)] = 348519,
  [SMALL_STATE(7423)] = 348540,
  [SMALL_STATE(7424)] = 348561,
  [SMALL_STATE(7425)] = 348580,
  [SMALL_STATE(7426)] = 348601,
  [SMALL_STATE(7427)] = 348620,
  [SMALL_STATE(7428)] = 348639,
  [SMALL_STATE(7429)] = 348658,
  [SMALL_STATE(7430)] = 348677,
  [SMALL_STATE(7431)] = 348698,
  [SMALL_STATE(7432)] = 348717,
  [SMALL_STATE(7433)] = 348738,
  [SMALL_STATE(7434)] = 348755,
  [SMALL_STATE(7435)] = 348774,
  [SMALL_STATE(7436)] = 348795,
  [SMALL_STATE(7437)] = 348814,
  [SMALL_STATE(7438)] = 348833,
  [SMALL_STATE(7439)] = 348854,
  [SMALL_STATE(7440)] = 348875,
  [SMALL_STATE(7441)] = 348894,
  [SMALL_STATE(7442)] = 348913,
  [SMALL_STATE(7443)] = 348934,
  [SMALL_STATE(7444)] = 348951,
  [SMALL_STATE(7445)] = 348968,
  [SMALL_STATE(7446)] = 348987,
  [SMALL_STATE(7447)] = 349008,
  [SMALL_STATE(7448)] = 349029,
  [SMALL_STATE(7449)] = 349048,
  [SMALL_STATE(7450)] = 349065,
  [SMALL_STATE(7451)] = 349082,
  [SMALL_STATE(7452)] = 349099,
  [SMALL_STATE(7453)] = 349118,
  [SMALL_STATE(7454)] = 349137,
  [SMALL_STATE(7455)] = 349156,
  [SMALL_STATE(7456)] = 349177,
  [SMALL_STATE(7457)] = 349198,
  [SMALL_STATE(7458)] = 349217,
  [SMALL_STATE(7459)] = 349238,
  [SMALL_STATE(7460)] = 349257,
  [SMALL_STATE(7461)] = 349276,
  [SMALL_STATE(7462)] = 349295,
  [SMALL_STATE(7463)] = 349314,
  [SMALL_STATE(7464)] = 349335,
  [SMALL_STATE(7465)] = 349356,
  [SMALL_STATE(7466)] = 349377,
  [SMALL_STATE(7467)] = 349396,
  [SMALL_STATE(7468)] = 349417,
  [SMALL_STATE(7469)] = 349438,
  [SMALL_STATE(7470)] = 349457,
  [SMALL_STATE(7471)] = 349476,
  [SMALL_STATE(7472)] = 349497,
  [SMALL_STATE(7473)] = 349516,
  [SMALL_STATE(7474)] = 349535,
  [SMALL_STATE(7475)] = 349554,
  [SMALL_STATE(7476)] = 349571,
  [SMALL_STATE(7477)] = 349592,
  [SMALL_STATE(7478)] = 349613,
  [SMALL_STATE(7479)] = 349634,
  [SMALL_STATE(7480)] = 349653,
  [SMALL_STATE(7481)] = 349670,
  [SMALL_STATE(7482)] = 349691,
  [SMALL_STATE(7483)] = 349712,
  [SMALL_STATE(7484)] = 349731,
  [SMALL_STATE(7485)] = 349750,
  [SMALL_STATE(7486)] = 349769,
  [SMALL_STATE(7487)] = 349788,
  [SMALL_STATE(7488)] = 349807,
  [SMALL_STATE(7489)] = 349828,
  [SMALL_STATE(7490)] = 349849,
  [SMALL_STATE(7491)] = 349868,
  [SMALL_STATE(7492)] = 349889,
  [SMALL_STATE(7493)] = 349910,
  [SMALL_STATE(7494)] = 349929,
  [SMALL_STATE(7495)] = 349950,
  [SMALL_STATE(7496)] = 349971,
  [SMALL_STATE(7497)] = 349990,
  [SMALL_STATE(7498)] = 350011,
  [SMALL_STATE(7499)] = 350032,
  [SMALL_STATE(7500)] = 350051,
  [SMALL_STATE(7501)] = 350070,
  [SMALL_STATE(7502)] = 350091,
  [SMALL_STATE(7503)] = 350110,
  [SMALL_STATE(7504)] = 350127,
  [SMALL_STATE(7505)] = 350144,
  [SMALL_STATE(7506)] = 350163,
  [SMALL_STATE(7507)] = 350182,
  [SMALL_STATE(7508)] = 350203,
  [SMALL_STATE(7509)] = 350224,
  [SMALL_STATE(7510)] = 350245,
  [SMALL_STATE(7511)] = 350266,
  [SMALL_STATE(7512)] = 350285,
  [SMALL_STATE(7513)] = 350306,
  [SMALL_STATE(7514)] = 350325,
  [SMALL_STATE(7515)] = 350344,
  [SMALL_STATE(7516)] = 350363,
  [SMALL_STATE(7517)] = 350384,
  [SMALL_STATE(7518)] = 350403,
  [SMALL_STATE(7519)] = 350422,
  [SMALL_STATE(7520)] = 350441,
  [SMALL_STATE(7521)] = 350462,
  [SMALL_STATE(7522)] = 350483,
  [SMALL_STATE(7523)] = 350504,
  [SMALL_STATE(7524)] = 350521,
  [SMALL_STATE(7525)] = 350540,
  [SMALL_STATE(7526)] = 350559,
  [SMALL_STATE(7527)] = 350578,
  [SMALL_STATE(7528)] = 350597,
  [SMALL_STATE(7529)] = 350618,
  [SMALL_STATE(7530)] = 350637,
  [SMALL_STATE(7531)] = 350654,
  [SMALL_STATE(7532)] = 350672,
  [SMALL_STATE(7533)] = 350690,
  [SMALL_STATE(7534)] = 350708,
  [SMALL_STATE(7535)] = 350724,
  [SMALL_STATE(7536)] = 350740,
  [SMALL_STATE(7537)] = 350758,
  [SMALL_STATE(7538)] = 350776,
  [SMALL_STATE(7539)] = 350794,
  [SMALL_STATE(7540)] = 350812,
  [SMALL_STATE(7541)] = 350828,
  [SMALL_STATE(7542)] = 350844,
  [SMALL_STATE(7543)] = 350862,
  [SMALL_STATE(7544)] = 350878,
  [SMALL_STATE(7545)] = 350896,
  [SMALL_STATE(7546)] = 350914,
  [SMALL_STATE(7547)] = 350930,
  [SMALL_STATE(7548)] = 350946,
  [SMALL_STATE(7549)] = 350958,
  [SMALL_STATE(7550)] = 350976,
  [SMALL_STATE(7551)] = 350992,
  [SMALL_STATE(7552)] = 351010,
  [SMALL_STATE(7553)] = 351028,
  [SMALL_STATE(7554)] = 351044,
  [SMALL_STATE(7555)] = 351062,
  [SMALL_STATE(7556)] = 351080,
  [SMALL_STATE(7557)] = 351096,
  [SMALL_STATE(7558)] = 351114,
  [SMALL_STATE(7559)] = 351132,
  [SMALL_STATE(7560)] = 351150,
  [SMALL_STATE(7561)] = 351168,
  [SMALL_STATE(7562)] = 351186,
  [SMALL_STATE(7563)] = 351204,
  [SMALL_STATE(7564)] = 351220,
  [SMALL_STATE(7565)] = 351238,
  [SMALL_STATE(7566)] = 351256,
  [SMALL_STATE(7567)] = 351274,
  [SMALL_STATE(7568)] = 351292,
  [SMALL_STATE(7569)] = 351310,
  [SMALL_STATE(7570)] = 351328,
  [SMALL_STATE(7571)] = 351346,
  [SMALL_STATE(7572)] = 351364,
  [SMALL_STATE(7573)] = 351382,
  [SMALL_STATE(7574)] = 351400,
  [SMALL_STATE(7575)] = 351418,
  [SMALL_STATE(7576)] = 351436,
  [SMALL_STATE(7577)] = 351454,
  [SMALL_STATE(7578)] = 351472,
  [SMALL_STATE(7579)] = 351490,
  [SMALL_STATE(7580)] = 351506,
  [SMALL_STATE(7581)] = 351524,
  [SMALL_STATE(7582)] = 351542,
  [SMALL_STATE(7583)] = 351560,
  [SMALL_STATE(7584)] = 351576,
  [SMALL_STATE(7585)] = 351592,
  [SMALL_STATE(7586)] = 351610,
  [SMALL_STATE(7587)] = 351628,
  [SMALL_STATE(7588)] = 351644,
  [SMALL_STATE(7589)] = 351662,
  [SMALL_STATE(7590)] = 351680,
  [SMALL_STATE(7591)] = 351698,
  [SMALL_STATE(7592)] = 351714,
  [SMALL_STATE(7593)] = 351732,
  [SMALL_STATE(7594)] = 351750,
  [SMALL_STATE(7595)] = 351768,
  [SMALL_STATE(7596)] = 351786,
  [SMALL_STATE(7597)] = 351804,
  [SMALL_STATE(7598)] = 351822,
  [SMALL_STATE(7599)] = 351840,
  [SMALL_STATE(7600)] = 351858,
  [SMALL_STATE(7601)] = 351874,
  [SMALL_STATE(7602)] = 351892,
  [SMALL_STATE(7603)] = 351910,
  [SMALL_STATE(7604)] = 351928,
  [SMALL_STATE(7605)] = 351946,
  [SMALL_STATE(7606)] = 351962,
  [SMALL_STATE(7607)] = 351978,
  [SMALL_STATE(7608)] = 351996,
  [SMALL_STATE(7609)] = 352014,
  [SMALL_STATE(7610)] = 352032,
  [SMALL_STATE(7611)] = 352050,
  [SMALL_STATE(7612)] = 352068,
  [SMALL_STATE(7613)] = 352086,
  [SMALL_STATE(7614)] = 352102,
  [SMALL_STATE(7615)] = 352120,
  [SMALL_STATE(7616)] = 352138,
  [SMALL_STATE(7617)] = 352156,
  [SMALL_STATE(7618)] = 352172,
  [SMALL_STATE(7619)] = 352190,
  [SMALL_STATE(7620)] = 352208,
  [SMALL_STATE(7621)] = 352226,
  [SMALL_STATE(7622)] = 352244,
  [SMALL_STATE(7623)] = 352260,
  [SMALL_STATE(7624)] = 352278,
  [SMALL_STATE(7625)] = 352294,
  [SMALL_STATE(7626)] = 352312,
  [SMALL_STATE(7627)] = 352330,
  [SMALL_STATE(7628)] = 352348,
  [SMALL_STATE(7629)] = 352366,
  [SMALL_STATE(7630)] = 352382,
  [SMALL_STATE(7631)] = 352400,
  [SMALL_STATE(7632)] = 352416,
  [SMALL_STATE(7633)] = 352434,
  [SMALL_STATE(7634)] = 352452,
  [SMALL_STATE(7635)] = 352470,
  [SMALL_STATE(7636)] = 352488,
  [SMALL_STATE(7637)] = 352506,
  [SMALL_STATE(7638)] = 352524,
  [SMALL_STATE(7639)] = 352542,
  [SMALL_STATE(7640)] = 352560,
  [SMALL_STATE(7641)] = 352578,
  [SMALL_STATE(7642)] = 352596,
  [SMALL_STATE(7643)] = 352614,
  [SMALL_STATE(7644)] = 352632,
  [SMALL_STATE(7645)] = 352650,
  [SMALL_STATE(7646)] = 352668,
  [SMALL_STATE(7647)] = 352686,
  [SMALL_STATE(7648)] = 352704,
  [SMALL_STATE(7649)] = 352722,
  [SMALL_STATE(7650)] = 352740,
  [SMALL_STATE(7651)] = 352758,
  [SMALL_STATE(7652)] = 352776,
  [SMALL_STATE(7653)] = 352794,
  [SMALL_STATE(7654)] = 352812,
  [SMALL_STATE(7655)] = 352830,
  [SMALL_STATE(7656)] = 352848,
  [SMALL_STATE(7657)] = 352864,
  [SMALL_STATE(7658)] = 352882,
  [SMALL_STATE(7659)] = 352894,
  [SMALL_STATE(7660)] = 352912,
  [SMALL_STATE(7661)] = 352930,
  [SMALL_STATE(7662)] = 352948,
  [SMALL_STATE(7663)] = 352962,
  [SMALL_STATE(7664)] = 352980,
  [SMALL_STATE(7665)] = 352998,
  [SMALL_STATE(7666)] = 353016,
  [SMALL_STATE(7667)] = 353028,
  [SMALL_STATE(7668)] = 353046,
  [SMALL_STATE(7669)] = 353062,
  [SMALL_STATE(7670)] = 353078,
  [SMALL_STATE(7671)] = 353094,
  [SMALL_STATE(7672)] = 353112,
  [SMALL_STATE(7673)] = 353130,
  [SMALL_STATE(7674)] = 353148,
  [SMALL_STATE(7675)] = 353166,
  [SMALL_STATE(7676)] = 353182,
  [SMALL_STATE(7677)] = 353198,
  [SMALL_STATE(7678)] = 353216,
  [SMALL_STATE(7679)] = 353234,
  [SMALL_STATE(7680)] = 353252,
  [SMALL_STATE(7681)] = 353268,
  [SMALL_STATE(7682)] = 353286,
  [SMALL_STATE(7683)] = 353304,
  [SMALL_STATE(7684)] = 353322,
  [SMALL_STATE(7685)] = 353340,
  [SMALL_STATE(7686)] = 353358,
  [SMALL_STATE(7687)] = 353376,
  [SMALL_STATE(7688)] = 353392,
  [SMALL_STATE(7689)] = 353410,
  [SMALL_STATE(7690)] = 353428,
  [SMALL_STATE(7691)] = 353446,
  [SMALL_STATE(7692)] = 353464,
  [SMALL_STATE(7693)] = 353482,
  [SMALL_STATE(7694)] = 353500,
  [SMALL_STATE(7695)] = 353518,
  [SMALL_STATE(7696)] = 353536,
  [SMALL_STATE(7697)] = 353554,
  [SMALL_STATE(7698)] = 353572,
  [SMALL_STATE(7699)] = 353590,
  [SMALL_STATE(7700)] = 353608,
  [SMALL_STATE(7701)] = 353626,
  [SMALL_STATE(7702)] = 353644,
  [SMALL_STATE(7703)] = 353662,
  [SMALL_STATE(7704)] = 353680,
  [SMALL_STATE(7705)] = 353698,
  [SMALL_STATE(7706)] = 353714,
  [SMALL_STATE(7707)] = 353732,
  [SMALL_STATE(7708)] = 353750,
  [SMALL_STATE(7709)] = 353768,
  [SMALL_STATE(7710)] = 353786,
  [SMALL_STATE(7711)] = 353804,
  [SMALL_STATE(7712)] = 353822,
  [SMALL_STATE(7713)] = 353840,
  [SMALL_STATE(7714)] = 353856,
  [SMALL_STATE(7715)] = 353874,
  [SMALL_STATE(7716)] = 353892,
  [SMALL_STATE(7717)] = 353910,
  [SMALL_STATE(7718)] = 353928,
  [SMALL_STATE(7719)] = 353946,
  [SMALL_STATE(7720)] = 353964,
  [SMALL_STATE(7721)] = 353982,
  [SMALL_STATE(7722)] = 354000,
  [SMALL_STATE(7723)] = 354018,
  [SMALL_STATE(7724)] = 354036,
  [SMALL_STATE(7725)] = 354054,
  [SMALL_STATE(7726)] = 354072,
  [SMALL_STATE(7727)] = 354090,
  [SMALL_STATE(7728)] = 354108,
  [SMALL_STATE(7729)] = 354126,
  [SMALL_STATE(7730)] = 354144,
  [SMALL_STATE(7731)] = 354162,
  [SMALL_STATE(7732)] = 354180,
  [SMALL_STATE(7733)] = 354196,
  [SMALL_STATE(7734)] = 354214,
  [SMALL_STATE(7735)] = 354232,
  [SMALL_STATE(7736)] = 354250,
  [SMALL_STATE(7737)] = 354268,
  [SMALL_STATE(7738)] = 354284,
  [SMALL_STATE(7739)] = 354302,
  [SMALL_STATE(7740)] = 354320,
  [SMALL_STATE(7741)] = 354338,
  [SMALL_STATE(7742)] = 354356,
  [SMALL_STATE(7743)] = 354374,
  [SMALL_STATE(7744)] = 354392,
  [SMALL_STATE(7745)] = 354410,
  [SMALL_STATE(7746)] = 354426,
  [SMALL_STATE(7747)] = 354444,
  [SMALL_STATE(7748)] = 354462,
  [SMALL_STATE(7749)] = 354478,
  [SMALL_STATE(7750)] = 354496,
  [SMALL_STATE(7751)] = 354514,
  [SMALL_STATE(7752)] = 354529,
  [SMALL_STATE(7753)] = 354544,
  [SMALL_STATE(7754)] = 354559,
  [SMALL_STATE(7755)] = 354574,
  [SMALL_STATE(7756)] = 354591,
  [SMALL_STATE(7757)] = 354606,
  [SMALL_STATE(7758)] = 354621,
  [SMALL_STATE(7759)] = 354636,
  [SMALL_STATE(7760)] = 354651,
  [SMALL_STATE(7761)] = 354666,
  [SMALL_STATE(7762)] = 354681,
  [SMALL_STATE(7763)] = 354696,
  [SMALL_STATE(7764)] = 354711,
  [SMALL_STATE(7765)] = 354726,
  [SMALL_STATE(7766)] = 354741,
  [SMALL_STATE(7767)] = 354756,
  [SMALL_STATE(7768)] = 354771,
  [SMALL_STATE(7769)] = 354786,
  [SMALL_STATE(7770)] = 354801,
  [SMALL_STATE(7771)] = 354816,
  [SMALL_STATE(7772)] = 354831,
  [SMALL_STATE(7773)] = 354846,
  [SMALL_STATE(7774)] = 354861,
  [SMALL_STATE(7775)] = 354876,
  [SMALL_STATE(7776)] = 354891,
  [SMALL_STATE(7777)] = 354908,
  [SMALL_STATE(7778)] = 354923,
  [SMALL_STATE(7779)] = 354938,
  [SMALL_STATE(7780)] = 354953,
  [SMALL_STATE(7781)] = 354968,
  [SMALL_STATE(7782)] = 354983,
  [SMALL_STATE(7783)] = 354998,
  [SMALL_STATE(7784)] = 355013,
  [SMALL_STATE(7785)] = 355028,
  [SMALL_STATE(7786)] = 355043,
  [SMALL_STATE(7787)] = 355058,
  [SMALL_STATE(7788)] = 355073,
  [SMALL_STATE(7789)] = 355088,
  [SMALL_STATE(7790)] = 355103,
  [SMALL_STATE(7791)] = 355118,
  [SMALL_STATE(7792)] = 355133,
  [SMALL_STATE(7793)] = 355148,
  [SMALL_STATE(7794)] = 355163,
  [SMALL_STATE(7795)] = 355178,
  [SMALL_STATE(7796)] = 355193,
  [SMALL_STATE(7797)] = 355208,
  [SMALL_STATE(7798)] = 355223,
  [SMALL_STATE(7799)] = 355238,
  [SMALL_STATE(7800)] = 355253,
  [SMALL_STATE(7801)] = 355266,
  [SMALL_STATE(7802)] = 355281,
  [SMALL_STATE(7803)] = 355296,
  [SMALL_STATE(7804)] = 355311,
  [SMALL_STATE(7805)] = 355326,
  [SMALL_STATE(7806)] = 355341,
  [SMALL_STATE(7807)] = 355356,
  [SMALL_STATE(7808)] = 355371,
  [SMALL_STATE(7809)] = 355382,
  [SMALL_STATE(7810)] = 355397,
  [SMALL_STATE(7811)] = 355412,
  [SMALL_STATE(7812)] = 355427,
  [SMALL_STATE(7813)] = 355438,
  [SMALL_STATE(7814)] = 355453,
  [SMALL_STATE(7815)] = 355468,
  [SMALL_STATE(7816)] = 355483,
  [SMALL_STATE(7817)] = 355498,
  [SMALL_STATE(7818)] = 355509,
  [SMALL_STATE(7819)] = 355526,
  [SMALL_STATE(7820)] = 355541,
  [SMALL_STATE(7821)] = 355556,
  [SMALL_STATE(7822)] = 355571,
  [SMALL_STATE(7823)] = 355586,
  [SMALL_STATE(7824)] = 355601,
  [SMALL_STATE(7825)] = 355616,
  [SMALL_STATE(7826)] = 355631,
  [SMALL_STATE(7827)] = 355646,
  [SMALL_STATE(7828)] = 355661,
  [SMALL_STATE(7829)] = 355676,
  [SMALL_STATE(7830)] = 355691,
  [SMALL_STATE(7831)] = 355708,
  [SMALL_STATE(7832)] = 355723,
  [SMALL_STATE(7833)] = 355738,
  [SMALL_STATE(7834)] = 355753,
  [SMALL_STATE(7835)] = 355768,
  [SMALL_STATE(7836)] = 355783,
  [SMALL_STATE(7837)] = 355798,
  [SMALL_STATE(7838)] = 355813,
  [SMALL_STATE(7839)] = 355828,
  [SMALL_STATE(7840)] = 355843,
  [SMALL_STATE(7841)] = 355860,
  [SMALL_STATE(7842)] = 355875,
  [SMALL_STATE(7843)] = 355890,
  [SMALL_STATE(7844)] = 355905,
  [SMALL_STATE(7845)] = 355920,
  [SMALL_STATE(7846)] = 355935,
  [SMALL_STATE(7847)] = 355950,
  [SMALL_STATE(7848)] = 355965,
  [SMALL_STATE(7849)] = 355980,
  [SMALL_STATE(7850)] = 355995,
  [SMALL_STATE(7851)] = 356010,
  [SMALL_STATE(7852)] = 356025,
  [SMALL_STATE(7853)] = 356040,
  [SMALL_STATE(7854)] = 356055,
  [SMALL_STATE(7855)] = 356070,
  [SMALL_STATE(7856)] = 356085,
  [SMALL_STATE(7857)] = 356100,
  [SMALL_STATE(7858)] = 356115,
  [SMALL_STATE(7859)] = 356130,
  [SMALL_STATE(7860)] = 356145,
  [SMALL_STATE(7861)] = 356160,
  [SMALL_STATE(7862)] = 356175,
  [SMALL_STATE(7863)] = 356190,
  [SMALL_STATE(7864)] = 356205,
  [SMALL_STATE(7865)] = 356220,
  [SMALL_STATE(7866)] = 356235,
  [SMALL_STATE(7867)] = 356250,
  [SMALL_STATE(7868)] = 356265,
  [SMALL_STATE(7869)] = 356280,
  [SMALL_STATE(7870)] = 356295,
  [SMALL_STATE(7871)] = 356310,
  [SMALL_STATE(7872)] = 356325,
  [SMALL_STATE(7873)] = 356340,
  [SMALL_STATE(7874)] = 356355,
  [SMALL_STATE(7875)] = 356370,
  [SMALL_STATE(7876)] = 356385,
  [SMALL_STATE(7877)] = 356400,
  [SMALL_STATE(7878)] = 356415,
  [SMALL_STATE(7879)] = 356430,
  [SMALL_STATE(7880)] = 356445,
  [SMALL_STATE(7881)] = 356460,
  [SMALL_STATE(7882)] = 356475,
  [SMALL_STATE(7883)] = 356490,
  [SMALL_STATE(7884)] = 356505,
  [SMALL_STATE(7885)] = 356520,
  [SMALL_STATE(7886)] = 356535,
  [SMALL_STATE(7887)] = 356550,
  [SMALL_STATE(7888)] = 356565,
  [SMALL_STATE(7889)] = 356580,
  [SMALL_STATE(7890)] = 356595,
  [SMALL_STATE(7891)] = 356610,
  [SMALL_STATE(7892)] = 356625,
  [SMALL_STATE(7893)] = 356640,
  [SMALL_STATE(7894)] = 356655,
  [SMALL_STATE(7895)] = 356670,
  [SMALL_STATE(7896)] = 356685,
  [SMALL_STATE(7897)] = 356700,
  [SMALL_STATE(7898)] = 356715,
  [SMALL_STATE(7899)] = 356730,
  [SMALL_STATE(7900)] = 356745,
  [SMALL_STATE(7901)] = 356760,
  [SMALL_STATE(7902)] = 356775,
  [SMALL_STATE(7903)] = 356790,
  [SMALL_STATE(7904)] = 356803,
  [SMALL_STATE(7905)] = 356818,
  [SMALL_STATE(7906)] = 356833,
  [SMALL_STATE(7907)] = 356848,
  [SMALL_STATE(7908)] = 356863,
  [SMALL_STATE(7909)] = 356878,
  [SMALL_STATE(7910)] = 356893,
  [SMALL_STATE(7911)] = 356906,
  [SMALL_STATE(7912)] = 356921,
  [SMALL_STATE(7913)] = 356936,
  [SMALL_STATE(7914)] = 356951,
  [SMALL_STATE(7915)] = 356966,
  [SMALL_STATE(7916)] = 356981,
  [SMALL_STATE(7917)] = 356996,
  [SMALL_STATE(7918)] = 357011,
  [SMALL_STATE(7919)] = 357026,
  [SMALL_STATE(7920)] = 357041,
  [SMALL_STATE(7921)] = 357056,
  [SMALL_STATE(7922)] = 357071,
  [SMALL_STATE(7923)] = 357086,
  [SMALL_STATE(7924)] = 357101,
  [SMALL_STATE(7925)] = 357116,
  [SMALL_STATE(7926)] = 357131,
  [SMALL_STATE(7927)] = 357146,
  [SMALL_STATE(7928)] = 357161,
  [SMALL_STATE(7929)] = 357176,
  [SMALL_STATE(7930)] = 357191,
  [SMALL_STATE(7931)] = 357206,
  [SMALL_STATE(7932)] = 357221,
  [SMALL_STATE(7933)] = 357236,
  [SMALL_STATE(7934)] = 357251,
  [SMALL_STATE(7935)] = 357266,
  [SMALL_STATE(7936)] = 357281,
  [SMALL_STATE(7937)] = 357296,
  [SMALL_STATE(7938)] = 357311,
  [SMALL_STATE(7939)] = 357326,
  [SMALL_STATE(7940)] = 357341,
  [SMALL_STATE(7941)] = 357356,
  [SMALL_STATE(7942)] = 357371,
  [SMALL_STATE(7943)] = 357386,
  [SMALL_STATE(7944)] = 357401,
  [SMALL_STATE(7945)] = 357416,
  [SMALL_STATE(7946)] = 357431,
  [SMALL_STATE(7947)] = 357446,
  [SMALL_STATE(7948)] = 357461,
  [SMALL_STATE(7949)] = 357476,
  [SMALL_STATE(7950)] = 357491,
  [SMALL_STATE(7951)] = 357504,
  [SMALL_STATE(7952)] = 357519,
  [SMALL_STATE(7953)] = 357536,
  [SMALL_STATE(7954)] = 357551,
  [SMALL_STATE(7955)] = 357566,
  [SMALL_STATE(7956)] = 357581,
  [SMALL_STATE(7957)] = 357596,
  [SMALL_STATE(7958)] = 357611,
  [SMALL_STATE(7959)] = 357626,
  [SMALL_STATE(7960)] = 357641,
  [SMALL_STATE(7961)] = 357656,
  [SMALL_STATE(7962)] = 357673,
  [SMALL_STATE(7963)] = 357688,
  [SMALL_STATE(7964)] = 357703,
  [SMALL_STATE(7965)] = 357718,
  [SMALL_STATE(7966)] = 357733,
  [SMALL_STATE(7967)] = 357748,
  [SMALL_STATE(7968)] = 357763,
  [SMALL_STATE(7969)] = 357778,
  [SMALL_STATE(7970)] = 357793,
  [SMALL_STATE(7971)] = 357808,
  [SMALL_STATE(7972)] = 357823,
  [SMALL_STATE(7973)] = 357838,
  [SMALL_STATE(7974)] = 357853,
  [SMALL_STATE(7975)] = 357868,
  [SMALL_STATE(7976)] = 357883,
  [SMALL_STATE(7977)] = 357898,
  [SMALL_STATE(7978)] = 357913,
  [SMALL_STATE(7979)] = 357928,
  [SMALL_STATE(7980)] = 357943,
  [SMALL_STATE(7981)] = 357958,
  [SMALL_STATE(7982)] = 357973,
  [SMALL_STATE(7983)] = 357988,
  [SMALL_STATE(7984)] = 358003,
  [SMALL_STATE(7985)] = 358018,
  [SMALL_STATE(7986)] = 358033,
  [SMALL_STATE(7987)] = 358048,
  [SMALL_STATE(7988)] = 358063,
  [SMALL_STATE(7989)] = 358078,
  [SMALL_STATE(7990)] = 358093,
  [SMALL_STATE(7991)] = 358108,
  [SMALL_STATE(7992)] = 358123,
  [SMALL_STATE(7993)] = 358138,
  [SMALL_STATE(7994)] = 358153,
  [SMALL_STATE(7995)] = 358168,
  [SMALL_STATE(7996)] = 358183,
  [SMALL_STATE(7997)] = 358198,
  [SMALL_STATE(7998)] = 358213,
  [SMALL_STATE(7999)] = 358228,
  [SMALL_STATE(8000)] = 358245,
  [SMALL_STATE(8001)] = 358260,
  [SMALL_STATE(8002)] = 358275,
  [SMALL_STATE(8003)] = 358290,
  [SMALL_STATE(8004)] = 358305,
  [SMALL_STATE(8005)] = 358320,
  [SMALL_STATE(8006)] = 358331,
  [SMALL_STATE(8007)] = 358346,
  [SMALL_STATE(8008)] = 358361,
  [SMALL_STATE(8009)] = 358376,
  [SMALL_STATE(8010)] = 358391,
  [SMALL_STATE(8011)] = 358406,
  [SMALL_STATE(8012)] = 358421,
  [SMALL_STATE(8013)] = 358434,
  [SMALL_STATE(8014)] = 358449,
  [SMALL_STATE(8015)] = 358464,
  [SMALL_STATE(8016)] = 358479,
  [SMALL_STATE(8017)] = 358494,
  [SMALL_STATE(8018)] = 358511,
  [SMALL_STATE(8019)] = 358526,
  [SMALL_STATE(8020)] = 358541,
  [SMALL_STATE(8021)] = 358556,
  [SMALL_STATE(8022)] = 358571,
  [SMALL_STATE(8023)] = 358586,
  [SMALL_STATE(8024)] = 358601,
  [SMALL_STATE(8025)] = 358616,
  [SMALL_STATE(8026)] = 358631,
  [SMALL_STATE(8027)] = 358646,
  [SMALL_STATE(8028)] = 358661,
  [SMALL_STATE(8029)] = 358676,
  [SMALL_STATE(8030)] = 358691,
  [SMALL_STATE(8031)] = 358706,
  [SMALL_STATE(8032)] = 358721,
  [SMALL_STATE(8033)] = 358736,
  [SMALL_STATE(8034)] = 358751,
  [SMALL_STATE(8035)] = 358766,
  [SMALL_STATE(8036)] = 358781,
  [SMALL_STATE(8037)] = 358796,
  [SMALL_STATE(8038)] = 358811,
  [SMALL_STATE(8039)] = 358822,
  [SMALL_STATE(8040)] = 358837,
  [SMALL_STATE(8041)] = 358852,
  [SMALL_STATE(8042)] = 358867,
  [SMALL_STATE(8043)] = 358882,
  [SMALL_STATE(8044)] = 358897,
  [SMALL_STATE(8045)] = 358912,
  [SMALL_STATE(8046)] = 358927,
  [SMALL_STATE(8047)] = 358944,
  [SMALL_STATE(8048)] = 358959,
  [SMALL_STATE(8049)] = 358970,
  [SMALL_STATE(8050)] = 358985,
  [SMALL_STATE(8051)] = 359000,
  [SMALL_STATE(8052)] = 359015,
  [SMALL_STATE(8053)] = 359030,
  [SMALL_STATE(8054)] = 359047,
  [SMALL_STATE(8055)] = 359062,
  [SMALL_STATE(8056)] = 359077,
  [SMALL_STATE(8057)] = 359092,
  [SMALL_STATE(8058)] = 359107,
  [SMALL_STATE(8059)] = 359122,
  [SMALL_STATE(8060)] = 359137,
  [SMALL_STATE(8061)] = 359152,
  [SMALL_STATE(8062)] = 359167,
  [SMALL_STATE(8063)] = 359182,
  [SMALL_STATE(8064)] = 359197,
  [SMALL_STATE(8065)] = 359212,
  [SMALL_STATE(8066)] = 359227,
  [SMALL_STATE(8067)] = 359244,
  [SMALL_STATE(8068)] = 359259,
  [SMALL_STATE(8069)] = 359274,
  [SMALL_STATE(8070)] = 359289,
  [SMALL_STATE(8071)] = 359304,
  [SMALL_STATE(8072)] = 359319,
  [SMALL_STATE(8073)] = 359334,
  [SMALL_STATE(8074)] = 359349,
  [SMALL_STATE(8075)] = 359364,
  [SMALL_STATE(8076)] = 359379,
  [SMALL_STATE(8077)] = 359394,
  [SMALL_STATE(8078)] = 359409,
  [SMALL_STATE(8079)] = 359424,
  [SMALL_STATE(8080)] = 359439,
  [SMALL_STATE(8081)] = 359454,
  [SMALL_STATE(8082)] = 359469,
  [SMALL_STATE(8083)] = 359484,
  [SMALL_STATE(8084)] = 359499,
  [SMALL_STATE(8085)] = 359514,
  [SMALL_STATE(8086)] = 359529,
  [SMALL_STATE(8087)] = 359544,
  [SMALL_STATE(8088)] = 359559,
  [SMALL_STATE(8089)] = 359574,
  [SMALL_STATE(8090)] = 359589,
  [SMALL_STATE(8091)] = 359604,
  [SMALL_STATE(8092)] = 359619,
  [SMALL_STATE(8093)] = 359634,
  [SMALL_STATE(8094)] = 359649,
  [SMALL_STATE(8095)] = 359664,
  [SMALL_STATE(8096)] = 359679,
  [SMALL_STATE(8097)] = 359694,
  [SMALL_STATE(8098)] = 359709,
  [SMALL_STATE(8099)] = 359724,
  [SMALL_STATE(8100)] = 359739,
  [SMALL_STATE(8101)] = 359754,
  [SMALL_STATE(8102)] = 359769,
  [SMALL_STATE(8103)] = 359784,
  [SMALL_STATE(8104)] = 359799,
  [SMALL_STATE(8105)] = 359814,
  [SMALL_STATE(8106)] = 359829,
  [SMALL_STATE(8107)] = 359844,
  [SMALL_STATE(8108)] = 359859,
  [SMALL_STATE(8109)] = 359874,
  [SMALL_STATE(8110)] = 359889,
  [SMALL_STATE(8111)] = 359904,
  [SMALL_STATE(8112)] = 359919,
  [SMALL_STATE(8113)] = 359934,
  [SMALL_STATE(8114)] = 359949,
  [SMALL_STATE(8115)] = 359964,
  [SMALL_STATE(8116)] = 359979,
  [SMALL_STATE(8117)] = 359994,
  [SMALL_STATE(8118)] = 360009,
  [SMALL_STATE(8119)] = 360024,
  [SMALL_STATE(8120)] = 360039,
  [SMALL_STATE(8121)] = 360054,
  [SMALL_STATE(8122)] = 360069,
  [SMALL_STATE(8123)] = 360084,
  [SMALL_STATE(8124)] = 360099,
  [SMALL_STATE(8125)] = 360114,
  [SMALL_STATE(8126)] = 360129,
  [SMALL_STATE(8127)] = 360144,
  [SMALL_STATE(8128)] = 360159,
  [SMALL_STATE(8129)] = 360174,
  [SMALL_STATE(8130)] = 360189,
  [SMALL_STATE(8131)] = 360204,
  [SMALL_STATE(8132)] = 360221,
  [SMALL_STATE(8133)] = 360236,
  [SMALL_STATE(8134)] = 360251,
  [SMALL_STATE(8135)] = 360266,
  [SMALL_STATE(8136)] = 360281,
  [SMALL_STATE(8137)] = 360296,
  [SMALL_STATE(8138)] = 360311,
  [SMALL_STATE(8139)] = 360326,
  [SMALL_STATE(8140)] = 360341,
  [SMALL_STATE(8141)] = 360356,
  [SMALL_STATE(8142)] = 360371,
  [SMALL_STATE(8143)] = 360386,
  [SMALL_STATE(8144)] = 360401,
  [SMALL_STATE(8145)] = 360416,
  [SMALL_STATE(8146)] = 360431,
  [SMALL_STATE(8147)] = 360446,
  [SMALL_STATE(8148)] = 360461,
  [SMALL_STATE(8149)] = 360478,
  [SMALL_STATE(8150)] = 360493,
  [SMALL_STATE(8151)] = 360508,
  [SMALL_STATE(8152)] = 360523,
  [SMALL_STATE(8153)] = 360538,
  [SMALL_STATE(8154)] = 360553,
  [SMALL_STATE(8155)] = 360568,
  [SMALL_STATE(8156)] = 360583,
  [SMALL_STATE(8157)] = 360600,
  [SMALL_STATE(8158)] = 360615,
  [SMALL_STATE(8159)] = 360630,
  [SMALL_STATE(8160)] = 360645,
  [SMALL_STATE(8161)] = 360660,
  [SMALL_STATE(8162)] = 360675,
  [SMALL_STATE(8163)] = 360692,
  [SMALL_STATE(8164)] = 360707,
  [SMALL_STATE(8165)] = 360722,
  [SMALL_STATE(8166)] = 360737,
  [SMALL_STATE(8167)] = 360752,
  [SMALL_STATE(8168)] = 360767,
  [SMALL_STATE(8169)] = 360782,
  [SMALL_STATE(8170)] = 360797,
  [SMALL_STATE(8171)] = 360808,
  [SMALL_STATE(8172)] = 360823,
  [SMALL_STATE(8173)] = 360838,
  [SMALL_STATE(8174)] = 360853,
  [SMALL_STATE(8175)] = 360868,
  [SMALL_STATE(8176)] = 360883,
  [SMALL_STATE(8177)] = 360898,
  [SMALL_STATE(8178)] = 360913,
  [SMALL_STATE(8179)] = 360928,
  [SMALL_STATE(8180)] = 360943,
  [SMALL_STATE(8181)] = 360958,
  [SMALL_STATE(8182)] = 360973,
  [SMALL_STATE(8183)] = 360988,
  [SMALL_STATE(8184)] = 361003,
  [SMALL_STATE(8185)] = 361018,
  [SMALL_STATE(8186)] = 361033,
  [SMALL_STATE(8187)] = 361048,
  [SMALL_STATE(8188)] = 361063,
  [SMALL_STATE(8189)] = 361078,
  [SMALL_STATE(8190)] = 361093,
  [SMALL_STATE(8191)] = 361108,
  [SMALL_STATE(8192)] = 361123,
  [SMALL_STATE(8193)] = 361138,
  [SMALL_STATE(8194)] = 361153,
  [SMALL_STATE(8195)] = 361168,
  [SMALL_STATE(8196)] = 361183,
  [SMALL_STATE(8197)] = 361198,
  [SMALL_STATE(8198)] = 361213,
  [SMALL_STATE(8199)] = 361228,
  [SMALL_STATE(8200)] = 361243,
  [SMALL_STATE(8201)] = 361258,
  [SMALL_STATE(8202)] = 361273,
  [SMALL_STATE(8203)] = 361288,
  [SMALL_STATE(8204)] = 361303,
  [SMALL_STATE(8205)] = 361318,
  [SMALL_STATE(8206)] = 361333,
  [SMALL_STATE(8207)] = 361348,
  [SMALL_STATE(8208)] = 361363,
  [SMALL_STATE(8209)] = 361378,
  [SMALL_STATE(8210)] = 361393,
  [SMALL_STATE(8211)] = 361408,
  [SMALL_STATE(8212)] = 361419,
  [SMALL_STATE(8213)] = 361434,
  [SMALL_STATE(8214)] = 361449,
  [SMALL_STATE(8215)] = 361464,
  [SMALL_STATE(8216)] = 361479,
  [SMALL_STATE(8217)] = 361494,
  [SMALL_STATE(8218)] = 361509,
  [SMALL_STATE(8219)] = 361524,
  [SMALL_STATE(8220)] = 361535,
  [SMALL_STATE(8221)] = 361550,
  [SMALL_STATE(8222)] = 361565,
  [SMALL_STATE(8223)] = 361580,
  [SMALL_STATE(8224)] = 361595,
  [SMALL_STATE(8225)] = 361610,
  [SMALL_STATE(8226)] = 361625,
  [SMALL_STATE(8227)] = 361640,
  [SMALL_STATE(8228)] = 361655,
  [SMALL_STATE(8229)] = 361670,
  [SMALL_STATE(8230)] = 361685,
  [SMALL_STATE(8231)] = 361700,
  [SMALL_STATE(8232)] = 361715,
  [SMALL_STATE(8233)] = 361730,
  [SMALL_STATE(8234)] = 361745,
  [SMALL_STATE(8235)] = 361760,
  [SMALL_STATE(8236)] = 361775,
  [SMALL_STATE(8237)] = 361790,
  [SMALL_STATE(8238)] = 361805,
  [SMALL_STATE(8239)] = 361820,
  [SMALL_STATE(8240)] = 361835,
  [SMALL_STATE(8241)] = 361850,
  [SMALL_STATE(8242)] = 361865,
  [SMALL_STATE(8243)] = 361880,
  [SMALL_STATE(8244)] = 361895,
  [SMALL_STATE(8245)] = 361910,
  [SMALL_STATE(8246)] = 361925,
  [SMALL_STATE(8247)] = 361940,
  [SMALL_STATE(8248)] = 361955,
  [SMALL_STATE(8249)] = 361970,
  [SMALL_STATE(8250)] = 361985,
  [SMALL_STATE(8251)] = 362000,
  [SMALL_STATE(8252)] = 362015,
  [SMALL_STATE(8253)] = 362030,
  [SMALL_STATE(8254)] = 362045,
  [SMALL_STATE(8255)] = 362060,
  [SMALL_STATE(8256)] = 362075,
  [SMALL_STATE(8257)] = 362090,
  [SMALL_STATE(8258)] = 362105,
  [SMALL_STATE(8259)] = 362120,
  [SMALL_STATE(8260)] = 362135,
  [SMALL_STATE(8261)] = 362150,
  [SMALL_STATE(8262)] = 362165,
  [SMALL_STATE(8263)] = 362180,
  [SMALL_STATE(8264)] = 362195,
  [SMALL_STATE(8265)] = 362210,
  [SMALL_STATE(8266)] = 362227,
  [SMALL_STATE(8267)] = 362242,
  [SMALL_STATE(8268)] = 362257,
  [SMALL_STATE(8269)] = 362272,
  [SMALL_STATE(8270)] = 362287,
  [SMALL_STATE(8271)] = 362302,
  [SMALL_STATE(8272)] = 362317,
  [SMALL_STATE(8273)] = 362332,
  [SMALL_STATE(8274)] = 362347,
  [SMALL_STATE(8275)] = 362362,
  [SMALL_STATE(8276)] = 362377,
  [SMALL_STATE(8277)] = 362392,
  [SMALL_STATE(8278)] = 362407,
  [SMALL_STATE(8279)] = 362424,
  [SMALL_STATE(8280)] = 362439,
  [SMALL_STATE(8281)] = 362454,
  [SMALL_STATE(8282)] = 362469,
  [SMALL_STATE(8283)] = 362484,
  [SMALL_STATE(8284)] = 362499,
  [SMALL_STATE(8285)] = 362514,
  [SMALL_STATE(8286)] = 362529,
  [SMALL_STATE(8287)] = 362544,
  [SMALL_STATE(8288)] = 362559,
  [SMALL_STATE(8289)] = 362574,
  [SMALL_STATE(8290)] = 362589,
  [SMALL_STATE(8291)] = 362604,
  [SMALL_STATE(8292)] = 362619,
  [SMALL_STATE(8293)] = 362634,
  [SMALL_STATE(8294)] = 362649,
  [SMALL_STATE(8295)] = 362664,
  [SMALL_STATE(8296)] = 362679,
  [SMALL_STATE(8297)] = 362694,
  [SMALL_STATE(8298)] = 362709,
  [SMALL_STATE(8299)] = 362726,
  [SMALL_STATE(8300)] = 362741,
  [SMALL_STATE(8301)] = 362756,
  [SMALL_STATE(8302)] = 362771,
  [SMALL_STATE(8303)] = 362786,
  [SMALL_STATE(8304)] = 362801,
  [SMALL_STATE(8305)] = 362816,
  [SMALL_STATE(8306)] = 362831,
  [SMALL_STATE(8307)] = 362846,
  [SMALL_STATE(8308)] = 362861,
  [SMALL_STATE(8309)] = 362876,
  [SMALL_STATE(8310)] = 362891,
  [SMALL_STATE(8311)] = 362906,
  [SMALL_STATE(8312)] = 362921,
  [SMALL_STATE(8313)] = 362936,
  [SMALL_STATE(8314)] = 362951,
  [SMALL_STATE(8315)] = 362962,
  [SMALL_STATE(8316)] = 362977,
  [SMALL_STATE(8317)] = 362992,
  [SMALL_STATE(8318)] = 363007,
  [SMALL_STATE(8319)] = 363022,
  [SMALL_STATE(8320)] = 363037,
  [SMALL_STATE(8321)] = 363052,
  [SMALL_STATE(8322)] = 363067,
  [SMALL_STATE(8323)] = 363082,
  [SMALL_STATE(8324)] = 363097,
  [SMALL_STATE(8325)] = 363112,
  [SMALL_STATE(8326)] = 363127,
  [SMALL_STATE(8327)] = 363142,
  [SMALL_STATE(8328)] = 363157,
  [SMALL_STATE(8329)] = 363172,
  [SMALL_STATE(8330)] = 363187,
  [SMALL_STATE(8331)] = 363202,
  [SMALL_STATE(8332)] = 363217,
  [SMALL_STATE(8333)] = 363232,
  [SMALL_STATE(8334)] = 363247,
  [SMALL_STATE(8335)] = 363262,
  [SMALL_STATE(8336)] = 363277,
  [SMALL_STATE(8337)] = 363292,
  [SMALL_STATE(8338)] = 363307,
  [SMALL_STATE(8339)] = 363322,
  [SMALL_STATE(8340)] = 363337,
  [SMALL_STATE(8341)] = 363352,
  [SMALL_STATE(8342)] = 363367,
  [SMALL_STATE(8343)] = 363382,
  [SMALL_STATE(8344)] = 363397,
  [SMALL_STATE(8345)] = 363412,
  [SMALL_STATE(8346)] = 363427,
  [SMALL_STATE(8347)] = 363442,
  [SMALL_STATE(8348)] = 363457,
  [SMALL_STATE(8349)] = 363472,
  [SMALL_STATE(8350)] = 363487,
  [SMALL_STATE(8351)] = 363502,
  [SMALL_STATE(8352)] = 363517,
  [SMALL_STATE(8353)] = 363532,
  [SMALL_STATE(8354)] = 363547,
  [SMALL_STATE(8355)] = 363562,
  [SMALL_STATE(8356)] = 363577,
  [SMALL_STATE(8357)] = 363592,
  [SMALL_STATE(8358)] = 363607,
  [SMALL_STATE(8359)] = 363622,
  [SMALL_STATE(8360)] = 363637,
  [SMALL_STATE(8361)] = 363652,
  [SMALL_STATE(8362)] = 363667,
  [SMALL_STATE(8363)] = 363682,
  [SMALL_STATE(8364)] = 363697,
  [SMALL_STATE(8365)] = 363712,
  [SMALL_STATE(8366)] = 363727,
  [SMALL_STATE(8367)] = 363742,
  [SMALL_STATE(8368)] = 363757,
  [SMALL_STATE(8369)] = 363772,
  [SMALL_STATE(8370)] = 363787,
  [SMALL_STATE(8371)] = 363802,
  [SMALL_STATE(8372)] = 363817,
  [SMALL_STATE(8373)] = 363832,
  [SMALL_STATE(8374)] = 363849,
  [SMALL_STATE(8375)] = 363864,
  [SMALL_STATE(8376)] = 363879,
  [SMALL_STATE(8377)] = 363894,
  [SMALL_STATE(8378)] = 363909,
  [SMALL_STATE(8379)] = 363924,
  [SMALL_STATE(8380)] = 363939,
  [SMALL_STATE(8381)] = 363954,
  [SMALL_STATE(8382)] = 363969,
  [SMALL_STATE(8383)] = 363984,
  [SMALL_STATE(8384)] = 363999,
  [SMALL_STATE(8385)] = 364014,
  [SMALL_STATE(8386)] = 364029,
  [SMALL_STATE(8387)] = 364044,
  [SMALL_STATE(8388)] = 364059,
  [SMALL_STATE(8389)] = 364074,
  [SMALL_STATE(8390)] = 364089,
  [SMALL_STATE(8391)] = 364104,
  [SMALL_STATE(8392)] = 364119,
  [SMALL_STATE(8393)] = 364134,
  [SMALL_STATE(8394)] = 364149,
  [SMALL_STATE(8395)] = 364164,
  [SMALL_STATE(8396)] = 364179,
  [SMALL_STATE(8397)] = 364194,
  [SMALL_STATE(8398)] = 364209,
  [SMALL_STATE(8399)] = 364224,
  [SMALL_STATE(8400)] = 364239,
  [SMALL_STATE(8401)] = 364254,
  [SMALL_STATE(8402)] = 364269,
  [SMALL_STATE(8403)] = 364284,
  [SMALL_STATE(8404)] = 364299,
  [SMALL_STATE(8405)] = 364314,
  [SMALL_STATE(8406)] = 364329,
  [SMALL_STATE(8407)] = 364344,
  [SMALL_STATE(8408)] = 364359,
  [SMALL_STATE(8409)] = 364374,
  [SMALL_STATE(8410)] = 364389,
  [SMALL_STATE(8411)] = 364404,
  [SMALL_STATE(8412)] = 364419,
  [SMALL_STATE(8413)] = 364434,
  [SMALL_STATE(8414)] = 364449,
  [SMALL_STATE(8415)] = 364460,
  [SMALL_STATE(8416)] = 364475,
  [SMALL_STATE(8417)] = 364490,
  [SMALL_STATE(8418)] = 364507,
  [SMALL_STATE(8419)] = 364522,
  [SMALL_STATE(8420)] = 364537,
  [SMALL_STATE(8421)] = 364552,
  [SMALL_STATE(8422)] = 364567,
  [SMALL_STATE(8423)] = 364582,
  [SMALL_STATE(8424)] = 364597,
  [SMALL_STATE(8425)] = 364612,
  [SMALL_STATE(8426)] = 364627,
  [SMALL_STATE(8427)] = 364642,
  [SMALL_STATE(8428)] = 364657,
  [SMALL_STATE(8429)] = 364672,
  [SMALL_STATE(8430)] = 364687,
  [SMALL_STATE(8431)] = 364702,
  [SMALL_STATE(8432)] = 364717,
  [SMALL_STATE(8433)] = 364732,
  [SMALL_STATE(8434)] = 364747,
  [SMALL_STATE(8435)] = 364762,
  [SMALL_STATE(8436)] = 364777,
  [SMALL_STATE(8437)] = 364792,
  [SMALL_STATE(8438)] = 364809,
  [SMALL_STATE(8439)] = 364824,
  [SMALL_STATE(8440)] = 364839,
  [SMALL_STATE(8441)] = 364854,
  [SMALL_STATE(8442)] = 364869,
  [SMALL_STATE(8443)] = 364884,
  [SMALL_STATE(8444)] = 364901,
  [SMALL_STATE(8445)] = 364916,
  [SMALL_STATE(8446)] = 364931,
  [SMALL_STATE(8447)] = 364946,
  [SMALL_STATE(8448)] = 364961,
  [SMALL_STATE(8449)] = 364976,
  [SMALL_STATE(8450)] = 364991,
  [SMALL_STATE(8451)] = 365006,
  [SMALL_STATE(8452)] = 365021,
  [SMALL_STATE(8453)] = 365036,
  [SMALL_STATE(8454)] = 365051,
  [SMALL_STATE(8455)] = 365066,
  [SMALL_STATE(8456)] = 365081,
  [SMALL_STATE(8457)] = 365096,
  [SMALL_STATE(8458)] = 365111,
  [SMALL_STATE(8459)] = 365126,
  [SMALL_STATE(8460)] = 365141,
  [SMALL_STATE(8461)] = 365156,
  [SMALL_STATE(8462)] = 365171,
  [SMALL_STATE(8463)] = 365186,
  [SMALL_STATE(8464)] = 365201,
  [SMALL_STATE(8465)] = 365216,
  [SMALL_STATE(8466)] = 365231,
  [SMALL_STATE(8467)] = 365246,
  [SMALL_STATE(8468)] = 365261,
  [SMALL_STATE(8469)] = 365276,
  [SMALL_STATE(8470)] = 365291,
  [SMALL_STATE(8471)] = 365306,
  [SMALL_STATE(8472)] = 365321,
  [SMALL_STATE(8473)] = 365336,
  [SMALL_STATE(8474)] = 365351,
  [SMALL_STATE(8475)] = 365366,
  [SMALL_STATE(8476)] = 365381,
  [SMALL_STATE(8477)] = 365396,
  [SMALL_STATE(8478)] = 365411,
  [SMALL_STATE(8479)] = 365426,
  [SMALL_STATE(8480)] = 365441,
  [SMALL_STATE(8481)] = 365456,
  [SMALL_STATE(8482)] = 365471,
  [SMALL_STATE(8483)] = 365486,
  [SMALL_STATE(8484)] = 365501,
  [SMALL_STATE(8485)] = 365516,
  [SMALL_STATE(8486)] = 365529,
  [SMALL_STATE(8487)] = 365544,
  [SMALL_STATE(8488)] = 365559,
  [SMALL_STATE(8489)] = 365574,
  [SMALL_STATE(8490)] = 365589,
  [SMALL_STATE(8491)] = 365604,
  [SMALL_STATE(8492)] = 365619,
  [SMALL_STATE(8493)] = 365634,
  [SMALL_STATE(8494)] = 365649,
  [SMALL_STATE(8495)] = 365664,
  [SMALL_STATE(8496)] = 365679,
  [SMALL_STATE(8497)] = 365694,
  [SMALL_STATE(8498)] = 365709,
  [SMALL_STATE(8499)] = 365724,
  [SMALL_STATE(8500)] = 365739,
  [SMALL_STATE(8501)] = 365754,
  [SMALL_STATE(8502)] = 365769,
  [SMALL_STATE(8503)] = 365784,
  [SMALL_STATE(8504)] = 365799,
  [SMALL_STATE(8505)] = 365810,
  [SMALL_STATE(8506)] = 365825,
  [SMALL_STATE(8507)] = 365840,
  [SMALL_STATE(8508)] = 365855,
  [SMALL_STATE(8509)] = 365870,
  [SMALL_STATE(8510)] = 365885,
  [SMALL_STATE(8511)] = 365900,
  [SMALL_STATE(8512)] = 365915,
  [SMALL_STATE(8513)] = 365930,
  [SMALL_STATE(8514)] = 365945,
  [SMALL_STATE(8515)] = 365960,
  [SMALL_STATE(8516)] = 365975,
  [SMALL_STATE(8517)] = 365990,
  [SMALL_STATE(8518)] = 366005,
  [SMALL_STATE(8519)] = 366020,
  [SMALL_STATE(8520)] = 366035,
  [SMALL_STATE(8521)] = 366050,
  [SMALL_STATE(8522)] = 366065,
  [SMALL_STATE(8523)] = 366080,
  [SMALL_STATE(8524)] = 366095,
  [SMALL_STATE(8525)] = 366110,
  [SMALL_STATE(8526)] = 366125,
  [SMALL_STATE(8527)] = 366140,
  [SMALL_STATE(8528)] = 366155,
  [SMALL_STATE(8529)] = 366170,
  [SMALL_STATE(8530)] = 366185,
  [SMALL_STATE(8531)] = 366200,
  [SMALL_STATE(8532)] = 366211,
  [SMALL_STATE(8533)] = 366226,
  [SMALL_STATE(8534)] = 366241,
  [SMALL_STATE(8535)] = 366256,
  [SMALL_STATE(8536)] = 366271,
  [SMALL_STATE(8537)] = 366286,
  [SMALL_STATE(8538)] = 366301,
  [SMALL_STATE(8539)] = 366316,
  [SMALL_STATE(8540)] = 366331,
  [SMALL_STATE(8541)] = 366346,
  [SMALL_STATE(8542)] = 366361,
  [SMALL_STATE(8543)] = 366376,
  [SMALL_STATE(8544)] = 366391,
  [SMALL_STATE(8545)] = 366408,
  [SMALL_STATE(8546)] = 366423,
  [SMALL_STATE(8547)] = 366438,
  [SMALL_STATE(8548)] = 366453,
  [SMALL_STATE(8549)] = 366468,
  [SMALL_STATE(8550)] = 366483,
  [SMALL_STATE(8551)] = 366500,
  [SMALL_STATE(8552)] = 366515,
  [SMALL_STATE(8553)] = 366530,
  [SMALL_STATE(8554)] = 366545,
  [SMALL_STATE(8555)] = 366560,
  [SMALL_STATE(8556)] = 366575,
  [SMALL_STATE(8557)] = 366590,
  [SMALL_STATE(8558)] = 366605,
  [SMALL_STATE(8559)] = 366620,
  [SMALL_STATE(8560)] = 366635,
  [SMALL_STATE(8561)] = 366650,
  [SMALL_STATE(8562)] = 366665,
  [SMALL_STATE(8563)] = 366682,
  [SMALL_STATE(8564)] = 366697,
  [SMALL_STATE(8565)] = 366714,
  [SMALL_STATE(8566)] = 366729,
  [SMALL_STATE(8567)] = 366744,
  [SMALL_STATE(8568)] = 366759,
  [SMALL_STATE(8569)] = 366774,
  [SMALL_STATE(8570)] = 366789,
  [SMALL_STATE(8571)] = 366804,
  [SMALL_STATE(8572)] = 366819,
  [SMALL_STATE(8573)] = 366834,
  [SMALL_STATE(8574)] = 366849,
  [SMALL_STATE(8575)] = 366864,
  [SMALL_STATE(8576)] = 366879,
  [SMALL_STATE(8577)] = 366894,
  [SMALL_STATE(8578)] = 366909,
  [SMALL_STATE(8579)] = 366924,
  [SMALL_STATE(8580)] = 366939,
  [SMALL_STATE(8581)] = 366954,
  [SMALL_STATE(8582)] = 366969,
  [SMALL_STATE(8583)] = 366984,
  [SMALL_STATE(8584)] = 366999,
  [SMALL_STATE(8585)] = 367014,
  [SMALL_STATE(8586)] = 367029,
  [SMALL_STATE(8587)] = 367044,
  [SMALL_STATE(8588)] = 367059,
  [SMALL_STATE(8589)] = 367074,
  [SMALL_STATE(8590)] = 367089,
  [SMALL_STATE(8591)] = 367104,
  [SMALL_STATE(8592)] = 367119,
  [SMALL_STATE(8593)] = 367134,
  [SMALL_STATE(8594)] = 367149,
  [SMALL_STATE(8595)] = 367164,
  [SMALL_STATE(8596)] = 367179,
  [SMALL_STATE(8597)] = 367194,
  [SMALL_STATE(8598)] = 367209,
  [SMALL_STATE(8599)] = 367224,
  [SMALL_STATE(8600)] = 367239,
  [SMALL_STATE(8601)] = 367254,
  [SMALL_STATE(8602)] = 367269,
  [SMALL_STATE(8603)] = 367284,
  [SMALL_STATE(8604)] = 367299,
  [SMALL_STATE(8605)] = 367314,
  [SMALL_STATE(8606)] = 367329,
  [SMALL_STATE(8607)] = 367344,
  [SMALL_STATE(8608)] = 367359,
  [SMALL_STATE(8609)] = 367374,
  [SMALL_STATE(8610)] = 367389,
  [SMALL_STATE(8611)] = 367404,
  [SMALL_STATE(8612)] = 367417,
  [SMALL_STATE(8613)] = 367432,
  [SMALL_STATE(8614)] = 367447,
  [SMALL_STATE(8615)] = 367462,
  [SMALL_STATE(8616)] = 367477,
  [SMALL_STATE(8617)] = 367492,
  [SMALL_STATE(8618)] = 367504,
  [SMALL_STATE(8619)] = 367516,
  [SMALL_STATE(8620)] = 367528,
  [SMALL_STATE(8621)] = 367540,
  [SMALL_STATE(8622)] = 367552,
  [SMALL_STATE(8623)] = 367562,
  [SMALL_STATE(8624)] = 367574,
  [SMALL_STATE(8625)] = 367586,
  [SMALL_STATE(8626)] = 367600,
  [SMALL_STATE(8627)] = 367612,
  [SMALL_STATE(8628)] = 367624,
  [SMALL_STATE(8629)] = 367636,
  [SMALL_STATE(8630)] = 367648,
  [SMALL_STATE(8631)] = 367660,
  [SMALL_STATE(8632)] = 367672,
  [SMALL_STATE(8633)] = 367682,
  [SMALL_STATE(8634)] = 367694,
  [SMALL_STATE(8635)] = 367706,
  [SMALL_STATE(8636)] = 367716,
  [SMALL_STATE(8637)] = 367728,
  [SMALL_STATE(8638)] = 367740,
  [SMALL_STATE(8639)] = 367752,
  [SMALL_STATE(8640)] = 367764,
  [SMALL_STATE(8641)] = 367776,
  [SMALL_STATE(8642)] = 367786,
  [SMALL_STATE(8643)] = 367798,
  [SMALL_STATE(8644)] = 367810,
  [SMALL_STATE(8645)] = 367822,
  [SMALL_STATE(8646)] = 367834,
  [SMALL_STATE(8647)] = 367848,
  [SMALL_STATE(8648)] = 367860,
  [SMALL_STATE(8649)] = 367870,
  [SMALL_STATE(8650)] = 367882,
  [SMALL_STATE(8651)] = 367894,
  [SMALL_STATE(8652)] = 367906,
  [SMALL_STATE(8653)] = 367920,
  [SMALL_STATE(8654)] = 367932,
  [SMALL_STATE(8655)] = 367944,
  [SMALL_STATE(8656)] = 367956,
  [SMALL_STATE(8657)] = 367968,
  [SMALL_STATE(8658)] = 367978,
  [SMALL_STATE(8659)] = 367988,
  [SMALL_STATE(8660)] = 368000,
  [SMALL_STATE(8661)] = 368012,
  [SMALL_STATE(8662)] = 368024,
  [SMALL_STATE(8663)] = 368036,
  [SMALL_STATE(8664)] = 368048,
  [SMALL_STATE(8665)] = 368060,
  [SMALL_STATE(8666)] = 368074,
  [SMALL_STATE(8667)] = 368086,
  [SMALL_STATE(8668)] = 368096,
  [SMALL_STATE(8669)] = 368108,
  [SMALL_STATE(8670)] = 368120,
  [SMALL_STATE(8671)] = 368132,
  [SMALL_STATE(8672)] = 368144,
  [SMALL_STATE(8673)] = 368156,
  [SMALL_STATE(8674)] = 368168,
  [SMALL_STATE(8675)] = 368180,
  [SMALL_STATE(8676)] = 368192,
  [SMALL_STATE(8677)] = 368204,
  [SMALL_STATE(8678)] = 368216,
  [SMALL_STATE(8679)] = 368228,
  [SMALL_STATE(8680)] = 368238,
  [SMALL_STATE(8681)] = 368250,
  [SMALL_STATE(8682)] = 368262,
  [SMALL_STATE(8683)] = 368274,
  [SMALL_STATE(8684)] = 368286,
  [SMALL_STATE(8685)] = 368298,
  [SMALL_STATE(8686)] = 368310,
  [SMALL_STATE(8687)] = 368322,
  [SMALL_STATE(8688)] = 368334,
  [SMALL_STATE(8689)] = 368346,
  [SMALL_STATE(8690)] = 368358,
  [SMALL_STATE(8691)] = 368370,
  [SMALL_STATE(8692)] = 368382,
  [SMALL_STATE(8693)] = 368394,
  [SMALL_STATE(8694)] = 368408,
  [SMALL_STATE(8695)] = 368420,
  [SMALL_STATE(8696)] = 368432,
  [SMALL_STATE(8697)] = 368444,
  [SMALL_STATE(8698)] = 368456,
  [SMALL_STATE(8699)] = 368468,
  [SMALL_STATE(8700)] = 368478,
  [SMALL_STATE(8701)] = 368490,
  [SMALL_STATE(8702)] = 368502,
  [SMALL_STATE(8703)] = 368514,
  [SMALL_STATE(8704)] = 368526,
  [SMALL_STATE(8705)] = 368538,
  [SMALL_STATE(8706)] = 368550,
  [SMALL_STATE(8707)] = 368562,
  [SMALL_STATE(8708)] = 368574,
  [SMALL_STATE(8709)] = 368586,
  [SMALL_STATE(8710)] = 368596,
  [SMALL_STATE(8711)] = 368608,
  [SMALL_STATE(8712)] = 368620,
  [SMALL_STATE(8713)] = 368632,
  [SMALL_STATE(8714)] = 368644,
  [SMALL_STATE(8715)] = 368656,
  [SMALL_STATE(8716)] = 368666,
  [SMALL_STATE(8717)] = 368678,
  [SMALL_STATE(8718)] = 368690,
  [SMALL_STATE(8719)] = 368702,
  [SMALL_STATE(8720)] = 368714,
  [SMALL_STATE(8721)] = 368724,
  [SMALL_STATE(8722)] = 368736,
  [SMALL_STATE(8723)] = 368746,
  [SMALL_STATE(8724)] = 368758,
  [SMALL_STATE(8725)] = 368770,
  [SMALL_STATE(8726)] = 368782,
  [SMALL_STATE(8727)] = 368794,
  [SMALL_STATE(8728)] = 368806,
  [SMALL_STATE(8729)] = 368818,
  [SMALL_STATE(8730)] = 368830,
  [SMALL_STATE(8731)] = 368842,
  [SMALL_STATE(8732)] = 368854,
  [SMALL_STATE(8733)] = 368866,
  [SMALL_STATE(8734)] = 368876,
  [SMALL_STATE(8735)] = 368888,
  [SMALL_STATE(8736)] = 368900,
  [SMALL_STATE(8737)] = 368912,
  [SMALL_STATE(8738)] = 368924,
  [SMALL_STATE(8739)] = 368936,
  [SMALL_STATE(8740)] = 368948,
  [SMALL_STATE(8741)] = 368960,
  [SMALL_STATE(8742)] = 368972,
  [SMALL_STATE(8743)] = 368984,
  [SMALL_STATE(8744)] = 368996,
  [SMALL_STATE(8745)] = 369006,
  [SMALL_STATE(8746)] = 369018,
  [SMALL_STATE(8747)] = 369030,
  [SMALL_STATE(8748)] = 369042,
  [SMALL_STATE(8749)] = 369054,
  [SMALL_STATE(8750)] = 369066,
  [SMALL_STATE(8751)] = 369078,
  [SMALL_STATE(8752)] = 369090,
  [SMALL_STATE(8753)] = 369102,
  [SMALL_STATE(8754)] = 369116,
  [SMALL_STATE(8755)] = 369128,
  [SMALL_STATE(8756)] = 369140,
  [SMALL_STATE(8757)] = 369152,
  [SMALL_STATE(8758)] = 369166,
  [SMALL_STATE(8759)] = 369178,
  [SMALL_STATE(8760)] = 369190,
  [SMALL_STATE(8761)] = 369202,
  [SMALL_STATE(8762)] = 369214,
  [SMALL_STATE(8763)] = 369226,
  [SMALL_STATE(8764)] = 369238,
  [SMALL_STATE(8765)] = 369250,
  [SMALL_STATE(8766)] = 369260,
  [SMALL_STATE(8767)] = 369272,
  [SMALL_STATE(8768)] = 369284,
  [SMALL_STATE(8769)] = 369296,
  [SMALL_STATE(8770)] = 369308,
  [SMALL_STATE(8771)] = 369318,
  [SMALL_STATE(8772)] = 369330,
  [SMALL_STATE(8773)] = 369342,
  [SMALL_STATE(8774)] = 369354,
  [SMALL_STATE(8775)] = 369364,
  [SMALL_STATE(8776)] = 369376,
  [SMALL_STATE(8777)] = 369388,
  [SMALL_STATE(8778)] = 369400,
  [SMALL_STATE(8779)] = 369412,
  [SMALL_STATE(8780)] = 369424,
  [SMALL_STATE(8781)] = 369436,
  [SMALL_STATE(8782)] = 369448,
  [SMALL_STATE(8783)] = 369460,
  [SMALL_STATE(8784)] = 369472,
  [SMALL_STATE(8785)] = 369484,
  [SMALL_STATE(8786)] = 369496,
  [SMALL_STATE(8787)] = 369508,
  [SMALL_STATE(8788)] = 369520,
  [SMALL_STATE(8789)] = 369532,
  [SMALL_STATE(8790)] = 369544,
  [SMALL_STATE(8791)] = 369556,
  [SMALL_STATE(8792)] = 369568,
  [SMALL_STATE(8793)] = 369580,
  [SMALL_STATE(8794)] = 369592,
  [SMALL_STATE(8795)] = 369604,
  [SMALL_STATE(8796)] = 369616,
  [SMALL_STATE(8797)] = 369628,
  [SMALL_STATE(8798)] = 369640,
  [SMALL_STATE(8799)] = 369652,
  [SMALL_STATE(8800)] = 369664,
  [SMALL_STATE(8801)] = 369676,
  [SMALL_STATE(8802)] = 369688,
  [SMALL_STATE(8803)] = 369700,
  [SMALL_STATE(8804)] = 369712,
  [SMALL_STATE(8805)] = 369724,
  [SMALL_STATE(8806)] = 369736,
  [SMALL_STATE(8807)] = 369746,
  [SMALL_STATE(8808)] = 369758,
  [SMALL_STATE(8809)] = 369770,
  [SMALL_STATE(8810)] = 369782,
  [SMALL_STATE(8811)] = 369794,
  [SMALL_STATE(8812)] = 369804,
  [SMALL_STATE(8813)] = 369816,
  [SMALL_STATE(8814)] = 369828,
  [SMALL_STATE(8815)] = 369840,
  [SMALL_STATE(8816)] = 369852,
  [SMALL_STATE(8817)] = 369864,
  [SMALL_STATE(8818)] = 369876,
  [SMALL_STATE(8819)] = 369890,
  [SMALL_STATE(8820)] = 369902,
  [SMALL_STATE(8821)] = 369914,
  [SMALL_STATE(8822)] = 369926,
  [SMALL_STATE(8823)] = 369938,
  [SMALL_STATE(8824)] = 369950,
  [SMALL_STATE(8825)] = 369962,
  [SMALL_STATE(8826)] = 369974,
  [SMALL_STATE(8827)] = 369986,
  [SMALL_STATE(8828)] = 369998,
  [SMALL_STATE(8829)] = 370010,
  [SMALL_STATE(8830)] = 370022,
  [SMALL_STATE(8831)] = 370034,
  [SMALL_STATE(8832)] = 370046,
  [SMALL_STATE(8833)] = 370058,
  [SMALL_STATE(8834)] = 370070,
  [SMALL_STATE(8835)] = 370082,
  [SMALL_STATE(8836)] = 370096,
  [SMALL_STATE(8837)] = 370108,
  [SMALL_STATE(8838)] = 370120,
  [SMALL_STATE(8839)] = 370130,
  [SMALL_STATE(8840)] = 370140,
  [SMALL_STATE(8841)] = 370152,
  [SMALL_STATE(8842)] = 370164,
  [SMALL_STATE(8843)] = 370176,
  [SMALL_STATE(8844)] = 370186,
  [SMALL_STATE(8845)] = 370198,
  [SMALL_STATE(8846)] = 370210,
  [SMALL_STATE(8847)] = 370222,
  [SMALL_STATE(8848)] = 370234,
  [SMALL_STATE(8849)] = 370246,
  [SMALL_STATE(8850)] = 370256,
  [SMALL_STATE(8851)] = 370268,
  [SMALL_STATE(8852)] = 370280,
  [SMALL_STATE(8853)] = 370292,
  [SMALL_STATE(8854)] = 370302,
  [SMALL_STATE(8855)] = 370314,
  [SMALL_STATE(8856)] = 370326,
  [SMALL_STATE(8857)] = 370338,
  [SMALL_STATE(8858)] = 370350,
  [SMALL_STATE(8859)] = 370362,
  [SMALL_STATE(8860)] = 370374,
  [SMALL_STATE(8861)] = 370386,
  [SMALL_STATE(8862)] = 370398,
  [SMALL_STATE(8863)] = 370410,
  [SMALL_STATE(8864)] = 370422,
  [SMALL_STATE(8865)] = 370434,
  [SMALL_STATE(8866)] = 370446,
  [SMALL_STATE(8867)] = 370460,
  [SMALL_STATE(8868)] = 370472,
  [SMALL_STATE(8869)] = 370484,
  [SMALL_STATE(8870)] = 370496,
  [SMALL_STATE(8871)] = 370508,
  [SMALL_STATE(8872)] = 370520,
  [SMALL_STATE(8873)] = 370532,
  [SMALL_STATE(8874)] = 370544,
  [SMALL_STATE(8875)] = 370556,
  [SMALL_STATE(8876)] = 370568,
  [SMALL_STATE(8877)] = 370580,
  [SMALL_STATE(8878)] = 370592,
  [SMALL_STATE(8879)] = 370606,
  [SMALL_STATE(8880)] = 370618,
  [SMALL_STATE(8881)] = 370630,
  [SMALL_STATE(8882)] = 370642,
  [SMALL_STATE(8883)] = 370654,
  [SMALL_STATE(8884)] = 370666,
  [SMALL_STATE(8885)] = 370678,
  [SMALL_STATE(8886)] = 370690,
  [SMALL_STATE(8887)] = 370702,
  [SMALL_STATE(8888)] = 370714,
  [SMALL_STATE(8889)] = 370728,
  [SMALL_STATE(8890)] = 370740,
  [SMALL_STATE(8891)] = 370752,
  [SMALL_STATE(8892)] = 370764,
  [SMALL_STATE(8893)] = 370776,
  [SMALL_STATE(8894)] = 370786,
  [SMALL_STATE(8895)] = 370798,
  [SMALL_STATE(8896)] = 370808,
  [SMALL_STATE(8897)] = 370818,
  [SMALL_STATE(8898)] = 370830,
  [SMALL_STATE(8899)] = 370842,
  [SMALL_STATE(8900)] = 370854,
  [SMALL_STATE(8901)] = 370864,
  [SMALL_STATE(8902)] = 370876,
  [SMALL_STATE(8903)] = 370888,
  [SMALL_STATE(8904)] = 370900,
  [SMALL_STATE(8905)] = 370912,
  [SMALL_STATE(8906)] = 370924,
  [SMALL_STATE(8907)] = 370936,
  [SMALL_STATE(8908)] = 370948,
  [SMALL_STATE(8909)] = 370960,
  [SMALL_STATE(8910)] = 370972,
  [SMALL_STATE(8911)] = 370984,
  [SMALL_STATE(8912)] = 370996,
  [SMALL_STATE(8913)] = 371008,
  [SMALL_STATE(8914)] = 371020,
  [SMALL_STATE(8915)] = 371032,
  [SMALL_STATE(8916)] = 371044,
  [SMALL_STATE(8917)] = 371056,
  [SMALL_STATE(8918)] = 371068,
  [SMALL_STATE(8919)] = 371078,
  [SMALL_STATE(8920)] = 371090,
  [SMALL_STATE(8921)] = 371102,
  [SMALL_STATE(8922)] = 371114,
  [SMALL_STATE(8923)] = 371126,
  [SMALL_STATE(8924)] = 371138,
  [SMALL_STATE(8925)] = 371150,
  [SMALL_STATE(8926)] = 371162,
  [SMALL_STATE(8927)] = 371174,
  [SMALL_STATE(8928)] = 371188,
  [SMALL_STATE(8929)] = 371200,
  [SMALL_STATE(8930)] = 371212,
  [SMALL_STATE(8931)] = 371224,
  [SMALL_STATE(8932)] = 371236,
  [SMALL_STATE(8933)] = 371245,
  [SMALL_STATE(8934)] = 371254,
  [SMALL_STATE(8935)] = 371263,
  [SMALL_STATE(8936)] = 371272,
  [SMALL_STATE(8937)] = 371281,
  [SMALL_STATE(8938)] = 371290,
  [SMALL_STATE(8939)] = 371299,
  [SMALL_STATE(8940)] = 371308,
  [SMALL_STATE(8941)] = 371317,
  [SMALL_STATE(8942)] = 371326,
  [SMALL_STATE(8943)] = 371335,
  [SMALL_STATE(8944)] = 371344,
  [SMALL_STATE(8945)] = 371353,
  [SMALL_STATE(8946)] = 371362,
  [SMALL_STATE(8947)] = 371371,
  [SMALL_STATE(8948)] = 371380,
  [SMALL_STATE(8949)] = 371389,
  [SMALL_STATE(8950)] = 371398,
  [SMALL_STATE(8951)] = 371407,
  [SMALL_STATE(8952)] = 371416,
  [SMALL_STATE(8953)] = 371425,
  [SMALL_STATE(8954)] = 371434,
  [SMALL_STATE(8955)] = 371443,
  [SMALL_STATE(8956)] = 371452,
  [SMALL_STATE(8957)] = 371461,
  [SMALL_STATE(8958)] = 371470,
  [SMALL_STATE(8959)] = 371479,
  [SMALL_STATE(8960)] = 371488,
  [SMALL_STATE(8961)] = 371497,
  [SMALL_STATE(8962)] = 371506,
  [SMALL_STATE(8963)] = 371515,
  [SMALL_STATE(8964)] = 371524,
  [SMALL_STATE(8965)] = 371533,
  [SMALL_STATE(8966)] = 371542,
  [SMALL_STATE(8967)] = 371551,
  [SMALL_STATE(8968)] = 371560,
  [SMALL_STATE(8969)] = 371569,
  [SMALL_STATE(8970)] = 371578,
  [SMALL_STATE(8971)] = 371587,
  [SMALL_STATE(8972)] = 371596,
  [SMALL_STATE(8973)] = 371605,
  [SMALL_STATE(8974)] = 371614,
  [SMALL_STATE(8975)] = 371623,
  [SMALL_STATE(8976)] = 371632,
  [SMALL_STATE(8977)] = 371641,
  [SMALL_STATE(8978)] = 371650,
  [SMALL_STATE(8979)] = 371659,
  [SMALL_STATE(8980)] = 371668,
  [SMALL_STATE(8981)] = 371677,
  [SMALL_STATE(8982)] = 371686,
  [SMALL_STATE(8983)] = 371695,
  [SMALL_STATE(8984)] = 371704,
  [SMALL_STATE(8985)] = 371713,
  [SMALL_STATE(8986)] = 371722,
  [SMALL_STATE(8987)] = 371731,
  [SMALL_STATE(8988)] = 371740,
  [SMALL_STATE(8989)] = 371749,
  [SMALL_STATE(8990)] = 371758,
  [SMALL_STATE(8991)] = 371767,
  [SMALL_STATE(8992)] = 371776,
  [SMALL_STATE(8993)] = 371785,
  [SMALL_STATE(8994)] = 371794,
  [SMALL_STATE(8995)] = 371803,
  [SMALL_STATE(8996)] = 371812,
  [SMALL_STATE(8997)] = 371821,
  [SMALL_STATE(8998)] = 371830,
  [SMALL_STATE(8999)] = 371839,
  [SMALL_STATE(9000)] = 371848,
  [SMALL_STATE(9001)] = 371857,
  [SMALL_STATE(9002)] = 371866,
  [SMALL_STATE(9003)] = 371875,
  [SMALL_STATE(9004)] = 371884,
  [SMALL_STATE(9005)] = 371893,
  [SMALL_STATE(9006)] = 371902,
  [SMALL_STATE(9007)] = 371911,
  [SMALL_STATE(9008)] = 371920,
  [SMALL_STATE(9009)] = 371929,
  [SMALL_STATE(9010)] = 371938,
  [SMALL_STATE(9011)] = 371947,
  [SMALL_STATE(9012)] = 371956,
  [SMALL_STATE(9013)] = 371965,
  [SMALL_STATE(9014)] = 371974,
  [SMALL_STATE(9015)] = 371983,
  [SMALL_STATE(9016)] = 371992,
  [SMALL_STATE(9017)] = 372001,
  [SMALL_STATE(9018)] = 372010,
  [SMALL_STATE(9019)] = 372019,
  [SMALL_STATE(9020)] = 372028,
  [SMALL_STATE(9021)] = 372037,
  [SMALL_STATE(9022)] = 372046,
  [SMALL_STATE(9023)] = 372055,
  [SMALL_STATE(9024)] = 372064,
  [SMALL_STATE(9025)] = 372073,
  [SMALL_STATE(9026)] = 372082,
  [SMALL_STATE(9027)] = 372091,
  [SMALL_STATE(9028)] = 372100,
  [SMALL_STATE(9029)] = 372109,
  [SMALL_STATE(9030)] = 372118,
  [SMALL_STATE(9031)] = 372127,
  [SMALL_STATE(9032)] = 372136,
  [SMALL_STATE(9033)] = 372145,
  [SMALL_STATE(9034)] = 372154,
  [SMALL_STATE(9035)] = 372163,
  [SMALL_STATE(9036)] = 372172,
  [SMALL_STATE(9037)] = 372181,
  [SMALL_STATE(9038)] = 372190,
  [SMALL_STATE(9039)] = 372199,
  [SMALL_STATE(9040)] = 372208,
  [SMALL_STATE(9041)] = 372217,
  [SMALL_STATE(9042)] = 372226,
  [SMALL_STATE(9043)] = 372235,
  [SMALL_STATE(9044)] = 372244,
  [SMALL_STATE(9045)] = 372253,
  [SMALL_STATE(9046)] = 372262,
  [SMALL_STATE(9047)] = 372271,
  [SMALL_STATE(9048)] = 372280,
  [SMALL_STATE(9049)] = 372289,
  [SMALL_STATE(9050)] = 372298,
  [SMALL_STATE(9051)] = 372307,
  [SMALL_STATE(9052)] = 372316,
  [SMALL_STATE(9053)] = 372325,
  [SMALL_STATE(9054)] = 372334,
  [SMALL_STATE(9055)] = 372343,
  [SMALL_STATE(9056)] = 372352,
  [SMALL_STATE(9057)] = 372361,
  [SMALL_STATE(9058)] = 372370,
  [SMALL_STATE(9059)] = 372379,
  [SMALL_STATE(9060)] = 372388,
  [SMALL_STATE(9061)] = 372397,
  [SMALL_STATE(9062)] = 372406,
  [SMALL_STATE(9063)] = 372415,
  [SMALL_STATE(9064)] = 372424,
  [SMALL_STATE(9065)] = 372433,
  [SMALL_STATE(9066)] = 372442,
  [SMALL_STATE(9067)] = 372451,
  [SMALL_STATE(9068)] = 372460,
  [SMALL_STATE(9069)] = 372469,
  [SMALL_STATE(9070)] = 372478,
  [SMALL_STATE(9071)] = 372487,
  [SMALL_STATE(9072)] = 372496,
  [SMALL_STATE(9073)] = 372505,
  [SMALL_STATE(9074)] = 372514,
  [SMALL_STATE(9075)] = 372523,
  [SMALL_STATE(9076)] = 372532,
  [SMALL_STATE(9077)] = 372541,
  [SMALL_STATE(9078)] = 372550,
  [SMALL_STATE(9079)] = 372559,
  [SMALL_STATE(9080)] = 372568,
  [SMALL_STATE(9081)] = 372577,
  [SMALL_STATE(9082)] = 372586,
  [SMALL_STATE(9083)] = 372595,
  [SMALL_STATE(9084)] = 372604,
  [SMALL_STATE(9085)] = 372613,
  [SMALL_STATE(9086)] = 372622,
  [SMALL_STATE(9087)] = 372631,
  [SMALL_STATE(9088)] = 372640,
  [SMALL_STATE(9089)] = 372649,
  [SMALL_STATE(9090)] = 372658,
  [SMALL_STATE(9091)] = 372667,
  [SMALL_STATE(9092)] = 372676,
  [SMALL_STATE(9093)] = 372685,
  [SMALL_STATE(9094)] = 372694,
  [SMALL_STATE(9095)] = 372703,
  [SMALL_STATE(9096)] = 372712,
  [SMALL_STATE(9097)] = 372721,
  [SMALL_STATE(9098)] = 372730,
  [SMALL_STATE(9099)] = 372739,
  [SMALL_STATE(9100)] = 372748,
  [SMALL_STATE(9101)] = 372757,
  [SMALL_STATE(9102)] = 372766,
  [SMALL_STATE(9103)] = 372775,
  [SMALL_STATE(9104)] = 372784,
  [SMALL_STATE(9105)] = 372793,
  [SMALL_STATE(9106)] = 372802,
  [SMALL_STATE(9107)] = 372811,
  [SMALL_STATE(9108)] = 372820,
  [SMALL_STATE(9109)] = 372829,
  [SMALL_STATE(9110)] = 372838,
  [SMALL_STATE(9111)] = 372847,
  [SMALL_STATE(9112)] = 372856,
  [SMALL_STATE(9113)] = 372865,
  [SMALL_STATE(9114)] = 372874,
  [SMALL_STATE(9115)] = 372883,
  [SMALL_STATE(9116)] = 372892,
  [SMALL_STATE(9117)] = 372901,
  [SMALL_STATE(9118)] = 372910,
  [SMALL_STATE(9119)] = 372919,
  [SMALL_STATE(9120)] = 372928,
  [SMALL_STATE(9121)] = 372937,
  [SMALL_STATE(9122)] = 372946,
  [SMALL_STATE(9123)] = 372955,
  [SMALL_STATE(9124)] = 372964,
  [SMALL_STATE(9125)] = 372973,
  [SMALL_STATE(9126)] = 372982,
  [SMALL_STATE(9127)] = 372991,
  [SMALL_STATE(9128)] = 373000,
  [SMALL_STATE(9129)] = 373009,
  [SMALL_STATE(9130)] = 373018,
  [SMALL_STATE(9131)] = 373027,
  [SMALL_STATE(9132)] = 373036,
  [SMALL_STATE(9133)] = 373045,
  [SMALL_STATE(9134)] = 373054,
  [SMALL_STATE(9135)] = 373063,
  [SMALL_STATE(9136)] = 373072,
  [SMALL_STATE(9137)] = 373081,
  [SMALL_STATE(9138)] = 373090,
  [SMALL_STATE(9139)] = 373099,
  [SMALL_STATE(9140)] = 373108,
  [SMALL_STATE(9141)] = 373117,
  [SMALL_STATE(9142)] = 373126,
  [SMALL_STATE(9143)] = 373135,
  [SMALL_STATE(9144)] = 373144,
  [SMALL_STATE(9145)] = 373153,
  [SMALL_STATE(9146)] = 373162,
  [SMALL_STATE(9147)] = 373171,
  [SMALL_STATE(9148)] = 373180,
  [SMALL_STATE(9149)] = 373189,
  [SMALL_STATE(9150)] = 373198,
  [SMALL_STATE(9151)] = 373207,
  [SMALL_STATE(9152)] = 373216,
  [SMALL_STATE(9153)] = 373225,
  [SMALL_STATE(9154)] = 373234,
  [SMALL_STATE(9155)] = 373243,
  [SMALL_STATE(9156)] = 373252,
  [SMALL_STATE(9157)] = 373261,
  [SMALL_STATE(9158)] = 373270,
  [SMALL_STATE(9159)] = 373279,
  [SMALL_STATE(9160)] = 373288,
  [SMALL_STATE(9161)] = 373297,
  [SMALL_STATE(9162)] = 373306,
  [SMALL_STATE(9163)] = 373315,
  [SMALL_STATE(9164)] = 373324,
  [SMALL_STATE(9165)] = 373333,
  [SMALL_STATE(9166)] = 373342,
  [SMALL_STATE(9167)] = 373351,
  [SMALL_STATE(9168)] = 373360,
  [SMALL_STATE(9169)] = 373369,
  [SMALL_STATE(9170)] = 373378,
  [SMALL_STATE(9171)] = 373387,
  [SMALL_STATE(9172)] = 373396,
  [SMALL_STATE(9173)] = 373405,
  [SMALL_STATE(9174)] = 373414,
  [SMALL_STATE(9175)] = 373423,
  [SMALL_STATE(9176)] = 373432,
  [SMALL_STATE(9177)] = 373441,
  [SMALL_STATE(9178)] = 373450,
  [SMALL_STATE(9179)] = 373459,
  [SMALL_STATE(9180)] = 373468,
  [SMALL_STATE(9181)] = 373477,
  [SMALL_STATE(9182)] = 373486,
  [SMALL_STATE(9183)] = 373495,
  [SMALL_STATE(9184)] = 373504,
  [SMALL_STATE(9185)] = 373513,
  [SMALL_STATE(9186)] = 373522,
  [SMALL_STATE(9187)] = 373531,
  [SMALL_STATE(9188)] = 373540,
  [SMALL_STATE(9189)] = 373549,
  [SMALL_STATE(9190)] = 373558,
  [SMALL_STATE(9191)] = 373567,
  [SMALL_STATE(9192)] = 373576,
  [SMALL_STATE(9193)] = 373585,
  [SMALL_STATE(9194)] = 373594,
  [SMALL_STATE(9195)] = 373603,
  [SMALL_STATE(9196)] = 373612,
  [SMALL_STATE(9197)] = 373621,
  [SMALL_STATE(9198)] = 373630,
  [SMALL_STATE(9199)] = 373639,
  [SMALL_STATE(9200)] = 373648,
  [SMALL_STATE(9201)] = 373657,
  [SMALL_STATE(9202)] = 373666,
  [SMALL_STATE(9203)] = 373675,
  [SMALL_STATE(9204)] = 373684,
  [SMALL_STATE(9205)] = 373693,
  [SMALL_STATE(9206)] = 373702,
  [SMALL_STATE(9207)] = 373711,
  [SMALL_STATE(9208)] = 373720,
  [SMALL_STATE(9209)] = 373729,
  [SMALL_STATE(9210)] = 373738,
  [SMALL_STATE(9211)] = 373747,
  [SMALL_STATE(9212)] = 373756,
  [SMALL_STATE(9213)] = 373765,
  [SMALL_STATE(9214)] = 373774,
  [SMALL_STATE(9215)] = 373783,
  [SMALL_STATE(9216)] = 373792,
  [SMALL_STATE(9217)] = 373801,
  [SMALL_STATE(9218)] = 373810,
  [SMALL_STATE(9219)] = 373819,
  [SMALL_STATE(9220)] = 373828,
  [SMALL_STATE(9221)] = 373837,
  [SMALL_STATE(9222)] = 373846,
  [SMALL_STATE(9223)] = 373855,
  [SMALL_STATE(9224)] = 373864,
  [SMALL_STATE(9225)] = 373873,
  [SMALL_STATE(9226)] = 373882,
  [SMALL_STATE(9227)] = 373891,
  [SMALL_STATE(9228)] = 373900,
  [SMALL_STATE(9229)] = 373909,
  [SMALL_STATE(9230)] = 373918,
  [SMALL_STATE(9231)] = 373927,
  [SMALL_STATE(9232)] = 373936,
  [SMALL_STATE(9233)] = 373945,
  [SMALL_STATE(9234)] = 373954,
  [SMALL_STATE(9235)] = 373965,
  [SMALL_STATE(9236)] = 373974,
  [SMALL_STATE(9237)] = 373983,
  [SMALL_STATE(9238)] = 373992,
  [SMALL_STATE(9239)] = 374001,
  [SMALL_STATE(9240)] = 374010,
  [SMALL_STATE(9241)] = 374019,
  [SMALL_STATE(9242)] = 374028,
  [SMALL_STATE(9243)] = 374037,
  [SMALL_STATE(9244)] = 374046,
  [SMALL_STATE(9245)] = 374055,
  [SMALL_STATE(9246)] = 374064,
  [SMALL_STATE(9247)] = 374073,
  [SMALL_STATE(9248)] = 374082,
  [SMALL_STATE(9249)] = 374091,
  [SMALL_STATE(9250)] = 374100,
  [SMALL_STATE(9251)] = 374109,
  [SMALL_STATE(9252)] = 374118,
  [SMALL_STATE(9253)] = 374127,
  [SMALL_STATE(9254)] = 374136,
  [SMALL_STATE(9255)] = 374145,
  [SMALL_STATE(9256)] = 374154,
  [SMALL_STATE(9257)] = 374163,
  [SMALL_STATE(9258)] = 374172,
  [SMALL_STATE(9259)] = 374181,
  [SMALL_STATE(9260)] = 374190,
  [SMALL_STATE(9261)] = 374199,
  [SMALL_STATE(9262)] = 374208,
  [SMALL_STATE(9263)] = 374217,
  [SMALL_STATE(9264)] = 374226,
  [SMALL_STATE(9265)] = 374235,
  [SMALL_STATE(9266)] = 374244,
  [SMALL_STATE(9267)] = 374253,
  [SMALL_STATE(9268)] = 374262,
  [SMALL_STATE(9269)] = 374271,
  [SMALL_STATE(9270)] = 374280,
  [SMALL_STATE(9271)] = 374289,
  [SMALL_STATE(9272)] = 374298,
  [SMALL_STATE(9273)] = 374307,
  [SMALL_STATE(9274)] = 374316,
  [SMALL_STATE(9275)] = 374325,
  [SMALL_STATE(9276)] = 374334,
  [SMALL_STATE(9277)] = 374343,
  [SMALL_STATE(9278)] = 374352,
  [SMALL_STATE(9279)] = 374361,
  [SMALL_STATE(9280)] = 374370,
  [SMALL_STATE(9281)] = 374379,
  [SMALL_STATE(9282)] = 374388,
  [SMALL_STATE(9283)] = 374397,
  [SMALL_STATE(9284)] = 374406,
  [SMALL_STATE(9285)] = 374415,
  [SMALL_STATE(9286)] = 374424,
  [SMALL_STATE(9287)] = 374433,
  [SMALL_STATE(9288)] = 374442,
  [SMALL_STATE(9289)] = 374451,
  [SMALL_STATE(9290)] = 374460,
  [SMALL_STATE(9291)] = 374469,
  [SMALL_STATE(9292)] = 374478,
  [SMALL_STATE(9293)] = 374487,
  [SMALL_STATE(9294)] = 374496,
  [SMALL_STATE(9295)] = 374505,
  [SMALL_STATE(9296)] = 374514,
  [SMALL_STATE(9297)] = 374523,
  [SMALL_STATE(9298)] = 374532,
  [SMALL_STATE(9299)] = 374541,
  [SMALL_STATE(9300)] = 374550,
  [SMALL_STATE(9301)] = 374559,
  [SMALL_STATE(9302)] = 374568,
  [SMALL_STATE(9303)] = 374577,
  [SMALL_STATE(9304)] = 374586,
  [SMALL_STATE(9305)] = 374595,
  [SMALL_STATE(9306)] = 374604,
  [SMALL_STATE(9307)] = 374613,
  [SMALL_STATE(9308)] = 374622,
  [SMALL_STATE(9309)] = 374631,
  [SMALL_STATE(9310)] = 374640,
  [SMALL_STATE(9311)] = 374649,
  [SMALL_STATE(9312)] = 374658,
  [SMALL_STATE(9313)] = 374667,
  [SMALL_STATE(9314)] = 374676,
  [SMALL_STATE(9315)] = 374685,
  [SMALL_STATE(9316)] = 374694,
  [SMALL_STATE(9317)] = 374703,
  [SMALL_STATE(9318)] = 374712,
  [SMALL_STATE(9319)] = 374721,
  [SMALL_STATE(9320)] = 374730,
  [SMALL_STATE(9321)] = 374739,
  [SMALL_STATE(9322)] = 374748,
  [SMALL_STATE(9323)] = 374757,
  [SMALL_STATE(9324)] = 374766,
  [SMALL_STATE(9325)] = 374775,
  [SMALL_STATE(9326)] = 374784,
  [SMALL_STATE(9327)] = 374793,
  [SMALL_STATE(9328)] = 374802,
  [SMALL_STATE(9329)] = 374811,
  [SMALL_STATE(9330)] = 374820,
  [SMALL_STATE(9331)] = 374829,
  [SMALL_STATE(9332)] = 374838,
  [SMALL_STATE(9333)] = 374847,
  [SMALL_STATE(9334)] = 374856,
  [SMALL_STATE(9335)] = 374865,
  [SMALL_STATE(9336)] = 374874,
  [SMALL_STATE(9337)] = 374883,
  [SMALL_STATE(9338)] = 374892,
  [SMALL_STATE(9339)] = 374901,
  [SMALL_STATE(9340)] = 374910,
  [SMALL_STATE(9341)] = 374919,
  [SMALL_STATE(9342)] = 374928,
  [SMALL_STATE(9343)] = 374937,
  [SMALL_STATE(9344)] = 374946,
  [SMALL_STATE(9345)] = 374955,
  [SMALL_STATE(9346)] = 374964,
  [SMALL_STATE(9347)] = 374973,
  [SMALL_STATE(9348)] = 374982,
  [SMALL_STATE(9349)] = 374991,
  [SMALL_STATE(9350)] = 375000,
  [SMALL_STATE(9351)] = 375009,
  [SMALL_STATE(9352)] = 375018,
  [SMALL_STATE(9353)] = 375027,
  [SMALL_STATE(9354)] = 375036,
  [SMALL_STATE(9355)] = 375045,
  [SMALL_STATE(9356)] = 375054,
  [SMALL_STATE(9357)] = 375063,
  [SMALL_STATE(9358)] = 375072,
  [SMALL_STATE(9359)] = 375081,
  [SMALL_STATE(9360)] = 375090,
  [SMALL_STATE(9361)] = 375099,
  [SMALL_STATE(9362)] = 375108,
  [SMALL_STATE(9363)] = 375117,
  [SMALL_STATE(9364)] = 375126,
  [SMALL_STATE(9365)] = 375135,
  [SMALL_STATE(9366)] = 375144,
  [SMALL_STATE(9367)] = 375153,
  [SMALL_STATE(9368)] = 375162,
  [SMALL_STATE(9369)] = 375171,
  [SMALL_STATE(9370)] = 375180,
  [SMALL_STATE(9371)] = 375189,
  [SMALL_STATE(9372)] = 375198,
  [SMALL_STATE(9373)] = 375207,
  [SMALL_STATE(9374)] = 375216,
  [SMALL_STATE(9375)] = 375225,
  [SMALL_STATE(9376)] = 375234,
  [SMALL_STATE(9377)] = 375243,
  [SMALL_STATE(9378)] = 375252,
  [SMALL_STATE(9379)] = 375261,
  [SMALL_STATE(9380)] = 375270,
  [SMALL_STATE(9381)] = 375279,
  [SMALL_STATE(9382)] = 375288,
  [SMALL_STATE(9383)] = 375297,
  [SMALL_STATE(9384)] = 375306,
  [SMALL_STATE(9385)] = 375315,
  [SMALL_STATE(9386)] = 375324,
  [SMALL_STATE(9387)] = 375333,
  [SMALL_STATE(9388)] = 375342,
  [SMALL_STATE(9389)] = 375351,
  [SMALL_STATE(9390)] = 375360,
  [SMALL_STATE(9391)] = 375369,
  [SMALL_STATE(9392)] = 375378,
  [SMALL_STATE(9393)] = 375387,
  [SMALL_STATE(9394)] = 375396,
  [SMALL_STATE(9395)] = 375405,
  [SMALL_STATE(9396)] = 375414,
  [SMALL_STATE(9397)] = 375423,
  [SMALL_STATE(9398)] = 375432,
  [SMALL_STATE(9399)] = 375441,
  [SMALL_STATE(9400)] = 375450,
  [SMALL_STATE(9401)] = 375459,
  [SMALL_STATE(9402)] = 375468,
  [SMALL_STATE(9403)] = 375477,
  [SMALL_STATE(9404)] = 375486,
  [SMALL_STATE(9405)] = 375495,
  [SMALL_STATE(9406)] = 375504,
  [SMALL_STATE(9407)] = 375513,
  [SMALL_STATE(9408)] = 375522,
  [SMALL_STATE(9409)] = 375531,
  [SMALL_STATE(9410)] = 375540,
  [SMALL_STATE(9411)] = 375549,
  [SMALL_STATE(9412)] = 375558,
  [SMALL_STATE(9413)] = 375567,
  [SMALL_STATE(9414)] = 375576,
  [SMALL_STATE(9415)] = 375585,
  [SMALL_STATE(9416)] = 375594,
  [SMALL_STATE(9417)] = 375603,
  [SMALL_STATE(9418)] = 375612,
  [SMALL_STATE(9419)] = 375621,
  [SMALL_STATE(9420)] = 375630,
  [SMALL_STATE(9421)] = 375639,
  [SMALL_STATE(9422)] = 375648,
  [SMALL_STATE(9423)] = 375657,
  [SMALL_STATE(9424)] = 375666,
  [SMALL_STATE(9425)] = 375675,
  [SMALL_STATE(9426)] = 375684,
  [SMALL_STATE(9427)] = 375693,
  [SMALL_STATE(9428)] = 375702,
  [SMALL_STATE(9429)] = 375711,
  [SMALL_STATE(9430)] = 375720,
  [SMALL_STATE(9431)] = 375729,
  [SMALL_STATE(9432)] = 375738,
  [SMALL_STATE(9433)] = 375747,
  [SMALL_STATE(9434)] = 375756,
  [SMALL_STATE(9435)] = 375765,
  [SMALL_STATE(9436)] = 375774,
  [SMALL_STATE(9437)] = 375783,
  [SMALL_STATE(9438)] = 375792,
  [SMALL_STATE(9439)] = 375801,
  [SMALL_STATE(9440)] = 375810,
  [SMALL_STATE(9441)] = 375819,
  [SMALL_STATE(9442)] = 375828,
  [SMALL_STATE(9443)] = 375837,
  [SMALL_STATE(9444)] = 375846,
  [SMALL_STATE(9445)] = 375855,
  [SMALL_STATE(9446)] = 375864,
  [SMALL_STATE(9447)] = 375873,
  [SMALL_STATE(9448)] = 375882,
  [SMALL_STATE(9449)] = 375891,
  [SMALL_STATE(9450)] = 375900,
  [SMALL_STATE(9451)] = 375909,
  [SMALL_STATE(9452)] = 375918,
  [SMALL_STATE(9453)] = 375927,
  [SMALL_STATE(9454)] = 375936,
  [SMALL_STATE(9455)] = 375945,
  [SMALL_STATE(9456)] = 375954,
  [SMALL_STATE(9457)] = 375963,
  [SMALL_STATE(9458)] = 375972,
  [SMALL_STATE(9459)] = 375981,
  [SMALL_STATE(9460)] = 375990,
  [SMALL_STATE(9461)] = 375999,
  [SMALL_STATE(9462)] = 376008,
  [SMALL_STATE(9463)] = 376017,
  [SMALL_STATE(9464)] = 376026,
  [SMALL_STATE(9465)] = 376035,
  [SMALL_STATE(9466)] = 376044,
  [SMALL_STATE(9467)] = 376053,
  [SMALL_STATE(9468)] = 376062,
  [SMALL_STATE(9469)] = 376071,
  [SMALL_STATE(9470)] = 376080,
  [SMALL_STATE(9471)] = 376089,
  [SMALL_STATE(9472)] = 376098,
  [SMALL_STATE(9473)] = 376107,
  [SMALL_STATE(9474)] = 376116,
  [SMALL_STATE(9475)] = 376125,
  [SMALL_STATE(9476)] = 376134,
  [SMALL_STATE(9477)] = 376143,
  [SMALL_STATE(9478)] = 376152,
  [SMALL_STATE(9479)] = 376161,
  [SMALL_STATE(9480)] = 376170,
  [SMALL_STATE(9481)] = 376179,
  [SMALL_STATE(9482)] = 376188,
  [SMALL_STATE(9483)] = 376197,
  [SMALL_STATE(9484)] = 376206,
  [SMALL_STATE(9485)] = 376215,
  [SMALL_STATE(9486)] = 376224,
  [SMALL_STATE(9487)] = 376233,
  [SMALL_STATE(9488)] = 376242,
  [SMALL_STATE(9489)] = 376251,
  [SMALL_STATE(9490)] = 376260,
  [SMALL_STATE(9491)] = 376269,
  [SMALL_STATE(9492)] = 376278,
  [SMALL_STATE(9493)] = 376287,
  [SMALL_STATE(9494)] = 376296,
  [SMALL_STATE(9495)] = 376305,
  [SMALL_STATE(9496)] = 376314,
  [SMALL_STATE(9497)] = 376323,
  [SMALL_STATE(9498)] = 376332,
  [SMALL_STATE(9499)] = 376341,
  [SMALL_STATE(9500)] = 376350,
  [SMALL_STATE(9501)] = 376359,
  [SMALL_STATE(9502)] = 376368,
  [SMALL_STATE(9503)] = 376377,
  [SMALL_STATE(9504)] = 376386,
  [SMALL_STATE(9505)] = 376395,
  [SMALL_STATE(9506)] = 376404,
  [SMALL_STATE(9507)] = 376413,
  [SMALL_STATE(9508)] = 376422,
  [SMALL_STATE(9509)] = 376431,
  [SMALL_STATE(9510)] = 376440,
  [SMALL_STATE(9511)] = 376449,
  [SMALL_STATE(9512)] = 376458,
  [SMALL_STATE(9513)] = 376467,
  [SMALL_STATE(9514)] = 376476,
  [SMALL_STATE(9515)] = 376485,
  [SMALL_STATE(9516)] = 376494,
  [SMALL_STATE(9517)] = 376503,
  [SMALL_STATE(9518)] = 376512,
  [SMALL_STATE(9519)] = 376521,
  [SMALL_STATE(9520)] = 376530,
  [SMALL_STATE(9521)] = 376539,
  [SMALL_STATE(9522)] = 376548,
  [SMALL_STATE(9523)] = 376557,
  [SMALL_STATE(9524)] = 376566,
  [SMALL_STATE(9525)] = 376575,
  [SMALL_STATE(9526)] = 376584,
  [SMALL_STATE(9527)] = 376593,
  [SMALL_STATE(9528)] = 376602,
  [SMALL_STATE(9529)] = 376611,
  [SMALL_STATE(9530)] = 376620,
  [SMALL_STATE(9531)] = 376629,
  [SMALL_STATE(9532)] = 376638,
  [SMALL_STATE(9533)] = 376647,
  [SMALL_STATE(9534)] = 376656,
  [SMALL_STATE(9535)] = 376665,
  [SMALL_STATE(9536)] = 376674,
  [SMALL_STATE(9537)] = 376683,
  [SMALL_STATE(9538)] = 376692,
  [SMALL_STATE(9539)] = 376701,
  [SMALL_STATE(9540)] = 376710,
  [SMALL_STATE(9541)] = 376719,
  [SMALL_STATE(9542)] = 376728,
  [SMALL_STATE(9543)] = 376737,
  [SMALL_STATE(9544)] = 376746,
  [SMALL_STATE(9545)] = 376755,
  [SMALL_STATE(9546)] = 376764,
  [SMALL_STATE(9547)] = 376773,
  [SMALL_STATE(9548)] = 376782,
  [SMALL_STATE(9549)] = 376791,
  [SMALL_STATE(9550)] = 376800,
  [SMALL_STATE(9551)] = 376809,
  [SMALL_STATE(9552)] = 376818,
  [SMALL_STATE(9553)] = 376827,
  [SMALL_STATE(9554)] = 376836,
  [SMALL_STATE(9555)] = 376845,
  [SMALL_STATE(9556)] = 376854,
  [SMALL_STATE(9557)] = 376863,
  [SMALL_STATE(9558)] = 376872,
  [SMALL_STATE(9559)] = 376881,
  [SMALL_STATE(9560)] = 376890,
  [SMALL_STATE(9561)] = 376899,
  [SMALL_STATE(9562)] = 376908,
  [SMALL_STATE(9563)] = 376917,
  [SMALL_STATE(9564)] = 376926,
  [SMALL_STATE(9565)] = 376935,
  [SMALL_STATE(9566)] = 376944,
  [SMALL_STATE(9567)] = 376953,
  [SMALL_STATE(9568)] = 376962,
  [SMALL_STATE(9569)] = 376971,
  [SMALL_STATE(9570)] = 376980,
  [SMALL_STATE(9571)] = 376989,
  [SMALL_STATE(9572)] = 376998,
  [SMALL_STATE(9573)] = 377007,
  [SMALL_STATE(9574)] = 377016,
  [SMALL_STATE(9575)] = 377025,
  [SMALL_STATE(9576)] = 377034,
  [SMALL_STATE(9577)] = 377043,
  [SMALL_STATE(9578)] = 377052,
  [SMALL_STATE(9579)] = 377061,
  [SMALL_STATE(9580)] = 377070,
  [SMALL_STATE(9581)] = 377079,
  [SMALL_STATE(9582)] = 377088,
  [SMALL_STATE(9583)] = 377097,
  [SMALL_STATE(9584)] = 377106,
  [SMALL_STATE(9585)] = 377115,
  [SMALL_STATE(9586)] = 377124,
  [SMALL_STATE(9587)] = 377133,
  [SMALL_STATE(9588)] = 377142,
  [SMALL_STATE(9589)] = 377151,
  [SMALL_STATE(9590)] = 377160,
  [SMALL_STATE(9591)] = 377169,
  [SMALL_STATE(9592)] = 377178,
  [SMALL_STATE(9593)] = 377187,
  [SMALL_STATE(9594)] = 377196,
  [SMALL_STATE(9595)] = 377205,
  [SMALL_STATE(9596)] = 377214,
  [SMALL_STATE(9597)] = 377223,
  [SMALL_STATE(9598)] = 377232,
  [SMALL_STATE(9599)] = 377241,
  [SMALL_STATE(9600)] = 377250,
  [SMALL_STATE(9601)] = 377259,
  [SMALL_STATE(9602)] = 377268,
  [SMALL_STATE(9603)] = 377277,
  [SMALL_STATE(9604)] = 377286,
  [SMALL_STATE(9605)] = 377295,
  [SMALL_STATE(9606)] = 377304,
  [SMALL_STATE(9607)] = 377313,
  [SMALL_STATE(9608)] = 377322,
  [SMALL_STATE(9609)] = 377331,
  [SMALL_STATE(9610)] = 377340,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3765),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9234),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9435),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7574),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7059),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2100),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8724),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1963),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4733),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2094),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2094),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2097),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9251),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1663),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1553),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9476),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9363),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9279),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5249),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4113),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7537),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7776),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8665),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4089),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4113),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5279),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2505),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [69] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2090),
  [73] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(495),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2205),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(287),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(74),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7064),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7081),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7164),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2561),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2009),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2010),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9335),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2012),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2013),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9315),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9485),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9486),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5530),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2268),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7612),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7999),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8646),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2274),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2268),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2930),
  [131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 3, 0, 0),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 3, 0, 0),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1959),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9060),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1961),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1962),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9411),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9514),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9518),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5519),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7616),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8437),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8888),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_break_expression, 2, 0, 0),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_break_expression, 2, 0, 0),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1960),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1446),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2139),
  [187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9300),
  [189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2141),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2142),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2040),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2344),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2140),
  [201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2585),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2541),
  [207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 4, 0, 9),
  [209] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 4, 0, 9),
  [211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2173),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2434),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2124),
  [221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2127),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9081),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2162),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2165),
  [231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9422),
  [233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9517),
  [235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9521),
  [237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5535),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2397),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7689),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8544),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8625),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2466),
  [249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2397),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2170),
  [253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2656),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2036),
  [263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2037),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9530),
  [269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2038),
  [271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2039),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9328),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9490),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9491),
  [279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5630),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2699),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7695),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8373),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8835),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2706),
  [291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2699),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2645),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1563),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9410),
  [299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1565),
  [301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1566),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2730),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1738),
  [311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8976),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1740),
  [315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1741),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9367),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9500),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9506),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5504),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2836),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7673),
  [329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7952),
  [331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8927),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2841),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2836),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2786),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2954),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1739),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4715),
  [349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1648),
  [351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9244),
  [353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1656),
  [355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1657),
  [357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9302),
  [359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9480),
  [361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9481),
  [363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5422),
  [365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4851),
  [367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7628),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8066),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8866),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4766),
  [375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4851),
  [377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4716),
  [379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2797),
  [383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1564),
  [385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 1, 0, 0),
  [387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 1, 0, 0),
  [389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5040),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4818),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2462),
  [403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 4, 0, 57),
  [407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_case, 4, 0, 57),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 2, 0, 0),
  [413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_case, 2, 0, 0),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 3, 0, 29),
  [423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_case, 3, 0, 29),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4542),
  [429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2476),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4283),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3905),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4432),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3822),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2248),
  [453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3731),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2627),
  [461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3096),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3884),
  [469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3368),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4656),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2822),
  [481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7212),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3612),
  [489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1981),
  [493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2261),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2142),
  [507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2855),
  [509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2979),
  [511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3196),
  [517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1803),
  [519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1803),
  [521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1813),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8997),
  [527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1814),
  [529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1815),
  [531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9378),
  [533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9505),
  [535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9509),
  [537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5259),
  [539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3146),
  [541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7694),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8046),
  [545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8693),
  [547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3061),
  [549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3146),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3070),
  [553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3026),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3414),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1877),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1877),
  [565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1878),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9018),
  [571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1879),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1880),
  [575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9389),
  [577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9508),
  [579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9512),
  [581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5551),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3315),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7557),
  [587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8156),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8757),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3354),
  [593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3315),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3025),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4408),
  [599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6766),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5495),
  [603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4697),
  [607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1983),
  [609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9529),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1985),
  [615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1986),
  [617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9056),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4898),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5515),
  [623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3447),
  [625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1925),
  [627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9039),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1930),
  [631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1931),
  [633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9400),
  [635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9511),
  [637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9515),
  [639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5264),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3577),
  [643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7544),
  [645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8265),
  [647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8818),
  [649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3581),
  [651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3577),
  [653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1553),
  [655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3847),
  [657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3713),
  [659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4129),
  [665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1485),
  [669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1486),
  [671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9080),
  [675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1487),
  [677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1488),
  [679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9172),
  [681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9461),
  [683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9462),
  [685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5221),
  [687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4202),
  [689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7711),
  [691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8131),
  [693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8878),
  [695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4027),
  [697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4202),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4012),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4052),
  [703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3622),
  [709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1925),
  [711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1926),
  [713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3444),
  [717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4232),
  [721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6796),
  [725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 0),
  [729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4543),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1611),
  [735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1613),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9609),
  [741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1615),
  [743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1617),
  [745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9341),
  [747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9495),
  [749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9496),
  [751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5674),
  [753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4558),
  [755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7567),
  [757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7830),
  [759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8753),
  [761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4559),
  [763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4558),
  [765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4413),
  [767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0),
  [769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(561),
  [771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6776),
  [773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 5, 0, 0),
  [775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7242),
  [777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5071),
  [779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9084),
  [781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5711),
  [783] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4911),
  [786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5521),
  [788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(800),
  [790] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(630),
  [793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5392),
  [795] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5645),
  [798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9144),
  [802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9086),
  [804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9452),
  [806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(9009),
  [809] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0),
  [812] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0),
  [815] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4911),
  [819] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(630),
  [823] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5645),
  [827] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(9009),
  [831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5330),
  [833] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0),
  [836] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0),
  [839] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4911),
  [843] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(630),
  [847] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5645),
  [851] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(9009),
  [855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0),
  [857] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0),
  [859] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4911),
  [862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(630),
  [865] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5645),
  [868] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(9009),
  [871] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0),
  [874] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0),
  [877] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4911),
  [881] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(630),
  [885] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5645),
  [889] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(9009),
  [893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0),
  [895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0),
  [897] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4911),
  [900] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(630),
  [903] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5645),
  [906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(9009),
  [909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0),
  [911] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0),
  [913] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4911),
  [916] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(630),
  [919] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5645),
  [922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(9009),
  [925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4228),
  [927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4533),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1983),
  [933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1984),
  [935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4539),
  [937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4698),
  [941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(904),
  [943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6803),
  [945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7105),
  [947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4970),
  [949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9064),
  [951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5710),
  [953] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4896),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5510),
  [958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1622),
  [960] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(627),
  [963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5512),
  [965] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5641),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9140),
  [972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9066),
  [974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9451),
  [976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5506),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9397),
  [980] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4896),
  [983] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(627),
  [986] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5641),
  [989] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4896),
  [992] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(627),
  [995] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5641),
  [998] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4896),
  [1001] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(627),
  [1004] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5641),
  [1007] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4896),
  [1011] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(627),
  [1015] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5641),
  [1019] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4896),
  [1023] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(627),
  [1027] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5641),
  [1031] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4896),
  [1035] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(627),
  [1039] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5641),
  [1043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1447),
  [1045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6767),
  [1047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7179),
  [1049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5054),
  [1051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9346),
  [1053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5701),
  [1055] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4921),
  [1059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5532),
  [1061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2340),
  [1063] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(575),
  [1067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5488),
  [1069] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5390),
  [1073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2346),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8937),
  [1077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9349),
  [1079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9360),
  [1081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9567),
  [1083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2015),
  [1085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8955),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2017),
  [1089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2018),
  [1091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4729),
  [1093] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4921),
  [1097] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(575),
  [1101] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5390),
  [1105] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4921),
  [1109] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(575),
  [1113] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5390),
  [1117] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4921),
  [1120] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(575),
  [1123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5390),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4844),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2015),
  [1132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2016),
  [1134] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4921),
  [1137] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(575),
  [1140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5390),
  [1143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4921),
  [1146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(575),
  [1149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5390),
  [1152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4921),
  [1155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(575),
  [1158] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5390),
  [1161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1278),
  [1163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6802),
  [1165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7295),
  [1167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5073),
  [1169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9097),
  [1171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5712),
  [1173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4943),
  [1176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5539),
  [1178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2465),
  [1180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(633),
  [1183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5335),
  [1185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5652),
  [1188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2471),
  [1190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9148),
  [1192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9099),
  [1194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9453),
  [1196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(9016),
  [1199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4943),
  [1202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(633),
  [1205] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5652),
  [1208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(9016),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4856),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1648),
  [1219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1655),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [1223] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4943),
  [1227] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(633),
  [1231] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5652),
  [1235] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(9016),
  [1239] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4943),
  [1243] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(633),
  [1247] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5652),
  [1251] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(9016),
  [1255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4943),
  [1258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(633),
  [1261] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5652),
  [1264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(9016),
  [1267] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4943),
  [1271] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(633),
  [1275] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5652),
  [1279] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(9016),
  [1283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4943),
  [1286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(633),
  [1289] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5652),
  [1292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(9016),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2058),
  [1299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2058),
  [1301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2059),
  [1303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9094),
  [1305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2060),
  [1307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2061),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9432),
  [1311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9523),
  [1313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5313),
  [1315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4073),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4387),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [1325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1612),
  [1327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1614),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [1331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9107),
  [1333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1618),
  [1335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1620),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9437),
  [1339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9520),
  [1341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9525),
  [1343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5266),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4415),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7677),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8298),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8652),
  [1353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4416),
  [1355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4415),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4072),
  [1359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2543),
  [1361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6768),
  [1363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7346),
  [1365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5058),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9425),
  [1369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5702),
  [1371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4935),
  [1374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5633),
  [1376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2660),
  [1378] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(585),
  [1381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5233),
  [1383] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5556),
  [1386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2661),
  [1388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8960),
  [1390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9431),
  [1392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9373),
  [1394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9534),
  [1396] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4935),
  [1400] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(585),
  [1404] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5556),
  [1408] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4935),
  [1411] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(585),
  [1414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5556),
  [1417] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4935),
  [1421] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(585),
  [1425] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5556),
  [1429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4935),
  [1432] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(585),
  [1435] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5556),
  [1438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4747),
  [1440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [1442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4804),
  [1444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4935),
  [1447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(585),
  [1450] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5556),
  [1453] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4935),
  [1457] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(585),
  [1461] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5556),
  [1465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6809),
  [1467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2702),
  [1469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6792),
  [1471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7274),
  [1473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5065),
  [1475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9001),
  [1477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5707),
  [1479] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4913),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5263),
  [1485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2953),
  [1487] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(613),
  [1491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5192),
  [1493] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5537),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2885),
  [1499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9098),
  [1501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9003),
  [1503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9439),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9579),
  [1507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4913),
  [1510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(613),
  [1513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5537),
  [1516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4913),
  [1519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(613),
  [1522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5537),
  [1525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4913),
  [1528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(613),
  [1531] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5537),
  [1534] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4913),
  [1537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(613),
  [1540] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5537),
  [1543] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4913),
  [1547] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(613),
  [1551] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5537),
  [1555] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4913),
  [1559] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(613),
  [1563] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5537),
  [1567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [1569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [1571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(3765),
  [1574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(893),
  [1577] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(9234),
  [1580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(9435),
  [1583] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(7574),
  [1586] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(7059),
  [1589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2100),
  [1592] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8724),
  [1595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(513),
  [1598] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1963),
  [1601] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(4733),
  [1604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2094),
  [1607] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2094),
  [1610] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2097),
  [1613] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(815),
  [1616] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(9251),
  [1619] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1663),
  [1622] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1553),
  [1625] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(9476),
  [1628] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(9363),
  [1631] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(9279),
  [1634] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(5249),
  [1637] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(4113),
  [1640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(7537),
  [1643] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(7776),
  [1646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(8665),
  [1649] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(4089),
  [1652] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(4113),
  [1655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(5279),
  [1658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5116),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [1662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3010),
  [1664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6783),
  [1666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7236),
  [1668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5064),
  [1670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8980),
  [1672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5706),
  [1674] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4895),
  [1678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5395),
  [1680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3307),
  [1682] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(603),
  [1686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5481),
  [1688] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5500),
  [1692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3312),
  [1694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9044),
  [1696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8982),
  [1698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9417),
  [1700] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(9176),
  [1704] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4895),
  [1708] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(603),
  [1712] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5500),
  [1716] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(9176),
  [1720] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4895),
  [1723] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(603),
  [1726] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5500),
  [1729] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(9176),
  [1732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2816),
  [1734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6777),
  [1736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7151),
  [1738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5061),
  [1740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8936),
  [1742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5704),
  [1744] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4947),
  [1748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5257),
  [1750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3121),
  [1752] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(610),
  [1756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5206),
  [1758] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5520),
  [1762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3122),
  [1764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9085),
  [1766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8938),
  [1768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9434),
  [1770] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(9306),
  [1774] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4947),
  [1778] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(610),
  [1782] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5520),
  [1786] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(9306),
  [1790] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4895),
  [1794] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(603),
  [1798] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5500),
  [1802] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(9176),
  [1806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4895),
  [1809] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(603),
  [1812] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5500),
  [1815] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(9176),
  [1818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4895),
  [1821] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(603),
  [1824] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5500),
  [1827] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(9176),
  [1830] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4947),
  [1833] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(610),
  [1836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5520),
  [1839] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(9306),
  [1842] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4947),
  [1846] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(610),
  [1850] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5520),
  [1854] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(9306),
  [1858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4895),
  [1861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(603),
  [1864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5500),
  [1867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(9176),
  [1870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4947),
  [1873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(610),
  [1876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5520),
  [1879] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(9306),
  [1882] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4947),
  [1885] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(610),
  [1888] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5520),
  [1891] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(9306),
  [1894] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4947),
  [1897] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(610),
  [1900] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5520),
  [1903] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(9306),
  [1906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3515),
  [1908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6778),
  [1910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7093),
  [1912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5051),
  [1914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9263),
  [1916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5700),
  [1918] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4906),
  [1922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5425),
  [1924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3767),
  [1926] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(685),
  [1930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5642),
  [1932] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5631),
  [1936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3789),
  [1938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9348),
  [1940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9266),
  [1942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9321),
  [1944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8940),
  [1946] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4906),
  [1949] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(685),
  [1952] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5631),
  [1955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3379),
  [1957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6770),
  [1959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7342),
  [1961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5068),
  [1963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9043),
  [1965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5709),
  [1967] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4946),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5265),
  [1973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3603),
  [1975] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(636),
  [1979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5218),
  [1981] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5666),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3604),
  [1987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9152),
  [1989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9045),
  [1991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9454),
  [1993] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(9031),
  [1997] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4946),
  [2001] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(636),
  [2005] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5666),
  [2009] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(9031),
  [2013] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4946),
  [2016] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(636),
  [2019] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5666),
  [2022] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(9031),
  [2025] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4946),
  [2029] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(636),
  [2033] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5666),
  [2037] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(9031),
  [2041] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4946),
  [2044] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(636),
  [2047] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5666),
  [2050] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(9031),
  [2053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4946),
  [2056] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(636),
  [2059] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5666),
  [2062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(9031),
  [2065] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4906),
  [2069] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(685),
  [2073] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5631),
  [2077] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4906),
  [2081] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(685),
  [2085] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5631),
  [2089] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4906),
  [2092] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(685),
  [2095] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5631),
  [2098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4906),
  [2101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(685),
  [2104] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5631),
  [2107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4906),
  [2110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(685),
  [2113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5631),
  [2116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4946),
  [2119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(636),
  [2122] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5666),
  [2125] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(9031),
  [2128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3616),
  [2130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6780),
  [2132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7193),
  [2134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5062),
  [2136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8959),
  [2138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5705),
  [2140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4892),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5626),
  [2145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3852),
  [2147] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(599),
  [2150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5320),
  [2152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5434),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3855),
  [2157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9023),
  [2159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8961),
  [2161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9406),
  [2163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5386),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9075),
  [2167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4892),
  [2170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(599),
  [2173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5434),
  [2176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4892),
  [2179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(599),
  [2182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5434),
  [2185] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4892),
  [2189] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(599),
  [2193] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5434),
  [2197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4892),
  [2200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(599),
  [2203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5434),
  [2206] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4892),
  [2210] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(599),
  [2214] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5434),
  [2218] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4892),
  [2222] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(599),
  [2226] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5434),
  [2230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3647),
  [2232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6791),
  [2234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7123),
  [2236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5119),
  [2238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9574),
  [2240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5478),
  [2242] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4893),
  [2246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5540),
  [2248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3924),
  [2250] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(578),
  [2254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5352),
  [2256] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5229),
  [2260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3931),
  [2262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9237),
  [2264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9499),
  [2266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8979),
  [2268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9399),
  [2270] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4893),
  [2274] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(578),
  [2278] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5229),
  [2282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3684),
  [2284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6788),
  [2286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7231),
  [2288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5019),
  [2290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9100),
  [2292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5699),
  [2294] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4952),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5230),
  [2300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3926),
  [2302] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(596),
  [2306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5185),
  [2308] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5423),
  [2312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3928),
  [2314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9102),
  [2316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9103),
  [2318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9183),
  [2320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9418),
  [2322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4952),
  [2325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(596),
  [2328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5423),
  [2331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4893),
  [2334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(578),
  [2337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5229),
  [2340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4952),
  [2343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(596),
  [2346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5423),
  [2349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4893),
  [2352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(578),
  [2355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5229),
  [2358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4893),
  [2361] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(578),
  [2364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5229),
  [2367] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4952),
  [2371] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(596),
  [2375] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5423),
  [2379] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4952),
  [2383] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(596),
  [2387] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5423),
  [2391] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4952),
  [2394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(596),
  [2397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5423),
  [2400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4952),
  [2403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(596),
  [2406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5423),
  [2409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4893),
  [2412] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(578),
  [2415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5229),
  [2418] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4893),
  [2422] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(578),
  [2426] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5229),
  [2430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3964),
  [2432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6808),
  [2434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7335),
  [2436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5075),
  [2438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9109),
  [2440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5713),
  [2442] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4918),
  [2446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5568),
  [2448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4298),
  [2450] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(639),
  [2454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5183),
  [2456] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5694),
  [2460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4299),
  [2462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9156),
  [2464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9111),
  [2466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9455),
  [2468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5564),
  [2470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8995),
  [2472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4918),
  [2475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(639),
  [2478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5694),
  [2481] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4918),
  [2485] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(639),
  [2489] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5694),
  [2493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4918),
  [2496] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(639),
  [2499] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5694),
  [2502] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4918),
  [2506] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(639),
  [2510] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5694),
  [2514] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4918),
  [2517] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(639),
  [2520] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5694),
  [2523] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4918),
  [2526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(639),
  [2529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5694),
  [2532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4014),
  [2534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6771),
  [2536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7089),
  [2538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5077),
  [2540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9119),
  [2542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5714),
  [2544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4925),
  [2547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5267),
  [2549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4336),
  [2551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(651),
  [2554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5242),
  [2556] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5170),
  [2559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4337),
  [2561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9169),
  [2563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9121),
  [2565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9459),
  [2567] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(9063),
  [2570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4925),
  [2573] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(651),
  [2576] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5170),
  [2579] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(9063),
  [2582] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4925),
  [2585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(651),
  [2588] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5170),
  [2591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(9063),
  [2594] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4925),
  [2597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(651),
  [2600] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5170),
  [2603] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(9063),
  [2606] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4925),
  [2610] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(651),
  [2614] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5170),
  [2618] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(9063),
  [2622] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4925),
  [2626] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(651),
  [2630] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5170),
  [2634] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(9063),
  [2638] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4925),
  [2642] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(651),
  [2646] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5170),
  [2650] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(9063),
  [2654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4022),
  [2656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6769),
  [2658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7114),
  [2660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5059),
  [2662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9548),
  [2664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5703),
  [2666] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4949),
  [2670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5679),
  [2672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4567),
  [2674] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(589),
  [2678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5474),
  [2680] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5250),
  [2684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4568),
  [2686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8981),
  [2688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9566),
  [2690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9384),
  [2692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9004),
  [2694] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4949),
  [2698] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(589),
  [2702] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5250),
  [2706] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4949),
  [2710] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(589),
  [2714] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5250),
  [2718] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4949),
  [2721] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(589),
  [2724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5250),
  [2727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4949),
  [2730] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(589),
  [2733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5250),
  [2736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4949),
  [2739] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(589),
  [2742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5250),
  [2745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4949),
  [2748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(589),
  [2751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5250),
  [2754] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(2816),
  [2758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6798),
  [2760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5312),
  [2762] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(648),
  [2766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5306),
  [2768] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(5169),
  [2772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9166),
  [2774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9458),
  [2776] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(9058),
  [2780] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(2816),
  [2783] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(648),
  [2786] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(5169),
  [2789] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(9058),
  [2792] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(2816),
  [2795] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(648),
  [2798] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(5169),
  [2801] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(9058),
  [2804] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(2816),
  [2808] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(648),
  [2812] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(5169),
  [2816] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(9058),
  [2820] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(2816),
  [2824] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(648),
  [2828] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(5169),
  [2832] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(9058),
  [2836] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(2816),
  [2839] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(648),
  [2842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(5169),
  [2845] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(9058),
  [2848] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(2816),
  [2851] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(648),
  [2854] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(5169),
  [2857] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(9058),
  [2860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [2864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(75),
  [2866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1543),
  [2868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2756),
  [2870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [2872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [2874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [2876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [2878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6750),
  [2880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7068),
  [2882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5136),
  [2884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7720),
  [2886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5514),
  [2888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [2890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1986),
  [2892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5513),
  [2894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(125),
  [2896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6753),
  [2898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7056),
  [2900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5078),
  [2902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7657),
  [2904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5171),
  [2906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5201),
  [2908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [2910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [2912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(84),
  [2914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3, 0, 0),
  [2916] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3, 0, 0),
  [2918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [2920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 5, 0, 0),
  [2922] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 5, 0, 0),
  [2924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4855),
  [2926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4016),
  [2928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [2930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [2932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5300),
  [2934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5370),
  [2936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2726),
  [2938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4584),
  [2940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 4, 0, 0),
  [2942] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 4, 0, 0),
  [2944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4121),
  [2946] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 1, 0, 0),
  [2948] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 1, 0, 0),
  [2950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [2952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [2954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(98),
  [2956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4096),
  [2958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2514),
  [2960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4653),
  [2962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4255),
  [2964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4259),
  [2966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4102),
  [2968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4085),
  [2970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4734),
  [2972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4738),
  [2974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4739),
  [2976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4223),
  [2978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4233),
  [2980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4128),
  [2982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4091),
  [2984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4105),
  [2986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4887),
  [2988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4890),
  [2990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2546),
  [2992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4751),
  [2994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4816),
  [2996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [2998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4764),
  [3000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4765),
  [3002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4767),
  [3004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4779),
  [3006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4781),
  [3008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4782),
  [3010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2800),
  [3012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2785),
  [3014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2776),
  [3016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4789),
  [3018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4790),
  [3020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4795),
  [3022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2722),
  [3024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2463),
  [3026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4878),
  [3028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4374),
  [3030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2329),
  [3032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2332),
  [3034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2334),
  [3036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2461),
  [3038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2470),
  [3040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2472),
  [3042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4525),
  [3044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4526),
  [3046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4527),
  [3048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2512),
  [3050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2517),
  [3052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2221),
  [3054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2597),
  [3056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2315),
  [3058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2598),
  [3060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2670),
  [3062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4879),
  [3064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4724),
  [3066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2729),
  [3068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2731),
  [3070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2737),
  [3072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2671),
  [3074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2674),
  [3076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2675),
  [3078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4783),
  [3080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4784),
  [3082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4785),
  [3084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2685),
  [3086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2686),
  [3088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2692),
  [3090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4621),
  [3092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4675),
  [3094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5675),
  [3096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4673),
  [3098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4693),
  [3100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4510),
  [3102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4613),
  [3104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4619),
  [3106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4620),
  [3108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5538),
  [3110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4254),
  [3112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4658),
  [3114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4692),
  [3116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2599),
  [3118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2876),
  [3120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2906),
  [3122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2911),
  [3124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2923),
  [3126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2924),
  [3128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2925),
  [3130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2937),
  [3132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2940),
  [3134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2941),
  [3136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2945),
  [3138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2946),
  [3140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2951),
  [3142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3032),
  [3144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3067),
  [3146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3079),
  [3148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [3150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3113),
  [3152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3114),
  [3154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3135),
  [3156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3139),
  [3158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3140),
  [3160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3151),
  [3162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3152),
  [3164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3205),
  [3166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3270),
  [3168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3328),
  [3170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3345),
  [3172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3377),
  [3174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3378),
  [3176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3380),
  [3178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3402),
  [3180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3406),
  [3182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3407),
  [3184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3417),
  [3186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3421),
  [3188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3432),
  [3190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3630),
  [3192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3675),
  [3194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [3196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3527),
  [3198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3528),
  [3200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3529),
  [3202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3543),
  [3204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3547),
  [3206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3548),
  [3208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3552),
  [3210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3553),
  [3212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3558),
  [3214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [3216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [3218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [3220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [3222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [3224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [3226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [3228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [3230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [3232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [3234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [3236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [3238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2312),
  [3240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2474),
  [3242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2518),
  [3244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2250),
  [3246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2253),
  [3248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2255),
  [3250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2287),
  [3252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2291),
  [3254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2292),
  [3256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2308),
  [3258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2311),
  [3260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2327),
  [3262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4263),
  [3264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4437),
  [3266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4467),
  [3268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4473),
  [3270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4486),
  [3272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4487),
  [3274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4488),
  [3276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4498),
  [3278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4501),
  [3280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4502),
  [3282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4267),
  [3284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4268),
  [3286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4273),
  [3288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4185),
  [3290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [3292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [3294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2807),
  [3296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [3298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [3300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4180),
  [3302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(71),
  [3304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(90),
  [3306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4076),
  [3308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [3310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4198),
  [3312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4252),
  [3314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4186),
  [3316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4193),
  [3318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4038),
  [3320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(101),
  [3322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(105),
  [3324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4194),
  [3326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(107),
  [3328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(108),
  [3330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(113),
  [3332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4848),
  [3334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4657),
  [3336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4229),
  [3338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4152),
  [3340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2204),
  [3342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [3344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [3346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1566),
  [3348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [3350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [3352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [3354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [3356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [3358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(555),
  [3360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1657),
  [3362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2114),
  [3364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(137),
  [3366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 4, 0, 0),
  [3368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 5, 0, 0),
  [3370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [3372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [3374] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 5, 0, 0),
  [3376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2550),
  [3378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5638),
  [3380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [3382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [3384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 6, 0, 0),
  [3386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [3388] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 6, 0, 0),
  [3390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2356),
  [3392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [3394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2342),
  [3396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [3398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [3400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 7, 0, 0),
  [3402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 7, 0, 0),
  [3404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2357),
  [3406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [3408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0),
  [3410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0),
  [3412] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9067),
  [3415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 7, 0, 0),
  [3417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(136),
  [3419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5634),
  [3421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [3423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [3425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 4, 0, 0),
  [3427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 4, 0, 0),
  [3429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1558),
  [3431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [3433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_type, 2, 0, 0),
  [3435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_type, 2, 0, 0),
  [3437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9067),
  [3439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 2, 0, 0),
  [3441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [3443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4982),
  [3445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 2, 0, 0),
  [3447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [3449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [3451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 3, 0, 0),
  [3453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5039),
  [3455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 3, 0, 0),
  [3457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [3459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [3461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4705),
  [3463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [3465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [3467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [3469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5037),
  [3471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2326),
  [3473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [3475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4172),
  [3477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [3479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [3481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [3483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 1, 0, 0),
  [3485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5644),
  [3487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [3489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4704),
  [3491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [3493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [3495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [3497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [3499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5025),
  [3501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2305),
  [3503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [3505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [3507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [3509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 5, 0, 0),
  [3511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 6, 0, 0),
  [3513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2341),
  [3515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [3517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [3519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [3521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1594),
  [3523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [3525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5114),
  [3527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [3529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [3531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4998),
  [3533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [3535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [3537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [3539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5782),
  [3541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4048),
  [3543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9068),
  [3545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9068),
  [3547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_type, 4, 0, 0),
  [3549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_type, 4, 0, 0),
  [3551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [3553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5834),
  [3555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4548),
  [3557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9210),
  [3559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9210),
  [3561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [3563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5831),
  [3565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [3567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9265),
  [3569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9265),
  [3571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [3573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5844),
  [3575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [3577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9394),
  [3579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9394),
  [3581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [3583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5887),
  [3585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3738),
  [3587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9046),
  [3589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9046),
  [3591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [3593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5840),
  [3595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [3597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9309),
  [3599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9309),
  [3601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [3603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5895),
  [3605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4915),
  [3607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9488),
  [3609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9488),
  [3611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [3613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5756),
  [3615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4761),
  [3617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9108),
  [3619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9108),
  [3621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [3623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5852),
  [3625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [3627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9006),
  [3629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9006),
  [3631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [3633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5838),
  [3635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3721),
  [3637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9221),
  [3639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9221),
  [3641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [3643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5798),
  [3645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3915),
  [3647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9256),
  [3649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9256),
  [3651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [3653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5794),
  [3655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [3657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9239),
  [3659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9239),
  [3661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [3663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5881),
  [3665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4900),
  [3667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9171),
  [3669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9171),
  [3671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [3673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5836),
  [3675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4420),
  [3677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9138),
  [3679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9138),
  [3681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [3683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5785),
  [3685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4551),
  [3687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9246),
  [3689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9246),
  [3691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [3693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5802),
  [3695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4748),
  [3697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9359),
  [3699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9359),
  [3701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0),
  [3703] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7455),
  [3706] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0),
  [3708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [3710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5795),
  [3712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [3714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9471),
  [3716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9471),
  [3718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [3720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5879),
  [3722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [3724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9090),
  [3726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9090),
  [3728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [3730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5894),
  [3732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [3734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9233),
  [3736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9233),
  [3738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [3740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5893),
  [3742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [3744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9368),
  [3746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9368),
  [3748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [3750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5845),
  [3752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [3754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9408),
  [3756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9408),
  [3758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [3760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5880),
  [3762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9147),
  [3766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9147),
  [3768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [3770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5804),
  [3772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [3774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8949),
  [3776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8949),
  [3778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [3780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5842),
  [3782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3522),
  [3784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9215),
  [3786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9215),
  [3788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [3790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5739),
  [3792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3999),
  [3794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9270),
  [3796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9270),
  [3798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [3800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5751),
  [3802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3462),
  [3804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9255),
  [3806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9255),
  [3808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [3810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5735),
  [3812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4396),
  [3814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9301),
  [3816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9301),
  [3818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [3820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5742),
  [3822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [3824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8984),
  [3826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8984),
  [3828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [3830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5766),
  [3832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3889),
  [3834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9231),
  [3836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9231),
  [3838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [3840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5814),
  [3842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [3844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9011),
  [3846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9011),
  [3848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [3850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5726),
  [3852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [3854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9423),
  [3856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9423),
  [3858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [3860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5725),
  [3862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [3864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9577),
  [3866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9577),
  [3868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [3870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5747),
  [3872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [3874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9483),
  [3876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9483),
  [3878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9468),
  [3880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [3882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1145),
  [3884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5861),
  [3886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [3888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8942),
  [3890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8942),
  [3892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [3894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5719),
  [3896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [3898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9241),
  [3900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9241),
  [3902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1150),
  [3904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5885),
  [3906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [3908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9414),
  [3910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9414),
  [3912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0),
  [3914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(1037),
  [3917] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression_no_tag, 1, 0, 0),
  [3919] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8751),
  [3922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [3924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5729),
  [3926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3968),
  [3928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8969),
  [3930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8969),
  [3932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [3934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5746),
  [3936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3457),
  [3938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9463),
  [3940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9463),
  [3942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [3944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5731),
  [3946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [3948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8935),
  [3950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8935),
  [3952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [3954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5738),
  [3956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [3958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9472),
  [3960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9472),
  [3962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [3964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5730),
  [3966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [3968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9199),
  [3970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9199),
  [3972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [3974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5740),
  [3976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4817),
  [3978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9238),
  [3980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9238),
  [3982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1162),
  [3984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5748),
  [3986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [3988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9592),
  [3990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9592),
  [3992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1159),
  [3994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5750),
  [3996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [3998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8972),
  [4000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8972),
  [4002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [4004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5752),
  [4006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [4008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9047),
  [4010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9047),
  [4012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [4014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5846),
  [4016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [4018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8962),
  [4020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8962),
  [4022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [4024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5764),
  [4026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4735),
  [4028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9093),
  [4030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9093),
  [4032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [4034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5793),
  [4036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4731),
  [4038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9030),
  [4040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9030),
  [4042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [4044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5763),
  [4046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [4048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8967),
  [4050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8967),
  [4052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [4054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5797),
  [4056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3382),
  [4058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8994),
  [4060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8994),
  [4062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [4064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5809),
  [4066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3419),
  [4068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8970),
  [4070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8970),
  [4072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [4074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5796),
  [4076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4821),
  [4078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9383),
  [4080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9383),
  [4082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [4084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5818),
  [4086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3830),
  [4088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9091),
  [4090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9091),
  [4092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [4094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5822),
  [4096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3363),
  [4098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9282),
  [4100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9282),
  [4102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [4104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5813),
  [4106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4736),
  [4108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9015),
  [4110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9015),
  [4112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [4114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5824),
  [4116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3418),
  [4118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9358),
  [4120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9358),
  [4122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [4124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5830),
  [4126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [4128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9594),
  [4130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9594),
  [4132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [4134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5823),
  [4136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3401),
  [4138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9327),
  [4140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9327),
  [4142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [4144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5835),
  [4146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [4148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9405),
  [4150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9405),
  [4152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [4154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5843),
  [4156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [4158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9447),
  [4160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9447),
  [4162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [4164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5833),
  [4166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3227),
  [4168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9146),
  [4170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9146),
  [4172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [4174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5847),
  [4176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [4178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9012),
  [4180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9012),
  [4182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [4184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5853),
  [4186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [4188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9125),
  [4190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9125),
  [4192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1188),
  [4194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5722),
  [4196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [4198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9074),
  [4200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9074),
  [4202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [4204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5855),
  [4206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [4208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9213),
  [4210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9213),
  [4212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [4214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5864),
  [4216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [4218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9353),
  [4220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9353),
  [4222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [4224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5854),
  [4226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [4228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9189),
  [4230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9189),
  [4232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [4234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5869),
  [4236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [4238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9466),
  [4240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9466),
  [4242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [4244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5884),
  [4246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [4248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8947),
  [4250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8947),
  [4252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [4254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5867),
  [4256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [4258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9379),
  [4260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9379),
  [4262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [4264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5888),
  [4266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [4268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8985),
  [4270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8985),
  [4272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [4274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5896),
  [4276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4388),
  [4278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9042),
  [4280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9042),
  [4282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [4284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5886),
  [4286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [4288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8974),
  [4290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8974),
  [4292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [4294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5737),
  [4296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4389),
  [4298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9089),
  [4300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9089),
  [4302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [4304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5757),
  [4306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3834),
  [4308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9159),
  [4310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9159),
  [4312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [4314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5773),
  [4316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4391),
  [4318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9200),
  [4320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9200),
  [4322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [4324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5786),
  [4326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3837),
  [4328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9209),
  [4330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9209),
  [4332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [4334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5805),
  [4336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [4338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9232),
  [4340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9232),
  [4342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [4344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5806),
  [4346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3840),
  [4348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9247),
  [4350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9247),
  [4352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [4354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5811),
  [4356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [4358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9261),
  [4360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9261),
  [4362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [4364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5899),
  [4366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [4368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9291),
  [4370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9291),
  [4372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [4374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5900),
  [4376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [4378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9296),
  [4380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9296),
  [4382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [4384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5723),
  [4386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [4388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9303),
  [4390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9303),
  [4392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [4394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5727),
  [4396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [4398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9336),
  [4400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9336),
  [4402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [4404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5812),
  [4406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4465),
  [4408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8992),
  [4410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8992),
  [4412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [4414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5715),
  [4416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4909),
  [4418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8944),
  [4420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8944),
  [4422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5817),
  [4424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3936),
  [4426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9582),
  [4428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9582),
  [4430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [4432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5892),
  [4434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4610),
  [4436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9143),
  [4438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9143),
  [4440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [4442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5841),
  [4444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [4446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9377),
  [4448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9377),
  [4450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_continue_expression, 2, 0, 0),
  [4452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [4454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_continue_expression, 2, 0, 0),
  [4456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_clause, 3, 0, 0),
  [4458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [4460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_where_clause, 3, 0, 0),
  [4462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_type, 2, 0, 0),
  [4464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_type, 2, 0, 0),
  [4466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0),
  [4468] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1590),
  [4471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0),
  [4473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [4475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_type, 3, 0, 0),
  [4477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_type, 3, 0, 0),
  [4479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_clause, 2, 0, 0),
  [4481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [4483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_where_clause, 2, 0, 0),
  [4485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1967),
  [4487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1969),
  [4489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1970),
  [4491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1971),
  [4493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1972),
  [4495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [4497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1973),
  [4499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1974),
  [4501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1974),
  [4503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [4505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1976),
  [4507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1977),
  [4509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1978),
  [4511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1978),
  [4513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1979),
  [4515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [4517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1980),
  [4519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [4521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [4523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [4525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(819),
  [4527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [4529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5772),
  [4531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4845),
  [4533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9571),
  [4535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9571),
  [4537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [4539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5769),
  [4541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4843),
  [4543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9433),
  [4545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9433),
  [4547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [4549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5777),
  [4551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4860),
  [4553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9025),
  [4555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9025),
  [4557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [4559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5780),
  [4561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4042),
  [4563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9052),
  [4565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9052),
  [4567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [4569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5781),
  [4571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4043),
  [4573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9059),
  [4575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9059),
  [4577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 8, 0, 0),
  [4579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 8, 0, 0),
  [4581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [4583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [4585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 9, 0, 0),
  [4587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 9, 0, 0),
  [4589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [4591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [4593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5761),
  [4595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [4597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9096),
  [4599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9096),
  [4601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [4603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5878),
  [4605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [4607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9366),
  [4609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9366),
  [4611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [4613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5775),
  [4615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3717),
  [4617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9292),
  [4619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9292),
  [4621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1167),
  [4623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5762),
  [4625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4889),
  [4627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9588),
  [4629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9588),
  [4631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal, 2, 0, 0),
  [4633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal, 2, 0, 0),
  [4635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 5),
  [4637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 5),
  [4639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 9, 0, 0),
  [4641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 9, 0, 0),
  [4643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 9, 0, 62),
  [4645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 9, 0, 62),
  [4647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map, 10, 0, 0),
  [4649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_map, 10, 0, 0),
  [4651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_set, 10, 0, 61),
  [4653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_set, 10, 0, 61),
  [4655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 10, 0, 0),
  [4657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 10, 0, 0),
  [4659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 10, 0, 0),
  [4661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 10, 0, 0),
  [4663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map, 11, 0, 0),
  [4665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_map, 11, 0, 0),
  [4667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 11, 0, 0),
  [4669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 11, 0, 0),
  [4671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map, 12, 0, 0),
  [4673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_map, 12, 0, 0),
  [4675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 12, 0, 0),
  [4677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 12, 0, 0),
  [4679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [4681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [4683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [4685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 0),
  [4687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [4689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [4691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 0),
  [4693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal, 1, 0, 0),
  [4695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal, 1, 0, 0),
  [4697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [4699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [4701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4, 0, 0),
  [4703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4, 0, 0),
  [4705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 1, 0, 0),
  [4707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 1, 0, 0),
  [4709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 5, 0, 0),
  [4711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 5, 0, 0),
  [4713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 2, 0, 0),
  [4715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 2, 0, 0),
  [4717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__procedure_type, 1, 0, 1),
  [4719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__procedure_type, 1, 0, 1),
  [4721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2, 0, 0),
  [4723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 2, 0, 0),
  [4725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix_type, 7, 0, 0),
  [4727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix_type, 7, 0, 0),
  [4729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [4731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 2),
  [4733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 2),
  [4735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type, 6, 0, 0),
  [4737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type, 6, 0, 0),
  [4739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type, 6, 0, 30),
  [4741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type, 6, 0, 30),
  [4743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type, 6, 0, 0),
  [4745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type, 6, 0, 0),
  [4747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3, 0, 0),
  [4749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 3, 0, 0),
  [4751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map_type, 5, 0, 0),
  [4753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_map_type, 5, 0, 0),
  [4755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 3, 0, 0),
  [4757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 3, 0, 0),
  [4759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_set_type, 6, 0, 0),
  [4761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_set_type, 6, 0, 0),
  [4763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_expression, 3, 0, 0),
  [4765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_expression, 3, 0, 0),
  [4767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [4769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [4771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [4773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_continue_expression, 3, 0, 6),
  [4775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_continue_expression, 3, 0, 6),
  [4777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7602),
  [4779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7066),
  [4781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1577),
  [4783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2018),
  [4785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [4787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type, 7, 0, 0),
  [4789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type, 7, 0, 0),
  [4791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_break_expression, 3, 0, 0),
  [4793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_break_expression, 3, 0, 0),
  [4795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type, 7, 0, 30),
  [4797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type, 7, 0, 30),
  [4799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 4, 0, 0),
  [4801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 4, 0, 0),
  [4803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_type, 7, 0, 0),
  [4805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_type, 7, 0, 0),
  [4807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type, 8, 0, 0),
  [4809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type, 8, 0, 0),
  [4811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type, 8, 0, 30),
  [4813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type, 8, 0, 30),
  [4815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type, 9, 0, 30),
  [4817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type, 9, 0, 30),
  [4819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 4, 0, 0),
  [4821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 4, 0, 0),
  [4823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 4, 0, 10),
  [4825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 4, 0, 10),
  [4827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 4, 0, 0),
  [4829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 4, 0, 0),
  [4831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_expression, 4, 0, 0),
  [4833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_index_expression, 4, 0, 0),
  [4835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 5, 0, 0),
  [4837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 5, 0, 0),
  [4839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 3, 0, 0),
  [4841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_struct_type_repeat2, 3, 0, 0),
  [4843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 5, 0, 0),
  [4845] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 5, 0, 0),
  [4847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 5, 0, 9),
  [4849] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 5, 0, 9),
  [4851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 5, 0, 15),
  [4853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 5, 0, 15),
  [4855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_field_type, 9, 0, 0),
  [4857] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_field_type, 9, 0, 0),
  [4859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_field_type, 10, 0, 0),
  [4861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_field_type, 10, 0, 0),
  [4863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_field_type, 11, 0, 0),
  [4865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_field_type, 11, 0, 0),
  [4867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 5, 0, 17),
  [4869] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 5, 0, 17),
  [4871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 5, 0, 19),
  [4873] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 5, 0, 19),
  [4875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 5, 0, 20),
  [4877] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 5, 0, 20),
  [4879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 5, 0, 21),
  [4881] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ternary_expression, 5, 0, 21),
  [4883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 6, 0, 0),
  [4885] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 6, 0, 0),
  [4887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_set, 6, 0, 0),
  [4889] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_set, 6, 0, 0),
  [4891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 6, 0, 9),
  [4893] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 6, 0, 9),
  [4895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1600),
  [4897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [4899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [4901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 6, 0, 15),
  [4903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 6, 0, 15),
  [4905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, 0, 4),
  [4907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, 0, 4),
  [4909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 2, 0, 0),
  [4911] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 2, 0, 0),
  [4913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_selector_call_expression, 3, 0, 4),
  [4915] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_selector_call_expression, 3, 0, 4),
  [4917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 6, 0, 17),
  [4919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 6, 0, 17),
  [4921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 2, 0, 0),
  [4923] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 2, 0, 0),
  [4925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_expression, 2, 0, 0),
  [4927] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variadic_expression, 2, 0, 0),
  [4929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 4, 0, 0),
  [4931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 4, 0, 0),
  [4933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_character, 3, 0, 0),
  [4935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_character, 3, 0, 0),
  [4937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_set, 9, 0, 61),
  [4939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_set, 9, 0, 61),
  [4941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_return_expression, 2, 0, 0),
  [4943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_return_expression, 2, 0, 0),
  [4945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_type, 2, 0, 0),
  [4947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variadic_type, 2, 0, 0),
  [4949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure, 10, 0, 0),
  [4951] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_procedure, 10, 0, 0),
  [4953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_empty_type, 1, 0, 0),
  [4955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_empty_type, 1, 0, 0),
  [4957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 5, 0, 0),
  [4959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 5, 0, 0),
  [4961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_distinct_type, 2, 0, 0),
  [4963] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_distinct_type, 2, 0, 0),
  [4965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 6, 0, 31),
  [4967] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 6, 0, 31),
  [4969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_expression, 6, 0, 0),
  [4971] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_index_expression, 6, 0, 0),
  [4973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 6, 0, 32),
  [4975] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 6, 0, 32),
  [4977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2359),
  [4979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [4981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 7, 0, 0),
  [4983] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 7, 0, 0),
  [4985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map, 7, 0, 0),
  [4987] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_map, 7, 0, 0),
  [4989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 2, 0, 0),
  [4991] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 2, 0, 0),
  [4993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5717),
  [4995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5543),
  [4997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9197),
  [4999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9197),
  [5001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constant_type, 2, 0, 0),
  [5003] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constant_type, 2, 0, 0),
  [5005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_type, 3, 0, 0),
  [5007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6622),
  [5009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_named_type, 3, 0, 0),
  [5011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_distinct_type, 3, 0, 0),
  [5013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_distinct_type, 3, 0, 0),
  [5015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_address, 2, 0, 0),
  [5017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_address, 2, 0, 0),
  [5019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_set, 7, 0, 0),
  [5021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_set, 7, 0, 0),
  [5023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_type, 5, 0, 0),
  [5025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_named_type, 5, 0, 0),
  [5027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 3, 0, 0),
  [5029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 3, 0, 0),
  [5031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 7, 0, 9),
  [5033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 7, 0, 9),
  [5035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [5037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [5039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [5041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [5043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 7, 0, 46),
  [5045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 7, 0, 46),
  [5047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 7, 0, 17),
  [5049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 7, 0, 17),
  [5051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 7, 0, 31),
  [5053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 7, 0, 31),
  [5055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 6, 0, 0),
  [5057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 6, 0, 0),
  [5059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_type, 5, 0, 0),
  [5061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_type, 5, 0, 0),
  [5063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 8, 0, 0),
  [5065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 8, 0, 0),
  [5067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_in_expression, 3, 0, 0),
  [5069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_in_expression, 3, 0, 0),
  [5071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1968),
  [5073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_set, 8, 0, 61),
  [5075] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_set, 8, 0, 61),
  [5077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_set, 8, 0, 0),
  [5079] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_set, 8, 0, 0),
  [5081] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), REDUCE(sym_array_type, 6, 0, 0),
  [5084] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 5, 0, 0), REDUCE(sym_array_type, 6, 0, 0),
  [5087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5825),
  [5089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5470),
  [5091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8932),
  [5093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8932),
  [5095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type, 2, 0, 0),
  [5097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type, 2, 0, 0),
  [5099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 8, 0, 46),
  [5101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 8, 0, 46),
  [5103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_specialized_type, 3, 0, 0),
  [5105] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_specialized_type, 3, 0, 0),
  [5107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [5109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(104),
  [5111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 8, 0, 17),
  [5113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 8, 0, 17),
  [5115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 8, 0, 62),
  [5117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 8, 0, 62),
  [5119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal, 3, 0, 0),
  [5121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal, 3, 0, 0),
  [5123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 9, 0, 0),
  [5125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct, 9, 0, 0),
  [5127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type, 4, 0, 0),
  [5129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type, 4, 0, 0),
  [5131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type, 4, 0, 0),
  [5133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type, 4, 0, 0),
  [5135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [5137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [5139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_set_type, 4, 0, 0),
  [5141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bit_set_type, 4, 0, 0),
  [5143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1389),
  [5145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__raw_string_literal, 3, 0, 0),
  [5147] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__raw_string_literal, 3, 0, 0),
  [5149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5857),
  [5151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5572),
  [5153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9304),
  [5155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9304),
  [5157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5859),
  [5159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5578),
  [5161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9317),
  [5163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9317),
  [5165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5862),
  [5167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5584),
  [5169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9330),
  [5171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9330),
  [5173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5865),
  [5175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5589),
  [5177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9343),
  [5179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9343),
  [5181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5868),
  [5183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5595),
  [5185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9356),
  [5187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9356),
  [5189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5870),
  [5191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5601),
  [5193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9369),
  [5195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9369),
  [5197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5874),
  [5199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5606),
  [5201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9380),
  [5203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9380),
  [5205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5876),
  [5207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5610),
  [5209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9391),
  [5211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9391),
  [5213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5877),
  [5215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5613),
  [5217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9402),
  [5219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9402),
  [5221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5882),
  [5223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5616),
  [5225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9413),
  [5227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9413),
  [5229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5883),
  [5231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5620),
  [5233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9424),
  [5235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9424),
  [5237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_type, 4, 0, 0),
  [5239] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_polymorphic_type, 4, 0, 0),
  [5241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type, 5, 0, 0),
  [5243] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type, 5, 0, 0),
  [5245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_type, 5, 0, 30),
  [5247] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_type, 5, 0, 30),
  [5249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type, 5, 0, 0),
  [5251] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type, 5, 0, 0),
  [5253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 5, 0, 0),
  [5255] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 5, 0, 0),
  [5257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__raw_string_literal, 2, 0, 0),
  [5259] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__raw_string_literal, 2, 0, 0),
  [5261] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9072),
  [5264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5736),
  [5266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9586),
  [5268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9586),
  [5270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4167),
  [5272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5223),
  [5274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5828),
  [5276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9381),
  [5278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9381),
  [5280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [5282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4056),
  [5284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [5286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4216),
  [5288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4078),
  [5290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [5292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4168),
  [5294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9072),
  [5296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [5298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4222),
  [5300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4109),
  [5302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4100),
  [5304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4041),
  [5306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4070),
  [5308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4018),
  [5310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4029),
  [5312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4057),
  [5314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4150),
  [5316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4235),
  [5318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4094),
  [5320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4101),
  [5322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [5324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4808),
  [5326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4837),
  [5328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4877),
  [5330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4891),
  [5332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4759),
  [5334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4772),
  [5336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4786),
  [5338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4792),
  [5340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4799),
  [5342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [5344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2732),
  [5346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2457),
  [5348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2238),
  [5350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2220),
  [5352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [5354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2262),
  [5356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2380),
  [5358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2487),
  [5360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2383),
  [5362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2237),
  [5364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4541),
  [5366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2718),
  [5368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2736),
  [5370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2668),
  [5372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2720),
  [5374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2765),
  [5376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2677),
  [5378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4257),
  [5380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2689),
  [5382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [5384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2698),
  [5386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2371),
  [5388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4576),
  [5390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4607),
  [5392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4624),
  [5394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4668),
  [5396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4560),
  [5398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4644),
  [5400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4670),
  [5402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4515),
  [5404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [5406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2867),
  [5408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2902),
  [5410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2909),
  [5412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2920),
  [5414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2931),
  [5416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2942),
  [5418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [5420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2948),
  [5422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2859),
  [5424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3110),
  [5426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3149),
  [5428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3057),
  [5430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3071),
  [5432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3103),
  [5434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3127),
  [5436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3143),
  [5438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3192),
  [5440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3019),
  [5442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3398),
  [5444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3241),
  [5446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3305),
  [5448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3332),
  [5450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3359),
  [5452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3392),
  [5454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3409),
  [5456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3427),
  [5458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3316),
  [5460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3585),
  [5462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3611),
  [5464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3661),
  [5466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3678),
  [5468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3624),
  [5470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3538),
  [5472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3549),
  [5474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3555),
  [5476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3563),
  [5478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [5480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [5482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [5484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [5486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [5488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [5490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [5492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [5494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [5496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2485),
  [5498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2263),
  [5500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2423),
  [5502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2499),
  [5504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2236),
  [5506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2271),
  [5508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2302),
  [5510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2319),
  [5512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2347),
  [5514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4419),
  [5516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4431),
  [5518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4462),
  [5520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4470),
  [5522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4483),
  [5524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4494),
  [5526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4503),
  [5528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4270),
  [5530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4277),
  [5532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5760),
  [5534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9240),
  [5536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9240),
  [5538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5791),
  [5540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9446),
  [5542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9446),
  [5544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5866),
  [5546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9339),
  [5548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9339),
  [5550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5873),
  [5552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9226),
  [5554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9226),
  [5556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5779),
  [5558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9438),
  [5560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9438),
  [5562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5790),
  [5564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9273),
  [5566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9273),
  [5568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5851),
  [5570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9079),
  [5572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9079),
  [5574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5720),
  [5576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9038),
  [5578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9038),
  [5580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5829),
  [5582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9158),
  [5584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9158),
  [5586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5872),
  [5588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9374),
  [5590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9374),
  [5592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5749),
  [5594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9479),
  [5596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9479),
  [5598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5816),
  [5600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9322),
  [5602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9322),
  [5604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5744),
  [5606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9370),
  [5608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9370),
  [5610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5716),
  [5612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9350),
  [5614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9350),
  [5616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5724),
  [5618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9576),
  [5620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9576),
  [5622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5810),
  [5624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8978),
  [5626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8978),
  [5628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5858),
  [5630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9007),
  [5632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9007),
  [5634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5765),
  [5636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9271),
  [5638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9271),
  [5640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5789),
  [5642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9286),
  [5644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9286),
  [5646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5758),
  [5648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9539),
  [5650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9539),
  [5652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5767),
  [5654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9590),
  [5656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9590),
  [5658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5891),
  [5660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9318),
  [5662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9318),
  [5664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5898),
  [5666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8934),
  [5668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8934),
  [5670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5732),
  [5672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9017),
  [5674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9017),
  [5676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5733),
  [5678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9154),
  [5680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9154),
  [5682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5741),
  [5684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9401),
  [5686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9401),
  [5688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5743),
  [5690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8998),
  [5692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8998),
  [5694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5754),
  [5696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9198),
  [5698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9198),
  [5700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5755),
  [5702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9235),
  [5704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9235),
  [5706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5774),
  [5708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9000),
  [5710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9000),
  [5712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5776),
  [5714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8951),
  [5716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8951),
  [5718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5800),
  [5720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9180),
  [5722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9180),
  [5724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5801),
  [5726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9295),
  [5728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9295),
  [5730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5819),
  [5732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9162),
  [5734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9162),
  [5736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5821),
  [5738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9229),
  [5740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9229),
  [5742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5826),
  [5744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9372),
  [5746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9372),
  [5748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5827),
  [5750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9409),
  [5752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9409),
  [5754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5837),
  [5756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9106),
  [5758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9106),
  [5760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5839),
  [5762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9201),
  [5764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9201),
  [5766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5849),
  [5768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9041),
  [5770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9041),
  [5772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5850),
  [5774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9062),
  [5776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9062),
  [5778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5856),
  [5780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9253),
  [5782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9253),
  [5784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5860),
  [5786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9287),
  [5788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9287),
  [5790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5871),
  [5792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9545),
  [5794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9545),
  [5796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5875),
  [5798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9601),
  [5800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9601),
  [5802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5889),
  [5804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8991),
  [5806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8991),
  [5808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5890),
  [5810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9013),
  [5812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9013),
  [5814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5799),
  [5816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9115),
  [5818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9115),
  [5820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5863),
  [5822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9135),
  [5824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9135),
  [5826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5788),
  [5828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9216),
  [5830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9216),
  [5832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5792),
  [5834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9222),
  [5836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9222),
  [5838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5820),
  [5840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9268),
  [5842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9268),
  [5844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5832),
  [5846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9272),
  [5848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9272),
  [5850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5815),
  [5852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9610),
  [5854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9610),
  [5856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5718),
  [5858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9325),
  [5860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9325),
  [5862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5728),
  [5864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9351),
  [5866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9351),
  [5868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5734),
  [5870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9371),
  [5872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9371),
  [5874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5768),
  [5876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9396),
  [5878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9396),
  [5880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5778),
  [5882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9036),
  [5884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9036),
  [5886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5783),
  [5888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9078),
  [5890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9078),
  [5892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5784),
  [5894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9092),
  [5896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9092),
  [5898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5848),
  [5900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9533),
  [5902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9533),
  [5904] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9142),
  [5907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4226),
  [5909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7339),
  [5911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4166),
  [5913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4175),
  [5915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7227),
  [5917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9580),
  [5919] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9580),
  [5922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4146),
  [5924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4077),
  [5926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4154),
  [5928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4203),
  [5930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7423),
  [5932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4244),
  [5934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4084),
  [5936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4023),
  [5938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [5940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4074),
  [5942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4099),
  [5944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4110),
  [5946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4204),
  [5948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4036),
  [5950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4160),
  [5952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4888),
  [5954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4756),
  [5956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4760),
  [5958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4773),
  [5960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4787),
  [5962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4800),
  [5964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4801),
  [5966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4802),
  [5968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4803),
  [5970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [5972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5129),
  [5974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [5976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2503),
  [5978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [5980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5144),
  [5982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2228),
  [5984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [5986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [5988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5372),
  [5990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2277),
  [5992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [5994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2293),
  [5996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [5998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [6000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2370),
  [6002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [6004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1535),
  [6006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [6008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1536),
  [6010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2301),
  [6012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2435),
  [6014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2266),
  [6016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2212),
  [6018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2489),
  [6020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2216),
  [6022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2241),
  [6024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2245),
  [6026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2249),
  [6028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2251),
  [6030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2697),
  [6032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2716),
  [6034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2721),
  [6036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2766),
  [6038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2680),
  [6040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2700),
  [6042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2701),
  [6044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2703),
  [6046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2704),
  [6048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4622),
  [6050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4687),
  [6052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4549),
  [6054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4574),
  [6056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4645),
  [6058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4682),
  [6060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4521),
  [6062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4522),
  [6064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4532),
  [6066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4535),
  [6068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2907),
  [6070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2916),
  [6072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2921),
  [6074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2932),
  [6076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2943),
  [6078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2950),
  [6080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2883),
  [6082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2810),
  [6084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [6086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2829),
  [6088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3068),
  [6090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3085),
  [6092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7085),
  [6094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3105),
  [6096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3128),
  [6098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3144),
  [6100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3204),
  [6102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3020),
  [6104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3021),
  [6106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3022),
  [6108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3023),
  [6110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3329),
  [6112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3352),
  [6114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9142),
  [6116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3393),
  [6118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3410),
  [6120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3429),
  [6122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3210),
  [6124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3211),
  [6126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3213),
  [6128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3215),
  [6130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3676),
  [6132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3699),
  [6134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3525),
  [6136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3539),
  [6138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3550),
  [6140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3557),
  [6142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3564),
  [6144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3565),
  [6146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3566),
  [6148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3567),
  [6150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [6152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [6154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [6156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [6158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [6160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [6162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4046),
  [6164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [6166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [6168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [6170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [6172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [6174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5104),
  [6176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2608),
  [6178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2549),
  [6180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2480),
  [6182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5111),
  [6184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2616),
  [6186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2553),
  [6188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2224),
  [6190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2242),
  [6192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2273),
  [6194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2303),
  [6196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5697),
  [6198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2321),
  [6200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2625),
  [6202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [6204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2350),
  [6206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2351),
  [6208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2355),
  [6210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2360),
  [6212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4468),
  [6214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2634),
  [6216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [6218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4478),
  [6220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2557),
  [6222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4484),
  [6224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4495),
  [6226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4266),
  [6228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4272),
  [6230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4278),
  [6232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4279),
  [6234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4280),
  [6236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4281),
  [6238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7423),
  [6241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2667),
  [6243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1430),
  [6245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [6247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2558),
  [6249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2639),
  [6251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2559),
  [6253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [6255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [6257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [6259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [6261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [6263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [6265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [6267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [6269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [6271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [6273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1412),
  [6275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [6277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4225),
  [6279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7111),
  [6281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [6283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8703),
  [6286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4170),
  [6288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7217),
  [6290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3360),
  [6292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2124),
  [6294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2165),
  [6296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2415),
  [6298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1880),
  [6300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [6302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [6304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5927),
  [6306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6211),
  [6308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [6310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [6312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2401),
  [6314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [6316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2407),
  [6318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5907),
  [6320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6209),
  [6322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1815),
  [6324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5914),
  [6326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6166),
  [6328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4737),
  [6330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5957),
  [6332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6194),
  [6334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3668),
  [6336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5903),
  [6338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6152),
  [6340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3682),
  [6342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [6344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5930),
  [6346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6163),
  [6348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1959),
  [6350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [6352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5952),
  [6354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6179),
  [6356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5905),
  [6358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6185),
  [6360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [6362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2548),
  [6364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5533),
  [6366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5911),
  [6368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6192),
  [6370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4386),
  [6372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5916),
  [6374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6197),
  [6376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5920),
  [6378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6203),
  [6380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [6382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5918),
  [6384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [6386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1605),
  [6389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [6391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [6393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1675),
  [6395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1689),
  [6397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1965),
  [6399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2014),
  [6401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1453),
  [6403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1453),
  [6405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1457),
  [6407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1464),
  [6409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [6411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [6413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1469),
  [6415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1472),
  [6417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1477),
  [6419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [6421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1478),
  [6423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [6425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [6427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2482),
  [6429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [6431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [6433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2230),
  [6435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [6437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5955),
  [6439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6159),
  [6441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4681),
  [6443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2061),
  [6445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9504),
  [6447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [6449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5963),
  [6451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5904),
  [6453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6207),
  [6455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5933),
  [6457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6182),
  [6459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4723),
  [6461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7481),
  [6464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [6466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3913),
  [6468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2381),
  [6470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9337),
  [6472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [6474] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(1049),
  [6477] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8762),
  [6480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [6482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [6484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2641),
  [6486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2560),
  [6488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [6490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2160),
  [6492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2161),
  [6494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [6496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5682),
  [6498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6626),
  [6500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [6502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4996),
  [6504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2831),
  [6506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2663),
  [6508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5122),
  [6510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2818),
  [6512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2602),
  [6514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2936),
  [6516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2363),
  [6518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2881),
  [6520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2366),
  [6522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2611),
  [6524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2856),
  [6526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2367),
  [6528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2615),
  [6530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2879),
  [6532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2617),
  [6534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [6536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2081),
  [6538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2155),
  [6540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1432),
  [6542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2156),
  [6544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2145),
  [6546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2146),
  [6548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2147),
  [6550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2152),
  [6552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2153),
  [6554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2154),
  [6556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2154),
  [6558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2143),
  [6560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2144),
  [6562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2148),
  [6564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2148),
  [6566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2149),
  [6568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2150),
  [6570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [6572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2151),
  [6574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2414),
  [6576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2138),
  [6578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [6580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2436),
  [6582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [6584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1875),
  [6586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1876),
  [6588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [6590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [6592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9214),
  [6595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6955),
  [6597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4952),
  [6599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3926),
  [6601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [6603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5188),
  [6605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5531),
  [6607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9354),
  [6609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9605),
  [6611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9501),
  [6613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5222),
  [6615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9257),
  [6617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [6619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9214),
  [6621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [6623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2643),
  [6625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1750),
  [6627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [6629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [6631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2122),
  [6633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2125),
  [6635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2126),
  [6637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2133),
  [6639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2134),
  [6641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2135),
  [6643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2135),
  [6645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2136),
  [6647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2137),
  [6649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2086),
  [6651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2132),
  [6653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2128),
  [6655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2128),
  [6657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2130),
  [6659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2131),
  [6661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2131),
  [6663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [6665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2091),
  [6667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2606),
  [6669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2826),
  [6671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2626),
  [6673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7501),
  [6676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [6678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5324),
  [6680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2735),
  [6682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [6684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9123),
  [6686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [6688] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(961),
  [6691] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8714),
  [6694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7501),
  [6696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9420),
  [6698] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9420),
  [6701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_in_expression, 3, 0, 0),
  [6703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [6705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2041),
  [6707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2042),
  [6709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2043),
  [6711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2044),
  [6713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2045),
  [6715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2046),
  [6717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2046),
  [6719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2047),
  [6721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2048),
  [6723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2048),
  [6725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2049),
  [6727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2050),
  [6729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2051),
  [6731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2052),
  [6733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2052),
  [6735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2053),
  [6737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [6739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2054),
  [6741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2715),
  [6743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2623),
  [6745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [6747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2717),
  [6749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [6751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [6753] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8725),
  [6756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [6758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2092),
  [6760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2093),
  [6762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1552),
  [6764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1572),
  [6766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1576),
  [6768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1582),
  [6770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1583),
  [6772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1584),
  [6774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [6776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1586),
  [6778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [6780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2900),
  [6782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [6784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [6786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [6788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1574),
  [6790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1569),
  [6792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [6794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1578),
  [6796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [6798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1579),
  [6800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1580),
  [6802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [6804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [6806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [6808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9026),
  [6810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [6812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1350),
  [6814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [6816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [6818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9020),
  [6820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [6822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [6824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(946),
  [6826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5458),
  [6828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [6830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [6832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [6834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [6836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [6838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2544),
  [6840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5181),
  [6842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [6844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1784),
  [6846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [6848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [6850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [6852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1753),
  [6854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1754),
  [6856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1755),
  [6858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1756),
  [6860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1757),
  [6862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1757),
  [6864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1768),
  [6866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1769),
  [6868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [6870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [6872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1771),
  [6874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1772),
  [6876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1773),
  [6878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [6880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2865),
  [6882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [6884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [6886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2866),
  [6888] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9020),
  [6891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [6893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [6895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [6897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2099),
  [6899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2099),
  [6901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [6903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [6905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [6907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [6909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [6911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3730),
  [6913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3477),
  [6915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [6917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3185),
  [6919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2975),
  [6921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3179),
  [6923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2538),
  [6925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5207),
  [6927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3732),
  [6929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2999),
  [6931] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9585),
  [6934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3014),
  [6936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3790),
  [6938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2957),
  [6940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [6942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [6944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [6946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3408),
  [6948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3006),
  [6950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [6952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [6954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3200),
  [6956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2976),
  [6958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3388),
  [6960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3172),
  [6962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3000),
  [6964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5036),
  [6966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3749),
  [6968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3446),
  [6970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3495),
  [6972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3195),
  [6974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2969),
  [6976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3203),
  [6978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2973),
  [6980] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(1001),
  [6983] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8731),
  [6986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5156),
  [6988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3155),
  [6990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2995),
  [6992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5076),
  [6994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3163),
  [6996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2959),
  [6998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2984),
  [7000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2992),
  [7002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2988),
  [7004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5045),
  [7006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3769),
  [7008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [7010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3133),
  [7012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5033),
  [7014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3306),
  [7016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3156),
  [7018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5001),
  [7020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3334),
  [7022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3160),
  [7024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5226),
  [7026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3175),
  [7028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2542),
  [7030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5497),
  [7032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9585),
  [7034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3356),
  [7036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2970),
  [7038] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7482),
  [7041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3715),
  [7043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3482),
  [7045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [7047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3425),
  [7049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3176),
  [7051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5445),
  [7053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2968),
  [7055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9040),
  [7057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [7059] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(1013),
  [7062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8736),
  [7065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3914),
  [7067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3038),
  [7069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [7071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [7073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1881),
  [7075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1892),
  [7077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1892),
  [7079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1893),
  [7081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1894),
  [7083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1895),
  [7085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [7087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1904),
  [7089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1904),
  [7091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1905),
  [7093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1906),
  [7095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1907),
  [7097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1908),
  [7099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1908),
  [7101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1909),
  [7103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1438),
  [7105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1913),
  [7107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3232),
  [7109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3033),
  [7111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [7113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3239),
  [7115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3303),
  [7117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3805),
  [7119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3048),
  [7121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3520),
  [7123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3962),
  [7125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3052),
  [7127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3508),
  [7129] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1502),
  [7132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3906),
  [7134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3440),
  [7136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field, 1, 0, 0),
  [7138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [7140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [7142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4217),
  [7144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [7146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1718),
  [7148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [7150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4997),
  [7152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3984),
  [7154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3506),
  [7156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5146),
  [7158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3992),
  [7160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3454),
  [7162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1547),
  [7164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1547),
  [7167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3985),
  [7169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3074),
  [7171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9324),
  [7173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [7175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3963),
  [7177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3077),
  [7179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3494),
  [7181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3989),
  [7183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3080),
  [7185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3510),
  [7187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3857),
  [7189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3490),
  [7191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [7193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5158),
  [7195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3933),
  [7197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3578),
  [7199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5082),
  [7201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3848),
  [7203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3579),
  [7205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3819),
  [7207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3092),
  [7209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3854),
  [7211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3095),
  [7213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3586),
  [7215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3897),
  [7217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3097),
  [7219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3589),
  [7221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3978),
  [7223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3590),
  [7225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [7227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1816),
  [7229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1818),
  [7231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1818),
  [7233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1829),
  [7235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1830),
  [7237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1831),
  [7239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [7241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1833),
  [7243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [7245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1834),
  [7247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [7249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [7251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1847),
  [7253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1847),
  [7255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1848),
  [7257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1437),
  [7259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1849),
  [7261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3142),
  [7263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3145),
  [7265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [7267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3147),
  [7269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5030),
  [7271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3987),
  [7273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3504),
  [7275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5253),
  [7277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9427),
  [7279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3056),
  [7281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7442),
  [7284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3162),
  [7286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3433),
  [7288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3178),
  [7290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3209),
  [7292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5085),
  [7294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3883),
  [7296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3466),
  [7298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3958),
  [7300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3483),
  [7302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6805),
  [7304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5438),
  [7306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3307),
  [7308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [7310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5214),
  [7312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5625),
  [7314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9132),
  [7316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9449),
  [7318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5431),
  [7320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(8971),
  [7323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6811),
  [7325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5501),
  [7327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3603),
  [7329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [7331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5391),
  [7333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5635),
  [7335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9136),
  [7337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9450),
  [7339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5499),
  [7341] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(8986),
  [7345] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(8971),
  [7349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(8986),
  [7352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6624),
  [7354] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(8986),
  [7357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [7359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5011),
  [7361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [7363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3576),
  [7365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3499),
  [7367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5012),
  [7369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3582),
  [7371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3502),
  [7373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2547),
  [7375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5219),
  [7377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3588),
  [7379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3254),
  [7381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3594),
  [7383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3257),
  [7385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3513),
  [7387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3597),
  [7389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3258),
  [7391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3517),
  [7393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3598),
  [7395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3518),
  [7397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(8971),
  [7400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3448),
  [7402] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(8986),
  [7406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [7408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [7410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3496),
  [7412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1891),
  [7414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3763),
  [7416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3442),
  [7418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1072),
  [7420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1817),
  [7422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [7424] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(8986),
  [7427] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9427),
  [7430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6623),
  [7432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3458),
  [7434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [7436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1828),
  [7438] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(8986),
  [7441] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(8971),
  [7445] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(8971),
  [7449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3941),
  [7451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3445),
  [7453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1369),
  [7455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(8971),
  [7458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4126),
  [7460] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(8986),
  [7464] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(8971),
  [7467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [7469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4292),
  [7471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3487),
  [7473] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7415),
  [7476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3774),
  [7478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9260),
  [7480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [7482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3929),
  [7484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(1025),
  [7487] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8742),
  [7490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9032),
  [7492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [7494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5007),
  [7496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4669),
  [7498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3948),
  [7500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5008),
  [7502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4650),
  [7504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3967),
  [7506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3580),
  [7508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4511),
  [7510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3468),
  [7512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6775),
  [7514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5526),
  [7516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3121),
  [7518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [7520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5224),
  [7522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5355),
  [7524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9002),
  [7526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9395),
  [7528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5542),
  [7530] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(8973),
  [7533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [7535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [7537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1932),
  [7539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1934),
  [7541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1934),
  [7543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1938),
  [7545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1939),
  [7547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [7549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [7551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1942),
  [7553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1942),
  [7555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1943),
  [7557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1944),
  [7559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1945),
  [7561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [7563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1946),
  [7565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1947),
  [7567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [7569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [7571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3608),
  [7573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3514),
  [7575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [7577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3610),
  [7579] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(8973),
  [7583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4520),
  [7585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3492),
  [7587] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(8973),
  [7590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3825),
  [7592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5052),
  [7594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4285),
  [7596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3944),
  [7598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5087),
  [7600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4287),
  [7602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3946),
  [7604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4528),
  [7606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [7608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_overloaded_procedure_declaration_repeat1, 2, 0, 0),
  [7610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_overloaded_procedure_declaration_repeat1, 2, 0, 0),
  [7612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4290),
  [7614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3484),
  [7616] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(8973),
  [7620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3812),
  [7622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3956),
  [7624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4293),
  [7626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3489),
  [7628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3960),
  [7630] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(8973),
  [7634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4294),
  [7636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3961),
  [7638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3969),
  [7640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1616),
  [7643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4531),
  [7645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [7647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4013),
  [7649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3595),
  [7651] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(8973),
  [7654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3505),
  [7656] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9032),
  [7659] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7413),
  [7662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3656),
  [7664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3599),
  [7666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3521),
  [7668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3600),
  [7670] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(8973),
  [7673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9193),
  [7676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9193),
  [7678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [7680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7374),
  [7683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7374),
  [7685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7413),
  [7687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [7689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [7691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4005),
  [7693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9027),
  [7695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9305),
  [7697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1933),
  [7699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6625),
  [7701] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9305),
  [7704] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9027),
  [7707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [7709] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8780),
  [7712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5174),
  [7714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3924),
  [7716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [7718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5231),
  [7720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5544),
  [7722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9182),
  [7724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9464),
  [7726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5172),
  [7728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9196),
  [7730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4534),
  [7732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3856),
  [7734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [7736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5204),
  [7738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3953),
  [7740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [7742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8914),
  [7745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4295),
  [7747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3973),
  [7749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4002),
  [7751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5258),
  [7753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9606),
  [7755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6787),
  [7757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5574),
  [7759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3852),
  [7761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [7763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5209),
  [7765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5508),
  [7767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9065),
  [7769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9428),
  [7771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5247),
  [7773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9288),
  [7775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [7777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9264),
  [7779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9308),
  [7781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [7783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4250),
  [7785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [7787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [7789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5353),
  [7791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6765),
  [7793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5603),
  [7795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4336),
  [7797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [7799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5417),
  [7801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5168),
  [7803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9163),
  [7805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9457),
  [7807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5592),
  [7809] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(9051),
  [7812] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(9051),
  [7816] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(9051),
  [7820] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(9051),
  [7823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(9051),
  [7826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [7828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4138),
  [7830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9311),
  [7832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [7834] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(9051),
  [7837] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(9051),
  [7841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4537),
  [7843] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9606),
  [7846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [7848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5016),
  [7850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [7852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4302),
  [7854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4143),
  [7856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1449),
  [7858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5017),
  [7860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4304),
  [7862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4153),
  [7864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2554),
  [7866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5243),
  [7868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4310),
  [7870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3877),
  [7872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4316),
  [7874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3898),
  [7876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4165),
  [7878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4323),
  [7880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3899),
  [7882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [7884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4177),
  [7886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4327),
  [7888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4178),
  [7890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5311),
  [7892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8933),
  [7894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [7896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4296),
  [7898] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8933),
  [7901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9444),
  [7903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [7905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [7907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1721),
  [7909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9130),
  [7911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [7913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5321),
  [7915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7520),
  [7917] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7528),
  [7920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6779),
  [7922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5552),
  [7924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [7926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5522),
  [7928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5554),
  [7930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9128),
  [7932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9448),
  [7934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5553),
  [7936] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(9242),
  [7939] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(9242),
  [7943] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(9242),
  [7947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [7949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1496),
  [7951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [7953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1555),
  [7955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1592),
  [7957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1598),
  [7959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [7961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1684),
  [7963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1787),
  [7965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [7967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1801),
  [7969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [7971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [7973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [7975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1862),
  [7977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1915),
  [7979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [7981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1923),
  [7983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4131),
  [7985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3845),
  [7987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [7989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4024),
  [7991] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(9242),
  [7994] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(9242),
  [7997] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(9242),
  [8001] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(9242),
  [8004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [8006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1509),
  [8008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [8010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1510),
  [8012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4999),
  [8014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2082),
  [8016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5034),
  [8018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5307),
  [8020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4065),
  [8022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4068),
  [8024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4069),
  [8026] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1665),
  [8029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8945),
  [8031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [8033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(1061),
  [8036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8771),
  [8039] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9130),
  [8042] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat2, 2, 0, 0), SHIFT_REPEAT(7520),
  [8045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2533),
  [8047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5354),
  [8049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1494),
  [8051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1498),
  [8053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1498),
  [8055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1499),
  [8057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1500),
  [8059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1501),
  [8061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [8063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1504),
  [8065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1504),
  [8067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [8069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [8071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [8073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [8075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1508),
  [8077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4256),
  [8079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3816),
  [8081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [8083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4033),
  [8085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4460),
  [8087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4893),
  [8089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5302),
  [8091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1545),
  [8093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [8095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [8097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1626),
  [8099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [8101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1632),
  [8103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1636),
  [8105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1638),
  [8107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1642),
  [8109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [8111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1647),
  [8113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [8115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [8117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [8119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [8121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [8123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1652),
  [8125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1653),
  [8127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [8129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [8131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4428),
  [8133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4095),
  [8135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [8137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4430),
  [8139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [8141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4162),
  [8143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 3, 0, 0),
  [8145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4330),
  [8147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4182),
  [8149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4333),
  [8151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1952),
  [8153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1955),
  [8155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [8157] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8721),
  [8160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [8162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [8164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2552),
  [8166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5205),
  [8168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [8170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [8172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1890),
  [8174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6797),
  [8176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5295),
  [8178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [8180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5286),
  [8182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5166),
  [8184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9160),
  [8186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9456),
  [8188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5296),
  [8190] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(9037),
  [8193] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(9037),
  [8197] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(9037),
  [8201] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(9037),
  [8204] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(9037),
  [8207] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(9037),
  [8210] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(9037),
  [8214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [8216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4892),
  [8218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2113),
  [8220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [8222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [8224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9105),
  [8226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [8228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4600),
  [8230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6627),
  [8232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [8234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2083),
  [8236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2083),
  [8239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2062),
  [8241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [8243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2064),
  [8245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2065),
  [8247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2066),
  [8249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2067),
  [8251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2067),
  [8253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2068),
  [8255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2069),
  [8257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2069),
  [8259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [8261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [8263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2072),
  [8265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [8267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2073),
  [8269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2074),
  [8271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2075),
  [8273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3142),
  [8275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3145),
  [8277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [8279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [8281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [8283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1623),
  [8285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [8287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [8289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1643),
  [8291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1644),
  [8293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1434),
  [8295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [8297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [8299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [8301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [8303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6773),
  [8305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5246),
  [8307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3767),
  [8309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [8311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5194),
  [8313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5677),
  [8315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9429),
  [8317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9334),
  [8319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5245),
  [8321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9531),
  [8323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2537),
  [8325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5498),
  [8327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1628),
  [8329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1629),
  [8331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [8333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1619),
  [8335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [8337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [8339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [8341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1635),
  [8343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [8345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [8347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4573),
  [8349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4414),
  [8351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [8353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4575),
  [8355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2063),
  [8357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [8359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2095),
  [8361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2096),
  [8363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1988),
  [8365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1989),
  [8367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1991),
  [8369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1991),
  [8371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1992),
  [8373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1993),
  [8375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1997),
  [8377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1998),
  [8379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1999),
  [8381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [8383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2000),
  [8385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2001),
  [8387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [8389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2195),
  [8391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2196),
  [8393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7011),
  [8395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6800),
  [8397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7313),
  [8399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5067),
  [8401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9022),
  [8403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5708),
  [8405] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(4928),
  [8409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5356),
  [8411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7198),
  [8413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [8415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5180),
  [8417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5597),
  [8419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7199),
  [8421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9120),
  [8423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9024),
  [8425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9445),
  [8427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5349),
  [8429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8958),
  [8431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 6, 0, 59),
  [8433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 5, 0, 45),
  [8435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [8437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1994),
  [8439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [8441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1996),
  [8443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [8445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [8447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [8449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(935),
  [8452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8690),
  [8455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9382),
  [8457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [8459] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(4928),
  [8462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [8464] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(4928),
  [8468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [8470] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(4928),
  [8473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4875),
  [8475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1, 0, 0),
  [8477] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(4928),
  [8481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(4928),
  [8484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(4928),
  [8487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4906),
  [8489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1514),
  [8491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1696),
  [8493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1431),
  [8495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1697),
  [8497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [8499] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), REDUCE(sym_array_type, 4, 0, 0), SHIFT(3684),
  [8503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6806),
  [8505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5292),
  [8507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [8509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5280),
  [8511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5567),
  [8513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9110),
  [8515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9442),
  [8517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5291),
  [8519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8948),
  [8521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1669),
  [8523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1671),
  [8525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1671),
  [8527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1672),
  [8529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1674),
  [8531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [8533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [8535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1683),
  [8537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1683),
  [8539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [8541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [8543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1688),
  [8545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1692),
  [8547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1692),
  [8549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4820),
  [8551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4732),
  [8553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [8555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4822),
  [8557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2087),
  [8559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [8561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [8563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [8565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 5, 0, 0), SHIFT(3684),
  [8568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8946),
  [8571] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(9467),
  [8574] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), REDUCE(sym_array_type, 3, 0, 0), SHIFT(3684),
  [8578] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0), SHIFT(3684),
  [8581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2079),
  [8583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2021),
  [8585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2021),
  [8587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2022),
  [8589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2023),
  [8591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [8593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [8595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [8597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2030),
  [8599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2031),
  [8601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [8603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2019),
  [8605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2020),
  [8607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [8609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [8611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2026),
  [8613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2026),
  [8615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2027),
  [8617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [8619] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), SHIFT(3684),
  [8622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6799),
  [8624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5563),
  [8626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [8628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5557),
  [8630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5548),
  [8632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9565),
  [8634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9347),
  [8636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5562),
  [8638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9188),
  [8640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1556),
  [8642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(8975),
  [8645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1299),
  [8647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1670),
  [8649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(9338),
  [8652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(9310),
  [8655] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 0), REDUCE(sym_array_type, 5, 0, 0), SHIFT(3684),
  [8659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [8661] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(3684),
  [8664] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(9570),
  [8667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6977),
  [8669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3918),
  [8671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3800),
  [8673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3264),
  [8675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [8677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3183),
  [8679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [8681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [8683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [8685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3370),
  [8687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4307),
  [8689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3890),
  [8691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4652),
  [8693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3169),
  [8695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3735),
  [8697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4009),
  [8699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2286),
  [8701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3341),
  [8703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [8705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3780),
  [8707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2832),
  [8709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [8711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [8713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3720),
  [8715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4300),
  [8717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [8719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2264),
  [8721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2479),
  [8723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4314),
  [8725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2840),
  [8727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2863),
  [8729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4339),
  [8731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2504),
  [8733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2294),
  [8735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7220),
  [8737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3867),
  [8739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3925),
  [8741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7261),
  [8743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4347),
  [8745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7287),
  [8747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3831),
  [8749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2631),
  [8751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4354),
  [8753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2650),
  [8755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [8757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2644),
  [8759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2486),
  [8761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3802),
  [8763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [8765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3607),
  [8767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3134),
  [8769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3619),
  [8771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4578),
  [8773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [8775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4665),
  [8777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3826),
  [8779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 6, 0, 0),
  [8781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [8783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 5, 0, 0),
  [8785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_declaration, 5, 0, 0),
  [8787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [8789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 4, 0, 0),
  [8791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_statement, 5, 0, 0),
  [8793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [8795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_declaration, 4, 0, 0),
  [8797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_statement, 4, 0, 0),
  [8799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_statement, 7, 0, 0),
  [8801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_statement, 6, 0, 0),
  [8803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_declaration, 3, 0, 0),
  [8805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 7, 0, 0),
  [8807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_return_statement_repeat1, 2, 0, 0),
  [8809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 8, 0, 0),
  [8811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_statement, 3, 0, 0),
  [8813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 3, 0, 0),
  [8815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_declaration, 6, 0, 0),
  [8817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8996),
  [8819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4606),
  [8821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3132),
  [8823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4946),
  [8825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [8827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5666),
  [8829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9031),
  [8831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7116),
  [8833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7224),
  [8835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6801),
  [8837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4947),
  [8839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [8841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9037),
  [8843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6652),
  [8845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5131),
  [8847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [8849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8986),
  [8851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(544),
  [8853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4911),
  [8855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [8857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [8859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5645),
  [8861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9009),
  [8863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1404),
  [8865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4943),
  [8867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2465),
  [8869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [8871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5652),
  [8873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9016),
  [8875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3190),
  [8877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5002),
  [8879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [8881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5080),
  [8883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0),
  [8885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3778),
  [8887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6707),
  [8889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5042),
  [8891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4313),
  [8893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2991),
  [8895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [8897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5520),
  [8899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9306),
  [8901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6756),
  [8903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4925),
  [8905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5021),
  [8907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1987),
  [8909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [8911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1722),
  [8913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6681),
  [8915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4895),
  [8917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4995),
  [8919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5083),
  [8921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [8923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8971),
  [8925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [8927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5142),
  [8929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [8931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5148),
  [8933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4978),
  [8935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3922),
  [8937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [8939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5169),
  [8941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5102),
  [8943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3744),
  [8945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3007),
  [8947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [8949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5500),
  [8951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5108),
  [8953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [8955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9051),
  [8957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [8959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9176),
  [8961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3771),
  [8963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [8965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5170),
  [8967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9063),
  [8969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [8971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5009),
  [8973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4972),
  [8975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5013),
  [8977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5109),
  [8979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6807),
  [8981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5055),
  [8983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_statement, 2, 0, 0),
  [8985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9398),
  [8987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [8989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5018),
  [8991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5006),
  [8993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9568),
  [8995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5151),
  [8997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4321),
  [8999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2862),
  [9001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5038),
  [9003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7101),
  [9005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4985),
  [9007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2808),
  [9009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5090),
  [9011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3644),
  [9013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3366),
  [9015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5004),
  [9017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5141),
  [9019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4642),
  [9021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5047),
  [9023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5024),
  [9025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5163),
  [9027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [9029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2285),
  [9031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [9033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8973),
  [9035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5089),
  [9037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5070),
  [9039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5056),
  [9041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4008),
  [9043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3182),
  [9045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5132),
  [9047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5066),
  [9049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9407),
  [9051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5121),
  [9053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5091),
  [9055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9375),
  [9057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [9059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9242),
  [9061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5137),
  [9063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9185),
  [9065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9205),
  [9067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2400),
  [9069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9019),
  [9071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9470),
  [9073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5153),
  [9075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9083),
  [9077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9299),
  [9079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9551),
  [9081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9055),
  [9083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2323),
  [9085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9184),
  [9087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9316),
  [9089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9404),
  [9091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5161),
  [9093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9581),
  [9095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8790),
  [9097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7286),
  [9099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5072),
  [9101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5094),
  [9103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5101),
  [9105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3829),
  [9107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5133),
  [9109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5003),
  [9111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5095),
  [9113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7343),
  [9115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4353),
  [9117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4361),
  [9119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7107),
  [9121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [9123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9058),
  [9125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [9127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5112),
  [9129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7302),
  [9131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7233),
  [9133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4984),
  [9135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5005),
  [9137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3797),
  [9139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5027),
  [9141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2642),
  [9143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [9145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [9147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3399),
  [9149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9076),
  [9151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3991),
  [9153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4979),
  [9155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5127),
  [9157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3975),
  [9159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5128),
  [9161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5092),
  [9163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2618),
  [9165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5140),
  [9167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3983),
  [9169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8734),
  [9171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5143),
  [9173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4975),
  [9175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5079),
  [9177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7087),
  [9179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4989),
  [9181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5155),
  [9183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2283),
  [9185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_const_declaration_repeat1, 2, 0, 0),
  [9187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [9189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5074),
  [9191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5010),
  [9193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5157),
  [9195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3628),
  [9197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8907),
  [9199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4977),
  [9201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4928),
  [9203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [9205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5232),
  [9207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4913),
  [9209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2953),
  [9211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [9213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5537),
  [9215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4918),
  [9217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4298),
  [9219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [9221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5694),
  [9223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [9225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5423),
  [9227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [9229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [9231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [9233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [9235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5631),
  [9237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5199),
  [9239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5189),
  [9241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [9243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5229),
  [9245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [9247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4935),
  [9249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2660),
  [9251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [9253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5556),
  [9255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [9257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [9259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [9261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5195),
  [9263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5240),
  [9265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5382),
  [9267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4949),
  [9269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4567),
  [9271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [9273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5250),
  [9275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5210),
  [9277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5255),
  [9279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5262),
  [9281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [9283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5281),
  [9285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5289),
  [9287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5309),
  [9289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [9291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5434),
  [9293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5493),
  [9295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5477),
  [9297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4921),
  [9299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2340),
  [9301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [9303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5390),
  [9305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5627),
  [9307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5472),
  [9309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [9311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [9313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5165),
  [9315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5415),
  [9317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5462),
  [9319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5516),
  [9321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [9323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5654),
  [9325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5251),
  [9327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4896),
  [9329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [9331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [9333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5641),
  [9335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5275),
  [9337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5361),
  [9339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5517),
  [9341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [9343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5237),
  [9345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5505),
  [9347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [9349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5670),
  [9351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [9353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5235),
  [9355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5502),
  [9357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [9359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(894),
  [9361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5487),
  [9363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [9365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5366),
  [9367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5534),
  [9369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5492),
  [9371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5378),
  [9373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5322),
  [9375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [9377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5528),
  [9379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5527),
  [9381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [9383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5558),
  [9385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5545),
  [9387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5239),
  [9389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5234),
  [9391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [9393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5480),
  [9395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5454),
  [9397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4936),
  [9399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [9401] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5453),
  [9404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [9406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [9408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [9410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 3, 0, 0),
  [9412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [9414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [9416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [9418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4684),
  [9420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [9422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [9424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [9426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [9428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [9430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3501),
  [9432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [9434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [9436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4411),
  [9438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4815),
  [9440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4390),
  [9442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4003),
  [9444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4749),
  [9446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [9448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [9450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3833),
  [9452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [9454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3467),
  [9456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [9458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4894),
  [9460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [9462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3480),
  [9464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [9466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7624),
  [9468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [9470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4880),
  [9472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4745),
  [9474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [9476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3860),
  [9478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [9480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4701),
  [9482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3966),
  [9484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3811),
  [9486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3488),
  [9488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4842),
  [9490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [9492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5272),
  [9494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [9496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5511),
  [9498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [9500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4846),
  [9502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4392),
  [9504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [9506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3723),
  [9508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [9510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4861),
  [9512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4872),
  [9514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [9516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4044),
  [9518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4049),
  [9520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4050),
  [9522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4051),
  [9524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4554),
  [9526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3838),
  [9528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7687),
  [9530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4393),
  [9532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [9534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4379),
  [9536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [9538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4394),
  [9540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4838),
  [9542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3383),
  [9544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3932),
  [9546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [9548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [9550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4725),
  [9552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4750),
  [9554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [9556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3842),
  [9558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [9560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_type_declaration, 6, 0, 0),
  [9562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [9564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [9566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4397),
  [9568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4740),
  [9570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [9572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [9574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4409),
  [9576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3853),
  [9578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4806),
  [9580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3849),
  [9582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3226),
  [9584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3218),
  [9586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3225),
  [9588] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5475),
  [9591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4721),
  [9593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3809),
  [9595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [9597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [9599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [9601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3850),
  [9603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3238),
  [9605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [9607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4385),
  [9609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3259),
  [9611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3785),
  [9613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3262),
  [9615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [9617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [9619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [9621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [9623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [9625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [9627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3319),
  [9629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [9631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3733),
  [9633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [9635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [9637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [9639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5575),
  [9642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [9644] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5580),
  [9647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [9649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5586),
  [9652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [9654] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5591),
  [9657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4552),
  [9659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [9661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5598),
  [9664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [9666] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5604),
  [9669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [9671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3748),
  [9673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [9675] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5609),
  [9678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [9680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5612),
  [9683] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5615),
  [9686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [9688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [9690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [9692] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5618),
  [9695] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression_no_tag, 1, 0, 0), SHIFT(5622),
  [9698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [9700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [9702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [9704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [9706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [9708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [9710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4659),
  [9712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [9714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [9716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4939),
  [9718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_type_declaration, 5, 0, 0),
  [9720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [9722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [9724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(951),
  [9726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5389),
  [9728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [9730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_assignment_statement, 3, 0, 0),
  [9732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2120),
  [9734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [9736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1515),
  [9738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4030),
  [9740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [9742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1728),
  [9744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4248),
  [9746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(899),
  [9748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [9750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4706),
  [9752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [9754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1854),
  [9756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3695),
  [9758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [9760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1882),
  [9762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2467),
  [9764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [9766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1885),
  [9768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2214),
  [9770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(972),
  [9772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [9774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_assignment_statement, 5, 0, 0),
  [9776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [9778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1742),
  [9780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4886),
  [9782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1550),
  [9784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1550),
  [9786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [9788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1807),
  [9790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2914),
  [9792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [9794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [9796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [9798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1851),
  [9800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3674),
  [9802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [9804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1870),
  [9806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [9808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [9810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1819),
  [9812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3064),
  [9814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [9816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1758),
  [9818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2222),
  [9820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [9822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1774),
  [9824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2693),
  [9826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [9828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1777),
  [9830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2705),
  [9832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [9834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1838),
  [9836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3349),
  [9838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4762),
  [9840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [9842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1745),
  [9844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4754),
  [9846] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [9848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2773),
  [9850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2085),
  [9852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [9854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1761),
  [9856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2451),
  [9858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [9860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1790),
  [9862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4506),
  [9864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [9866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1804),
  [9868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2905),
  [9870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [9872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [9874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [9876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1835),
  [9878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3327),
  [9880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [9882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1867),
  [9884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [9886] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_assignment_statement, 4, 0, 0),
  [9888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4618),
  [9890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [9892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1900),
  [9894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4476),
  [9896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [9898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1982),
  [9900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4021),
  [9902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [9904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1731),
  [9906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4040),
  [9908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [9910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1793),
  [9912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4685),
  [9914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5656),
  [9916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2574),
  [9918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [9920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1822),
  [9922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3083),
  [9924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [9926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1897),
  [9928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4466),
  [9930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2665),
  [9932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8784),
  [9934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2333),
  [9936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [9938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [9940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4028),
  [9942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2498),
  [9944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8688),
  [9946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [9948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3194),
  [9950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2213),
  [9952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3413),
  [9954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8676),
  [9956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2223),
  [9958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [9960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2232),
  [9962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [9964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2235),
  [9966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8711),
  [9968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2343),
  [9970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [9972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3561),
  [9974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [9976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3434),
  [9978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [9980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3436),
  [9982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [9984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7333),
  [9986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8647),
  [9988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1805),
  [9990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [9992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2908),
  [9994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [9996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [9998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4744),
  [10000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4015),
  [10002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8735),
  [10004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [10006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [10008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [10010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4617),
  [10012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3872),
  [10014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8911),
  [10016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3667),
  [10018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8872),
  [10020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4319),
  [10022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8832),
  [10024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [10026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3138),
  [10028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [10030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3323),
  [10032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8685),
  [10034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [10036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4325),
  [10038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8861),
  [10040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2376),
  [10042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8683),
  [10044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4332),
  [10046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8874),
  [10048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [10050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2812),
  [10052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8783),
  [10054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3129),
  [10056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [10058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [10060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2949),
  [10062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(827),
  [10064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [10066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4227),
  [10068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [10070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [10072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [10074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [10076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2768),
  [10078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3813),
  [10080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8928),
  [10082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7308),
  [10084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8864),
  [10086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4174),
  [10088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4274),
  [10090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1421),
  [10092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [10094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [10096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [10098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8696),
  [10100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2933),
  [10102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [10104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [10106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2307),
  [10108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3018),
  [10110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [10112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [10114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [10116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [10118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3330),
  [10120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [10122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3111),
  [10124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3559),
  [10126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [10128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [10130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2922),
  [10132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [10134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8814),
  [10136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3394),
  [10138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [10140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8829),
  [10142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [10144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2728),
  [10146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3188),
  [10148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8741),
  [10150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [10152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8840),
  [10154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4276),
  [10156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [10158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [10160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [10162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2488),
  [10164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [10166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [10168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4148),
  [10170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [10172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2246),
  [10174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2767),
  [10176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9274),
  [10178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6615),
  [10180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [10182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [10184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8929),
  [10186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4677),
  [10188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3396),
  [10190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8670),
  [10192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7319),
  [10194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8812),
  [10196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4136),
  [10198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [10200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2673),
  [10202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [10204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2469),
  [10206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7118),
  [10208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8833),
  [10210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3879),
  [10212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8803),
  [10214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [10216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2887),
  [10218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8776),
  [10220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [10222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [10224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [10226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2952),
  [10228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [10230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4598),
  [10232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3972),
  [10234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8781),
  [10236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4694),
  [10238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [10240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [10242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3545),
  [10244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2603),
  [10246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8924),
  [10248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [10250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2290),
  [10252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1898),
  [10254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [10256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4469),
  [10258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1826),
  [10260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8816),
  [10262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2690),
  [10264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [10266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3405),
  [10268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__simple_assignment_statement_repeat1, 2, 0, 0),
  [10270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2694),
  [10272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [10274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [10276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4672),
  [10278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2696),
  [10280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [10282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2830),
  [10284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1352),
  [10286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2629),
  [10288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8707),
  [10290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [10292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4763),
  [10294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4098),
  [10296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3126),
  [10298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8767),
  [10300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3198),
  [10302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8756),
  [10304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [10306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [10308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [10310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [10312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [10314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4359),
  [10316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8792),
  [10318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4603),
  [10320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8887),
  [10322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7321),
  [10324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8871),
  [10326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4513),
  [10328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8624),
  [10330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [10332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4500),
  [10334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4364),
  [10336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8854),
  [10338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2320),
  [10340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4192),
  [10342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [10344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3903),
  [10346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8919),
  [10348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4006),
  [10350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8845),
  [10352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4774),
  [10354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1868),
  [10356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1387),
  [10358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [10360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [10362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [10364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3069),
  [10366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4649),
  [10368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8921),
  [10370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [10372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8796),
  [10374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [10376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4780),
  [10378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [10380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8791),
  [10382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2280),
  [10384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [10386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3206),
  [10388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [10390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4197),
  [10392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [10394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4242),
  [10396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [10398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_call_expression_repeat1, 2, 0, 14),
  [10400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2117),
  [10402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3955),
  [10404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8785),
  [10406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [10408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4184),
  [10410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4368),
  [10412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8875),
  [10414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [10416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3376),
  [10418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [10420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1729),
  [10422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [10424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4104),
  [10426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [10428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [10430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4623),
  [10432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [10434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4161),
  [10436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [10438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3526),
  [10440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3540),
  [10442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4097),
  [10444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1852),
  [10446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [10448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3677),
  [10450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3642),
  [10452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8795),
  [10454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3786),
  [10456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8899),
  [10458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [10460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2328),
  [10462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7108),
  [10464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8708),
  [10466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [10468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4793),
  [10470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7330),
  [10472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8649),
  [10474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3806),
  [10476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8819),
  [10478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [10480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [10482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [10484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4191),
  [10486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_declaration_repeat1, 4, 0, 0),
  [10488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7299),
  [10490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8855),
  [10492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4796),
  [10494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [10496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3556),
  [10498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [10500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4798),
  [10502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [10504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2298),
  [10506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8673),
  [10508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [10510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4485),
  [10512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3428),
  [10514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [10516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2939),
  [10518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3659),
  [10520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8637),
  [10522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4496),
  [10524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2390),
  [10526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8672),
  [10528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3772),
  [10530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8740),
  [10532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [10534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8738),
  [10536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4508),
  [10538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [10540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4271),
  [10542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7099),
  [10544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8712),
  [10546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5332),
  [10548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4666),
  [10550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_parameter, 3, 0, 0),
  [10552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_in_expression, 4, 0, 0),
  [10554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5303),
  [10556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2279),
  [10558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5187),
  [10560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7480),
  [10562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5430),
  [10564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3891),
  [10566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5407),
  [10568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3620),
  [10570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5376),
  [10572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9223),
  [10574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5413),
  [10576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1694),
  [10578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5647),
  [10580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9430),
  [10582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5380),
  [10584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2842),
  [10586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5650),
  [10588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9127),
  [10590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_call_expression_repeat1, 4, 0, 14),
  [10592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5653),
  [10594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9028),
  [10596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5367),
  [10598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3342),
  [10600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5657),
  [10602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9283),
  [10604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5632),
  [10606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8988),
  [10608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5660),
  [10610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9329),
  [10612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5184),
  [10614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3927),
  [10616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5662),
  [10618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9587),
  [10620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5664),
  [10622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9126),
  [10624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__param_type, 6, 0, 0),
  [10626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5667),
  [10628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9333),
  [10630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_map_repeat1, 4, 0, 0),
  [10632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5671),
  [10634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9584),
  [10636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5676),
  [10638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9192),
  [10640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5680),
  [10642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9035),
  [10644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 1, 0, 0),
  [10646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 1, 0, 0),
  [10648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5357),
  [10650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3878),
  [10652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5446),
  [10654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4348),
  [10656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5424),
  [10658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [10660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5318),
  [10662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2651),
  [10664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_parameter, 4, 0, 0),
  [10666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_type, 3, 0, 0),
  [10668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5394),
  [10670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7263),
  [10672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__param_type, 5, 0, 0),
  [10674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5432),
  [10676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2269),
  [10678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bit_field_declaration_repeat1, 6, 0, 0),
  [10680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_case_repeat1, 2, 0, 29),
  [10682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_field, 3, 0, 0),
  [10684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_in_expression, 2, 0, 0),
  [10686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_parameter, 5, 0, 0),
  [10688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0),
  [10690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0),
  [10692] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0), SHIFT_REPEAT(8724),
  [10695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5437),
  [10697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4308),
  [10699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__param_type, 4, 0, 0),
  [10701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5340),
  [10703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7040),
  [10705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5341),
  [10707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3170),
  [10709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5276),
  [10711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3782),
  [10713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7606),
  [10715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [10717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5648),
  [10719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4081),
  [10721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [10723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2368),
  [10725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2369),
  [10727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2218),
  [10729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [10731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [10733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5278),
  [10735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1747),
  [10737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [10739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5509),
  [10741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [10743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4477),
  [10745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5406),
  [10747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [10749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5453),
  [10751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5304),
  [10753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1763),
  [10755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [10757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [10759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [10761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5658),
  [10763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5669),
  [10765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [10767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5193),
  [10769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [10771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5319),
  [10773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1779),
  [10775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [10777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5672),
  [10779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1953),
  [10781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [10783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5333),
  [10785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1795),
  [10787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [10789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [10791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2104),
  [10793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2515),
  [10795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [10797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5468),
  [10799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5546),
  [10801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [10803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5342),
  [10805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1809),
  [10807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [10809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [10811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5628),
  [10813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3084),
  [10815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [10817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5358),
  [10819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1824),
  [10821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [10823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1482),
  [10825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4491),
  [10827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4492),
  [10829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [10831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9212),
  [10833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5369),
  [10835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1840),
  [10837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [10839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3150),
  [10841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [10843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5383),
  [10845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1856),
  [10847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1131),
  [10849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3247),
  [10851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5202),
  [10853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5381),
  [10855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [10857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5396),
  [10859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1872),
  [10861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [10863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [10865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3350),
  [10867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [10869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [10871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5164),
  [10873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1887),
  [10875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [10877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2259),
  [10879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2260),
  [10881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3119),
  [10883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [10885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5186),
  [10887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5414),
  [10889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1902),
  [10891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [10893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5570),
  [10895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [10897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5426),
  [10899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [10901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [10903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5433),
  [10905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [10907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3696),
  [10909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5439),
  [10911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [10913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2077),
  [10915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5448),
  [10917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [10919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5365),
  [10921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [10923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [10925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [10927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [10929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [10931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [10933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [10935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [10937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2915),
  [10939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [10941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [10943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1733),
  [10945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5640),
  [10947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [10949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5475),
  [10951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4045),
  [10953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [10955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2078),
  [10957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4125),
  [10959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5541),
  [10961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2007),
  [10963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2008),
  [10965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [10967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2719),
  [10969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5605),
  [10971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5329),
  [10973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4122),
  [10975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2928),
  [10977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2929),
  [10979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1679),
  [10981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [10983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3120),
  [10985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5284),
  [10987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3536),
  [10989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5416),
  [10991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5290),
  [10993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [10995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [10997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5325),
  [10999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5328),
  [11001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3386),
  [11003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5203),
  [11005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3387),
  [11007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2714),
  [11009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5503),
  [11011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4151),
  [11013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5398),
  [11015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5177),
  [11017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5400),
  [11019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4037),
  [11021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [11023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5228),
  [11025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [11027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2159),
  [11029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [11031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2760),
  [11033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [11035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5575),
  [11037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5577),
  [11039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5580),
  [11041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3537),
  [11043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5583),
  [11045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5586),
  [11047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [11049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5536),
  [11051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5588),
  [11053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5591),
  [11055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5213),
  [11057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1700),
  [11059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2869),
  [11061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4849),
  [11063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5594),
  [11065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5260),
  [11067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [11069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5598),
  [11071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7541),
  [11073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5600),
  [11075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5581),
  [11077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5604),
  [11079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1918),
  [11081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [11083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5217),
  [11085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5609),
  [11087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5447),
  [11089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5241),
  [11091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5612),
  [11093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4538),
  [11095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5615),
  [11097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5479),
  [11099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2267),
  [11101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4770),
  [11103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5443),
  [11105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5618),
  [11107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4771),
  [11109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5695),
  [11111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4577),
  [11113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5254),
  [11115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5622),
  [11117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4433),
  [11119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2468),
  [11121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1455),
  [11123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4234),
  [11125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1712),
  [11127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4540),
  [11129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [11131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [11133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5379),
  [11135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5529),
  [11137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4236),
  [11139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [11141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [11143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5261),
  [11145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5310),
  [11147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5483),
  [11149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2198),
  [11151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2199),
  [11153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2200),
  [11155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2201),
  [11157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [11159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2203),
  [11161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [11163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4686),
  [11165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5561),
  [11167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [11169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [11171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [11173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [11175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4755),
  [11177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5331),
  [11179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1548),
  [11181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [11183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [11185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2034),
  [11187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2035),
  [11189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5491),
  [11191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute, 6, 0, 0),
  [11193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 6, 0, 0),
  [11195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute, 7, 0, 0),
  [11197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 7, 0, 0),
  [11199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute, 4, 0, 0),
  [11201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 4, 0, 0),
  [11203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute, 2, 0, 0),
  [11205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 2, 0, 0),
  [11207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute, 5, 0, 0),
  [11209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 5, 0, 0),
  [11211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7559),
  [11213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9186),
  [11215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9195),
  [11217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7538),
  [11219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9547),
  [11221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9595),
  [11223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7577),
  [11225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9538),
  [11227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9589),
  [11229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7549),
  [11231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9541),
  [11233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9591),
  [11235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7555),
  [11237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9544),
  [11239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9593),
  [11241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7619),
  [11243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9550),
  [11245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9597),
  [11247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7722),
  [11249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9553),
  [11251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9599),
  [11253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_overloaded_procedure_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1493),
  [11256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_overloaded_procedure_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1511),
  [11259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [11261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2106),
  [11263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [11265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1956),
  [11267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4994),
  [11269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [11271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7326),
  [11273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6804),
  [11275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3293),
  [11277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6853),
  [11279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [11281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5351),
  [11283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6747),
  [11285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [11287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4410),
  [11289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4993),
  [11291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3099),
  [11293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2519),
  [11295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4398),
  [11297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [11299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4407),
  [11301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3187),
  [11303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5154),
  [11305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [11307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3709),
  [11309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3687),
  [11311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3186),
  [11313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5050),
  [11315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5147),
  [11317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5063),
  [11319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [11321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5550),
  [11323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9427),
  [11325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [11327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3351),
  [11329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3422),
  [11331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3546),
  [11333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2484),
  [11335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5215),
  [11337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6679),
  [11339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [11341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5134),
  [11343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2163),
  [11345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5138),
  [11347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6667),
  [11349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6670),
  [11351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6671),
  [11353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5057),
  [11355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6676),
  [11357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6678),
  [11359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5248),
  [11361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9585),
  [11363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4987),
  [11365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5410),
  [11367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6687),
  [11369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6690),
  [11371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6659),
  [11373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5049),
  [11375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5405),
  [11377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6697),
  [11379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6700),
  [11381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6701),
  [11383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1562),
  [11386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6715),
  [11388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5274),
  [11390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9020),
  [11392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6718),
  [11394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6755),
  [11396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6761),
  [11398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6746),
  [11400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1575),
  [11403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6706),
  [11405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5044),
  [11407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6624),
  [11409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6729),
  [11411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6730),
  [11413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5162),
  [11415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2113),
  [11418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7433),
  [11420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6793),
  [11422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6760),
  [11424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4976),
  [11426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6625),
  [11428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6722),
  [11430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7188),
  [11432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6786),
  [11434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6863),
  [11436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [11438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9387),
  [11440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [11442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9218),
  [11444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6655),
  [11446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6623),
  [11448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [11450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5305),
  [11452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9606),
  [11454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7503),
  [11456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6784),
  [11458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5088),
  [11460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [11462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5053),
  [11464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6639),
  [11466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6640),
  [11468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6650),
  [11470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6645),
  [11472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [11474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4990),
  [11476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7135),
  [11478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6952),
  [11480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6642),
  [11482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5093),
  [11484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5014),
  [11486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1554),
  [11488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5043),
  [11490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7404),
  [11492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6868),
  [11494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5020),
  [11496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7144),
  [11498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6972),
  [11500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7229),
  [11502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5028),
  [11504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2004),
  [11506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4981),
  [11508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5139),
  [11510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5107),
  [11512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5294),
  [11514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5547),
  [11516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5084),
  [11518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5418),
  [11520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6816),
  [11522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6819),
  [11524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6820),
  [11526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5287),
  [11528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6841),
  [11530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6858),
  [11532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6829),
  [11534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7175),
  [11536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6864),
  [11538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6828),
  [11540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6838),
  [11542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6840),
  [11544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5123),
  [11546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5126),
  [11548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6827),
  [11550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6850),
  [11552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7181),
  [11554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6867),
  [11556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5524),
  [11558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6856),
  [11560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6859),
  [11562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6862),
  [11564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7159),
  [11566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6866),
  [11568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6963),
  [11570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1640),
  [11573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6987),
  [11575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7186),
  [11577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6965),
  [11579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7475),
  [11581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6822),
  [11583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6884),
  [11585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6627),
  [11587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5238),
  [11589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6891),
  [11591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2011),
  [11594] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1556),
  [11597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6893),
  [11599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5190),
  [11601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [11603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5211),
  [11605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 4, 0, 0),
  [11607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2006),
  [11609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_declaration, 7, 0, 0),
  [11611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7187),
  [11613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6976),
  [11615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [11617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6937),
  [11619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2080),
  [11621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 3, 0, 0),
  [11623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [11625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 47),
  [11627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7664),
  [11629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 33),
  [11631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 34),
  [11633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 48),
  [11635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 49),
  [11637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 35),
  [11639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 47),
  [11641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 63),
  [11643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 48),
  [11645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 49),
  [11647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 8, 0, 63),
  [11649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 3, 0, 0),
  [11651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2545),
  [11653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5227),
  [11655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_member, 3, 0, 0),
  [11657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8780),
  [11659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9323),
  [11661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9027),
  [11663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_statement, 4, 0, 0),
  [11665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7749),
  [11667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_statement, 5, 0, 0),
  [11669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 5, 0, 0),
  [11671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [11673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_member, 4, 0, 0),
  [11675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_statement, 3, 0, 0),
  [11677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 3, 0, 11),
  [11679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 22),
  [11681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 23),
  [11683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_member, 5, 0, 0),
  [11685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 11),
  [11687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_member, 6, 0, 0),
  [11689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7190),
  [11691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5404),
  [11693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [11695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 33),
  [11697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 34),
  [11699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 6, 0, 0),
  [11701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 22),
  [11703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 4, 0, 0),
  [11705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 35),
  [11707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 7, 0, 0),
  [11709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 23),
  [11711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_const_declaration_repeat1, 3, 0, 0),
  [11713] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_return_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(743),
  [11716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7716),
  [11718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9220),
  [11720] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_overloaded_procedure_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1668),
  [11723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7528),
  [11725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_when_statement_repeat1, 2, 0, 0),
  [11727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_when_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9069),
  [11730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 5, 0, 0),
  [11732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_statement, 8, 0, 0),
  [11734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7627),
  [11736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_const_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(530),
  [11739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 9, 0, 0),
  [11741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [11743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(9211),
  [11746] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(900),
  [11749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_declaration, 8, 0, 0),
  [11751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9220),
  [11754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [11756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [11758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [11760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8720),
  [11762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7338),
  [11764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7222),
  [11766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7468),
  [11768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [11770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8758),
  [11772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7469),
  [11774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7200),
  [11776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7195),
  [11778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7209),
  [11780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7197),
  [11782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7194),
  [11784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5196),
  [11786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [11788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7176),
  [11790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 1, 0, 0),
  [11792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7153),
  [11794] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 1, 0, 0),
  [11796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7253),
  [11798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7241),
  [11800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7388),
  [11802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7167),
  [11804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7169),
  [11806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7171),
  [11808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7216),
  [11810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7316),
  [11812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7337),
  [11814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [11816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [11818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7156),
  [11820] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [11822] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_overloaded_procedure_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1987),
  [11825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_field_declaration, 6, 0, 0),
  [11827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 3, 0, 3),
  [11829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_overloaded_procedure_declaration, 5, 0, 0),
  [11831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 10, 0, 0),
  [11833] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_declaration, 10, 0, 0),
  [11835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 5, 0, 0),
  [11837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7910),
  [11839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5282),
  [11841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4932),
  [11843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4342),
  [11845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2194),
  [11847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5559),
  [11849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 9, 0, 63),
  [11851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_if_clause, 6, 0, 47),
  [11853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_if_clause, 6, 0, 70),
  [11855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 7, 0, 57),
  [11857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [11859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 11, 0, 0),
  [11861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 5, 0, 0),
  [11863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_declaration, 5, 0, 0),
  [11865] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_overloaded_procedure_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1603),
  [11868] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 11, 0, 0),
  [11870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_declaration, 11, 0, 0),
  [11872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_field_declaration, 11, 0, 0),
  [11874] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_if_clause, 7, 0, 71),
  [11876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 12, 0, 0),
  [11878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_overloaded_procedure_declaration, 6, 0, 0),
  [11880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 3, 0, 12),
  [11882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 6, 0, 0),
  [11884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_declaration, 6, 0, 0),
  [11886] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 12, 0, 0),
  [11888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_field_declaration, 12, 0, 0),
  [11890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4951),
  [11892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4612),
  [11894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2174),
  [11896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 13, 0, 0),
  [11898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_field_declaration, 13, 0, 0),
  [11900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 3, 0, 13),
  [11902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_field_declaration, 14, 0, 0),
  [11904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4945),
  [11906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [11908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2190),
  [11910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 3, 0, 11),
  [11912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 2, 0, 7),
  [11914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 67),
  [11916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 11),
  [11918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 36),
  [11920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 37),
  [11922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tagged_block, 2, 0, 0),
  [11924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 38),
  [11926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 34),
  [11928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 39),
  [11930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 40),
  [11932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 41),
  [11934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 4, 0, 24),
  [11936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 35),
  [11938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 42),
  [11940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 43),
  [11942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 4, 0, 25),
  [11944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 3, 0, 0),
  [11946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7482),
  [11948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defer_statement, 2, 0, 0),
  [11950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2, 0, 0),
  [11952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 5, 0, 44),
  [11954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4905),
  [11956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3159),
  [11958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [11960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [11962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 5, 0, 29),
  [11964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [11966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5397),
  [11968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [11970] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(40),
  [11973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 4, 0, 26),
  [11975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_label_statement, 3, 0, 0),
  [11977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 4, 0, 22),
  [11979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreign_block, 2, 0, 0),
  [11981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 7, 0, 0),
  [11983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_declaration, 3, 0, 0),
  [11985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 7, 0, 8),
  [11987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 4, 0, 27),
  [11989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 7, 0, 3),
  [11991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 7, 0, 0),
  [11993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 4, 0, 23),
  [11995] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 4, 0, 28),
  [11997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 5, 0, 0),
  [11999] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 4, 0, 0),
  [12001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8485),
  [12003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__param_type, 3, 0, 0),
  [12005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [12007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 5, 0, 3),
  [12009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 4, 0, 29),
  [12011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4912),
  [12013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3754),
  [12015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2166),
  [12017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_when_clause, 4, 0, 0),
  [12019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__param_header, 2, 0, 0),
  [12021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__param_header, 2, 0, 0),
  [12023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [12025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4926),
  [12027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2234),
  [12029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2168),
  [12031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4903),
  [12033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3886),
  [12035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [12037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8268),
  [12039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8174),
  [12041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4929),
  [12043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3939),
  [12045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2178),
  [12047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7347),
  [12049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7207),
  [12051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreign_block, 4, 0, 0),
  [12053] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 2, 0, 0),
  [12055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 5, 0, 0),
  [12057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 5, 0, 29),
  [12059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7828),
  [12061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_declaration, 4, 0, 0),
  [12063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 6, 0, 0),
  [12065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 6, 0, 8),
  [12067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 5, 0, 18),
  [12069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 7, 0, 18),
  [12071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 6, 0, 3),
  [12073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_overloaded_procedure_declaration, 7, 0, 0),
  [12075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 7, 0, 0),
  [12077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 6, 0, 0),
  [12079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 9, 0, 18),
  [12081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_declaration, 7, 0, 0),
  [12083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8007),
  [12085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 5, 0, 57),
  [12087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_overloaded_procedure_declaration, 9, 0, 0),
  [12089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 9, 0, 0),
  [12091] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__param_header, 3, 0, 0),
  [12093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__param_header, 3, 0, 0),
  [12095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [12097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bit_field_declaration, 7, 0, 0),
  [12099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 4, 0, 8),
  [12101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_declaration, 9, 0, 0),
  [12103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 4, 0, 0),
  [12105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7442),
  [12107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4910),
  [12109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3321),
  [12111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2180),
  [12113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4930),
  [12115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3996),
  [12117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2129),
  [12119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8110),
  [12121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7455),
  [12123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4916),
  [12125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [12127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2191),
  [12129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 7, 0, 59),
  [12131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 7, 0, 68),
  [12133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 22),
  [12135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 8, 0, 47),
  [12137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7225),
  [12139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8012),
  [12141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__param_type, 2, 0, 0),
  [12143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1874),
  [12145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 8, 0, 48),
  [12147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 8, 0, 49),
  [12149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 23),
  [12151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 7),
  [12153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 7, 0, 60),
  [12155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 64),
  [12157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 3, 0, 0),
  [12159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 50),
  [12161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_if_clause, 5, 0, 33),
  [12163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 51),
  [12165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_if_clause, 5, 0, 34),
  [12167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 65),
  [12169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 52),
  [12171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 53),
  [12173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreign_block, 3, 0, 0),
  [12175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4923),
  [12177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2878),
  [12179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2183),
  [12181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 54),
  [12183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 49),
  [12185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 55),
  [12187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 56),
  [12189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 4, 0, 0),
  [12191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7481),
  [12193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 4, 0, 29),
  [12195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 69),
  [12197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 6, 0, 44),
  [12199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 6, 0, 45),
  [12201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 6, 0, 60),
  [12203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 6, 0, 29),
  [12205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4920),
  [12207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2524),
  [12209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2192),
  [12211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 8, 0, 8),
  [12213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_case, 6, 0, 57),
  [12215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4931),
  [12217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7243),
  [12219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [12221] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 8, 0, 0),
  [12223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__param_header, 1, 0, 0),
  [12225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__param_header, 1, 0, 0),
  [12227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [12229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 8, 0, 68),
  [12231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 10, 0, 0),
  [12233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_procedure_declaration, 5, 0, 0),
  [12235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 66),
  [12237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 9, 0, 0),
  [12239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_statement, 6, 0, 0),
  [12241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 8, 0, 0),
  [12243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 8, 0, 18),
  [12245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_overloaded_procedure_declaration, 8, 0, 0),
  [12247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 8, 0, 0),
  [12249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 3, 0, 12),
  [12251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7415),
  [12253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_declaration, 8, 0, 0),
  [12255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4948),
  [12257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3614),
  [12259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2187),
  [12261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8263),
  [12263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4940),
  [12265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2653),
  [12267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2171),
  [12269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4902),
  [12271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4303),
  [12273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2193),
  [12275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 33),
  [12277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 34),
  [12279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 35),
  [12281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_if_clause, 4, 0, 22),
  [12283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [12285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3344),
  [12287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4306),
  [12289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4988),
  [12291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4664),
  [12293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5035),
  [12295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3920),
  [12297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [12299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [12301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4667),
  [12303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6726),
  [12305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5343),
  [12307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 0),
  [12309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3902),
  [12311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3864),
  [12313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5086),
  [12315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4648),
  [12317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8095),
  [12319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3724),
  [12321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9440),
  [12323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3880),
  [12325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8608),
  [12327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7218),
  [12329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9426),
  [12331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8926),
  [12333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3949),
  [12335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2394),
  [12337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5041),
  [12339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2601),
  [12341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3942),
  [12343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3764),
  [12345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [12347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4346),
  [12349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5097),
  [12351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4509),
  [12353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7113),
  [12355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7467),
  [12357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3779),
  [12359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4986),
  [12361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3742),
  [12363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7340),
  [12365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5463),
  [12367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4350),
  [12369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4504),
  [12371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2655),
  [12373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5106),
  [12375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3784),
  [12377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7086),
  [12379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7106),
  [12381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [12383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3977),
  [12385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [12387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3706),
  [12389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3233),
  [12391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3609),
  [12393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3788),
  [12395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [12397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3274),
  [12399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8777),
  [12401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8048),
  [12403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3340),
  [12405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5032),
  [12407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [12409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3907),
  [12411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4974),
  [12413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [12415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3296),
  [12417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [12419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5103),
  [12421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2473),
  [12423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3912),
  [12425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5120),
  [12427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2239),
  [12429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [12431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [12433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3959),
  [12435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3851),
  [12437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7117),
  [12439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [12441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3098),
  [12443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3375),
  [12445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3801),
  [12447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4309),
  [12449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3871),
  [12451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5046),
  [12453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3102),
  [12455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [12457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2849),
  [12459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [12461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3896),
  [12463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2098),
  [12465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3167),
  [12467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5048),
  [12469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4482),
  [12471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2838),
  [12473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4284),
  [12475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3171),
  [12477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [12479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5023),
  [12481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2847),
  [12483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2833),
  [12485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7088),
  [12487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7817),
  [12489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_declaration_repeat1, 1, 0, 0),
  [12491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_struct_declaration_repeat1, 1, 0, 0),
  [12493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7817),
  [12495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3106),
  [12497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7394),
  [12499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1602),
  [12501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2501),
  [12503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2647),
  [12505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__param_header, 4, 0, 0),
  [12507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [12509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5152),
  [12511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2635),
  [12513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5115),
  [12515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7255),
  [12517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [12519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2372),
  [12521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3100),
  [12523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2215),
  [12525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7336),
  [12527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5096),
  [12529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7260),
  [12531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5081),
  [12533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4643),
  [12535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7266),
  [12537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2256),
  [12539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5149),
  [12541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7248),
  [12543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1695),
  [12545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 0),
  [12547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6621),
  [12549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8211),
  [12551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2270),
  [12553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2272),
  [12555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2607),
  [12557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4286),
  [12559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2612),
  [12561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7228),
  [12563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8504),
  [12565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3662),
  [12567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5145),
  [12569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4463),
  [12571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [12573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2527),
  [12575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3679),
  [12577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4400),
  [12579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3618),
  [12581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5159),
  [12583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3621),
  [12585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3708),
  [12587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3908),
  [12589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4471),
  [12591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4405),
  [12593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2109),
  [12595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7259),
  [12597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8836),
  [12599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [12601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [12603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [12605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [12607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4212),
  [12609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7697),
  [12611] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [12613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [12615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8751),
  [12617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9323),
  [12619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4434),
  [12621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7682),
  [12623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7305),
  [12625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [12627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7306),
  [12629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [12631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3601),
  [12633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7552),
  [12635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_union_declaration_repeat1, 2, 0, 0),
  [12637] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__simple_assignment_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2120),
  [12640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [12642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8736),
  [12644] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_overloaded_procedure_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(2085),
  [12647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1745),
  [12649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3623),
  [12651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_type_repeat1, 2, 0, 0),
  [12653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4119),
  [12655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [12657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8742),
  [12659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2115),
  [12661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3438),
  [12663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7571),
  [12665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3947),
  [12667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8749),
  [12669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1732),
  [12671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1790),
  [12673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_parameters_repeat2, 6, 0, 0),
  [12675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4352),
  [12677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8760),
  [12679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1936),
  [12681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4570),
  [12683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7597),
  [12685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3166),
  [12687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8710),
  [12689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1806),
  [12691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1758),
  [12693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3267),
  [12695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [12697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8903),
  [12699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1901),
  [12701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8669),
  [12703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [12705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [12707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8731),
  [12709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7177),
  [12711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2837),
  [12713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8739),
  [12715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [12717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [12719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [12721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [12723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1807),
  [12725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3712),
  [12727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8752),
  [12729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [12731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_assignment_statement, 6, 0, 0),
  [12733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2624),
  [12735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8925),
  [12737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [12739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2861),
  [12741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8764),
  [12743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [12745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4581),
  [12747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1690),
  [12749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8700),
  [12751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1899),
  [12753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_declaration_repeat1, 2, 0, 0),
  [12755] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(7469),
  [12758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2640),
  [12760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8889),
  [12762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [12764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8768),
  [12766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7057),
  [12768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1728),
  [12770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1777),
  [12772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7245),
  [12774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7247),
  [12776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2188),
  [12778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7219),
  [12780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8747),
  [12782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2121),
  [12784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3181),
  [12786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8730),
  [12788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [12790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1982),
  [12792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [12794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8891),
  [12796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1823),
  [12798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2353),
  [12800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7635),
  [12802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7267),
  [12804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [12806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7625),
  [12808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_identifier, 2, 0, 0),
  [12810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [12812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8762),
  [12814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__struct_members, 2, 0, 0),
  [12816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0),
  [12818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(579),
  [12821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2392),
  [12823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8908),
  [12825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1760),
  [12827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7154),
  [12829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [12831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [12833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1964),
  [12835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4813),
  [12837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7701),
  [12839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_identifier_repeat1, 2, 0, 0),
  [12841] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(9323),
  [12844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2508),
  [12846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [12848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [12850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [12852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3339),
  [12854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8650),
  [12856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [12858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [12860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [12862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7172),
  [12864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8704),
  [12866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1765),
  [12868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2254),
  [12870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8654),
  [12872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [12874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1870),
  [12876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7157),
  [12878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5026),
  [12880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9179),
  [12882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 3, 0, 0),
  [12884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [12886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3995),
  [12888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8910),
  [12890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [12892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_declaration_repeat1, 2, 0, 0),
  [12894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2111),
  [12896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7285),
  [12898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8847),
  [12900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [12902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [12904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [12906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [12908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8644),
  [12910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [12912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_type_repeat1, 2, 0, 0),
  [12914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_parameters_repeat2, 5, 0, 0),
  [12916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3863),
  [12918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8862),
  [12920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [12922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2282),
  [12924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8666),
  [12926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1920),
  [12928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2853),
  [12930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7714),
  [12932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 0),
  [12934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5942),
  [12936] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(9274),
  [12939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4425),
  [12941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7539),
  [12943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [12945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__string_literal_repeat1, 2, 0, 0),
  [12947] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(7682),
  [12950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [12952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8769),
  [12954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [12956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3365),
  [12958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8664),
  [12960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1839),
  [12962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [12964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7182),
  [12966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2325),
  [12968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7696),
  [12970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3900),
  [12972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8701),
  [12974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [12976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [12978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3124),
  [12980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7712),
  [12982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2710),
  [12984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7710),
  [12986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2300),
  [12988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4142),
  [12990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1900),
  [12992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4345),
  [12994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8884),
  [12996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1935),
  [12998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [13000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4852),
  [13002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3870),
  [13004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8830),
  [13006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1966),
  [13008] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_repeat1, 2, 0, 0), SHIFT_REPEAT(6726),
  [13011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_repeat1, 2, 0, 0),
  [13013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__struct_members, 3, 0, 0),
  [13015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [13017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1819),
  [13019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [13021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2723),
  [13023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4140),
  [13025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7554),
  [13027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3024),
  [13029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7328),
  [13031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2873),
  [13033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3617),
  [13035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8915),
  [13037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [13039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4973),
  [13041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9082),
  [13043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [13045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8771),
  [13047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [13049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8810),
  [13051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1911),
  [13053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4312),
  [13055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8827),
  [13057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1928),
  [13059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [13061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3795),
  [13063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8661),
  [13065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [13067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1731),
  [13069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1882),
  [13071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_parameters_repeat2, 4, 0, 0),
  [13073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1822),
  [13075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [13077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7304),
  [13079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3627),
  [13081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8633),
  [13083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [13085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4305),
  [13087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8808),
  [13089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1927),
  [13091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4608),
  [13093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8850),
  [13095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [13097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4662),
  [13099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8779),
  [13101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [13103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [13105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6618),
  [13107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [13109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2658),
  [13111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5283),
  [13113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(975),
  [13116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4435),
  [13118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8562),
  [13120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4917),
  [13122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3974),
  [13124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8786),
  [13126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5288),
  [13128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [13130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [13132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [13134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2759),
  [13136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [13138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5359),
  [13140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7376),
  [13142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [13144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4775),
  [13146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [13148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4776),
  [13150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [13152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4777),
  [13154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(5469),
  [13157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4938),
  [13159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5419),
  [13161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5444),
  [13163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4289),
  [13165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [13167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [13169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4241),
  [13171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8564),
  [13173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2609),
  [13175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8802),
  [13177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3979),
  [13179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2659),
  [13181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [13183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2672),
  [13185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [13187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [13189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8912),
  [13191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [13193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [13195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [13197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3775),
  [13199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8726),
  [13201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2682),
  [13203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2637),
  [13205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8916),
  [13207] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_polymorphic_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2539),
  [13210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2604),
  [13212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5308),
  [13214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [13216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2687),
  [13218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [13220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [13222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4189),
  [13224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2622),
  [13226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8656),
  [13228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [13230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [13232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5549),
  [13234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [13236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2695),
  [13238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_build_tag, 2, 0, 0),
  [13240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [13242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4351),
  [13244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8745),
  [13246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [13248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_declaration, 2, 0, 0),
  [13250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [13252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2646),
  [13254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8718),
  [13256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_repeat2, 2, 0, 0),
  [13258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_repeat2, 2, 0, 0), SHIFT_REPEAT(1435),
  [13261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5099),
  [13263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4853),
  [13265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4357),
  [13267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1391),
  [13269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [13271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4269),
  [13273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4360),
  [13275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8820),
  [13277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7077),
  [13279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4362),
  [13281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7215),
  [13283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7054),
  [13285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8859),
  [13287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4571),
  [13289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7840),
  [13291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5643),
  [13293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [13295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4363),
  [13297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8841),
  [13299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_map_repeat1, 2, 0, 0),
  [13301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_map_repeat1, 2, 0, 0), SHIFT_REPEAT(1483),
  [13304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4365),
  [13306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [13308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7392),
  [13310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4265),
  [13312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8858),
  [13314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4582),
  [13316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4369),
  [13318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8901),
  [13320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [13322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [13324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [13326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [13328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bit_field_declaration_repeat1, 2, 0, 0),
  [13330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_bit_field_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(9194),
  [13333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [13335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5293),
  [13337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2107),
  [13339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [13341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1786),
  [13343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8706),
  [13345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [13347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6641),
  [13349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4402),
  [13351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7110),
  [13353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8817),
  [13355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5375),
  [13357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [13359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4275),
  [13361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [13363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [13365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4752),
  [13367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4904),
  [13369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5637),
  [13371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [13373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5252),
  [13375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [13377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7883),
  [13379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5489),
  [13381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [13383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4676),
  [13385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [13387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4683),
  [13389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [13391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4753),
  [13393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [13395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8622),
  [13397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9312),
  [13399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8620),
  [13401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [13403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7406),
  [13405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6635),
  [13407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [13409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [13411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5696),
  [13413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4601),
  [13415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8848),
  [13417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [13419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4971),
  [13421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [13423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [13425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4671),
  [13427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [13429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2108),
  [13431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [13433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4514),
  [13435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [13437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4529),
  [13439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [13441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [13443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5182),
  [13445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1842),
  [13447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8868),
  [13449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat1, 1, 0, 0),
  [13451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8733),
  [13453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [13455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7121),
  [13457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8877),
  [13459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [13461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5277),
  [13463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4605),
  [13465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8894),
  [13467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [13469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [13471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4609),
  [13473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [13475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4614),
  [13477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [13479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2289),
  [13481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [13483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4646),
  [13485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4647),
  [13487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8920),
  [13489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4651),
  [13491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [13493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4123),
  [13495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [13497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4663),
  [13499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [13501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5198),
  [13503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [13505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4907),
  [13507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [13509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4691),
  [13511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8618),
  [13513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [13515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4507),
  [13517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [13519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [13521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5427),
  [13523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [13525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [13527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4523),
  [13529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8627),
  [13531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [13533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5100),
  [13535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2854),
  [13537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7961),
  [13539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [13541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [13543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5473),
  [13545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [13547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [13549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9313),
  [13551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3665),
  [13553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8746),
  [13555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [13557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2874),
  [13559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [13561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6656),
  [13563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [13565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [13567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4187),
  [13569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1788),
  [13571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [13573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [13575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5175),
  [13577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [13579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [13581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [13583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [13585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9053),
  [13587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5256),
  [13589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8643),
  [13591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4897),
  [13593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5608),
  [13595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [13597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4258),
  [13599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [13601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2912),
  [13603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [13605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2913),
  [13607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [13609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5285),
  [13611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [13613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [13615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4017),
  [13617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4941),
  [13619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5482),
  [13621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [13623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2354),
  [13625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8017),
  [13627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [13629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3180),
  [13631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8729),
  [13633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2339),
  [13635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4980),
  [13637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7069),
  [13639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3184),
  [13641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7211),
  [13643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7071),
  [13645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [13647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2926),
  [13649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [13651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2927),
  [13653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [13655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, 0, 0),
  [13657] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(7214),
  [13660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [13662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [13664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2511),
  [13666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3189),
  [13668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8743),
  [13670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7072),
  [13672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [13674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [13676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2938),
  [13678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2304),
  [13680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [13682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [13684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2944),
  [13686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3197),
  [13688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8755),
  [13690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [13692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3199),
  [13694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [13696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2947),
  [13698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4231),
  [13700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3202),
  [13702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8761),
  [13704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8946),
  [13706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8977),
  [13708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [13710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2110),
  [13712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2823),
  [13714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3794),
  [13716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8660),
  [13718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [13720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [13722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3137),
  [13724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8773),
  [13726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [13728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8809),
  [13730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3125),
  [13732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8053),
  [13734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [13736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_parameters, 5, 0, 0),
  [13738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4214),
  [13740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4000),
  [13742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8844),
  [13744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3027),
  [13746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [13748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6646),
  [13750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5117),
  [13752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [13754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1863),
  [13756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5000),
  [13758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9139),
  [13760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1461),
  [13762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9310),
  [13764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [13766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4814),
  [13768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7818),
  [13770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [13772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2592),
  [13774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3917),
  [13776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [13778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2593),
  [13780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6653),
  [13782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [13784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [13786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8822),
  [13788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9034),
  [13790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [13792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4934),
  [13794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [13796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8828),
  [13798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [13800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5393),
  [13802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9061),
  [13804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [13806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [13808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3081),
  [13810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [13812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3082),
  [13814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [13816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8831),
  [13818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4927),
  [13820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5346),
  [13822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [13824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [13826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4253),
  [13828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3777),
  [13830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [13832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8842),
  [13834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [13836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [13838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2523),
  [13840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [13842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2419),
  [13844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8772),
  [13846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5385),
  [13848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [13850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2594),
  [13852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [13854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [13856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [13858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8631),
  [13860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [13862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4919),
  [13864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5639),
  [13866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [13868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7055),
  [13870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3824),
  [13872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8890),
  [13874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [13876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4768),
  [13878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [13880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4769),
  [13882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5113),
  [13884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7058),
  [13886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [13888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3836),
  [13890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7507),
  [13892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6634),
  [13894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7074),
  [13896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [13898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3116),
  [13900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [13902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3118),
  [13904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [13906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_repeat1, 2, 0, 0), SHIFT_REPEAT(8946),
  [13909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_repeat1, 2, 0, 0),
  [13911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3881),
  [13913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8913),
  [13915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3888),
  [13917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [13919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3136),
  [13921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3672),
  [13923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8638),
  [13925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [13927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4221),
  [13929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8148),
  [13931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [13933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [13935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3148),
  [13937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3901),
  [13939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8917),
  [13941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5273),
  [13943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3904),
  [13945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [13947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3153),
  [13949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2275),
  [13951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8642),
  [13953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [13955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [13957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4011),
  [13959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8923),
  [13961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [13963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3028),
  [13965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [13967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2799),
  [13969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5060),
  [13971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4118),
  [13973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [13975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [13977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3875),
  [13979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8930),
  [13981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5518),
  [13983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [13985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [13987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4474),
  [13989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3324),
  [13991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8162),
  [13993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [13995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [13997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4475),
  [13999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [14001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [14003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2324),
  [14005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3268),
  [14007] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_repeat1, 2, 0, 0), SHIFT_REPEAT(7883),
  [14010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_repeat1, 2, 0, 0),
  [14012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3643),
  [14014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8636),
  [14016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1522),
  [14018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6617),
  [14020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [14022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5315),
  [14024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1916),
  [14026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [14028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2335),
  [14030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [14032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2336),
  [14034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [14036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [14038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4517),
  [14040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_declaration_repeat2, 2, 0, 0),
  [14042] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(7724),
  [14045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [14047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4518),
  [14049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [14051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4519),
  [14053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4908),
  [14055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7045),
  [14057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5486),
  [14059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [14061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3660),
  [14063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4901),
  [14065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5619),
  [14067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1361),
  [14069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(6680),
  [14072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0),
  [14074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [14076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3346),
  [14078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [14080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3348),
  [14082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6633),
  [14084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3337),
  [14086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [14088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2393),
  [14090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8674),
  [14092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [14094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2033),
  [14096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [14098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3364),
  [14100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8663),
  [14102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5118),
  [14104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2452),
  [14106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_parameters, 7, 0, 0),
  [14108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3373),
  [14110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2281),
  [14112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8662),
  [14114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [14116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [14118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4944),
  [14120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5069),
  [14122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [14124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2464),
  [14126] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_call_expression_repeat1, 2, 0, 16), SHIFT_REPEAT(497),
  [14129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_call_expression_repeat1, 2, 0, 16),
  [14131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [14133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3381),
  [14135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [14137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3384),
  [14139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5496),
  [14141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [14143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2288),
  [14145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5525),
  [14147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2076),
  [14149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3397),
  [14151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8671),
  [14153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3400),
  [14155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [14157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4080),
  [14159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [14161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3403),
  [14163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [14165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4108),
  [14167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2322),
  [14169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8678),
  [14171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3736),
  [14173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8807),
  [14175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [14177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [14179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3645),
  [14181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2331),
  [14183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3411),
  [14185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3412),
  [14187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8675),
  [14189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2491),
  [14191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3416),
  [14193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [14195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3423),
  [14197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [14199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [14201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8687),
  [14203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2375),
  [14205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8682),
  [14207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2509),
  [14209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3431),
  [14211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8680),
  [14213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8314),
  [14215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [14217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5560),
  [14219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [14221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2520),
  [14223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3435),
  [14225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2377),
  [14227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6654),
  [14229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [14231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [14233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3212),
  [14235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8686),
  [14237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2391),
  [14239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8692),
  [14241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7180),
  [14243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7073),
  [14245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [14247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3602),
  [14249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8278),
  [14251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2219),
  [14253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8695),
  [14255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [14257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7234),
  [14259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7063),
  [14261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [14263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [14265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9441),
  [14267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9467),
  [14269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9484),
  [14271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2231),
  [14273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9493),
  [14275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [14277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [14279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3711),
  [14281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2408),
  [14283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8698),
  [14285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3752),
  [14287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__struct_members, 1, 0, 0),
  [14289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7621),
  [14291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3916),
  [14293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8748),
  [14295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [14297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4743),
  [14299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9168),
  [14301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [14303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [14305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9259),
  [14307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9570),
  [14309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9014),
  [14311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5135),
  [14313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9230),
  [14315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1950),
  [14317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [14319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8898),
  [14321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [14323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [14325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8815),
  [14327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5401),
  [14329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [14331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4426),
  [14333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7755),
  [14335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2247),
  [14337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8617),
  [14339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9118),
  [14341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9275),
  [14343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9583),
  [14345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9598),
  [14347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3950),
  [14349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5440),
  [14351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [14353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4992),
  [14355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [14357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [14359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4103),
  [14361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [14363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4139),
  [14365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_parameters, 8, 0, 0),
  [14367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9326),
  [14369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [14371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9338),
  [14373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9415),
  [14375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9474),
  [14377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5191),
  [14379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [14381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5485),
  [14383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4924),
  [14385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5409),
  [14387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [14389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4699),
  [14391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9498),
  [14393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [14395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4700),
  [14397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8963),
  [14399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9114),
  [14401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9124),
  [14403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [14405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [14407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4730),
  [14409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [14411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3692),
  [14413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [14415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3694),
  [14417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [14419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [14421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8941),
  [14423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6644),
  [14425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3697),
  [14427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8953),
  [14429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8993),
  [14431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8999),
  [14433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [14435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [14437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2313),
  [14439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [14441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [14443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9150),
  [14445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9181),
  [14447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9207),
  [14449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9225),
  [14451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [14453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4489),
  [14455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [14457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2858),
  [14459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8763),
  [14461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3810),
  [14463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8619),
  [14465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5029),
  [14467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4922),
  [14469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9340),
  [14471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9357),
  [14473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9386),
  [14475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9390),
  [14477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2877),
  [14479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5269),
  [14481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [14483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [14485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4490),
  [14487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [14489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3530),
  [14491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [14493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3531),
  [14495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3965),
  [14497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8788),
  [14499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9596),
  [14501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2712),
  [14503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8417),
  [14505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9608),
  [14507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9293),
  [14509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9477),
  [14511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [14513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [14515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [14517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3807),
  [14519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [14521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [14523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4026),
  [14525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9243),
  [14527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9285),
  [14529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9352),
  [14531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9365),
  [14533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2806),
  [14535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8778),
  [14537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6620),
  [14539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1888),
  [14541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [14543] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_case_repeat1, 2, 0, 58), SHIFT_REPEAT(804),
  [14546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_case_repeat1, 2, 0, 58),
  [14548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [14550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3544),
  [14552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5698),
  [14554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9049),
  [14556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8975),
  [14558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9057),
  [14560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9087),
  [14562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9104),
  [14564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [14566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1903),
  [14568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3551),
  [14570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2811),
  [14572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8782),
  [14574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9236),
  [14576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2813),
  [14578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1912),
  [14580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [14582] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_where_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1518),
  [14585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [14587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3554),
  [14589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9355),
  [14591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [14593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [14595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2724),
  [14597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9478),
  [14599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2815),
  [14601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8787),
  [14603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1929),
  [14605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4157),
  [14607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [14609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9607),
  [14611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3560),
  [14613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [14615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3876),
  [14617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8799),
  [14619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3885),
  [14621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1384),
  [14623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [14625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2824),
  [14627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8793),
  [14629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [14631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4020),
  [14633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7409),
  [14635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(876),
  [14637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8443),
  [14639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [14641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [14643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4788),
  [14645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [14647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3781),
  [14649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8897),
  [14651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(858),
  [14653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [14655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3940),
  [14657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8813),
  [14659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7706),
  [14661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [14663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [14665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [14667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [14669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5200),
  [14671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2101),
  [14673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [14675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8922),
  [14677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4311),
  [14679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8826),
  [14681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5451),
  [14683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [14685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5167),
  [14687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4218),
  [14689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [14691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3714),
  [14693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [14695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [14697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5022),
  [14699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat1, 2, 0, 0),
  [14701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_type_repeat1, 2, 0, 0), SHIFT_REPEAT(7910),
  [14704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [14706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5490),
  [14708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [14710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [14712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4791),
  [14714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [14716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3820),
  [14718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8823),
  [14720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4315),
  [14722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5208),
  [14724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5212),
  [14726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4933),
  [14728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5334),
  [14730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1473),
  [14732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5216),
  [14734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [14736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [14738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [14740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [14742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4320),
  [14744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8851),
  [14746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [14748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6637),
  [14750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3058),
  [14752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3994),
  [14754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8904),
  [14756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4322),
  [14758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6657),
  [14760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2458),
  [14762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [14764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5124),
  [14766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7284),
  [14768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8846),
  [14770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5456),
  [14772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5105),
  [14774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5220),
  [14776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7290),
  [14778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2157),
  [14780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_polymorphic_parameters, 6, 0, 0),
  [14782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [14784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [14786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [14788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [14790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5301),
  [14792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4324),
  [14794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8860),
  [14796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_polymorphic_parameters_repeat2, 2, 0, 0), SHIFT_REPEAT(8777),
  [14799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_parameters_repeat2, 2, 0, 0),
  [14801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [14803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3986),
  [14805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8775),
  [14807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5576),
  [14809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7300),
  [14811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8857),
  [14813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7303),
  [14815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7439),
  [14817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [14819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [14821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5582),
  [14823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_member_repeat1, 2, 0, 0), SHIFT_REPEAT(8772),
  [14826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_member_repeat1, 2, 0, 0),
  [14828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5244),
  [14830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [14832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [14834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7307),
  [14836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8863),
  [14838] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4964),
  [14841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5587),
  [14843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7309),
  [14845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4326),
  [14847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [14849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [14851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5593),
  [14853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7315),
  [14855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8867),
  [14857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4329),
  [14859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8869),
  [14861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [14863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [14865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5599),
  [14867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [14869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [14871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4942),
  [14873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [14875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7324),
  [14877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8873),
  [14879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5377),
  [14881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2425),
  [14883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8550),
  [14885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [14887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__struct_members_repeat1, 2, 0, 0),
  [14889] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__struct_members_repeat1, 2, 0, 0), SHIFT_REPEAT(8043),
  [14892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7405),
  [14894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4334),
  [14896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8885),
  [14898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2309),
  [14900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [14902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5225),
  [14904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [14906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [14908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5461),
  [14910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [14912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2676),
  [14914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [14916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2683),
  [14918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [14920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__raw_string_literal_repeat1, 2, 0, 0),
  [14922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__raw_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(8562),
  [14925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4147),
  [14927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [14929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5368),
  [14931] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_polymorphic_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(8815),
  [14934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_parameters_repeat1, 2, 0, 0),
  [14936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3761),
  [14938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8655),
  [14940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4950),
  [14942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5467),
  [14944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6638),
  [14946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [14948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2526),
  [14950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [14952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2528),
  [14954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [14956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [14958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [14960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [14962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8737),
  [14964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [14966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [14968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [14970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [14972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9537),
  [14974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9540),
  [14976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3626),
  [14978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8732),
  [14980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9543),
  [14982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9546),
  [14984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9549),
  [14986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5031),
  [14988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9552),
  [14990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9555),
  [14992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9556),
  [14994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9557),
  [14996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9558),
  [14998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9559),
  [15000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9560),
  [15002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9561),
  [15004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9562),
  [15006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9563),
  [15008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9564),
  [15010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3631),
  [15012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2638),
  [15014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8865),
  [15016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3799),
  [15018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5337),
  [15020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [15022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2257),
  [15024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [15026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2258),
  [15028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2117),
  [15030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5130),
  [15032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [15034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4499),
  [15036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4797),
  [15038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9177),
  [15040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2252),
  [15042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7662),
  [15044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4512),
  [15046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3821),
  [15048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8895),
  [15050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9460),
  [15052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9403),
  [15054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9403),
  [15056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4536),
  [15058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8914),
  [15060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [15062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3673),
  [15064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9569),
  [15066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7230),
  [15068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8964),
  [15070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8964),
  [15072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8968),
  [15074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8968),
  [15076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3768),
  [15078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2628),
  [15080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 3, 0, 0),
  [15082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9443),
  [15084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9443),
  [15086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3430),
  [15088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5125),
  [15090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9217),
  [15092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_repeat1, 4, 0, 0),
  [15094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3437),
  [15096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2387),
  [15098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3216),
  [15100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2217),
  [15102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8272),
  [15104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9419),
  [15106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2402),
  [15108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9117),
  [15110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9117),
  [15112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2233),
  [15114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2409),
  [15116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8703),
  [15118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8288),
  [15120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9077),
  [15122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [15124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8303),
  [15126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8954),
  [15128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_member, 7, 0, 0),
  [15130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2648),
  [15132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8317),
  [15134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9254),
  [15136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6619),
  [15138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9258),
  [15140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8329),
  [15142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9252),
  [15144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3776),
  [15146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8341),
  [15148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9503),
  [15150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7653),
  [15152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8351),
  [15154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9113),
  [15156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8362),
  [15158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9320),
  [15160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3666),
  [15162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8374),
  [15164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9575),
  [15166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9361),
  [15168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9361),
  [15170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3201),
  [15172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8965),
  [15174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8965),
  [15176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8296),
  [15178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9385),
  [15180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3154),
  [15182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8386),
  [15184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9151),
  [15186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_member_repeat1, 3, 0, 0),
  [15188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8721),
  [15190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8398),
  [15192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9021),
  [15194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8838),
  [15196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9284),
  [15198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3141),
  [15200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_polymorphic_parameters_repeat1, 3, 0, 0),
  [15202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3861),
  [15204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8508),
  [15206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9297),
  [15208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8064),
  [15210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9604),
  [15212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2814),
  [15214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [15216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8725),
  [15218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7608),
  [15220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7100),
  [15222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2825),
  [15224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3937),
  [15226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4004),
  [15228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8893),
  [15230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9436),
  [15232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7120),
  [15234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9331),
  [15236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9331),
  [15238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3835),
  [15240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [15242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [15244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9131),
  [15246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9131),
  [15248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4366),
  [15250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [15252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 8, 0, 0),
  [15254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3910),
  [15256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [15258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8714),
  [15260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4367),
  [15262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7686),
  [15264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4328),
  [15266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7314),
  [15268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9489),
  [15270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9489),
  [15272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7320),
  [15274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1858),
  [15276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4331),
  [15278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [15280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8690),
  [15282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7325),
  [15284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7124),
  [15286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9600),
  [15288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9600),
  [15290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4335),
  [15292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9191),
  [15294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9191),
  [15296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_repeat1, 3, 0, 0),
  [15298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3729),
  [15300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4370),
  [15302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7607),
  [15304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [15306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8397),
  [15308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9249),
  [15310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2620),
  [15312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4010),
  [15314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4690),
  [15316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9054),
  [15318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7083),
  [15320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3988),
  [15322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7878),
  [15324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8957),
  [15326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9319),
  [15328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9319),
  [15330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3815),
  [15332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4239),
  [15334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5338),
  [15336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5327),
  [15338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [15340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [15342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [15344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7611),
  [15346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [15348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8722),
  [15350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [15352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [15354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5555),
  [15356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3722),
  [15358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8153),
  [15360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [15362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5347),
  [15364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5339),
  [15366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [15368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2513),
  [15370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3269),
  [15372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4436),
  [15374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [15376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [15378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5336),
  [15380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [15382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [15384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5362),
  [15386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5348),
  [15388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [15390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [15392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [15394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [15396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7599),
  [15398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5344),
  [15400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [15402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5373),
  [15404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5363),
  [15406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [15408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [15410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [15412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [15414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [15416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5360),
  [15418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7569),
  [15420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3002),
  [15422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5387),
  [15424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5374),
  [15426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [15428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [15430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3791),
  [15432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [15434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [15436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3693),
  [15438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [15440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [15442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [15444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5371),
  [15446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [15448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5402),
  [15450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5388),
  [15452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [15454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7572),
  [15456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [15458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9281),
  [15460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5494),
  [15462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7719),
  [15464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [15466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [15468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5384),
  [15470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [15472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5411),
  [15474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5403),
  [15476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [15478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [15480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [15482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [15484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [15486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7704),
  [15488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5173),
  [15490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5399),
  [15492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7644),
  [15494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5420),
  [15496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5412),
  [15498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [15500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [15502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5569),
  [15504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [15506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5428),
  [15508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5421),
  [15510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [15512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5178),
  [15514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5179),
  [15516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [15518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [15520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [15522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5408),
  [15524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5435),
  [15526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5429),
  [15528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [15530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [15532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [15534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3207),
  [15536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7601),
  [15538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5441),
  [15540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5436),
  [15542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [15544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [15546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [15548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1452),
  [15550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [15552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5571),
  [15554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4427),
  [15556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2725),
  [15558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5442),
  [15560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3562),
  [15562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5449),
  [15564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7558),
  [15566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5450),
  [15568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [15570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5452),
  [15572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5455),
  [15574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7685),
  [15576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5457),
  [15578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [15580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5459),
  [15582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5460),
  [15584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5464),
  [15586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3390),
  [15588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5465),
  [15590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5466),
  [15592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5471),
  [15594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [15596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [15598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5523),
  [15600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [15602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5476),
  [15604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [15606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7683),
  [15608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7594),
  [15610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5350),
  [15612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1465),
  [15614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [15616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [15618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [15620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3719),
  [15622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1463),
  [15624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [15626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [15628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7747),
  [15630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [15632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [15634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5160),
  [15636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2595),
  [15638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5098),
  [15640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_calling_convention, 1, 0, 0),
  [15642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7065),
  [15644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1802),
  [15646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1370),
  [15648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4406),
  [15650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [15652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7808),
  [15654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7725),
  [15656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5197),
  [15658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [15660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7738),
  [15662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5268),
  [15664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2379),
  [15666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2619),
  [15668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5236),
  [15670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [15672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7750),
  [15674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7667),
  [15676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [15678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5270),
  [15680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5271),
  [15682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [15684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [15686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [15688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [15690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3104),
  [15692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5176),
  [15694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [15696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8765),
  [15698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [15700] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [15702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [15704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [15706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8307),
  [15708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7581),
  [15710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5646),
  [15712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5573),
  [15714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3727),
  [15716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [15718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [15720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [15722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8895),
  [15724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7660),
  [15726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [15728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5579),
  [15730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7654),
  [15732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2875),
  [15734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [15736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8414),
  [15738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [15740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7744),
  [15742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5585),
  [15744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [15746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3625),
  [15748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4404),
  [15750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [15752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [15754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5297),
  [15756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [15758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7595),
  [15760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5590),
  [15762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [15764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5298),
  [15766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [15768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5299),
  [15770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [15772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [15774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5596),
  [15776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7672),
  [15778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [15780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4583),
  [15782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2118),
  [15784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [15786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5602),
  [15788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [15790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7623),
  [15792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [15794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5607),
  [15796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [15798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [15800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8460),
  [15802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [15804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5611),
  [15806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [15808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [15810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [15812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [15814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5136),
  [15816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [15818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5614),
  [15820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2310),
  [15822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7743),
  [15824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [15826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7590),
  [15828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5314),
  [15830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5617),
  [15832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [15834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7509),
  [15836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [15838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [15840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [15842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5621),
  [15844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5316),
  [15846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7878),
  [15848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3461),
  [15850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [15852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5317),
  [15854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [15856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [15858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5623),
  [15860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [15862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7812),
  [15864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8774),
  [15866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5624),
  [15868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [15870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8395),
  [15872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7729),
  [15874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [15876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4075),
  [15878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [15880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [15882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [15884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [15886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [15888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [15890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [15892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [15894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [15896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [15898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [15900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [15902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [15904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [15906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8679),
  [15908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [15910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [15912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [15914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [15916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [15918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7671),
  [15920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [15922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5636),
  [15924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5345),
  [15926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1390),
  [15928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7726),
  [15930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2164),
  [15932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [15934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5649),
  [15936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [15938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [15940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1256),
  [15942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5651),
  [15944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4854),
  [15946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2169),
  [15948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [15950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5655),
  [15952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [15954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2172),
  [15956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [15958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5659),
  [15960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7609),
  [15962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [15964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2175),
  [15966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [15968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5661),
  [15970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [15972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2177),
  [15974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [15976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5663),
  [15978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2179),
  [15980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [15982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5665),
  [15984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2181),
  [15986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [15988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5668),
  [15990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2184),
  [15992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [15994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5673),
  [15996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2186),
  [15998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [16000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5678),
  [16002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [16004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [16006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5681),
  [16008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [16010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5683),
  [16012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [16014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5684),
  [16016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5685),
  [16018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5686),
  [16020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5687),
  [16022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5566),
  [16024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [16026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [16028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [16030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2197),
  [16032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9475),
  [16034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5688),
  [16036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9482),
  [16038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5689),
  [16040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3573),
  [16042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9487),
  [16044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5690),
  [16046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9492),
  [16048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5691),
  [16050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5326),
  [16052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9497),
  [16054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5692),
  [16056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7531),
  [16058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9502),
  [16060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5693),
  [16062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9507),
  [16064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9510),
  [16066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9513),
  [16068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9516),
  [16070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9519),
  [16072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9522),
  [16074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9524),
  [16076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9526),
  [16078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9527),
  [16080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9528),
  [16082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5565),
  [16084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [16086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [16088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7691),
  [16090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5364),
  [16092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [16094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5484),
  [16096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [16098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [16100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7699),
  [16102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [16104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1388),
  [16106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3042),
  [16108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [16110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2206),
  [16112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2207),
  [16114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2208),
  [16116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2209),
  [16118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7663),
  [16120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2210),
  [16122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [16124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [16126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4120),
  [16128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [16130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [16132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [16134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4115),
  [16136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7564),
  [16138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5323),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__newline = 0,
  ts_external_token__backslash = 1,
  ts_external_token__nl_comma = 2,
  ts_external_token_float = 3,
  ts_external_token_block_comment = 4,
  ts_external_token_LBRACE = 5,
  ts_external_token_DQUOTE = 6,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__newline] = sym__newline,
  [ts_external_token__backslash] = sym__backslash,
  [ts_external_token__nl_comma] = sym__nl_comma,
  [ts_external_token_float] = sym_float,
  [ts_external_token_block_comment] = sym_block_comment,
  [ts_external_token_LBRACE] = anon_sym_LBRACE,
  [ts_external_token_DQUOTE] = anon_sym_DQUOTE,
};

static const bool ts_external_scanner_states[12][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__newline] = true,
    [ts_external_token__backslash] = true,
    [ts_external_token__nl_comma] = true,
    [ts_external_token_float] = true,
    [ts_external_token_block_comment] = true,
    [ts_external_token_LBRACE] = true,
    [ts_external_token_DQUOTE] = true,
  },
  [2] = {
    [ts_external_token__backslash] = true,
    [ts_external_token_float] = true,
    [ts_external_token_block_comment] = true,
    [ts_external_token_LBRACE] = true,
    [ts_external_token_DQUOTE] = true,
  },
  [3] = {
    [ts_external_token__newline] = true,
    [ts_external_token__backslash] = true,
    [ts_external_token_float] = true,
    [ts_external_token_block_comment] = true,
    [ts_external_token_LBRACE] = true,
    [ts_external_token_DQUOTE] = true,
  },
  [4] = {
    [ts_external_token__newline] = true,
    [ts_external_token__backslash] = true,
    [ts_external_token_block_comment] = true,
    [ts_external_token_LBRACE] = true,
  },
  [5] = {
    [ts_external_token__newline] = true,
    [ts_external_token__backslash] = true,
    [ts_external_token_block_comment] = true,
  },
  [6] = {
    [ts_external_token__backslash] = true,
    [ts_external_token_block_comment] = true,
    [ts_external_token_LBRACE] = true,
  },
  [7] = {
    [ts_external_token__backslash] = true,
    [ts_external_token_block_comment] = true,
  },
  [8] = {
    [ts_external_token__newline] = true,
    [ts_external_token__backslash] = true,
    [ts_external_token__nl_comma] = true,
    [ts_external_token_block_comment] = true,
    [ts_external_token_LBRACE] = true,
  },
  [9] = {
    [ts_external_token__backslash] = true,
    [ts_external_token_block_comment] = true,
    [ts_external_token_LBRACE] = true,
    [ts_external_token_DQUOTE] = true,
  },
  [10] = {
    [ts_external_token__newline] = true,
    [ts_external_token__backslash] = true,
    [ts_external_token__nl_comma] = true,
    [ts_external_token_block_comment] = true,
  },
  [11] = {
    [ts_external_token__backslash] = true,
    [ts_external_token_block_comment] = true,
    [ts_external_token_DQUOTE] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_odin_external_scanner_create(void);
void tree_sitter_odin_external_scanner_destroy(void *);
bool tree_sitter_odin_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_odin_external_scanner_serialize(void *, char *);
void tree_sitter_odin_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_odin(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_odin_external_scanner_create,
      tree_sitter_odin_external_scanner_destroy,
      tree_sitter_odin_external_scanner_scan,
      tree_sitter_odin_external_scanner_serialize,
      tree_sitter_odin_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
